<?php
/**
 * WHMCS Language File
 * Persian (fa)
 *
 * Please Note: These language files are overwritten during software updates
 * and therefore editing of these files directly is not advised. Instead we
 * recommend that you use overrides to customise the text displayed in a way
 * which will be safely preserved through the upgrade process.
 *
 * For instructions on overrides, please visit:
 *   https://developers.whmcs.com/languages/overrides/
 *
 * @package    WHMCS
 * @author     WHMCS Limited <development@whmcs.com>
 * @copyright  Copyright (c) WHMCS Limited 2005-2018
 * @license    https://www.whmcs.com/license/ WHMCS Eula
 * @version    $Id$
 * @link       https://www.whmcs.com/
 */

if (!defined("WHMCS")) die("This file cannot be accessed directly");

$_LANG['locale'] = "fa_IR";

$_LANG['accountinfo'] = "مشخصات حساب";
$_LANG['accountstats'] = "آمار حساب";
$_LANG['addfunds'] = "واریز";
$_LANG['addfundsamount'] = "مبلغ واریزی";
$_LANG['addfundsmaximum'] = "حداکثر واریز";
$_LANG['addfundsmaximumbalance'] = "حداکثر موجودی";
$_LANG['addfundsmaximumbalanceerror'] = " حداکثر مقدار موجودی :";
$_LANG['addfundsmaximumerror'] = "حداکثر مقدار سپرده : ";
$_LANG['addfundsminimum'] = "حداقل سپرده";
$_LANG['addfundsminimumerror'] = "حداقل مقدار سپرده : ";
$_LANG['addmore'] = "افزودن موارد دیگر";
$_LANG['addtocart'] = "افزودن به کارت";
$_LANG['affiliatesactivate'] = "فعال سازی حساب رابط";
$_LANG['affiliatesamount'] = "مقدار";
$_LANG['affiliatesbalance'] = "باقی مانده حساب";
$_LANG['affiliatesbullet1'] = "دریافت سود سپرده آغازین در حساب وابسته شما ";
$_LANG['affiliatesbullet2'] = "هر پرداخت مشتری که شما برای ما فرستاده اید حساب هاستینگ کل دوره آنها را ایجاد میکند.";
$_LANG['affiliatescommission'] = "کمیسیون";
$_LANG['affiliatesdescription'] = "برای رابط شدن یا مشاهده درآمد خود اینجا را کلیک کنید.";
$_LANG['affiliatesdisabled'] = "ما در حال حاضر سیستم رابط را برای مشتریهایمان توصیه نمیکنیم.";
$_LANG['affiliatesearn'] = "درآمد";
$_LANG['affiliatesearningstodate'] = "کل درآمد به تاریخ";
$_LANG['affiliatesfootertext'] = "وقتی شما کسی را با شناسه مربوطه خودتان به وب سایت ما بفرستید ، کوکی آن شناسه روی کامپیوتر او جای میگیرد درنتیجه اگر سایت را انتخاب کند و بعدا دوباره به آن مراجعه کند شما باز هم کمیسیون خود را دریافت خواهید کرد.";
$_LANG['affiliateshostingpackage'] = " پکیج هاستینگ";
$_LANG['affiliatesintrotext'] = "فعال کردن حساب وابسته خود امروز جهت:";
$_LANG['affiliateslinktous'] = "لینک دادن به ما";
$_LANG['affiliatesnosignups'] = "شما در حال حاضر هیچ ورودی دریافت نکرده اید";
$_LANG['affiliatesrealtime'] = " آمار لحظه ای است و سریعا بروز میشود";
$_LANG['affiliatesreferallink'] = "لینک انتصابی منحصر بفرد شما";
$_LANG['affiliatesreferals'] = "مراجعات شما";
$_LANG['affiliatesregdate'] = "تاریخ ثبت نام";
$_LANG['affiliatesrequestwithdrawal'] = "درخواست دریافت وجه";
$_LANG['affiliatessignupdate'] = "تاریخ ورود";
$_LANG['affiliatesstatus'] = "وضعیت";
$_LANG['affiliatestitle'] = "بازاریابی";
$_LANG['affiliatesvisitorsreferred'] = "تعداد بازدیدکنندگان ارسالی ";
$_LANG['affiliateswithdrawalrequestsuccessful'] = "درخواست دریافت وجه شما ارسال شد.به زودی تماس حاصل میشود.";
$_LANG['affiliatesWithdrawalRequestUnsuccessful'] = "Your request for a withdrawal was not successful. Please try again later.";
$_LANG['affiliateswithdrawn'] = "کل مقادیر دریافت شده";
$_LANG['all'] = "همه";
$_LANG['alreadyregistered'] = "قبلا ثبت نام کرده اید ؟";
$_LANG['announcementsdescription'] = "مشاهده آخرین اخبار و اطلاعیه ها";
$_LANG['announcementsnone'] = "اخباری برای نمایش موجود نیست";
$_LANG['announcementsrss'] = "مشاهده RSS ";
$_LANG['announcementstitle'] = "اخبار";
$_LANG['announcementscontinue'] = "ادامه مطلب";
$_LANG['bannedbanexpires'] = "انقضای ممنوعیت";
$_LANG['bannedbanreason'] = "دلیل ممنوعیت";
$_LANG['bannedhasbeenbanned'] = "ممنوع شد";
$_LANG['bannedtitle'] = "ممنوعیت ip";
$_LANG['bannedyourip'] = " Ip شما";
$_LANG['cartaddons'] = "افزودنی ها";
$_LANG['cartbrowse'] = "یافتن محصولات و سرویس ها";
$_LANG['cartconfigdomainextras'] = " تعریف اضافات دامنه";
$_LANG['cartconfigoptionsdesc'] = "این سرویس/محصول که انتخاب نموده اید دارای امکانات اضافه ای است که میتوانید برای سفارش خود انتخاب نمایید";
$_LANG['cartconfigserver'] = "پیکره بندی سرور";
$_LANG['cartcustomfieldsdesc'] = "این سرویس/محصول نیاز به بعضی اطلاعات اضافی از شما دارد تا ما بتوانیم پروسه ی سفارش شما را تکمیل نماییم";
$_LANG['cartdomainsconfig'] = "پیکره بندی دامنه ها";
$_LANG['cartdomainsconfigdesc'] = "در زیر شما میتوانید نام های دامنه را در کارت خرید خود قرار دهید،اطلاعات لازم و نام های سرور را برای آن مشخص کنید";
$_LANG['cartdomainshashosting'] = "دارای فضا است";
$_LANG['cartdomainsnohosting'] = "هاستینگ ندارید! برای افزودن کلیک کنید";
$_LANG['carteditproductconfig'] = "ویرایش پیکره بندی ";
$_LANG['cartempty'] = "کارت خرید شما خالی است";
$_LANG['cartemptyconfirm'] = "آیا شما از اینکه می خواهید کارت خرید خود را خالی کنید اطمینان دارید؟";
$_LANG['cartexistingclientlogin'] = "ورود کاربر موجود";
$_LANG['cartexistingclientlogindesc'] = "جهت افزودن این سفارش به حساب خود ،شما باید در زیر وارد شوید";
$_LANG['cartnameserversdesc'] = "اگر مایل به استفاده از NameServer های سرویس دیگری هستید آنها را در اینجا وارد کنید. به صورت پیش فرض روی دامنه های جدید ،NameServer های ما تنظیم میشود.";
$_LANG['cartproductaddons'] = " افزونه های محصولات ";
$_LANG['cartproductaddonschoosepackage'] = "انتخاب پکیج";
$_LANG['cartproductaddonsnone'] = "افزودنی مورد نظر برای محصول شما موجود نمی باشد.";
$_LANG['cartproductconfig'] = "شکل محصول";
$_LANG['cartproductdesc'] = "این سرویس/محصولی که انتخاب کرده اید دارای امکانات ساختاری زیر است";
$_LANG['cartproductdomain'] = "دامنه ها";
$_LANG['cartproductdomainchoose'] = "انتخاب دامنه";
$_LANG['cartproductdomaindesc'] = "محصول/سرویسی که انتخاب نموده اید نیاز به نام دامنه دارد پس لطفا نام دامنه انتخابی خود را در زیر وارد کنید";
$_LANG['cartproductdomainuseincart'] = "از دامنه که هم اکنون در کارت خرید است استفاده شود";
$_LANG['cartremove'] = "پاک کردن";
$_LANG['cartremoveitemconfirm'] = "آیا شما از اینک می خواهید این آیتم را از کارت خرید خود حذف کنید اطمینان دارید؟";
$_LANG['carttaxupdateselections'] = "ممکن است با توجه به شهر یا کشور انتخابی شما مالیات در نظر گرفته شود .جهت حساب شدن مجدد پس از انتخاب هایتان کلیک کنید";
$_LANG['carttaxupdateselectionsupdate'] = "بروزرسانی";
$_LANG['carttitle'] = "کارت خرید";
$_LANG['changessavedsuccessfully'] = "تغییرات با موفقیت اعمال شدند!";
$_LANG['checkavailability'] = " بررسی قابلیت ثبت ";
$_LANG['checkout'] = "تکمیل سفارش";
$_LANG['choosecurrency'] = "واحد پول";
$_LANG['choosedomains'] = " دامنه انتخاب کنید";
$_LANG['clickheretologin'] = "جهت ورود کلیک کنید";
$_LANG['clientareaaccountaddons'] = "حساب افزودنی ها";
$_LANG['clientareaactive'] = "فعال";
$_LANG['clientareaaddfundsdisabled'] = "در حال حاضر امکان افزودن وجه به حسابتان امکان پذیر نمیباشد.";
$_LANG['clientareaaddfundsnotallowed'] = "شما باید برای افزودن وجه به حسابتان حداقل یک سفارش فعال شده داشته باشید در غیر این صورت انجام این عملیات امکان پذیر نمی باشد!";
$_LANG['clientareaaddon'] = " افزودنی ها";
$_LANG['clientareaaddonorderconfirmation'] = "متشکریم. سفارش شما برای افزودنی های موجود ثبت شد. لطفا طریقه پرداخت را از لیست زیر انتخاب کنید.";
$_LANG['clientareaaddonpricing'] = "قیمت";
$_LANG['clientareaaddonsfor'] = " افزودنی ها برای ";
$_LANG['clientareaaddress1'] = "آدرس 1";
$_LANG['clientareaaddress2'] = "آدرس 2 ";
$_LANG['clientareabwlimit'] = "محدودیت پهنای باند";
$_LANG['clientareabwusage'] = "پهنای باند مصرفی";
$_LANG['clientareacancel'] = "لغو تغییرات";
$_LANG['clientareacancelconfirmation'] = "متشکریم. درخواست شما برای لغو ارسال شد. اگر با خطایی مواجه شدید ، درخواست پشتیبانی را ارسال کنید و سریعا ما را مطلع سازید.البته این امکان وجود دارد که آن حساب منقضی شده باشد.";
$_LANG['clientareacancelinvalid'] = "خطا! حسابی که میخواهید لغو کنید ممکن است هم اکنون برای لغو شدن معلق باشد و یا این آیتم یافت نشده باشد.";
$_LANG['clientareacancellationendofbillingperiod'] = " اتمام دوره صورتحساب";
$_LANG['clientareacancellationimmediate'] = "سریع";
$_LANG['clientareacancellationtype'] = "نوع لغو";
$_LANG['clientareacancelled'] = "لغو شده";
$_LANG['clientareacancelproduct'] = "درخواست لغو برای";
$_LANG['clientareacancelreason'] = "علت لغو کردن خود را مختصرا توضیح دهید";
$_LANG['clientareacancelrequest'] = "درخواست لغو کردن حساب";
$_LANG['clientareacancelrequestbutton'] = "درخواست لغو";
$_LANG['clientareachangepassword'] = "تغییر کلمه عبور";
$_LANG['clientareachangesuccessful'] = "مشخصات شما با موفقیت تغییر داده شد.";
$_LANG['clientareachoosecontact'] = "انتخاب تماس";
$_LANG['clientareacity'] = "شهر";
$_LANG['clientareacompanyname'] = "نام شرکت";
$_LANG['clientareaconfirmpassword'] = "تایید کلمه عبور";
$_LANG['clientareacontactsemails'] = "انواع ایمیل";
$_LANG['clientareacontactsemailsdomain'] = "ایمیل های دامنه - اطلاعات بروز شده، تائیدات ثبت نام ها و غیره...";
$_LANG['clientareacontactsemailsgeneral'] = "ایمیل های کلی- اعلانات کلی و یاد آوری های کلمه عبور ";
$_LANG['clientareacontactsemailsinvoice'] = "ایمیل های صورتحساب - یاد آوریهای صورتحساب ها";
$_LANG['clientareacontactsemailsproduct'] = "ایمیل های محصول-جزئیات سفارش ،ایمیل خوش آمدگویی و غیره...";
$_LANG['clientareacontactsemailssupport'] = "ایمیل های پشتیبانی - یک نسخه از تمام ارتباطات پشتیبانی  ایجاد شده توسط دارنده حساب اصلی دریافت کنید";
$_LANG['clientareacountry'] = "کشور";
$_LANG['clientareacurrentsecurityanswer'] = "لطفا پاسخ خود را وارد کنید";
$_LANG['clientareacurrentsecurityquestion'] = "لطفا یک سوال امنیتی انتخاب کنید";
$_LANG['clientareadeletecontact'] = "حذف تماس";
$_LANG['clientareadeletecontactareyousure'] = "آیا مایل به حذف این تماس میباشید؟";
$_LANG['clientareadescription'] = "نمایش و بروزرسانی مشخصات کاربری شما";
$_LANG['clientareadisklimit'] = " محدودیت فضای دیسک مصرفی";
$_LANG['clientareadiskusage'] = "فضای دیسک مصرفی";
$_LANG['clientareadomainexpirydate'] = "تاریخ انقضا";
$_LANG['clientareadomainnone'] = " دامنه ای نزد ما ثبت نشده است";
$_LANG['clientareaemail'] = "آدرس ایمیل";
$_LANG['clientareaemails'] = "ایمیل های من";
$_LANG['clientareaemailsdate'] = "تاریخ ارسال";
$_LANG['clientareaemailsintrotext'] = "در زیر آرشیوی از کلیه پیغامهایی که برایتان ارسال کرده ایم موجود میباشد، بدین ترتیب در مواقعی که ایمیل هایتان را گم کرده باشید این امکان برای شما وجود دارد که به راحتی به کلیه موارد مربوط به حساب خود دسترسی داشته باشید.";
$_LANG['clientareaemailssubject'] = "موضوع پیام";
$_LANG['clientareaerroraddress1'] = " آدرس خود را وارد نکرده اید(خط 1)";
$_LANG['clientareaerroraddress12'] = "آدرس شما فقط میتواند شامل حروف، اعداد و فواصل باشد";
$_LANG['clientareaerrorbannedemail'] = "کاربران با این آدرس ایمیل مجاز نمیباشند.لطفا آدرس دیگری را وارد کنید.";
$_LANG['clientareaerrorcity'] = "شهر خود را وارد نکرده اید";
$_LANG['clientareaerrorcity2'] = "شهر شما فقط میتواند شامل حروف و فواصل باشد";
$_LANG['clientareaerrorcountry'] = "کشور خود را انتخاب کنید";
$_LANG['clientareaerroremail'] = "آدرس ایمیل خود را وارد نکرده اید";
$_LANG['clientareaerroremailinvalid'] = "این آدرس ایمیل نامعتبر است";
$_LANG['clientareaerroremailexists'] = "آدرس ایمیل وارد شده برای استفاده در دسترس نیست";
$_LANG['clientareaerrorusernotassoc'] = "آدرس ایمیل وارد شده برای استفاده در دسترس نیست";
$_LANG['clientareaerrorfirstname'] = "نام خود را وارد نکرده اید";
$_LANG['clientareaerrorfirstname2'] = "نام شما فقط میتواند شامل حروف باشد";
$_LANG['clientareaerrorisrequired'] = " الزامیست";
$_LANG['clientareaerrorlastname'] = "نام خانوادگی خود را وارد نکرده اید";
$_LANG['clientareaerrorlastname2'] = "نام خانوادگی شما فقط میتواند شامل حروف باشد";
$_LANG['clientareaerroroccured'] = "خطا رخ داده است، لطفا مجددا سعی کنید.";
$_LANG['clientareaerrorpasswordconfirm'] = "کلمه عبور خود را تایید نکرده اید";
$_LANG['clientareaerrorpasswordnotmatch'] = "کلمه عبور شما یکسان نیست";
$_LANG['clientareaerrorphonenumber'] = "تلفن خود را وارد نکرده اید";
$_LANG['clientareaerrorphonenumber2'] = "تلفن شما مجاز نمیباشد";
$_LANG['clientareaerrorpostcode'] = "کد پستی خود را وارد نکرده اید";
$_LANG['clientareaerrorpostcode2'] = "کدپستی شما فقط میتواند شامل حروف ،اعداد و فواصل باشد";
$_LANG['clientareaerrors'] = " خطای زیر روی داده است:";
$_LANG['clientareaerrorstate'] = "استان خود را وارد نکرده اید";
$_LANG['clientareaerrorlanguage'] = "یک زبان معتبر ارائه نشده است";
$_LANG['clientareaexpired'] = "منقضی شده";
$_LANG['clientareafirstname'] = "نام";
$_LANG['clientareafraud'] = "تقلب";
$_LANG['clientareafullname'] = "نام کاربر";
$_LANG['clientareaheader'] = "به ناحیه کاربری خود خوش آمدید.ناحیه کاربری به شما این امکان را میدهد که مشخصات خود را مشاهده و بروز نمایید، جزئیات مربوط به بسته هاستینگ و دامنه را که با ما دارید مشاهده کنید و درخواست پشتیبانی و سفارش جدیدتان را ارائه نمایید.";
$_LANG['clientareahostingaddons'] = " افزودنی ها";
$_LANG['clientareahostingaddonsintro'] = "شما افزودنی های زیر را برای این محصول دارید.";
$_LANG['clientareahostingaddonsview'] = "مشاهده";
$_LANG['clientareahostingamount'] = "مقدار";
$_LANG['clientareahostingdomain'] = "دامنه";
$_LANG['clientareahostingnextduedate'] = "تاریخ سررسید";
$_LANG['clientareahostingpackage'] = " پکیج ";
$_LANG['clientareahostingregdate'] = "تاریخ ثبت سرویس";
$_LANG['clientarealastname'] = "نام خانوادگی";
$_LANG['clientarealastupdated'] = "آخرین بروزرسانی";
$_LANG['clientarealeaveblank'] = "خالی بگذارید مگر اینکه بخواهید کلمه عبورتان را تغییر دهید.";
$_LANG['clientareamodifydomaincontactinfo'] = "تعیین اطلاعات تماس دامنه";
$_LANG['clientareamodifynameservers'] = "تعیین NameServerها";
$_LANG['clientareamodifywhoisinfo'] = "تعیین اطلاعات تماس WHOIS";
$_LANG['clientareanameserver'] = "NameServer";
$_LANG['clientareanavaddcontact'] = "افزودن فرد جدید";
$_LANG['clientareanavchangecc'] = "تغییر مشخصات کارت اعتباری ";
$_LANG['clientareanavchangepw'] = "تغییر کلمه ی عبور";
$_LANG['clientareanavdetails'] = "مشخصات من";
$_LANG['clientareanavdomains'] = "دامنه های من";
$_LANG['clientareanavhome'] = "ناحیه کاربری";
$_LANG['clientareanavlogout'] = "خروج";
$_LANG['clientareanavorder'] = "سفارش آیتم های اضافی";
$_LANG['clientareanavsecurityquestions'] = "تغییر سوال امنیتی";
$_LANG['clientareanavservices'] = "سرویس های من";
$_LANG['clientareanavsupporttickets'] = "پشتیبانی";
$_LANG['clientareanocontacts'] = "تماس/حساب فرعی یافت نشد";
$_LANG['clientareapassword'] = "کلمه عبور";
$_LANG['clientareapending'] = "معلق";
$_LANG['clientareapendingregistration'] = "در انتظار ثبت نام";
$_LANG['clientareapendingtransfer'] = "در حال انتقال";
$_LANG['clientareaphonenumber'] = "تلفن";
$_LANG['clientareapostcode'] = "کدپستی";
$_LANG['clientareaproductdetails'] = "مشخصات محصول";
$_LANG['clientareaproducts'] = "سرویس ها و محصولات";
$_LANG['clientareaproductsnone'] = " محصولی /سرویسی درخواست نشد";
$_LANG['clientarearegistrationperiod'] = "دوره ی ثبت";
$_LANG['clientareasavechanges'] = "ذخیره تغییرات";
$_LANG['clientareasecurityanswer'] = "لطفا یک پاسخ را وارد کنید";
$_LANG['clientareasecurityconfanswer'] = "لطفا پاسخ خود را تایید کنید";
$_LANG['clientareasecurityquestion'] = "لطفا یک سوال امنیتی انتخاب کنید";
$_LANG['clientareaselectcountry'] = "انتخاب کشور";
$_LANG['clientareasetlocking'] = "قفل گذاری";
$_LANG['clientareastate'] = "استان/ناحیه";
$_LANG['clientareastatus'] = "وضعیت";
$_LANG['clientareasuspended'] = "معلق";
$_LANG['clientareaterminated'] = "پایان یافته";
$_LANG['clientareaticktoenable'] = "برای فعال سازی علامت بزنید";
$_LANG['clientareatitle'] = "ناحیه کاربری";
$_LANG['clientareaunlimited'] = " نامحدود";
$_LANG['clientareaupdatebutton'] = "بروزرسانی";
$_LANG['clientareaupdateyourdetails'] = "بروز رسانی مشخصات شما";
$_LANG['clientareaused'] = "استفاده شده";
$_LANG['clientareaviewaddons'] = "دیدن افزودنی های موجود";
$_LANG['clientareaviewdetails'] = "دیدن جزئیات";
$_LANG['clientarealanguage'] = "زبان";
$_LANG['clientlogin'] = "ورود کاربر";
$_LANG['clientregisterheadertext'] = "برای ثبت نام حساب جدید موارد زیر را کامل کنید.پاسخگویی به موارد * دار اجباری میباشد.";
$_LANG['clientregistertitle'] = "ثبت نام کنید";
$_LANG['clientregisterverify'] = "تایید ثبت نام";
$_LANG['clientregisterverifydescription'] = "متن نمایش داده شده در عکس را وارد کنید. این برای جلوگیری از ثبت خودکار میباشد.";
$_LANG['clientregisterverifyinvalid'] = "کد تایید صحیح وارد نشده است";
$_LANG['closewindow'] = "بستن پنجره";
$_LANG['completeorder'] = "تکمیل سفارش";
$_LANG['confirmnewpassword'] = "تائید کلمه ی عبور جدید";
$_LANG['contactemail'] = "ایمیل";
$_LANG['contacterrormessage'] = "پیام را وارد نکرده اید";
$_LANG['contacterrorname'] = "نام خود را وارد نکرده اید";
$_LANG['contacterrorsubject'] = "موضوع را وارد نکرده اید";
$_LANG['contactheader'] = "اگر برای پیش فروش سوالی دارید یا میخواهید با ما تماس بگیرید فرم زیر را پر کنید.";
$_LANG['contactmessage'] = " پیام";
$_LANG['contactname'] = "نام";
$_LANG['contactsend'] = "ارسال پیام";
$_LANG['contactUs'] = "Contact Us";
$_LANG['contactsent'] = "پیام شما ارسال";
$_LANG['contactsubject'] = "موضوع";
$_LANG['contacttitle'] = "تماس قبل از خرید";
$_LANG['continueshopping'] = "سفارش دیگر";
$_LANG['creditcard'] = "پرداخت با کارت اعتباری";
$_LANG['creditcard3dsecure'] = "هم اکنون برای جلوگیری از کلاه برداری سوالاتی در زمنیه سرویس های کارت اعتباری تایید شده شما نمایان می شود";
$_LANG['creditcardcardexpires'] = "تاریخ انقضا";
$_LANG['creditcardcardissuenum'] = "شماره مورد";
$_LANG['creditcardcardnumber'] = "شماره کارت";
$_LANG['creditcardcardstart'] = "تاریخ شروع";
$_LANG['creditcardcardtype'] = "نوع کارت";
$_LANG['creditcardccvinvalid'] = "کد کارت ورودی شما غیر مجاز است";
$_LANG['creditcardconfirmation'] = " متشکریم! مشخصات جدید کارت شما پذیرفته شد و اولین پرداخت از حساب شما برداشته شد.شما ایمیل تاییدیه در این باره دریافت خواهید کرد.";
$_LANG['creditcardcvvnumber'] = "CVV/CVC2 شماره";
$_LANG['creditcardcvvnumbershort'] = "CVV/CVC2";
$_LANG['creditcardcvvwhere'] = "کجا میتوانم آن را بیابم ؟";
$_LANG['creditcarddeclined'] = "مشخصات کارتی که شما وارد کردید پذیرفته نشد . لطفا کارت دیگری را امتحان کنید یا با پشتیبانی تماس بگیرید.";
$_LANG['creditcarddetails'] = "مشخصات کارت اعتباری";
$_LANG['creditcardenterexpirydate'] = "تاریخ انقضای کارت را وارد نکردید";
$_LANG['creditcardenternewcard'] = "وارد کردن اطلاعات کارت جدید در زیر ";
$_LANG['creditcardenternumber'] = "شماره کارت خود را وارد نکرده اید.";
$_LANG['creditcardinvalid'] = "مشخصات کارت شما غیر مجاز است.لطفا کارت دیگری را امتحان کنید یا با پشتیبانی تماس بگیرید.";
$_LANG['creditcardnumberinvalid'] = "شماره کارت اعتباری وارد شده اشتباه است.";
$_LANG['creditcardsecuritynotice'] = "هر تاریخی که شما وارد کنید محرمانه باقی میماند و برای کاهش ریسک تقلب مخفی میباشد ";
$_LANG['creditcarduseexisting'] = "استفاده از کارت موجود";
$_LANG['customfieldvalidationerror'] = "مقدار مورد نظر معتبر نمی باشد";
$_LANG['days'] = "روز";
$_LANG['hours'] = "Hours";
$_LANG['minutes'] = "Minutes";
$_LANG['seconds'] = "Seconds";
$_LANG['defaultbillingcontact'] = "تماس صورتحساب پیش فرض";
$_LANG['domainalternatives'] = "اینها را پشت سر هم امتحان کنید:";
$_LANG['domainavailable'] = "موجود است! هم اکنون سفارش دهید";
$_LANG['domainavailablemessage'] = "<strong>:domain</strong> is available.";
$_LANG['domainavailableexplanation'] = "برای ثبت دامنه روی لینک زیر کلیک کنید";
$_LANG['domainbulksearch'] = "جستجوی چند دامنه";
$_LANG['domainbulksearchintro'] = "توسط این قسمت شما می توانید 20 دامنه را با هم جستجو کنید.لطفا هر دامنه را در یک خط و دامنه بعدی را با زدن کلید Enter در خط بعدی وارد کنید. برای جستجوی خود در ابتدای نام دامنه، لطفا از www. و http:// استفاده نکنید.";
$_LANG['domainbulktransferdescription'] = "برای انتقال دامنه خود به ما می توانید در قسمت زیر به ازای هر خط یک دامنه را وارد کنید - دامنه شما نباید شامل www. یا http:// باشد.";
$_LANG['domainbulktransfersearch'] = "انتقال دامنه به صورت جمعی";
$_LANG['domaincontactinfo'] = "اطلاعات تماس";
$_LANG['domaincurrentrenewaldate'] = "تاریخ تمدید فعلی";
$_LANG['domaindnsaddress'] = "آدرس";
$_LANG['domaindnshostname'] = "نام هاست";
$_LANG['domaindnsmanagement'] = "مدیریت DNS";
$_LANG['domaindnsmanagementdesc'] = "دامنه خود را از طریق اشاره به آدرس IP ، یا ارسال برای سایت دیگر ، یا اشاره به صفحات موقتی(به نام پارکینگ)،و غیره به وب سایت اشاره دهید. این رکوردها نیز به نام زیر دامنه شناخته میشوند.";
$_LANG['domaindnsrecordtype'] = " نوع رکورد";
$_LANG['domainemailforwarding'] = "ارسال ایمیل";
$_LANG['domainemailforwardingdesc'] = "اگر سرور ارسال ایمیل، مشخص کرد که آدرس ارسالی غیر مجاز میباشد ، ما رکورد ارسال را خودکار غیر فعال میکنیم.لطفا قبل از ارسال مجدد آدرس را چک کنید.تغییر بر هر رکورد ارسال موجود ،بیش از یک سال اثر ندارد.";
$_LANG['domainemailforwardingforwardto'] = "فرستاده شود برای";
$_LANG['domainemailforwardingprefix'] = "پیشوند";
$_LANG['domaineppcode'] = "EPP کد";
$_LANG['domaineppcodedesc'] = "این کد را باید از شرکت ثبت کننده فعلی دامنه درخواست کنید";
$_LANG['domaineppcoderequired'] = "شما باید کد تایید انتقال را وارد کنید.";
$_LANG['domainerror'] = "در درخواست شما خطا وجود دارد:";
$_LANG['domainerrornodomain'] = "لطفا نام دامنه مجاز وارد کنید";
$_LANG['domainerrortoolong'] = "دامنه که وارد کرده اید طولانی میباشد.حداکثر طول دامنه 67 کاراکتر میباشد.";
$_LANG['domaingeteppcode'] = "دریافت کد انتقال یا EPP دامنه";
$_LANG['domaingeteppcodeemailconfirmation'] = "درخواست شما برای کد EPP با موفقیت ارسال شد!کد EPP دامنه مورد نظر شما به ایمیلی که در هنگام ثبت دامنه خود وارد کرده اید به زودی ارسال می شود.";
$_LANG['domaingeteppcodeexplanation'] = "EPP کدی برای دامنه مورد نظر شما است. شما توسط این کد می توانید دامنه خود را در صورت نیاز به مرکز های ثبت دامنه دیگر انتقال دهید.";
$_LANG['domaingeteppcodefailure'] = "خطایی در هنگام درخواست کد EPP به وجود آمده است :";
$_LANG['domaingeteppcodeis'] = "کد EPP دامنه شما :";
$_LANG['domainidprotection'] = "عدم نمایش مشخصات شما در Whois";
$_LANG['domainintrotext'] = "دامنه مورد نظرتان را وارد کرده و کلید ,مراجعه , را کلیک کنید تا ببینید آیا آن دامنه موجود است یا خیر.";
$_LANG['domainlookupbutton'] = "جستجو کن";
$_LANG['domainmanagementtools'] = "مدیریت ابزار ها";
$_LANG['domainminyears'] = "تعداد سال";
$_LANG['domainmoreinfo'] = "اطلاعات بیشتر";
$_LANG['domainname'] = "نام دامنه";
$_LANG['domainnameserver1'] = "NameServer 1";
$_LANG['domainnameserver2'] = "NameServer 2";
$_LANG['domainnameserver3'] = "NameServer 3";
$_LANG['domainnameserver4'] = "NameServer 4";
$_LANG['domainnameserver5'] = "Nameserver 5";
$_LANG['domainnameservers'] = "مدیریت NameServer";
$_LANG['domainordernow'] = " هم اکنون سفارش دهید!";
$_LANG['domainorderrenew'] = "سفارش تمدید";
$_LANG['domainprice'] = " قیمت دامنه";
$_LANG['domainregisterns'] = "ثبت Nameserver";
$_LANG['domainregisternscurrentip'] = "IP آدرس فعلی";
$_LANG['domainregisternsdel'] = "حذف یک Nameserver";
$_LANG['domainregisternsdelsuccess'] = "Nameserver با موفقیت حذف شد.";
$_LANG['domainregisternsexplanation'] = "توسط این قسمت شما می توانید nameserver های دامنه خود را ویرایش کنید.(مثال : ns1.example.com , ns2.example.com (";
$_LANG['domainregisternsip'] = "آدرس IP";
$_LANG['domainregisternsmod'] = "ویرایش IP یک Nameserver";
$_LANG['domainregisternsmodsuccess'] = "Nameserver با موفقیت ویرایش شد.";
$_LANG['domainregisternsnewip'] = "IP آدرس جدید";
$_LANG['domainregisternsns'] = "Nameserver";
$_LANG['domainregisternsreg'] = "ثبت اسم یک Nameserver";
$_LANG['domainregisternsregsuccess'] = "Nameserver با موفقیت ثبت شد.";
$_LANG['domainregistrantchoose'] = "مشخصاتی را که میخواهید استفاده کنید انتخاب نمایید";
$_LANG['domainregistrantinfo'] = "اطلاعات ثبت دامنه";
$_LANG['domainregistrarlock'] = "قفل ثبت کننده";
$_LANG['domainregistrarlockdesc'] = "فعال سازی قفل ثبت کننده( پیشنهاد میشود). گذاشتن قفل از انتقال غیر معتبر جلوگیری میکند.";
$_LANG['domainregistration'] = "ثبت نام دامنه";
$_LANG['domainregistryinfo'] = "اطلاعات ثبت دامنه ";
$_LANG['domainregnotavailable'] = "هیچکدام";
$_LANG['domainrenew'] = "تمدید دامنه";
$_LANG['domainrenewal'] = "تمدید دامنه";
$_LANG['domainrenewalprice'] = " تمدید";
$_LANG['domainrenewdesc'] = "با افزایش سال به دامنه تان آن را امن تر کنید.از زیر مشخص کنید چند سال مایلید آن را تمدید نمایید و سپس سفارش تمدید را کلیک کنید.";
$_LANG['domainsautorenew'] = "تمدید خودکار";
$_LANG['domainsautorenewdisable'] = "غیر فعال کردن تمدید خودکار";
$_LANG['domainsautorenewdisabled'] = "خیر";
$_LANG['domainsautorenewdisabledwarning'] = "هشدار! تمدید خودکار دامنه غیر فعال است.هنگامی که تاریخ انقضای این دامنه فرا رسد این دامنه غیر فعال شده و شما باید آن را به صورت دستی شارژ کنید.";
$_LANG['domainsautorenewenable'] = "فعال کردن تمدید خودکار";
$_LANG['domainsautorenewenabled'] = "فعال";
$_LANG['domainsautorenewstatus'] = "وضعیت";
$_LANG['domainsimplesearch'] = "جستجوی ساده دامنه";
$_LANG['domainspricing'] = "قیمت دامنه";
$_LANG['domainsregister'] = "ثبت نام";
$_LANG['domainsrenew'] = "تمدید";
$_LANG['domainsrenewnow'] = "تمدید کنید";
$_LANG['domainstatus'] = "وضعیت";
$_LANG['domainstransfer'] = "انتقال";
$_LANG['domaintitle'] = " جستجوگر دامنه ";
$_LANG['domaintld'] = "پسوند";
$_LANG['domaintransfer'] = "انتقال دامنه";
$_LANG['domainunavailable'] = "موجود نیست";
$_LANG['domainunavailable1'] = "متاسفیم!";
$_LANG['domainunavailable2'] = "موجود نمیباشد!";
$_LANG['domainreserved'] = "رزرو شده";
$_LANG['domainreserved1'] = "دامنه";
$_LANG['domainreserved2'] = "در دسترس است ، اما محفوظ است";
$_LANG['domainviewwhois'] = "مشاهده گزارش ";
$_LANG['domainDnsSec']['management'] = "DNSSEC Management";
$_LANG['domainDnsSec']['dsRecords'] = "DS Records";
$_LANG['domainDnsSec']['keyTag'] = "Key Tag";
$_LANG['domainDnsSec']['algorithm'] = "Algorithm";
$_LANG['domainDnsSec']['digestType'] = "Digest Type";
$_LANG['domainDnsSec']['digest'] = "Digest";
$_LANG['domainDnsSec']['keyRecords'] = "KEY Records";
$_LANG['domainDnsSec']['flags'] = "Flags";
$_LANG['domainDnsSec']['protocol'] = "Protocol";
$_LANG['domainDnsSec']['publicKey'] = "Public Key";
$_LANG['domainDnsSec']['publicKeyNoSpace'] = "Public Key should not have any whitespace.";
$_LANG['domainDnsSec']['warning'] = "Caution: Incorrect DNSSEC settings might render your domain unreachable.";
$_LANG['downloaddescription'] = "توضیحات";
$_LANG['downloadloginrequired'] = "شما امکان دسترسی به این صفحه را ندارید - برای استفاده از این صفحه شما باید در ابتدا وارد سیستم شوید.";
$_LANG['downloadname'] = "دریافت";
$_LANG['downloadpurchaserequired'] = "شما امکان دسترسی به این صفحه را ندارید - برای دسترسی به این صفحه شما باید در ابتدا سفارشی که با این محصول در ارتباط است را سفارش دهید.";
$_LANG['downloadscategories'] = "دسته بندی ها";
$_LANG['downloadsdescription'] = "نمایش محتویات مرکز دانلود";
$_LANG['downloadsfiles'] = "فایل ها";
$_LANG['downloadsfilesize'] = "اندازه فایل";
$_LANG['downloadsintrotext'] = "آرشیو دریافت فایل ،تمام برنامه ها و فایل هایی را که شما برای بالا بردن و راه اندازی سایت خود نیاز دارید را شامل میشود .";
$_LANG['downloadspopular'] = "محبوب ترین دانلودها";
$_LANG['downloadsnone'] = "دانلودی برای نمایش موجود نیست.";
$_LANG['downloadstitle'] = " دانلود فایل";
$_LANG['email'] = "ایمیل";
$_LANG['emptycart'] = "خالی کردن کارت خرید";
$_LANG['existingpassword'] = "رمز عبور فعلی";
$_LANG['existingpasswordincorrect'] = "رمزعبور فعلی شما صحیح نمی باشد";
$_LANG['firstpaymentamount'] = "مبلغ اولین پرداخت ";
$_LANG['flashtutorials'] = "آموزش بصورت فلش";
$_LANG['flashtutorialsdescription'] = "برای مشاهده آموزش هاستینگ کنترل پنل خود اینجا را کلیک کنید";
$_LANG['flashtutorialsheadertext'] = "آموزش بصورت فلش ما به شما برای وب هاستینگ کنترل پنل کمک میکند.مراحل زیر را انتخاب کنید تا آموزش مرحله به مرحله را دریافت نمایید.";
$_LANG['forwardingtogateway'] = "Please wait while the system redirects you to complete payment using the selected payment method.";
$_LANG['globalsystemname'] = "اعضا";
$_LANG['globalyouarehere'] = "مکان فعلی شما ";
$_LANG['go'] = "برو";
$_LANG['headertext'] = "به ناحیه پشتیبانی ما خوش آمدید.";
$_LANG['hometitle'] = "خانه";
$_LANG['imagecheck'] = "لطفا کد امنیتی موجود در عکس را وارد کنید-این مورد برای جلوگیری از ثبت خودکار میباشد.";
$_LANG['invoiceaddcreditamount'] = "لطفا مبلغ مورد نظر خود را وارد کنید";
$_LANG['invoiceaddcreditapply'] = "اعتبار قابل استفاده";
$_LANG['invoiceaddcreditdesc1'] = "موجودی حساب شما :";
$_LANG['invoiceaddcreditdesc2'] = "این میتواند توسط فرم زیر روی صورت حساب ها اعمال شود.";
$_LANG['invoiceaddcreditoverbalance'] = "شما برای میزان بدهی خود نمی توانید بیشتر از موجودی قابل استفاده حساب خود استفاده کنید";
$_LANG['invoiceaddcreditovercredit'] = "شما نمی توانید از اعتبار قابل استفاده خود فراتر استفاده کنید.";
$_LANG['invoicenumber'] = "صورتحساب #";
$_LANG['invoiceofflinepaid'] = "پروسه پرداخت آفلاین با کارت اعتباری بصورت دستی انجام میشود.هنگامی که پروسه پرداخت تکمیل شود شما ایمیل تاییدیه دریافت خواهید کرد .";
$_LANG['invoicerefnum'] = "شماره مرجع";
$_LANG['invoices'] = "صورتحساب ها";
$_LANG['invoicesamount'] = "مقدار";
$_LANG['invoicesattn'] = "ATTN";
$_LANG['invoicesbacktoclientarea'] = "&laquo; بازگشت به ناحیه کاربری";
$_LANG['invoicesbalance'] = "باقی مانده حساب";
$_LANG['invoicesbefore'] = "قبل";
$_LANG['invoicescancelled'] = "لغو شده";
$_LANG['invoicescollections'] = "مجموعه ها";
$_LANG['invoicescredit'] = "اعتبار";
$_LANG['invoicesdatecreated'] = "تاریخ صورتحساب";
$_LANG['invoicesdatedue'] = "تاریخ سررسید";
$_LANG['invoicesdescription'] = "توضیحات";
$_LANG['invoicesdownload'] = "دریافت فایل";
$_LANG['invoiceserror'] = "خطایی رخ داده است. لطفا مجددا سعی کنید.";
$_LANG['invoicesinvoicedto'] = "صورتحساب برای ";
$_LANG['invoicesinvoicenotes'] = "یادداشت صورتحساب";
$_LANG['invoicesnoinvoices'] = "صورتحسابی وجود ندارد";
$_LANG['invoicesnotes'] = "یادداشت ها";
$_LANG['invoicesoutstandinginvoices'] = "صورت حساب های واریز نشده";
$_LANG['invoicespaid'] = "پرداخت شده";
$_LANG['invoicespaynow'] = " هم اکنون پرداخت کنید";
$_LANG['invoicespayto'] = "پرداخت به ";
$_LANG['invoicesrefunded'] = "پس داده شده";
$_LANG['invoicesstatus'] = "وضعیت";
$_LANG['invoicessubtotal'] = "جمع جزء";
$_LANG['invoicestax'] = "موعد مالیات";
$_LANG['invoicestaxindicator'] = "نشان دهنده آیتم های مالیاتی.";
$_LANG['invoicestitle'] = "صورتحساب #";
$_LANG['invoicestotal'] = "کل";
$_LANG['invoicestransactions'] = "معامله";
$_LANG['invoicestransamount'] = "مقدار";
$_LANG['invoicestransdate'] = "تاریخ پرداخت";
$_LANG['invoicestransgateway'] = "درگاه";
$_LANG['invoicestransid'] = "شناسه پرداخت";
$_LANG['invoicestransnonefound'] = "معامله مربوطی یافت نشد";
$_LANG['invoicesunpaid'] = "پرداخت نشده";
$_LANG['invoicesdraft'] = "Draft";
$_LANG['invoicesview'] = "مشاهده صورتحساب";
$_LANG['jobtitle'] = "شغل";
$_LANG['kbsuggestions'] = "پیشنهادهای مرکز اطلاعات";
$_LANG['kbsuggestionsexplanation'] = "مقاله های زیر در قسمت مرکز اطلاعات ما یافت شد، لطفا قبل از ارسال درخواست برای دریافت پاسخ خود مقاله های زیر را مطالعه کنید.";
$_LANG['knowledgebasearticles'] = "مقالات";
$_LANG['knowledgebasecategories'] = "دسته بندی ها";
$_LANG['nokbcategories'] = "هیچ دسته ای وجود ندارد";
$_LANG['knowledgebasedescription'] = "مشاهده سوال و جواب های متداول";
$_LANG['knowledgebasefavorites'] = "افزودن به مورد علاقه ها";
$_LANG['knowledgebasehelpful'] = "آیا این پاسخ به شما کمک کرد؟";
$_LANG['knowledgebaseintrotext'] = "اطلاعات پایه به دسته های مختلف تقسیم شده است. برای پاسخ سوال خود میتوانید این دسته بندی ها را در زیر انتخاب کنید و یا در اطلاعات پایه جستجو کنید.";
$_LANG['knowledgebasemore'] = "بیشتر";
$_LANG['knowledgebaseno'] = "خیر";
$_LANG['knowledgebasenoarticles'] = "مقاله ای یافت نشد";
$_LANG['knowledgebasenorelated'] = "مقاله مربوطه ای یافت نشد";
$_LANG['knowledgebasepopular'] = " پربازدید ترین";
$_LANG['knowledgebaseprint'] = "پرینت این مقاله";
$_LANG['knowledgebaserating'] = "رتبه بندی:";
$_LANG['knowledgebaseratingtext'] = "کاربر این را مفید یافتند";
$_LANG['knowledgebaserelated'] = "مقالات مربوطه";
$_LANG['knowledgebasesearch'] = "جستجو";
$_LANG['knowledgebasetitle'] = "مرکز آموزش";
$_LANG['knowledgebaseviews'] = "مشاهدات";
$_LANG['knowledgebasevote'] = "نظر";
$_LANG['knowledgebasevotes'] = "نظرات";
$_LANG['knowledgebaseyes'] = "بلی";
$_LANG['knowledgebaseArticleRatingThanks'] = "از رتبه ای که دادید سپاسگزاریم.";
$_LANG['language'] = "زبان";
$_LANG['latefee'] = "هزینه دیرکرد";
$_LANG['latefeeadded'] = "افزوده شد";
$_LANG['latestannouncements'] = "آخرین اخبار";
$_LANG['loginbutton'] = "وارد شوید";
$_LANG['loginemail'] = "آدرس ایمیل";
$_LANG['loginforgotten'] = "رمزعبور خود را فراموش کرده اید؟";
$_LANG['loginforgotteninstructions'] = "درخواست رمز عبور جدید";
$_LANG['loginincorrect'] = "مشخصات ورود اشتباه است لطفا دوباره سعی کنید.";
$_LANG['loginintrotext'] = "برای دسترسی به این صفحه باید وارد شوید.این مشخصات ورود با نام کاربری و کلمه عبور کنترل پانل شما متفاوت است.";
$_LANG['loginpassword'] = "کلمه عبور";
$_LANG['loginrememberme'] = "مرا به خاطر بسپار";
$_LANG['logoutcontinuetext'] = "برای ادامه اینجا را کلیک کنید.";
$_LANG['logoutsuccessful'] = "شما با موفقیت خارج شدید.";
$_LANG['logouttitle'] = "خروج";
$_LANG['maxmind_anonproxy'] = "ما سفارش هایی که مشتری از پروکسی استفاده می کند نمی پذیریم";
$_LANG['maxmind_callingnow'] = "ما تماس خودکار با تلفن شما خواهیم داشت . این بخشی از بررسی احتمال میزان تقلب میباشد. شما کد امنیتی 4 رقمی که برای تکمیل سفارش های خود در زیر لازم است را دریافت خواهید کرد .";
$_LANG['maxmind_countrymismatch'] = "کشور ثبت شده شما با کشوری که ip نشان میدهد متفاوت است، ما نمیتوانیم سفارش شما را قبول کنیم .";
$_LANG['maxmind_error'] = "خطا";
$_LANG['maxmind_faileddescription'] = "کد ورودی اشتباه است. اگر فکر میکنید اشتباهی رخ داده است لطفا سریعا با بخش پشتیبانی ما تماس بگیرید.";
$_LANG['maxmind_highfraudriskscore'] = "سیستم ما متوجه ریسک بالای تقلب برای سفارش شما شده است و آن را ممنوع میکند ";
$_LANG['maxmind_highriskcountry'] = "ما از کشور شما بعلت ریسک بالای تقلب سفارش قبول نمیکنیم ";
$_LANG['maxmind_incorrectcode'] = "کد اشتباه";
$_LANG['maxmind_pincode'] = "پین کد";
$_LANG['maxmind_rejectemail'] = "ما سفارشاتی که با آدرس ایمیل رایگان باشد را نمیپذیریم لطفا ایمیل دیگری وارد کنید";
$_LANG['maxmind_title'] = "MaxMind";
$_LANG['more'] = "بیشتر";
$_LANG['morechoices'] = "انتخاب های بیشتر";
$_LANG['networkissuesaffecting'] = "تاثیر";
$_LANG['networkissuesaffectingyourservers'] = "توجه: در صورتی که مشکلات سرور بر روی حساب کاربری شما تاثیر داشته باشد، با سرویس های ویژه جبران خواهد شد.";
$_LANG['networkissuesdate'] = "تاریخ";
$_LANG['networkissuesdescription'] = "مشاهده اخبار مربوطه به سرورهای شرکت";
$_LANG['networkissueslastupdated'] = "آخرین بروزرسانی";
$_LANG['networkissuesnonefound'] = "هیچ مشکل شبکه ای پیدا نشد.";
$_LANG['networkissuespriority'] = "اهمیت";
$_LANG['networkissuesprioritycritical'] = "ضروری";
$_LANG['networkissuespriorityhigh'] = "زیاد";
$_LANG['networkissuesprioritylow'] = "کم";
$_LANG['networkissuesprioritymedium'] = "معمولی";
$_LANG['networkissuesstatusinprogress'] = "در حال گذراندن مراحل";
$_LANG['networkissuesstatusinvestigating'] = "در حال بررسی";
$_LANG['networkissuesstatusopen'] = "باز";
$_LANG['networkissuesstatusoutage'] = "قطعی";
$_LANG['networkissuesstatusreported'] = "گزارش شده";
$_LANG['networkissuesstatusresolved'] = "حل شده";
$_LANG['networkissuesstatusscheduled'] = "زمان بندی شده";
$_LANG['networkissuestitle'] = "مشکلات شبکه";
$_LANG['networkissuestypeother'] = "دیگر";
$_LANG['networkissuestypeserver'] = "سرور";
$_LANG['networkissuestypesystem'] = "سیستم";
$_LANG['networkIssuesAware'] = "ما از یک مشکل تأثیرگذار بر خدمات آگاه هستیم";
$_LANG['networkIssuesScheduled'] = "رویدادهای تعمیر و نگهداری  در آینده  وجود دارد که ممکن است خدمات ما را تحت تأثیر قرار دهد";
$_LANG['newpassword'] = "کلمه ی عبور جدید";
$_LANG['nextpage'] = "صفحه بعد";
$_LANG['no'] = "خیر";
$_LANG['nocarddetails'] = "رکوردی از مشخصات کارت موجود نمیباشد";
$_LANG['none'] = "هیچکدام";
$_LANG['norecordsfound'] = "هیچ محصول یا سرویسی یافت نشد";
$_LANG['or'] = "یا";
$_LANG['orderadditionalrequiredinfo'] = "اطلاعات تکمیلی";
$_LANG['orderaddon'] = " افزودنی ها";
$_LANG['orderaddondescription'] = "افزودنی های زیر برای این محصول موجود است.افزودنی مورد نظر خود را از زیر انتخاب کنید.";
$_LANG['orderavailable'] = "موجود است";
$_LANG['orderavailableaddons'] = " برای مشاهده افزونه های موجود کلیک کنید";
$_LANG['orderbillingcycle'] = "دوره پرداخت";
$_LANG['ordercategories'] = "دسته بندی ها";
$_LANG['orderchangeaddons'] = "تغییر افزودنی ها";
$_LANG['orderchangeconfig'] = "تغییر انتخاب های پیکربندی";
$_LANG['orderchangedomain'] = "تغییر دامنه";
$_LANG['orderchangenameservers'] = "فقط تغییر NameServer";
$_LANG['orderchangeproduct'] = "تغییر محصول";
$_LANG['ordercheckout'] = "تکمیل سفارش";
$_LANG['orderchooseaddons'] = "انتخاب افزودنی های محصول ";
$_LANG['orderchooseapackage'] = "انتخاب پکیج";
$_LANG['ordercodenotfound'] = "کد تخفیف شما در سیستم تعریف نشده است";
$_LANG['ordercompletebutnotpaid'] = " اخطار! سفارش شما تکمیل شد اما هنوز برای آن پرداختی نکرده اید پس هنوز فعال نشده است جهت دسترسی به صورتحساب و پرداخت روی لینک زیر کلیک کنید";
$_LANG['orderconfigpackage'] = "انتخاب های قابل پبکربندی";
$_LANG['orderconfigure'] = " پیکربندی";
$_LANG['orderconfirmation'] = "درخواست تایید";
$_LANG['orderconfirmorder'] = "تایید سفارش";
$_LANG['ordercontinuebutton'] = " ادامه خرید » ";
$_LANG['orderdesc'] = "توضیحات";
$_LANG['orderdescription'] = "ارسال سفارش جدید";
$_LANG['orderdiscount'] = "تخفیف";
$_LANG['orderdomain'] = "دامنه";
$_LANG['orderdomainoption1part1'] = "میخواهم";
$_LANG['orderdomainoption1part2'] = "برای من دامنه جدید ثبت کند.";
$_LANG['orderdomainoption2'] = "NameServer های شرکت را بر روی دامنه ام تنظیم می کنم.";
$_LANG['orderdomainoption3'] = "میخواهم دامنه ام را منتقل کنم به";
$_LANG['orderdomainoption4'] = "مایل به استفاده از زیر دامنه های رایگان هستم.";
$_LANG['orderdomainoptions'] = "اختیارات دامنه";
$_LANG['orderdomainregistration'] = " ثبت دامنه ";
$_LANG['orderdomainregonly'] = " فقط سفارش ثبت دامنه ";
$_LANG['orderdomaintransfer'] = " انتقال دامنه ";
$_LANG['orderdontusepromo'] = "از کد پیشرفت استفاده نمیشود";
$_LANG['ordererroraccepttos'] = "شما باید شرایط سرویس را بپذیرید";
$_LANG['ordererrordomainalreadyexists'] = "دامنه ای که سفارش داده اید قبلا نزد ما سفارش داده شده است. شما باید سفارش فوق را لغو کنید تا بتوانید این دامنه را سفارش دهید";
$_LANG['ordererrordomaininvalid'] = "دامنه که وارد کردید مجاز نمیباشد";
$_LANG['ordererrordomainnotld'] = "شما باید پسوند دامنه را وارد کنید";
$_LANG['ordererrordomainnotregistered'] = "شما نمیتوانید دامنه را که ثبت نشده است منتقل کنید";
$_LANG['ordererrordomainregistered'] = "دامنه که شما وارد کردید قبلا ثبت شده است";
$_LANG['ordererrornameserver1'] = "شما باید NameServer 1 را وارد کنید";
$_LANG['ordererrornameserver2'] = "شما باید NameServer 2 را وارد کنید ";
$_LANG['ordererrornodomain'] = "نام دامنه وارد نکردید";
$_LANG['ordererrorpassword'] = "کلمه عبور وارد نکردید";
$_LANG['ordererrorserverhostnameinuse'] = "hostname وارد شده قبلا استفاده شده است. لطفا مورد دیگری انتخاب کنید.";
$_LANG['ordererrorservernohostname'] = "شما باید نام هاست برای سرورتان وارد کنید";
$_LANG['ordererrorservernonameservers'] = "شما باید برای هر دو NameServer پیشوند وارد کنید";
$_LANG['ordererrorservernorootpw'] = "شما باید برای روت کلمه عبوری به دلخواه وارد کنید.";
$_LANG['ordererrorsubdomaintaken'] = "زیردامنه که وارد کردید قبلا گرفته شده است.لطفا دوباره سعی کنید.";
$_LANG['ordererrortransfersecret'] = "شما باید رمز انتقال را وارد کنید";
$_LANG['ordererroruserexists'] = " کاربر با این آدرس ایمیل موجود میباشد";
$_LANG['orderexistinguser'] = "من در حال حاضر مشتری شما هستم و مایل به افزودن این سفارش به حساب خود میباشم";
$_LANG['orderfailed'] = "سفارش رد شد";
$_LANG['orderfinalinstructions'] = "اگر هر سوالی در مورد سفارش خود دارید لطفا درخواست پشتیبانی را از ناحیه کاربری خود باز کرده و شماره سفارش خود را بیان کنید .";
$_LANG['orderfree'] = "رایگان!";
$_LANG['orderfreedomainappliesto'] = "تنها برای افزایش موارد زیر بکار رود";
$_LANG['orderfreedomaindescription'] = "بر شرایط انتخابی پرداخت ";
$_LANG['orderfreedomainonly'] = "دامنه رایگان";
$_LANG['orderfreedomainregistration'] = "ثبت رایگان دامنه";
$_LANG['ordergotoclientarea'] = "برای ورود به ناحیه کاربری اینجا را کلیک کنید";
$_LANG['orderinvalidcodeforbillingcycle'] = "این کد برای سیکل صورتحساب انتخاب شده استفاده نمیشود";
$_LANG['orderlogininfo'] = "اطلاعات ورود";
$_LANG['orderlogininfopart1'] = "لطفا کلمه عبوری را که هنگام ورود مایلید داشته باشید وارد نمایید";
$_LANG['orderlogininfopart2'] = "ناحیه کاربری.این با نام کاربری کنترل پنل سایت شما تفاوت دارد.";
$_LANG['ordernewuser'] = "من مشتری جدید هستم و مایل به ایجاد حساب کاربری میباشم";
$_LANG['ordernoproducts'] = "محصولی یافت نشد";
$_LANG['ordernotes'] = "توضیحات شما";
$_LANG['ordernotesdescription'] = "شما می توانید هر توضیحی که در مورد سفارش خود دارید را در این قسمت وارد کنید.";
$_LANG['ordernowbutton'] = "سفارش دهید";
$_LANG['ordernumberis'] = "شماره سفارش شما :";
$_LANG['orderpaymentmethod'] = "طریقه پرداخت ";
$_LANG['orderpaymentterm12month'] = "قیمت سالیانه";
$_LANG['orderpaymentterm1month'] = "قیمت ماهیانه";
$_LANG['orderpaymentterm24month'] = "قیمت 2 ساله";
$_LANG['orderpaymentterm3month'] = "قیمت 3 ماه";
$_LANG['orderpaymentterm6month'] = "قیمت 6 ماه ";
$_LANG['orderpaymenttermannually'] = "سالانه";
$_LANG['orderpaymenttermbiennially'] = "دوساله";
$_LANG['orderpaymenttermfreeaccount'] = "حساب رایگان ";
$_LANG['orderpaymenttermmonthly'] = "ماهانه";
$_LANG['orderpaymenttermonetime'] = "به صورت یک بار";
$_LANG['orderpaymenttermquarterly'] = "سه ماهه";
$_LANG['orderpaymenttermsemiannually'] = "شش ماهه";
$_LANG['orderprice'] = "قیمت";
$_LANG['orderproduct'] = " محصول/سرویس";
$_LANG['orderprogress'] = "پیشروی";
$_LANG['orderpromoexpired'] = " کد پیشرفت ورودی منقضی شده است";
$_LANG['orderpromoinvalid'] = "کد پیشرفت ورودی برای هیچ یک از آیتم های سفارشی شما بکار نمیرود";
$_LANG['orderpromomaxusesreached'] = "کد پیشرفت وارد شده قبلا استفاده شده است";
$_LANG['orderpromotioncode'] = "کد تخفیف";
$_LANG['orderpromovalidatebutton'] = "معتبر سازی کد >>";
$_LANG['orderPromoCodePlaceholder'] = "اگر کوپن تخفیف دارید، آن را وارد کنید";
$_LANG['orderprorata'] = "Pro Rata";
$_LANG['orderreceived'] = "از سفارش شما متشکریم.به زودی ایمیل تاییدیه دریافت خواهید کرد.";
$_LANG['orderregisterdomain'] = "ثبت دامنه جدید";
$_LANG['orderregperiod'] = " مدت ثبت ";
$_LANG['ordersecure'] = "فرم سفارش در محیط امنی ایجاد میشود و به جلوگیری از تقلب با IP آدرس شما کمک میکند";
$_LANG['ordersecure2'] = " وارد شده است.";
$_LANG['orderserverhostname'] = "نام هاست سرور";
$_LANG['orderservernameservers'] = "NameServer";
$_LANG['orderservernameserversdescription'] = "پیشوند هایی که شما وارد میکنید، نام پیش فرض سرور را تعیین میکند eg. ns1.example.com and ns2.example.com";
$_LANG['orderservernameserversprefix1'] = "پیشوند 1 ";
$_LANG['orderservernameserversprefix2'] = "پیشوند 2";
$_LANG['orderserverrootpassword'] = "کلمه عبور root";
$_LANG['ordersetupfee'] = "هزینه تنظیم ";
$_LANG['orderstartover'] = "شروع دوباره";
$_LANG['ordersubdomaininuse'] = "زیر دامنه که وارد کردید استفاده شده است";
$_LANG['ordersubtotal'] = "زیرمجموعه";
$_LANG['ordersummary'] = "خلاصه سفارش";
$_LANG['ordertaxcalculations'] = "حسابهای مالیات";
$_LANG['ordertaxstaterequired'] = "شما باید منطقه خود برای حسابهای مالیاتی را وارد کنید";
$_LANG['ordertitle'] = "سفارش";
$_LANG['ordertos'] = "شرایط سرویس";
$_LANG['ordertosagreement'] = "را خواندم و موافقم.";
$_LANG['ordertotalduetoday'] = " قابل پرداخت ";
$_LANG['ordertotalrecurring'] = "تمدید";
$_LANG['ordertransferdomain'] = "انتقال دامنه موجود";
$_LANG['ordertransfersecret'] = "کد انتقال";
$_LANG['ordertransfersecretexplanation'] = "لطفا رمز ارسال دامنه خود را که از نام دامنه ثبتی شما بدست می اید وارد کنید . ";
$_LANG['orderusesubdomain'] = "استفاده از زیر دامنه";
$_LANG['orderyears'] = "ساله";
$_LANG['orderyourinformation'] = "اطلاعات شما";
$_LANG['orderyourorder'] = "سفارش شما";
$_LANG['organizationname'] = "نام شرکت";
$_LANG['outofstock'] = "خارج از دسترس";
$_LANG['outofstockdescription'] = "در حال حاضر این سفارش خارج از دسترس می باشد و سفارش های ارسال شده برای این آیتم تا هنگامی که این سرویس در دسترس قرار بگیرید به حالت معلق در می آیند، برای اطلاعات بیشتر با ما تماس بگیرید.";
$_LANG['page'] = "صفحه";
$_LANG['pageof'] = "از";
$_LANG['please'] = "لطفا";
$_LANG['pleasewait'] = "لطفا صبر کنید ...";
$_LANG['presalescontactdescription'] = "سوالات پیش از خرید";
$_LANG['previouspage'] = "صفحه قبل";
$_LANG['proformainvoicenumber'] = "صورتحساب پیش صورتحساب #";
$_LANG['promoexistingclient'] = "شما باید حداقل یک محصول فعال داشته باشید تا اجازه استفاده از این کد را پیدا کنید.";
$_LANG['promoonceperclient'] = "از این کد تنها یک کاربر و یک بار می تواند استفاده کند.";
$_LANG['pwstrengthfail'] = "رمزعبور وارد شده شما بسیار ساده می باشد لطفا رمزعبور پیچیده تری انتخاب کنید.";
$_LANG['pwdoesnotmatch'] = "گذرواژه های وارد شده مطابقت ندارند";
$_LANG['quicknav'] = "منوی سریع";
$_LANG['recordsfound'] = "مورد یافت شد";
$_LANG['recurring'] = "دوره ای";
$_LANG['recurringamount'] = "مبلغ تمدید";
$_LANG['every'] = "هر";
$_LANG['registerdomain'] = " ثبت دامنه ";
$_LANG['registerdomaindesc'] = "نام دامنه انتخابی خود را جهت ثبت وارد کنید تا در دسترس بودن آن بررسی شود.";
$_LANG['registerdomainname'] = "ثبت یک نام دامنه";
$_LANG['relatedservice'] = "سرویس مربوطه";
$_LANG['rssfeed'] = "فید";
$_LANG['securityanswerrequired'] = "شما باید یک سوال امنیتی انتخاب کنید.";
$_LANG['securityquestionrequired'] = "You must select a security question";
$_LANG['securitybothnotmatch'] = "پاسخ شما با تکرار پاسخ شما مطابقت ندارد";
$_LANG['securitycurrentincorrect'] = "سوال امنیتی و پاسخ فعلی شما اشتباه است.";
$_LANG['serverchangepassword'] = "تغییر کلمه عبور";
$_LANG['serverchangepasswordintro'] = "از اینجا میتوانید پسورد سرویس یا محصول را تغییر دهید. (توجه : پسورد ناحیه کاربری شما تغییری نمیکند)";
$_LANG['serverchangepasswordconfirm'] = "تایید کلمه عبور";
$_LANG['serverchangepasswordenter'] = "کلمه عبور جدید را وارد کنید";
$_LANG['serverchangepasswordfailed'] = "تغییر کلمه عبور انجام نشد!";
$_LANG['serverchangepasswordsuccessful'] = "کلمه عبور با موفقیت تغییر کرد!";
$_LANG['serverchangepasswordupdate'] = "بروز رسانی";
$_LANG['serverhostname'] = "نام هاست";
$_LANG['serverlogindetails'] = "مشخصات ورودی";
$_LANG['serverns1prefix'] = "NS1 Prefix";
$_LANG['serverns2prefix'] = "NS2 Prefix";
$_LANG['serverpassword'] = "کلمه عبور";
$_LANG['serverrootpw'] = "کلمه عبور اصلی Root";
$_LANG['serverstatusdescription'] = "مشاهده وضعیت سرورهای ما";
$_LANG['serverstatusnoservers'] = "در حال حاضر سروری مشاهده نشده است";
$_LANG['serverstatusnotavailable'] = "در دسترس نیست ";
$_LANG['serverstatusoffline'] = "آفلاین";
$_LANG['serverstatusonline'] = "آنلاین";
$_LANG['serverstatusphpinfo'] = "اطلاعات php";
$_LANG['serverstatusserverload'] = "بارگذاری سرور";
$_LANG['serverstatustitle'] = "وضعیت سرور";
$_LANG['serverstatusuptime'] = "پایداری";
$_LANG['serverusername'] = "نام کاربر";
$_LANG['show'] = "نمایش";
$_LANG['ssladmininfo'] = "اطلاعات ارتباط با مدیریت";
$_LANG['ssladmininfodetails'] = "این اطلاعات ارتباطی در گواهینامه نمایش داده نخواهد شد و فقط برای ارسال یادآوری تاریخ انقضا و اطلاعات دیگر استفاده می شود.";
$_LANG['sslcertinfo'] = "اطلاعات گواهینامه SSL";
$_LANG['pleasechooseone'] = "لطفا یکی را انتخاب کنید ...";
$_LANG['sslcerttype'] = "نوع گواهینامه";
$_LANG['sslconfigcomplete'] = "تکمیل پیکربندی";
$_LANG['sslconfsslcertificate'] = "پیکربندی گواهینامه SSL";
$_LANG['sslcsr'] = "CSR";
$_LANG['sslerrorapproveremail'] = "شما باید ایمیل تایید کنده گواهینامه را وارد کنید";
$_LANG['sslerrorentercsr'] = "شما باید کد CSR سرور خود را وارد کنید";
$_LANG['sslerrorselectserver'] = "شما باید نوع سرور خود را انتخاب کنید";
$_LANG['sslinvalidlink'] = "لینک مورد نظر اشتباه است.";
$_LANG['sslorderdate'] = "تاریخ سفارش";
$_LANG['sslserverinfo'] = "اطلاعات سرور";
$_LANG['sslserverinfodetails'] = "برای اینکار شما باید کد \"CSR\" دقیقی برای اطلاعات خود بدست آورید، کد \"CSR\" حاوی اطلاعات سرور شما است که طبق این کد گواهینامه شما صادر می شود.";
$_LANG['sslservertype'] = "نوع وب سرور";
$_LANG['ssl']['selectWebserver'] = "Select a :serverType";
$_LANG['sslstatus'] = "موقعیت گواهینامه";
$_LANG['sslawaitingconfig'] = "در انتظار پیکربندی";
$_LANG['sslconfigure'] = "پیکربندی";
$_LANG['ssldomain'] = "دامنه";
$_LANG['sslproduct'] = "ssl محصول";
$_LANG['sslrenewaldate'] = "تاریخ تمدید";
$_LANG['sslresendmail'] = "ارسال مجدد ایمیل";
$_LANG['sslinstantissuancebenefit'] = "Your order benefitted from Immediate Issuance";
$_LANG['statscreditbalance'] = "موجودی حساب شما";
$_LANG['statsdueinvoicesbalance'] = "مبلغ صورت حساب های پرداخت نشده";
$_LANG['statsnumdomains'] = "تعداد دامنه ها";
$_LANG['statsnumproducts'] = "تعداد محصولات/سرویس ها";
$_LANG['statsnumreferredsignups'] = "تعداد عضوهای معرفی شده توسط شما";
$_LANG['statsnumtickets'] = "تعداد درخواست های پشتیبانی";
$_LANG['submitticketdescription'] = "ارسال درخواست پشتیبانی";
$_LANG['supportclickheretocontact'] = "برای تماس با ما اینجا را کلیک کنید";
$_LANG['supportpresalesquestions'] = "اگر سوالهای پیش خرید دارید ";
$_LANG['supportticketinvalid'] = "خطا رخ داده است.درخواست شما یافت نشد";
$_LANG['supportticketsallowedextensions'] = "پسوند های مجاز";
$_LANG['supportticketschoosedepartment'] = "انتخاب بخش";
$_LANG['supportticketsclient'] = "کاربر";
$_LANG['supportticketsclientemail'] = " آدرس ایمیل";
$_LANG['supportticketsclientname'] = "نام";
$_LANG['supportticketsdate'] = "تاریخ";
$_LANG['supportticketsdepartment'] = "بخش";
$_LANG['supportticketsdescription'] = "مشاهده و پاسخ به درخواست فعلی";
$_LANG['supportticketserror'] = "خطا";
$_LANG['supportticketserrornoemail'] = "ایمیل خود را وارد نکرده اید";
$_LANG['supportticketserrornomessage'] = "پیام را وارد نکرده اید";
$_LANG['supportticketserrornoname'] = "نام خود را وارد نکرده اید";
$_LANG['supportticketserrornosubject'] = "موضوع را وارد نکرده اید";
$_LANG['supportticketsfilenotallowed'] = "فایلی که سعی در آپلود آن دارید مجاز نمیباشد.";
$_LANG['supportticketsheader'] = "اگر شما در بانک اطلاعاتی ما راه حلی برای مشکلتان نمیابید میتوانید با انتخاب بخش مناسب درخواست خود را ارسال کنید..";
$_LANG['supportticketsnotfound'] = "درخواست یافت نشد";
$_LANG['supportticketsopentickets'] = "درخواست باز";
$_LANG['supportticketspagetitle'] = " درخواستهای پشتیبانی";
$_LANG['supportticketsposted'] = "ارسال شد";
$_LANG['supportticketsreply'] = "پاسخ";
$_LANG['supportticketsstaff'] = "کارمندان";
$_LANG['supportticketsstatus'] = "وضعیت";
$_LANG['supportticketsstatusanswered'] = "پاسخ داده شد";
$_LANG['supportticketsstatusclosed'] = "بسته شده";
$_LANG['supportticketsstatuscloseticket'] = "بستن درخواست";
$_LANG['supportticketsstatuscustomerreply'] = "پاسخ مشتری";
$_LANG['supportticketsstatusinprogress'] = "در حال رسیدگی";
$_LANG['supportticketsstatusonhold'] = "نگه داشته شده";
$_LANG['supportticketsstatusopen'] = "در انتظار پاسخ";
$_LANG['supportticketssubject'] = "موضوع";
$_LANG['supportticketssubmitticket'] = "ارسال درخواست";
$_LANG['supportticketssystemdescription'] = "سیستم درخواست پشتیبانی به شما امکان میدهد برای نیازها و مشکلاتتان سریعا پاسخ دریافت کنید .هنگامی که به درخواست شما پاسخ بدهیم به وسیله ایمیل شما را مطلع میسازیم.";
$_LANG['supportticketsticketattachments'] = "ضمیمه ها";
$_LANG['supportticketsticketcreated'] = "درخواست ایجاد شد";
$_LANG['supportticketsticketcreateddesc'] = "درخواست شما با موفقیت ایجاد شد.ایمیلی با اطلاعات درخواست شما به ایمیلتان ارسال میشود.اگر مایل باشید میتوانید هم اکنون درخواست خود را ببینید.";
$_LANG['supportticketsticketid'] = "شناسه درخواست";
$_LANG['supportticketsticketsubject'] = "موضوع";
$_LANG['supportticketsticketsubmit'] = "ارسال";
$_LANG['supportticketsticketurgency'] = "وضعیت";
$_LANG['supportticketsticketurgencyhigh'] = "زیاد";
$_LANG['supportticketsticketurgencylow'] = "کم";
$_LANG['supportticketsticketurgencymedium'] = "متوسط";
$_LANG['supportticketsuploadfailed'] = "فایل الصاقی آپلود نشد";
$_LANG['supportticketsuploadtoolarge'] = "فایل بارگذاری شده بسیار بزرگ بود. لطفاً فایل کوچکتر را بارگذاری کنید";
$_LANG['supportticketsviewticket'] = "مشاهده تیکت";
$_LANG['supportticketclosedmsg'] = "این تیکت بسته شده است. جهت بازگشایی آن، باید پاسخی ارسال کنید.";
$_LANG['telesignincorrectpin'] = "کد اشتباه است!";
$_LANG['telesigninitiatephone'] = "ما نمی توانیم تایید شما را با تلفن انجام دهیم. لطفا به واحد پشتیبانی اطلاع دهید.";
$_LANG['telesigninvalidnumber'] = "شماره تلفن نادرست است";
$_LANG['telesigninvalidpin'] = "کدی که وارد کردید اشتباه است!";
$_LANG['telesigninvalidpin2'] = "کدی که وارد کردید معتبر نیست.";
$_LANG['telesigninvalidpinmessage'] = "کدی که وارد کردید تایید نشد.";
$_LANG['telesignmessage'] = "تایید کد شماره %s شروع شد. لطفا شکیبا باشید...";
$_LANG['telesignphonecall'] = "شماره تلفن تماس";
$_LANG['telesignpin'] = "کد خود را وارد کنید: ";
$_LANG['telesignsms'] = "پیامک";
$_LANG['telesignsmstextmessage'] = "از شما برای استفاده از سیستم تایید به وسیله پیامک متشکریم. کد شما %s است. لطفا این کد را در رایانه خود وارد فرمایید.";
$_LANG['telesigntitle'] = "تایید بوسیله تماس تلفنی.";
$_LANG['telesigntype'] = "لطفا یک شیوه تایید برای شماره %s انتخاب فرمایید:";
$_LANG['telesignverificationcanceled'] = "در حال حاضر سیستم تایید تلفنی ما با مشکل مواجه است. تایید تلفنی لغو گردید.";
$_LANG['telesignverificationproblem'] = "سیستم تایید تلفنی ما با مشکل مواجه است. خرید شما موفقیت آمیز نبود. لطفا بعدا تلاش فرمایید.";
$_LANG['telesignverify'] = "شماره تلفن شما %s نیاز به تایید دارد. سپس خرید شما ادامه خواهد یافت.";
$_LANG['ticketratingexcellent'] = "عالی";
$_LANG['ticketratingpoor'] = "ضعیف";
$_LANG['ticketratingquestion'] = "امتیاز شما به این پاسخ چند است؟";
$_LANG['ticketreatinggiven'] = "امتیاز شما با موفقیت ارسال شد.";
$_LANG['transferdomain'] = " انتقال دامنه ";
$_LANG['transferdomaindesc'] = "مایلید دامنه خود را به ما منتقل کنید؟ برای شروع این دامنه را در زیر وارد کنید";
$_LANG['transferdomainname'] = " انتقال دامنه ";
$_LANG['updatecart'] = "به روز رسانی سفارش";
$_LANG['upgradechooseconfigoptions'] = " بالا /پایین بردن درجه انتخاب های پیکربندی برای این محصول.";
$_LANG['upgradechoosepackage'] = "پلن مورد نظرتان را جهت ارتقا/تنزیل پلن فعلیتان ، از زیر انتخاب نماید .";
$_LANG['upgradecurrentconfig'] = "پیکربندی فعلی";
$_LANG['upgradedowngradeconfigoptions'] = "گزینه های ارتقا";
$_LANG['upgradenewconfig'] = "پیکربندی جدید";
$_LANG['upgradenochange'] = "بدون تغییر";
$_LANG['upgradeproductlogic'] = "هزینه بروزرسانی از اعتباری که از آن استفاده نکرده اید استفاده می شود و قسمت مالی بسته های جدید به صورت دوره ای می باشد.";
$_LANG['upgradesummary'] = "در زیر خلاصه ‏ی آپگرید سفارش شما موجود میباشد.";
$_LANG['usedefaultcontact'] = "استفاده از مشخصات پیش فرض(جزئیات بالا)";
$_LANG['varilogixfraudcall_callnow'] = " هم اکنون تماس بگیرید!";
$_LANG['varilogixfraudcall_description'] = "به عنوان بخشی از کاهش احتمال تقلب، ما با تلفن شما تماس گرفته و از شما میخواهیم تا پین کد زیر را وارد کنید.لطفا پین کد را یادداشت کرده و هرگاه آماده تماس ما بودید روی دکمه زیر کلیک کنید.";
$_LANG['varilogixfraudcall_error'] = "خطا رخ داده است و ما قادر به تماس با شما برای تایید سفارشتان نمیباشیم. لطفا برای تکمیل سفارش خود به سرعت با بخش پشتیبانی ما تماس بگیرید.";
$_LANG['varilogixfraudcall_fail'] = "تماس برای تایید سفارش شما رد شد.این ممکن است به علت اشتباه بودن شماره تلفن یا عضویت شما در لیست سیاه باشد.لطفا برای تکمیل سفارش خود به سرعت با بخش پشتیبانی ما تماس بگیرید.";
$_LANG['varilogixfraudcall_failed'] = "رد شد";
$_LANG['varilogixfraudcall_pincode'] = "پین کد";
$_LANG['varilogixfraudcall_title'] = "VariLogix FraudCall";
$_LANG['viewcart'] = "مشاهده کارت خرید";
$_LANG['welcomeback'] = "خوش آمدید";
$_LANG['whoisresults'] = "نتایج جستجو برای";
$_LANG['yes'] = "بلی";
$_LANG['yourdetails'] = "مشخصات شما";
$_LANG['user'] = "کاربر";
$_LANG['loggedInAs'] = "وارد شده به عنوان";
$_LANG['viewAllPricing'] = "مشاهده همه قیمت ها";
$_LANG['default'] = "پیش فرض";
$_LANG['maxFileSize'] = "Max file size: :fileSize";

# Version 4.1

$_LANG['clientareafiles'] = "ضمیمه فایل";
$_LANG['clientareafilesdate'] = "تاریخ افزودن";
$_LANG['clientareafilesfilename'] = "نام فایل";

$_LANG['pwreset'] = "بازیابی کلمه عبور";
$_LANG['pwresetdesc'] = "در صورتی که رمز عبورتان را فراموش کرده اید با داشتن ایمیلی که هنگام ثبت نام وارد کرده اید ( و پاسخ دادن به سوال امنیتی در صورتی که ثبت کرده اید) میتوانید رمزتان را بازیابی کنید.";
$_LANG['pwresetemailrequired'] = "شما هیچ آدرس ایمیلی وارد نکرده اید.";
$_LANG['pwresetemailnotfound'] = "هیچ اکانتی با ایمیلی که شما وارد کرده اید ثبت نشده است.";
$_LANG['pwresetsecurityquestionrequired'] = "شما در کنترل پنل خود سوال امنیتی تنظیم کرده اید. لطفا به سوال امنیتی زیر پاسخ دهید.";
$_LANG['pwresetsecurityquestionincorrect'] = "پاسخی که به سوال امنیتی داده اید با پاسخی که در اکانت شما ثبت است مطابقت ندارد.";
$_LANG['pwresetsubmit'] = "ارسال";
$_LANG['pwresetrequested'] = "درخواست بازنشانی رمز";
$_LANG['pwresetcheckemail'] = "اگر آدرس ایمیلی که وارد کرده اید با حساب موجود مطابقت دارد ، لطفاً ایمیل خود را برای دستورالعمل های بعدی بررسی کنید";
$_LANG['pwresetkeyinvalid'] = "لینک بازیابی معتبر نیست. لطفا مجددا تلاش فرمایید.";
$_LANG['pwresetkeyexpired'] = "مدت زمان فعال بودن این لینک به پایان رسیده است. لطفا مجددا تلاش فرمایید.";
$_LANG['pwresetvalidationsuccess'] = "بازیابی کلمه عبور با موفقیت انجام گرفت.";

$_LANG['overagescharges'] = "شارژ متوسط";
$_LANG['overagestotaldiskusage'] = "حجم کل اطلاعات";
$_LANG['overagestotalbwusage'] = "حجم کل پهنای باند مصرف شده";

$_LANG['affiliatescommissionspending'] = "درآمدهای در حال تایید";
$_LANG['affiliatescommissionsavailable'] = "میزان درآمدهای تایید شده";

$_LANG['configoptionqtyminmax'] = "%s دارای حداقل الزامات %s و حداکثر%s";

$_LANG['creditcardnostore'] = "اگر شما نمی خواهید اطلاعات کارت شما برای پرداخت های بعدی به صورت خودکار نزد ما بماند، این قسمت را تیک بزنید.";
$_LANG['creditcarddelete'] = "حذف اطلاعات کارت های ذخیره شده";
$_LANG['creditcarddeleteconfirmation'] = "اطلاعات ذخیره شده کارت های شما اکنون حذف گردیدند.";
$_LANG['creditcardupdatenotpossible'] = "اطلاعات کارت هم اکنون قابل به روز رسانی نیست. لطفا بعدا تلاش فرمایید.";

$_LANG['invoicepaymentsuccessconfirmation'] = "از شما متشکریم! پرداخت شما موفقیت آمیز بود!";
$_LANG['invoicepaymentfailedconfirmation'] = "متاسفانه پرداخت شما با موفقیت انجام نشد. لطفا مجددا تلاش کنید یا با واحد پشتیبانی مشکل را مطرح فرمایید.";

# Version 4.2

$_LANG['promoappliedbutnodiscount'] = "کد تخفیفی  که وارد کرده اید بر روی سبد خرید شما اعمال شده است اما هنوز هیچ موردی مشمول تخفیف نمی شود - لطفاً شرایط تخفیف را بررسی کنید";

$_LANG['upgradeerroroverdueinvoice'] = "در حال حاضر نمی توانید این محصول را ارتقاء یا تنزل دهید زیرا قبلاً یک فاکتور برای تمدید بعدی ایجاد شده است<br /><br />برای ادامه ، لطفاً ابتدا فاکتور پرداخت نشده خود  را پرداخت کنید و سپس بلافاصله پس از آن می توانید ارتقاء یا تنزل دهید و مابه التفاوت آن را از شما کسر کرده یا به صورت مناسب اعتبار دهید";
$_LANG['upgradeexistingupgradeinvoice'] = "شما در حال حاضر نمی توانید این محصول را ارتقاء یا تنزل دهید زیرا ارتقاء یا تنزل در حال انجام است<br /><br />برای ادامه ، لطفاً ابتدا فاکتور پرداخت نشده  را پرداخت کنید و سپس بلافاصله پس از آن می توانید ارتقاء یا تنزل دهید و مابه التفاوت آن را از شما کسر کرده یا به صورت مناسب اعتبار دهید<br/><br/>اگر فکر می کنید این پیام را به اشتباه دریافت کرده اید ، لطفاً یک تیکت مشکل ارسال کنید";

$_LANG['subaccountactivate'] = "فعال نمودن حساب فرعی";
$_LANG['subaccountactivatedesc'] = "تنظیم به عنوان یک حساب فرعی با اجازه ورود به پنل کاربری";
$_LANG['subaccountpermissions'] = "مجوزهای حساب فرعی";
$_LANG['subaccountpermsprofile'] = "ویرایش نمایه ی حساب اصلی";
$_LANG['subaccountpermscontacts'] = "مشاهده و مدیریت تماسها";
$_LANG['subaccountpermsproducts'] = "مشاهده محصولات و سرویس ها";
$_LANG['subaccountpermsmanageproducts'] = "مشاهده و تغییر رمز عبور مخصولات";
$_LANG['subaccountpermsdomains'] = "مشاهده دامنه ها";
$_LANG['subaccountpermsmanagedomains'] = "مدیریت تنظیمات دامنه";
$_LANG['subaccountpermsinvoices'] = "مشاهده و پرداخت صورت حساب ها";
$_LANG['subaccountpermstickets'] = "مشاهده و بازنمودن درخواست پشتیبانی";
$_LANG['subaccountpermsaffiliates'] = "مشاهده و مدیریت حساب ";
$_LANG['subaccountpermsemails'] = "مشاهده ایمیل ها";
$_LANG['subaccountpermsorders'] = "سفارش جدید/ارتقا ها / انصراف ها";
$_LANG['subaccountpermissiondenied'] = "شما مجوز لازم جهت دسترسی به این صفحه را ندارید";
$_LANG['subaccountallowedperms'] = "مجوزهای دسترسی شما عبارتند از :";
$_LANG['subaccountcontactmaster'] = "در صورتی که احساس میکنید اشتباهی صورت گرفته است با صاحب حساب اصلی تماس بگیرید.";
$_LANG['subaccountSsoDenied'] = " Single Sign-On اجازه ورود به سیستم با استفاده از";

$_LANG['knowledgebasealsoread'] = "در همین زمینه";

$_LANG['orderpaymenttermtriennially'] = "سه سالانه";
$_LANG['orderpaymentterm36month'] = "قیمت سه ساله";

$_LANG['domainrenewals'] = " تمدید دامنه ";
$_LANG['domaindaysuntilexpiry'] = "روزهای باقیمانده تا انقضا";
$_LANG['domainrenewalsnoneavailable'] = "هیچ دامنه قابل تمدیدی در حساب شما نیست.";
$_LANG['domainrenewalspastgraceperiod'] = "دوره قابل تمدید گذشته";
$_LANG['domainrenewalsingraceperiod'] = "آخرین شانس تمدید!";
$_LANG['domainrenewalsdays'] = "روز";
$_LANG['domainrenewalsdaysago'] = "روز پیش";

$_LANG['invoicespartialpayments'] = "پرداخت جزء";
$_LANG['invoicestotaldue'] = "قابل پرداخت";

$_LANG['masspaytitle'] = "پرداخت انبوه";
$_LANG['masspaydescription'] = "در ذیل خلاصه ای از صورت حساب ها و مبالغ قابل پرداخت آنها جهت پرداخت مشاهده میکنید.برای پرداخت لطفا روش پرداخت مورد نظرتان را انتخاب کنید و پرداخت را انجام دهید.";
$_LANG['masspayselected'] = "پرداخت موارد انتخابی";
$_LANG['masspayall'] = "پرداخت همه";
$_LANG['masspaymakepayment'] = "پرداخت";

# Version 4.3

$_LANG['searchenterdomain'] = "دامنه ای جهت جستجو وارد کنید";
$_LANG['searchfilter'] = "فیلتر";

$_LANG['suspendreason'] = "دلیل تعلیق";
$_LANG['suspendreasonoverdue'] = "عدم پرداخت در سررسید";

$_LANG['vpsnetmanagement'] = "مدیریت VPS";
$_LANG['vpsnetpowermanagement'] = "مدیریت Power";
$_LANG['poweron'] = "روشن کردن";
$_LANG['poweroffforced'] = "خاموش کردن (اجباری)";
$_LANG['powerreboot'] = "ریبوت";
$_LANG['powershutdown'] = "خاموش کردن";
$_LANG['vpsnetcpugraphs'] = "نمودار های CPU";
$_LANG['vpsnetnetworkgraphs'] = "نمودار های شبکه";
$_LANG['vpsnethourly'] = "ساعتی";
$_LANG['vpsnetdaily'] = "روزانه";
$_LANG['vpsnetweekly'] = "هفتگی";
$_LANG['vpsnetmonthly'] = "ماهانه";
$_LANG['view'] = "نمایش";
$_LANG['vpsnetbackups'] = "گزینه های پشتیبان";
$_LANG['vpsnetgenbackup'] = "ایجاد پشتیبان";
$_LANG['vpsnetrestorebackup'] = "بازیابی پشتیبان";
$_LANG['vpsnetrestorebackupwarning'] = "بازیابی نسخه پشتیبان ، وی پی اس شما را رو نویسی میکند";
$_LANG['vpsnetnobackups'] = "نسخه پشتیبانی وجود ندارد";
$_LANG['vpsnetrunning'] = "در حال اجرا";
$_LANG['vpsnetnotrunning'] = "عدم اجرا";
$_LANG['vpsnetpowercycling'] = "Power is cycling";
$_LANG['vpsnetcloud'] = "کلود";
$_LANG['vpsnettemplate'] = "قالب";
$_LANG['vpsnetstatus'] = "وضعیت سیستم";
$_LANG['vpsnetbwusage'] = "کارکرد پهنای باند";

$_LANG['twitterlatesttweets'] = "آخرین تویت های ما";
$_LANG['twitterfollow'] = "ما را در تویتر دنبال کنید";
$_LANG['twitterfollowus'] = "ما را دنبال کنید";
$_LANG['twitterfollowuswhy'] = "برای اینکه همواره از آخرین اخبار و پیشنهاد های ما مطلع باشید";

$_LANG['chatlivehelp'] = "راهنمای زنده";

$_LANG['domainrelease'] = "آزاد سازی دامنه";
$_LANG['domainreleasedescription'] = "جدید وارد کنید تا نام دامنه خود را به ثبت کننده دیگری منتقل کنیدTAGدر اینجا یک";
$_LANG['domainreleasetag'] = "تگ ثبت کننده جدید";

# Ajax Order Form

$_LANG['orderformtitle'] = "فرم سفارش";

$_LANG['signup'] = "ثبت نام";
$_LANG['loading'] = "بارگذاری ... ";

$_LANG['cartchooseproduct'] = "انتخاب محصول";
$_LANG['cartconfigurationoptions'] = "انتخاب های قابل تنظیم";

$_LANG['ordererrorsoccurred'] = "خطاهای زیر رخ داد و جهت تکمیل سفارش باید تصحیح شوند:";
$_LANG['ordererrortermsofservice'] = "با شرایط خدمات باید موافقت شود.";
$_LANG['ordertostickconfirm'] = "لطفا علامت گذاری کنید جهت تایید اینکه شما موافقید با";

$_LANG['cartnewcustomer'] = "مشتری جدید هستم";
$_LANG['cartexistingcustomer'] = "قبلا ثبت نام کرده ام و مشتری قبلی میباشم";

$_LANG['cartpromo'] = "تخفیف";
$_LANG['cartenterpromo'] = "کد تخفیف را وارد کنید";
$_LANG['cartremovepromo'] = "حذف تخفیف";

$_LANG['cartrecurringcharges'] = "هزینه های دوره ای";

$_LANG['cartenterdomain'] = "لطفا دامنه را که مایل به استفاده هستید در ادامه وارد نمایید.";

$_LANG['cartdomainavailableoptions'] = "تبریک ، این دامنه آزاد است!";
$_LANG['cartdomainavailableregister'] = "لطفا این دامنه را ثبت کنید برای";
$_LANG['cartdomainavailablemanual'] = "این دامنه را جداگانه ثبت خواهم کرد";

$_LANG['cartdomainunavailableoptions'] = "متاسفانه این دامنه قبلا ثبت شده است. اگر شما مالک آن هستید ، یکی از گزینه های زیر را انتخاب نمایید...";
$_LANG['cartdomainunavailabletransfer'] = "لطفا دامنه‏ی من را منتقل کنید برای";
$_LANG['cartdomainunavailablemanual'] = "من مالک این دامنه هستم و خودم تنظیمات DNS را اعمال خواهم کرد";

$_LANG['cartdomaininvalid'] = "دامنه‏ی وارد شده صحیح نمیباشد. لطفا فقط بخش بعد از www را به علاوه‏ی پسوند مورد نظرتان وارد کنید";

# Version 4.4

$_LANG['dlinvalidlink'] = "پیوند اشتباهی دنبال شده است. لطفا با مدیریت تماس بگیرید.";

$_LANG['domaindnsmanagementlaunch'] = "باز نمودن مدیریت DNS";
$_LANG['domainemailforwardinglaunch'] = "باز نمودن Mail Forwarding Manager";

# Version 4.5

$_LANG['domaindnspriority'] = "اولویت";
$_LANG['domaindnsmxonly'] = "ضبط اولویت فقط برای MX";

$_LANG['orderpromoprestart'] = "این فروش ویژه هنوز شروع نشده است. لطفا بعدا تلاش کنید.";

$_LANG['ticketmerge'] = "ادغام شدند";

$_LANG['quote'] = "مظنه";
$_LANG['quotestitle'] = "مظنه ها";
$_LANG['quoteview'] = "مشاهده";
$_LANG['quotedownload'] = "مشاهده/دانلود";
$_LANG['quoteacceptbtn'] = "قبول مظنه";
$_LANG['quotedlpdfbtn'] = "دانلود PDF";
$_LANG['quotediscountheading'] = "تخفیف (%)";
$_LANG['noquotes'] = "در حال حاضر مظنه ای در حساب شما ذخیره نشده است.برای درخواست مظنه درخواست خود را از طریق تیکت ارسال کنید.";
$_LANG['quotenumber'] = "مظنه #";
$_LANG['quotesubject'] = "موضوع";
$_LANG['quotedatecreated'] = "تاریخ ایجاد";
$_LANG['quotevaliduntil'] = "تاریخ اعتبار";
$_LANG['quotestage'] = "مرحله";
$_LANG['quoterecipient'] = "گیرنده";
$_LANG['quoteqty'] = "تعداد";
$_LANG['quotedesc'] = "توصیف";
$_LANG['quoteunitprice'] = "قیمت واحد";
$_LANG['quotediscount'] = "تخفیف %";
$_LANG['quotelinetotal'] = "مجموع";
$_LANG['quotestagedraft'] = "پیش نویس";
$_LANG['quotestagedelivered'] = "تحویل";
$_LANG['quotestageonhold'] = "در انتظار";
$_LANG['quotestageaccepted'] = "پذیرفته";
$_LANG['quotestagelost'] = "مفقود";
$_LANG['quotestagedead'] = "کهنه";
$_LANG['quoteref'] = "مظنه مجدد #";
$_LANG['quotedeposit'] = "سپرده";
$_LANG['quotefinalpayment'] = "مانده از سپرده";

$_LANG['invoiceoneoffpayment'] = "پرداخت انبوه";
$_LANG['invoicesubscriptionpayment'] = "ایجاد اشتراک خودکار مکرر";

$_LANG['invoicepaymentpendingreview'] = "متشکرم! پرداخت شما با موفقیت انجام شد و به محض اتمام فرآیند بازبینی  ، در صورتحساب شما اعمال می شود\n\nاین کار ممکن است چند ساعت طول بکشد ، بنابراین از صبر شما قدردانی می شود.";

$_LANG['step'] = "مرحله %s";
$_LANG['cartdomainexists'] = "این دامنه در سیستم ما وجود دارد بنابراین مجددا قابل سفارش نیست";
$_LANG['cartcongratsdomainavailable'] = "تبریک, %s موجود است!";
$_LANG['cartregisterhowlong'] = "برای چند سال آن را ثبت میکنید ؟";
$_LANG['cartdomaintaken'] = "متاسفیم, %s قبلا ثبت شده است.";
$_LANG['carttransfernotregistered'] = "%s تا کنون ثبت نشده است.";
$_LANG['carttransferpossible'] = "تبریک, ما میتوانیم %s را فقط با مبلغ %s منتقل کنیم";
$_LANG['cartotherdomainsuggestions'] = "دامنه های دیگری که احتمالا به آن علاقمندید...";
$_LANG['cartdomainsconfiginfo'] = "اختیارات و تنظیمات زیر برای دامنه های انتخابی شما موجود است.گزینه های اجباری با * مشخص شده اند.";
$_LANG['cartnameserverchoice'] = "انتخاب NameServer";
$_LANG['cartnameserverchoicedefault'] = "استفاده از NameServer پیش فرض برای میزبانی توسط ما";
$_LANG['cartnameserverchoicecustom'] = "استفاده از NameServer انتخابی";
$_LANG['cartfollowingaddonsavailable'] = "این افزونه ها برای محصولات و سرویس های فعال شما موجود میباشد.";
$_LANG['cartregisterdomainchoice'] = "ثبت دامنه جدید";
$_LANG['carttransferdomainchoice'] = "انتقال دامنه از شرکت دیگر";
$_LANG['cartexistingdomainchoice'] = "از دامنه ای که قبلا ثبت کرده ام استفاده میکنم";
$_LANG['cartsubdomainchoice'] = "استفاده از زیر دامنه ای از %s";
$_LANG['carterrordomainconfigskipped'] = "باید برگردی د و فیلدهای تنظیمات مورد نیاز دامنه که در بالا آمده است را تکمیل کنید";
$_LANG['cartproductchooseoptions'] = "انتخاب گزینه ها";
$_LANG['cartproductselection'] = "انتخاب محصول";
$_LANG['cartreviewcheckout'] = "مرور و پرداخت نهایی";
$_LANG['cartchoosecycle'] = "دوره ی پرداخت را انتخاب کنید";
$_LANG['cartavailableaddons'] = "افزونه های موجود";
$_LANG['cartsetupfees'] = "هزینه ستاپ";
$_LANG['cartchooseanotherproduct'] = "انتخاب محصولی دیگر";
$_LANG['cartaddandcheckout'] = "افزودن به کارت و پرداخت نهایی";
$_LANG['cartchooseanothercategory'] = "انتخاب گروه دیگر";
$_LANG['carttryanotherdomain'] = "دامنه دیگر را امتحان کنید";
$_LANG['cartmakedomainselection'] = "لطفا با انتخاب یکی از گزینه های زیر ، دامنه ای را که میخواهید با سرویس ما میزبانی کنید مشخص کنید.";
$_LANG['cartfraudcheck'] = "بررسی تقلب";
$_LANG['cartapifailedtoloadcart'] = "The system could not load the requested cart. <strong><a href=\"cart.php\">Click here</a></strong> to start a new order.";

$_LANG['newcustomer'] = "مشتری جدید";
$_LANG['existingcustomer'] = "مشتری قبلی";
$_LANG['newcustomersignup'] = "<strong>هنوز ثبت نام نکرده اید؟</strong> %sجهت ثبت نام کلیک کنید...%s";

$_LANG['upgradeonselectedoptions'] = "(روی گزینه های انتخابی)";
$_LANG['recurringpromodesc'] = "این کد تبلیغاتی همچنین شامل  %s تخفیف مکرر (این تخفیف برای تمدید قیمت کل محصول در آینده اعمال می شود)";

# Version 4.5.2

$_LANG['ajaxcartcheckout'] = "رفتن مستقیما به پرداخت نهایی »";
$_LANG['ajaxcartconfigreqnotice'] = "شما در حال ثبت نام هستید ، ولی قبل از آن باید دامنه را انتخاب کنید تا بتوانید محصول انتخابی را به کارت خود اضافه کنید...";

# Version 5.0.0

$_LANG['cancelrequestdomain'] = "تمدید دامنه لغو گردد ؟";
$_LANG['cancelrequestdomaindesc'] = "شما همچنین یک دامنه فعال برای دامنه مرتبط با این محصول دارید<br />این دامنه باید تمدید شود %s به قیمت %s برای %s سال%/s<br /><br />اگر می خواهید دامنه را نیز لغو کنید و اجازه دهید در پایان ثبت نام فعلی منقضی شود ، به سادگی کادر زیر را علامت بزنید";
$_LANG['cancelrequestdomainconfirm'] = "من تایید میکنم که مایل به تمدید مجدد این دامنه نیستم";

$_LANG['startingfrom'] = "شروع از";

$_LANG['orderpromopriceoverride'] = "نادیده گرفتن قیمت";
$_LANG['orderpromofreesetup'] = "ستاپ رایگان";

$_LANG['thereisaproblem'] = "اووپس...مشکلی پیش آمده";
$_LANG['problemgoback'] = "بازگشت به عقب و تلاش مجدد";

$_LANG['quantity'] = "موجودی";
$_LANG['cartqtyenterquantity'] = "بیش از یکی از این مورد میخواهید؟ تعداد مورد نیاز را اینجا وارد کنید:";
$_LANG['cartqtyupdate'] = "به روز رسانی";
$_LANG['invoiceqtyeach'] = "/هر عدد";

$_LANG['nschoicedefault'] = "استفاده از NameServer پیش فرض";
$_LANG['nschoicecustom'] = "استفاده از NameServer انتخابی (وارد کنید)";

$_LANG['jumpto'] = "پرش به";
$_LANG['top'] = "بالا";

$_LANG['domaincontactusexisting'] = "استفاده از اطلاعات حساب فعلی";
$_LANG['domaincontactusecustom'] = "مشخص نمودن اطلاعات سفارشی ";
$_LANG['domaincontactchoose'] = "انتخاب تماس";
$_LANG['domaincontactprimary'] = "اطلاعات نمایه ی اصلی";

$_LANG['invoicepdfgenerated'] = "PDF ایجاد شده است در";

$_LANG['domainrenewalsbeforerenewlimit'] = "حداقل تمدید پیشین است %s Days";

$_LANG['promonewsignupsonly'] = "این کد تخفیف تنها برای کاربران جدید قابل استفاده است";

# Bulk Domain Management

$_LANG['domainbulkmanagement'] = "مدیریت دسته جمعی";
$_LANG['domainbulkmanagementchangesaffect'] = "این تغییرات بر روی دامنه های زیر اعمال خواهد شد:";
$_LANG['domainbulkmanagementchangeaffect'] = "این تغییر بر روی دامنه های زیر اعمال خواهد شد:";
$_LANG['domaincannotbemanaged'] = "متاسفانه امکان مدیریت خودکار فراهم نیست. لطفا تغییرات مورد نظر را به بخش پشتیبانی اطلاع دهید";
$_LANG['domainbulkmanagementnotpossible'] = "متاسفانه در حال حاظر ویرایش این تنظیمات از طریق بخش کاربری غیر قابل انجام است. لطفا تغییرات مورد نظر را به بخش پشتیبانی اطلاع دهید";

$_LANG['domainmanagens'] = "مدیریت NameServer ها";

$_LANG['domainautorenewstatus'] = "وضعیت تمدید خودکار";
$_LANG['domainautorenewinfo'] = "تمدید خودکار در حفظ دامنه شما مفید است. وقتی که فعال باشد ما مدتی قبل از انقضای دامنه صورت حسابی برای تمدید آن ارسال میکنیم و پس از پرداخت دامنه شما تمدید میشود.";
$_LANG['domainautorenewrecommend'] = "ما پیشنهاد میکنیم تمدید خودکار را فعال نگه دارید تا از، از دست دادن دامنه جلوگیری کنید.";

$_LANG['domainreglockstatus'] = "وضعیت قفل ثبت";
$_LANG['domainreglockinfo'] = "قفل رجیسترار که به Theft Protection نیز نامیده میشود از دامنه شما در برابر انتقال بدون اجازه محافظت میکند.";
$_LANG['domainreglockrecommend'] = "ما پیشنهاد میکنیم که همیشه این مورد را فعال نگه دارید مگر اینکه قصد داشته باشید دامنهتان را منتقل کنید.";
$_LANG['domainreglockenable'] = "فعال کردن قفل ثبت";
$_LANG['domainreglockdisable'] = "غیر فعال کردن قفل ثبت";

$_LANG['domaincontactinfoedit'] = "ویرایش اطلاعات تماس";

$_LANG['domainmassrenew'] = "تمدید دامنه ها";

# reCAPTCHA

$_LANG['captchatitle'] = "مقابله با روبات اسپم";
$_LANG['captchaverify'] = "لطفا کارکترهایی که در عکس زیر مشاهده میکنید را وارد کنید . این مورد برای جلوگیری از ارسال های خودکار میباشد.";
$_LANG['captchaverifyincorrect'] = "کاراکترهایی که شما وارد کرده اید با عکس نمایش داده شده همخوانی ندارد. لطفا مجددا تلاش کنید.";
$_LANG['googleRecaptchaIncorrect'] = "لطفا کد امنیتی را تکمیل و مجدد اقدام کنید";
$_LANG['recaptcha-invalid-site-private-key'] = "خطایی رخ داد. لطفا با بخش پشتیبانی تماس بگیرید. (کد خطا : cap1)";
$_LANG['recaptcha-invalid-request-cookie'] = "خطایی رخ داد. لطفا مجددا تلاش کنید. (کد خطا : cap2)";
$_LANG['recaptcha-incorrect-captcha-sol'] = "کاراکترهای ورودی با کلمه ی تایید مطابقت ندارد . لطفا مجددا امتحان کنید.";

# Product Bundles

$_LANG['bundledeal'] = "معامله بسته نرم افزاری!";
$_LANG['bundlevaliddateserror'] = "بسته نرم افزاری موجود نیست";
$_LANG['bundlevaliddateserrordesc'] = "این بسته نرم افزاری موجود نیست و یا منقضی شده است.اگر تصور میکنید اشتباهی رخ داده است، لطفا با بخش پشتیبانی ارتباط برقرار کنید.";
$_LANG['bundlemaxusesreached'] = "بسته نرم افزاری موجود نیست";
$_LANG['bundlemaxusesreacheddesc'] = "این بسته نرم افزاری به حداکثر تعداد استفاده مجاز رسیده است و متاسفانه دیگر در دسترس نیست.اگر شما علاقه مند به خدمات ما هستید لطفا از طریق بخش پشتیبانی با ما در تماس باشید";
$_LANG['bundlereqsnotmet'] = "بسته نرم افزاری مورد نیاز من نیست";
$_LANG['bundlewarningpromo'] = "بسته انتخاب شده نمی تواند همراه با تخفیفات یا پیشنهادات دیگر استفاده شود";
$_LANG['bundlewarningproductcycle'] = "بسته انتخاب شده نیاز به انتخاب چرخه صورتحساب دارد '%s' برای محصول %s واجد شرایط بودن";
$_LANG['bundlewarningproductconfopreq'] = "بسته انتخاب شده نیاز به انتخاب شما دارد'%s' برای '%s 'به منظور واجد شرایط بودن";
$_LANG['bundlewarningproductconfopyesnoenable'] = "بسته انتخاب شده باید گزینه را فعال کنید '%s'به منظور واجد شرایط بودن";
$_LANG['bundlewarningproductconfopyesnodisable'] = "بسته انتخاب شده نیاز به حذف انتخاب گزینه دارد '%s 'به منظور واجد شرایط بودن ";
$_LANG['bundlewarningproductconfopqtyreq'] = "The selected bundle requires you choose a quantity of '%s' for '%s' in order to qualify";
$_LANG['bundlewarningproductaddonreq'] = "The selected bundle requires you select the addon '%s' for product %s to qualify";
$_LANG['bundlewarningdomainreq'] = "The selected bundle requires you register or transfer a domain with the product %s to qualify";
$_LANG['bundlewarningdomaintld'] = "The selected bundle requires you choose a domain with the extension(s) '%s' for domain %s to qualify";
$_LANG['bundlewarningdomainregperiod'] = "The selected bundle requires you select the registration period '%s' for domain %s to qualify";
$_LANG['bundlewarningdomainaddon'] = "The selected bundle requires you select the addon '%s' for domain %s to qualify";

# New Client Area Template  Lines

$_LANG['navservices'] = "سرویس ها";
$_LANG['navservicesorder'] = "سفارش سرویس جدید";
$_LANG['navservicesplaceorder'] = "سفارش سرویس جدید";
$_LANG['navdomains'] = "دامنه ها";
$_LANG['navrenewdomains'] = "تمدید دامنه ها";
$_LANG['navregisterdomain'] = "ثبت دامنه جدید";
$_LANG['navtransferdomain'] = "انتقال دامنه به ما";
$_LANG['navdomainsearch'] = "جستجوی دامنه";
$_LANG['navbilling'] = "مالی";
$_LANG['navinvoices'] = "صورت حساب ها";
$_LANG['navsupport'] = "پشتیبانی";
$_LANG['navtickets'] = "تیکت ها";
$_LANG['navopenticket'] = "ارسال تیکت پشتیبانی";
$_LANG['navmanagecc'] = "مدیریت کردیت کارت";
$_LANG['navemailssent'] = "تاریخچه ایمیل";

$_LANG['hello'] = "سلام";
$_LANG['helloname'] = "سلام, %s!";
$_LANG['account'] = "حساب";
$_LANG['login'] = "ورود";
$_LANG['register'] = "ثبت نام";
$_LANG['forgotpw'] = "رمز عبور را فراموش کرده اید؟";

$_LANG['clientareanavccdetails'] = "مشخصات کارت اعتباری";

$_LANG['manageyouraccount'] = "حسابتان را مدیریت کنید";
$_LANG['accountoverview'] = "آمار کلی";
$_LANG['paymentmethod'] = "روش پرداخت";
$_LANG['paymentmethoddefault'] = "پیش فرض (تنظیم در هر خرید)";
$_LANG['productmanagementactions'] = "عملیات مدیریتی";
$_LANG['clientareanoaddons'] = "تاکنون افزونه ای خریداری نشده است";
$_LANG['downloadssearch'] = "جستجوی دانلودها";
$_LANG['emailviewmessage'] = "مشاهده پیام";
$_LANG['resultsperpage'] = "نتیجه در صفحه";
$_LANG['accessdenied'] = "دسترسی غیر مجاز";
$_LANG['search'] = "جستجو";
$_LANG['cancel'] = "لغو";
$_LANG['clientareabacklink'] = "« برگشت";
$_LANG['backtoserviceslist'] = "« برگشت به لیست سرویس ها";
$_LANG['backtodomainslist'] = "« برگشت به لیست دامنه ها";
$_LANG['copy'] = "Copy";

$_LANG['clientareahomeorder'] = "برای مشاهده سرویس ها و محصولات ما فرم سفارش را مشاهده نمایید.همچنین مشتریان فعلی میتوانند افزونه ها و سرویس های ویژه را از اینجا سفارش دهند.";
$_LANG['clientareahomelogin'] = "آیا درحال حاضر نزد ما ثبت نام کرده اید؟ اگر اینطور است برای ورود به بخش کاربران بر روی دکمه زیر کلیک کنید تا بتوانید حساب و سرویس های خود را مدیریت کنید.";
$_LANG['clientareahomeorderbtn'] = "مشاهده فرم سفارش";
$_LANG['clientareahomeloginbtn'] = "ورود به ناحیه کاربری";

$_LANG['clientareaproductsintro'] = "لیست تمام سرویس هایی که از ما خریداری کرده اید.";
$_LANG['clientareaproductdetailsintro'] = "در اینجا خلاصه ای از سرویس ها و محصولاتی که نزد ما دارید را مشاهده میکنید";
$_LANG['clientareadomainsintro'] = "دامنه های خود را میتوانید از این بخش مدیریت کنید";
$_LANG['quotesintro'] = "اینجا تمام مظنه هایی که برای شما ارسال شده است را مشاهده میکنید.";
$_LANG['emailstagline'] = "یک نسخه از آخرین ایمیل هایی که به شما ارسال کرده ایم را اینجا مشاهده میکنید ...";
$_LANG['supportticketsintro'] = "هر سوالی دارید در اینجا از ما بپرسید و پیگیری کنید...";
$_LANG['addfundsintro'] = "حسابتان را به صورت حرفه ای مدیریت کنید";
$_LANG['registerintro'] = "لطفا فرم ثبت نام را با حروف انگلیسی پر نمایید";
$_LANG['networkstatusintro'] = "اطلاعات وضعیت سرویس ها و اخبار شبکه";

$_LANG['creditcardyourinfo'] = "اطلاعات مالی";
$_LANG['ourlatestnews'] = "آخرین اخبار ما";
$_LANG['ccexpiringsoon'] = "کارت اعتباری به زودی باطل خواهد شد";
$_LANG['ccexpiringsoondesc'] = "کارت اعتباری شما به زودی منقضی میشود بنابراین هر زمان توانستید، %sاطلاعات جدید را در سایت بروز رسانی%s کنید";
$_LANG['availcreditbal'] = "میزان اعتبار موجود";
$_LANG['availcreditbaldesc'] = "شما موجودی به مبلغ %s در حسابتان دارید و این مبلغ به صورت خودکار برای پرداخت صورتحساب های صادره استفاده میشود";
$_LANG['youhaveoverdueinvoices'] = "شما %s صورتحساب پرداخت نشده دارید که سررسید پرداخت آن گذشته است";
$_LANG['overdueinvoicesdesc'] = "برای جلوگیری از بروز وقفه در ارائه خدمات ، لطفا صورت حساب های پرداخت نشده را هرچه سریعتر پرداخت کنید. %sپرداخت »%s";
$_LANG['supportticketsnoneopen'] = "هیچ درخواست پشتیبانی فعال ندارید";
$_LANG['invoicesnoneunpaid'] = "در حال حاضر صورتحساب پرداخت نشده ای وجود ندارد";

$_LANG['registerdisablednotice'] = "لطفا یک سفارش برای ثبت ارسال کنید.";
$_LANG['registerCreateAccount'] = "جهت ایجاد اکانت،لطفا";
$_LANG['registerCreateAccountOrder'] = "ارسال سفارش نزد ما";

$_LANG['pwstrength'] = "امنیت رمز عبور";
$_LANG['pwstrengthenter'] = "رمزی وارد کنید";
$_LANG['pwstrengthweak'] = "ضعیف";
$_LANG['pwstrengthmoderate'] = "متعادل";
$_LANG['pwstrengthstrong'] = "قوی";
$_LANG['pwstrengthrating'] = "امتیاز رمز عبور جدید";

$_LANG['managing'] = "مدیریت";
$_LANG['information'] = "اطلاعات";
$_LANG['withselected'] = "با موارد انتخابی";
$_LANG['managedomain'] = "مدیریت دامنه";
$_LANG['changenameservers'] = "تغییر NameServer";
$_LANG['clientareadomainmanagedns'] = "مدیریت DNS";
$_LANG['clientareadomainmanageemailfwds'] = "مدیریت انتقال ایمیل";
$_LANG['moduleactionsuccess'] = "عملیات با موفقیت انجام شد!";
$_LANG['moduleactionfailed'] = "عملیات ناموفق";

$_LANG['domaininfoexp'] = "اینجا میتوانید جزئیات دامنه تان را مشاهده کنید. میتوانید دامنه تان را از گزینه های تب بالا مدیریت کنید.";
$_LANG['domainrenewexp'] = "تمدید خودکار را فعال کنید تا ما قبل از انقضای دامنه به صورت خودکار صورتحساب تمدید آن را برایتان ارسال کنیم.";
$_LANG['domainnsexp'] = "در نظر داشته باشید تغییرات ممکن است تا 24 ساعت طول بکشد تا در همه جا منتشر شود.";
$_LANG['domainlockingexp'] = "دامنهتان را قفل کنید تا از انتقال آن به سرویس دهنده های دیگر بدون اجازه شما جلوگیری شود.";
$_LANG['domaincurrentlyunlocked'] = "دامنه در حال حاضر قفل نمیباشد.";
$_LANG['domaincurrentlyunlockedexp'] = "بهتر است همیشه قفل رجیسترار فعال باشد مگر اینکه قصد داشته باشید دامنه را به سرویس دهنده یا شخص دیگری منتقل کنید.";
$_LANG['searchmultipletlds'] = "جستجوی همزمان چندین پسوند";

$_LANG['networkstatustitle'] = "وضعیت شبکه";
$_LANG['networkstatusnone'] = "هم اکنون مشکل %s شبکه وجود ندارد";
$_LANG['serverstatusheadingtext'] = "جدول زیر وضعیت سرور ما را نشان میدهد. شما میتوانید در صورت قطع بودن سرویسی آن را چک کنید .";

$_LANG['clientareacancelreasonrequired'] = "لطفا دلیل لغو این سرویس را ذکر کنید.";

$_LANG['addfundsdescription'] = "حسابتان را شارژ کنید تا از انبوهی از تراکنش های کوچک در صورتحساب بانکیتان جلوگیری کنید و بتوانید صورت حساب های صادره را براحتی یا خودکار پرداخت نمایید.";
$_LANG['addfundsnonrefundable'] = "* مبلغ شارژ به سادگی قابل برگشت نخواهد بود";

$_LANG['creditcardexpirydateinvalid'] = "تاریخ انقضا باید به فرمت MM/YY وارد شود و از آن نگذشته باشد.";

$_LANG['domaincheckerchoosedomain'] = "یک دامنه انتخاب کنید...";
$_LANG['domaincheckerchecknewdomain'] = "جستجو برای دامنه جدید";
$_LANG['domaincheckerdomainexample'] = " برای مثال example.com";
$_LANG['domaincheckerhostingonly'] = "فقط سفارش هاست";
$_LANG['domaincheckerenterdomain'] = "میزبانی سایتتان را با ما تجربه کنید. کافیست نام دامنه ای که مایل به ثبت یا انتقال هستید وارد کنید یا فقط سرویس هاستینگ سفارش دهید...";

$_LANG['kbquestionsearchere'] = "سوالی دارید ؟ از اینجا پاسختان را بیابید";
$_LANG['contactus'] = "تماس با ما";

$_LANG['opennewticket'] = "درخواست جدید";
$_LANG['searchtickets'] = "شماره یا موضوع درخواست را وارد کنید";
$_LANG['supportticketspriority'] = "اولویت";
$_LANG['supportticketsubmitted'] = "ارسال شده";
$_LANG['supportticketscontact'] = "تماس";
$_LANG['supportticketsticketlastupdated'] = "آخرین به روز رسانی";

$_LANG['upgradedowngradepackage'] = "ارتقا/تنزیل";
$_LANG['upgradedowngradechooseproduct'] = "محصول را انتخاب کنید";

$_LANG['jobtitlereqforcompany'] = "(الزامی در صورتی که نام شرکت ثبت شده باشد)";

$_LANG['downloadproductrequired'] = "شما باید یک سفارش فعال برای محصولات یا سرویس های زیر داشته باشید تا بتوانید این آیتم را دانلود کنید :";

$_LANG['affiliatesignuptitle'] = "با ارجاء مشتریان به ما کسب درآمد کنید";
$_LANG['affiliatesignupintro'] = "حساب بازاریابی خود را فعال کنید و از همین الان شروع به پول در آوردن کنید...";
$_LANG['affiliatesignupinfo1'] = "ما بابت هر ثبت نامی که از لینک ثبت نام ویژه شما آمده باشد به شما پرداخت داریم.";
$_LANG['affiliatesignupinfo2'] = "ما مشتریانی را که شما معرفی میکنید با کوکی ها شناسایی میکنیم.بنابراین کاربرانی که شما معرفی میکنید نیاز نیست که همان موقع خرید کنند تا شما کمیسیونتان را دریافت کنید.کوکی ها تا 90 روز پس از اولین بازدید کاربر باقی میمانند.";
$_LANG['affiliatesignupinfo3'] = "در صورت نیاز به اطلاعات بیشتر با ما تماس بگیرید.";

# Version 5.1

$_LANG['copyright'] = "کپی رایت";
$_LANG['allrightsreserved'] = "تمام حقوق محفوظ است";
$_LANG['supportticketsclose'] = "بستن درخواست";
$_LANG['affiliatesinitialthen'] = "در ابتدا پس از آن";
$_LANG['invoicesoutstandingbalance'] = "میزان واریز نشده";

$_LANG['cpanellogin'] = "ورود به cPanel";
$_LANG['cpanelwhmlogin'] = "ورود به WHM";
$_LANG['cpanelwebmaillogin'] = "ورود به Webmail";
$_LANG['enkompasslogin'] = "ورود به Enkompass";
$_LANG['plesklogin'] = "ورود به Plesk";
$_LANG['helmlogin'] = "Log in to Helm";
$_LANG['hypervmrestart'] = "ریستارت VPS";
$_LANG['siteworxlogin'] = "ورود به SiteWorx Control Panel";
$_LANG['nodeworxlogin'] = "ورود به NodeWorx Control Panel";
$_LANG['veportallogin'] = "ورود به vePortal";
$_LANG['virtualminlogin'] = "ورود به کنترل پنل";
$_LANG['websitepanellogin'] = "ورود به کنترل پنل";
$_LANG['whmsoniclogin'] = "ورود به کنترل پنل";
$_LANG['xpanelmaillogin'] = "ورود به Webmail";
$_LANG['xpanellogin'] = "ورود به XPanel";
$_LANG['heartinternetlogin'] = "ورود به کنترل پنل";
$_LANG['gamecplogin'] = "ورود به GameCP";
$_LANG['fluidvmrestart'] = "ریستارت VPS";
$_LANG['enomtrustedesc'] = "TRUSTe Control Panel دارای مراحل تنظیم میباشد تا سیاست حفاظت از حریم شخصی شما را اجرا کند.";
$_LANG['enomtrustelogin'] = "ورود به TrustE Control Panel";
$_LANG['directadminlogin'] = "ورود به DirectAdmin";
$_LANG['centovacastlogin'] = "ورود به Centova Cast";
$_LANG['castcontrollogin'] = "ورود به کنترل پنل";

$_LANG['sslconfigurenow'] = "هم اکنون پیکربندی کنید";
$_LANG['sslprovisioningdate'] = "تاریخ SSL Provisioning";
$_LANG['globalsignvoucherscode'] = "کد OneClickSSL Voucher شما";
$_LANG['globalsignvouchersnotissued'] = "هنوز صادر نشده است";

$_LANG['domaintrffailreasonunavailable'] = "دلیل عدم موفقیت موجود نیست";

$_LANG['clientareaprojects'] = "پروژه های من";

$_LANG['clientgroupdiscount'] = "تحفیف مشتری";
$_LANG['billableitemshours'] = "ساعت ها";
$_LANG['billableitemshour'] = "ساعت";
$_LANG['billableitemsquantity'] = "Qty";
$_LANG['billableitemseach'] = "Each";

$_LANG['invoicefilename'] = "صورتحساب-";
$_LANG['quotefilename'] = "نقل قول-";

# Domain Addons

$_LANG['domainaddons'] = "افزونه ها";
$_LANG['domainaddonsinfo'] = "افزونه های زیر برای دامنه شما موجود میباشد...";
$_LANG['domainaddonsdnsmanagement'] = "مدیریت رکورد DNS";
$_LANG['domainaddonsidprotectioninfo'] = "محافظت از اطلاعات شخصی شما و کاهش ارسال اسپم به ایمیل ثبت شده در اطلاعات دامنه با فعال سازی محافظت شناسه (ID Protection)";
$_LANG['domainaddonsdnsmanagementinfo'] = "یک DNS سرور مجزا میتواند سرعت و پایداری وبسایت شما را با کم کردن تعداد درخواست ها برای رسیدن به IP سرور از طرف آی اس پی شما ، زیاد کند.";
$_LANG['domainaddonsemailforwardinginfo'] = "ایمیل هایتان را به ایمیل دیگری فوروارد کنید و با این کار میتوانید همه آنها را در یک حساب بخوانید و مدیریت کنید.";
$_LANG['domainaddonsbuynow'] = "هم اکنون خرید کنید با";
$_LANG['domainaddonsperyear'] = "/سال";
$_LANG['domainaddonscancelareyousure'] = "آیا از غیر فعال سازی و حذف این افزونه مطمئن هستید ؟";
$_LANG['domainaddonsconfirm'] = "تایید کنسل نمودن";
$_LANG['domainaddonscancelsuccess'] = "افزونه با موفقیت غیر فعال شد!";
$_LANG['domainaddonscancelfailed'] = "غیر فعال نمودن افزونه ناموفق بود ، لطفا با پشتیبانی تماس بگیرید";

# Version 5.2

$_LANG['yourclientareahostingaddons'] = "شما افزونه های زیر را برای این محصول در اختیار دارید.";
$_LANG['loginrequired'] = "نیاز به وارد شدن به سیستم";
$_LANG['unsubscribe'] = "لغو اشتراک";
$_LANG['emailoptout'] = "انتخاب خبرنامه";
$_LANG['emailoptoutdesc'] = "جهت لغو اشتراک خبرنامه ما علامت بزنید";
$_LANG['alreadyunsubscribed'] = "شما مشترک خبرنامه ما نیستید یا اشتراک خود را قبلا لغو نموده اید";
$_LANG['newsletterresubscribe'] = "اگر میخواهید که مجددا به اعضای خبرنامه بپیوندید میتوانید از قیمت %sمشخصات من%s در پروفایلتان این کار را انجام دهید.";
$_LANG['unsubscribehashinvalid'] = "لغو اشتراک انجام نشد. با پشتیبانی تماس بگیرید";
$_LANG['unsubscribesuccess'] = "لغو اشتراک انجام شد";
$_LANG['newsletterremoved'] = "با تشکر از شما، ایمیل شما هم اکنون از لیست اعضای خبرنامه ما حذف شد.";
$_LANG['newslettersubscribed'] = "شما با موفقیت در لیست خبرنامه ما مشترک شدید";
$_LANG['emailMarketingAlreadyOptedIn'] = "شما قبلاً در لیست خبرنامه ما مشترک شده اید";
$_LANG['emailMarketingAlreadyOptedOut'] = "شما قبلاً اشتراک لیست خبرنامه ما را لغو کرده اید";
$_LANG['manageSubscription'] = "مدیریت اشتراک";

$_LANG['erroroccured'] = "خطایی رخ داد";
$_LANG['pwresetsuccessdesc'] = "پسورد شما هم اکنون جایگزین شد. جهت ادامه %sاینجا کلیک کنید%s ...";
$_LANG['pwresetenternewpw'] = "لطفا پسورد جدید مورد نظرتان را اینجا وارد کنید.";
$_LANG['ordererrorsbudomainbanned'] = "پیشوند ساب دامنه وارد شده مورد قبول نمیباشد. لطفا نام دیگری انتخاب کنید";

$_LANG['ticketfeedbacktitle'] = "تقاضای نظر در مورد تیکت";

$_LANG['nosupportdepartments'] = "بخش پشتیبانی ای یافت نشد ، لطفا بعدا تلاش کنید.";

$_LANG['feedbackclosed'] = "بازخورد تا زمان بسته شدن تیکت قابل ارائه نمیباشد.";
$_LANG['feedbackprovided'] = "شما در حال حاضر نظرتان را در مورد این تیکت ارائه داده اید";
$_LANG['feedbackthankyou'] = "از وقتی که برای ارائه نظرتان در مورد این تیکت صرف نمودید سپاسگذاریم";
$_LANG['feedbackreceived'] = "اطلاعات دریافت شد";
$_LANG['feedbackdesc'] = "آیا میتوانیم از شما خواهش کنیم که چند لحظه از وقتتان را صرف پر کردن فرم زیر در مورد کیفیت و تجربه شما با تیم پشتیبانی ما کنید ؟";
$_LANG['feedbackclickreview'] = "اینجا کلیک کنید تا تیکت را بازبینی کنید";
$_LANG['feedbackopenedat'] = "باز شده در";
$_LANG['feedbacklastreplied'] = "آخرین پاسخ به ";
$_LANG['feedbackstaffinvolved'] = "کارکنان ";
$_LANG['feedbacktotalduration'] = "زمان کل";
$_LANG['feedbackpleaserate1'] = "لطفا از 1 تا 10 نمره دهید چطور";
$_LANG['feedbackpleasecomment1'] = "لطفا توضیح دهید چطور";
$_LANG['feedbackhandled'] = "به این تیکت رسیدگی شد";
$_LANG['feedbackworst'] = "بدترین";
$_LANG['feedbackbest'] = "بهترین";
$_LANG['feedbackimprove'] = "چطور میتوانیم در آینده بهتر به شما کمک کنیم؟";
$_LANG['pleaserate2'] = "به این تیکت رسیدگی شد";
$_LANG['feedbacksupplyrating'] = "لطفاً حداقل رتبه ای برای :staffname (comments are optional)";

$_LANG['returnclient'] = "بازگشت به بخش کاربران";

$_LANG['clientareanavsecurity'] = "تنظیمات امنیتی";
$_LANG['twofactorauth'] = "تایید هویت دو عاملی";
$_LANG['twofaenable'] = "فعال سازی تایید هویت دو عاملی";
$_LANG['twofadisable'] = "غیر فعال کردن تایید هویت دو عاملی";
$_LANG['twofaenableclickhere'] = "برای فعال سازی کلیک کنید";
$_LANG['twofadisableclickhere'] = "جهت غیر فعال کردن کلیک کیند";
$_LANG['twofaenforced'] = "مدیر سیستم سیستم تایید هویت دو عاملی را الزامی دانسته است. شما باید تایید هویت دو عاملی را فعال کنید تا بتوانید ادامه دهید. این صفحه شما را در مراحل تنظیم این سیستم یاری میدهد.";

$_LANG['twofasetupgetstarted'] = "شروع کنید";
$_LANG['twofaactivationintro'] = "تایید هویت دو عاملی یک لایه ی امنیتی اضافی در مقابل ورود به حساب شما قرار میدهد. با فعال سازی و تنظیم این سیستم هر موقع که میخواهید به سایت وارد شوید از شما علاوه بر نام کاربری و پسورد ، عامل دیگری نیز پرسیده میشود که به عنوان یک کد امنیتی به کار میرود.";
$_LANG['twofaactivationmultichoice'] = "یرای ادامه ، لطفا روش مورد نظرتان را جهت تایید هویت دو عاملی انتخاب کنید";
$_LANG['twofadisableintro'] = "برای غیر فعال نمودن تایید هویت دو عاملی رمز ورودتان را در این قسمت وارد کنید.";
$_LANG['twofaactivationerror'] = "خظایی در فعال کردن تایید هویت دو عاملی برای حساب شما رخ داد. لطفا مجددا تلاش کنید.";
$_LANG['twofamoduleerror'] = "خطایی در بارگذاری ماژول مربوطه رخ داد. لطفا مجددا تلاش کنید.";
$_LANG['twofadisableconfirmation'] = "تایید هویت دو عاملی هم اکنون روی حساب شما غیر فعال شد";
$_LANG['twofabackupcode'] = "کد پشتیبان";
$_LANG['twofabackupcodeintro'] = "در صورتی که نتوانید احراز هویت دو مرحله ای را تکمیل کنید ، کد پشتیبان برای دسترسی به حساب شما مورد نیاز است";
$_LANG['twofabackupcodeis'] = "کد پشتیبان شما عبارت است از: ";
$_LANG['twofanewbackupcodeis'] = "کد جدید پشتیبان شما";
$_LANG['twofabackupcodelogin'] = "جهت ورود ،کد پشتیبان را وارد کنید";
$_LANG['twofabackupcodeexpl'] = "این کد را در جایی امن نگهداری کنید.این کد در مواقعی که دستگاه تایید هویت دو مرحله ای را همراه نداشته باشید یا آن را گم کرده باشید به کارتان خواهد آمد.";
$_LANG['twofaconfirmpw'] = "رمزتان را وارد کنید";
$_LANG['twofa2ndfactorreq'] = "دومین فاکتور شما برای تکمیل ورود، نیاز است.";
$_LANG['twofa2ndfactorincorrect'] = "دومین فاکتوری که ارائه کردید نادرست بود. لطفا دوباره تلاش کنید. شما دارید :attempts همچنان باقی می مانند.";
$_LANG['twofabackupcodereset'] = "ورود از طریق کد پشتیبان گیری موفقیت آمیز بود. کدهای پشتیبان فقط یک بار معتبر هستند. این کد هم اکنون ریست خواهد شد.";
$_LANG['twofacantaccess2ndfactor'] = "دسترسی به دستگاه از طریق فاکتور دوم مقدور نیست؟";
$_LANG['twofaloginusingbackupcode'] = "ورود با کد پشتیبان گیری";
$_LANG['twofageneralerror'] = "برای اجرای ماژول خطایی رخ داده است.مجدد تلاش کنید";

$_LANG['continue'] = "ادامه";
$_LANG['disable'] = "غیر فعال";
$_LANG['manage'] = "مدیریت";

# Version 5.3
$_LANG['quoteacceptancetitle'] = " پذیرش نقل قول";
$_LANG['quoteacceptancehowto'] = "برای پذیرفتن نقل قول ، لطفاً پذیرفتن شرایط خدمات ما را که می توانید مشاهده کنید تأیید کنید";
$_LANG['quoteacceptancewarning'] = "لطفاً توجه داشته باشید که پذیرفتن نقل قول به منزله انعقاد قرارداد تلقی می شود و پس از پذیرش نمی توانید آن را لغو کنید";

$_LANG['contactform'] = "فرم ارتباط";

$_LANG['twoipconnect'] = "اتصال به برنامه";
$_LANG['twoipinstruct'] = "با استفاده از یک برنامه احراز هویت مانند %s یا %s, کد کیو آر زیر را اسکن کنید. در اسکن کد مشکل دارید؟ کد را به صورت دستی وارد کنید:";
$_LANG['twoipverificationstepmsg'] = "کد 6 رقمی را که برنامه برای تأیید و تکمیل راه اندازی ایجاد می کند وارد کنید";
$_LANG['twoipenterauth'] = "کد احراز هویت را وارد کنید";
$_LANG['twoipgoogleauth'] = "Google Authenticator";
$_LANG['twoipduo'] = "Duo";
$_LANG['twoipcodemissmatch'] = "کدی که وارد کردید با مقدار مورد انتظار مطابقت ندارد.لطفا مجدد تلاش کنید";
$_LANG['twoipgdmissing'] = "GD is missing from the PHP build on your server so unable to generate image";

$_LANG['domaincontactdetails']['First Name'] = "نام";
$_LANG['domaincontactdetails']['Last Name'] = "نام خانوادگی";
$_LANG['domaincontactdetails']['Full Name'] = "نام کامل";
$_LANG['domaincontactdetails']['Contact Name'] = "نام مخاطب";
$_LANG['domaincontactdetails']['Email'] = "ایمیل";
$_LANG['domaincontactdetails']['Email Address'] = "آدرس ایمیل";
$_LANG['domaincontactdetails']['Job Title'] = "عنوان کاری";
$_LANG['domaincontactdetails']['Company Name'] = "نام شرکت";
$_LANG['domaincontactdetails']['Organisation Name'] = "نام سازمان";
$_LANG['domaincontactdetails']['Address'] = "آدرس";
$_LANG['domaincontactdetails']['Street'] = "خیابان";
$_LANG['domaincontactdetails']['Address 1'] = "آدرس 1";
$_LANG['domaincontactdetails']['Address 2'] = "آدرس 2";
$_LANG['domaincontactdetails']['Address 3'] = "آدرس 3";
$_LANG['domaincontactdetails']['City'] = "شهر";
$_LANG['domaincontactdetails']['State'] = "استان";
$_LANG['domaincontactdetails']['County'] = "کسور";
$_LANG['domaincontactdetails']['Region'] = "منطقه";
$_LANG['domaincontactdetails']['Postcode'] = "کد پستی";
$_LANG['domaincontactdetails']['ZIP Code'] = "کد پستی";
$_LANG['domaincontactdetails']['ZIP'] = "کد پستی";
$_LANG['domaincontactdetails']['Country'] = "کشور";
$_LANG['domaincontactdetails']['Phone'] = "تلفن";
$_LANG['domaincontactdetails']['Phone Number'] = "شماره تلفن";
$_LANG['domaincontactdetails']['Fax'] = "فکس";
$_LANG['domaincontactdetails']['Phone Country Code'] = "کد کشور تلفن";

$_LANG['serverhostnameexample'] = "eg. server1(.example.com)";
$_LANG['serverns1prefixexample'] = "eg. ns1(.example.com)";
$_LANG['serverns2prefixexample'] = "eg. ns2(.example.com)";

$_LANG['hosting'] = "Hosting";

$_LANG['enomfrregistration']['Heading'] = ".fr domains have different required values depending on your nationality and type of registration:";
$_LANG['enomfrregistration']['French Individuals']['Name'] = "افراد فرانسوی";
$_LANG['enomfrregistration']['French Individuals']['Requirements'] = "Please provide your \"Birthdate\", \"Birthplace City\", and \"Birthplace Postcode\".";
$_LANG['enomfrregistration']['EU Non-French Individuals']['Name'] = "EU Non-French Individuals";
$_LANG['enomfrregistration']['EU Non-French Individuals']['Requirements'] = "Please provide your \"Birthdate\".";
$_LANG['enomfrregistration']['French Companies']['Name'] = "French Companies";
$_LANG['enomfrregistration']['French Companies']['Requirements'] = "Please provide the \"Birthdate\", \"Birthplace City\", and \"Birthplace Postcode\" for the owner contact, along with your SIRET number.";
$_LANG['enomfrregistration']['EU Non-French Companies']['Name'] = "EU Non-French Companies";
$_LANG['enomfrregistration']['EU Non-French Companies']['Requirements'] = "Please provide the company \"DUNS Number\", and the \"Birthdate\" of the Owner Contact.";
$_LANG['enomfrregistration']['Non-EU Warning'] = "اطلاعات تماس مشتری باید در اتحادیه اروپا باشد در غیر این صورت ثبت نام ناموفق خواهد بود";

$_LANG['confirm'] = "تایید";

$_LANG['maxmind_checkconfiguration'] = "هنگام بررسی تقلب خطایی روی داد. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['maxmind_addressinvalid'] = "آدرس شما به رسمیت شناخته نمی شود. لطفاً بررسی کنید و دوباره وارد کنید";
$_LANG['maxmind_invalidip'] = "آدرس آیپی نامعتبر یا آدرس محلی است. لطفاً با پشتیبانی تماس بگیرید";

$_LANG['ssounabletologin'] = "ورود به سیستم خودکار امکان پذیر نیست. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['ssofatalerror'] = "یک خطای مهلک رخ داد. لطفاً با پشتیبانی تماس بگیرید";

$_LANG['customActionGenericError'] = "Unable to perform action. Please contact support.";
$_LANG['customActionException'] = "An exception has occurred. Please contact support.";

# Version 6.0

$_LANG['announcementschoosemonth'] = "انتخاب ماه";
$_LANG['announcementsbymonth'] = "بر اساس ماه";
$_LANG['announcementsolder'] = "اخبار قدیمی";
$_LANG['createnewcontact'] = "تماس جدید ...";
$_LANG['due'] = "سررسید";
$_LANG['affiliatessignups'] = "ثبت نامی ها";
$_LANG['affiliatesconversionrate'] = "گفتگو ها";
$_LANG['affiliatesclicks'] = "کلیک ها";
$_LANG['contacts'] = "حساب های فرعی";
$_LANG['backtoservicedetails'] = "بازگشت به جزئیات محصول";
$_LANG['invoicesintro'] = "تاریخچه صورت حساب های شما";

$_LANG['sidebars']['viewAccount']['yourAccount'] = "حساب شما";
$_LANG['sidebars']['viewAccount']['myDetails'] = "جزئیات من";
$_LANG['sidebars']['viewAccount']['billingInformation'] = "اطلاعات مالی";
$_LANG['sidebars']['viewAccount']['contacts/subAccounts'] = "اطلاعات تماس/زیر اکانت";
$_LANG['sidebars']['viewAccount']['changePassword'] = "تغییر رمز عبور";
$_LANG['sidebars']['viewAccount']['securitySettings'] = "تنظیمات امنیتی";
$_LANG['sidebars']['viewAccount']['emailHistory'] = "تاریخچه ایمیل";

$_LANG['aboutsecurityquestions'] = "چرا سوال امنیتی مهم است؟";
$_LANG['registersecurityquestionblurb'] = "سوال امنیتی درواقع امنیت اکانت شما را با اختصاصی کردن آن، بالا خواهد برد";

$_LANG['update'] = "بروز رسانی";
$_LANG['yourinfo'] = "اطلاعات شما";
$_LANG['shortcuts'] = "میانبر";

$_LANG['yourservices'] = "سرویس های شما";
$_LANG['yourdomains'] = "دامنه های شما";
$_LANG['yourtickets'] = "تیکت های شما";
$_LANG['managecontacts'] = "مدیریت تماس ها";
$_LANG['billingdetails'] = "جزئیات مالی";
$_LANG['homechooseproductservice'] = "یک سرویس یا محصول انتخاب کنید";

$_LANG['invoicesdue'] = "سر رسید صورت حساب ها";
$_LANG['invoicesduemsg'] = "شما %s صورت حساب پرداخت نشده با میزان بدهی %s دارید.";
$_LANG['noinvoicesduemsg'] = "همینک صورت حساب پرداخت نشده ای ندارید.";

$_LANG['expiringsoon'] = "بزودی منقضی میشود";

$_LANG['notice'] = "اطلاع";
$_LANG['networkstatussubtitle'] = "اخبار و اطلاعیه ها";

$_LANG['myaccount'] = "حساب من";

$_LANG['manageproduct'] = "مدیریت محصول";
$_LANG['overview'] = "بررسی";
$_LANG['servername'] = "نام سرور";
$_LANG['visitwebsite'] = "مشاهده وب سایت";
$_LANG['whoisinfo'] = "اطلاعات هویز";

$_LANG['tableshowing'] = "نمایش _START_ تا _END_ از مجموع _TOTAL_ مقدار";
$_LANG['tableempty'] = "نمایش 0 تا 0 از 0 مورد";
$_LANG['tablefiltered'] = "(filtered from _MAX_ total entries)";
$_LANG['tablelength'] = "نمایش _MENU_ مقادیر";
$_LANG['tableloading'] = "در حال انجام...";
$_LANG['tableprocessing'] = "در حال پردازش ...";
$_LANG['tablepagesfirst'] = "اول";
$_LANG['tablepageslast'] = "آخر";
$_LANG['tablepagesnext'] = "بعدی";
$_LANG['tablepagesprevious'] = "قبلی";
$_LANG['tableviewall'] = "همه";
$_LANG['tableentersearchterm'] = "جستجو";

$_LANG['actions'] = "عملیات";

$_LANG['upgradedowngradeshort'] = "ارتقا یا تنزیل";

$_LANG['masspayintro'] = "پرداخت کل صورت حساب ها با یک کلیک.";
$_LANG['masspaymentselectgateway'] = "انتخاب درگاه جهت پرداخت انبود";

$_LANG['ticketfeedbackrequest'] = "درخواست بازخورد";
$_LANG['ticketfeedbackforticket'] = "برای تیکت #";

$_LANG['notifications'] = "پیام ها";
$_LANG['notificationsnone'] = "شما هیچ پیامی در این لحظه ندارید";

$_LANG['creditcardnonestored'] = "کارتی در پرونده نیست";

$_LANG['kbviewingarticlestagged'] = "مشاهده مقالات برچسب زده شده";

$_LANG['domainprivatenameservers'] = "Nameservers خصوصی";

$_LANG['transferinadomain'] = "Transfer in a Domain";

$_LANG['nodomainextensions'] = "همینک هیچ پسوند دامنه ای جهت سفارش موجود نیست";

$_LANG['homebegin'] = "برای یافتن بهترین نام همینک جستجو کنید...";
$_LANG['howcanwehelp'] = "امروز چگونه میتوانیم به شما کمک کنیم؟";
$_LANG['exampledomain'] = "eg. example.com";
$_LANG['buyadomain'] = "خرید دامنه";
$_LANG['orderhosting'] = "سفارش میزبانی (هاست)";
$_LANG['makepayment'] = "ایجاد تراکنش";
$_LANG['getsupport'] = "پشتیبانی";

$_LANG['news'] = "اخبار";
$_LANG['allthelatest'] = "آخرین اخبار";
$_LANG['readmore'] = "بیشتر";
$_LANG['noannouncements'] = "اخباری جهت نمایش موجود نیست";

$_LANG['kbsearchexplain'] = "سوالی دارید ؟ از همین جا جستجو کنید";
$_LANG['readyforquestions'] = "ما آماده و منتظر سوالات شما هستیم.";

$_LANG['restrictedpage'] = "این صفحه محدود شده است";
$_LANG['enteremail'] = "ایمیل را وارد کنید";
$_LANG['restricted'] = "محصور";

$_LANG['passwordtips'] = "<strong>نکاتی برای رمز عبور مناسب</strong><br />از حروف کوچک و بزرگ استفاده کنید<br />شامل حداقل یک علامت (# $ ! % &amp; etc...)<br />کلمه معنادار استفاده نکنید";

$_LANG['regdate'] = "تاریخ ثبت";
$_LANG['nextdue'] = "سررسید بعدی";

$_LANG['findyourdomain'] = "دامنه جدید خود را پیدا کنید";
$_LANG['searchtermrequired'] = "شما باید یک نام یا کلید واژه وارد کنید";
$_LANG['unabletolookup'] = "متأسفیم ، نمی توانم اصطلاح موجود را جستجو کنم";
$_LANG['invalidchars'] = "لطفا فاصله و حروف خاص را حذف کنید.";
$_LANG['bulkoptions'] = "تنظیمات انبوه";
$_LANG['checkingdomain'] = "در حال جستحوی دامنه درخواستی شما، امیدواریم در دسترس باشد...";
$_LANG['domainsgotocheckout'] = "رفتن به مرحله پرداخت";
$_LANG['domainssearchresults'] = "نتایج جستجو";
$_LANG['domainssuggestions'] = "پیشنهادات";
$_LANG['domainsothersuggestions'] = "شاید علاقه مند به استفاده از نام های جایگزین زیر باشید";
$_LANG['domainsmoresuggestions'] = "پیشنهادات دیگری میخواهم.";
$_LANG['domainssuggestionswarnings'] = "پیشنهاد نام های دیگر به معنای در دسترس بودن قطعی این نام ها و امکان ثبت برای شما نمیباشد زیرا بررسی در دسترس بودن دامنه ها به صورت لحظه ای انجام میشود";
$_LANG['disclaimers'] = "رفع مسئولیت";
$_LANG['tldpricing'] = "قیمت پسوند های ";
$_LANG['alltldpricing'] = "قیمت کلیه پسوند ها";

$_LANG['quotesdesc'] = "نقل قول هایی که برای شما ایجاد کرده ایم";
$_LANG['quotesrejected'] = "رد شده است";

$_LANG['ticketsyourhistory'] = "تاریخچه تیکت شما";

$_LANG['clientareaemaildesc'] = "تاریخچه ایمیل شما";

$_LANG['sslconfssl'] = "تنظیمات لایسنس SSL";
$_LANG['sslnoconfigurationpossible'] = "تنظیمات اعمال شده اند. در صورتی که مشکلی داشتید لطفا با پشتیبانی در ارتباط باشید";

$_LANG['adminloggedin'] = "شما به عنوان مدیر وارد شده اید.";
$_LANG['returntoadminarea'] = "بازگشت به محیط مدیریتی";
$_LANG['adminmasqueradingasclient'] = "شما به عنوان کاربر وارد شده اید";
$_LANG['logoutandreturntoadminarea'] = "خروج و ورود به بخش مدیریتی";

$_LANG['supportAndUpdatesExpired'] = "پشتیبانی و بروز رسانی منقضی شده اند";
$_LANG['supportAndUpdatesExpiredLicense'] = "مدت پشتیبانی و به روزرسانی های شما برای این مجوز به پایان رسیده است";
$_LANG['supportAndUpdatesRenewalRequired'] = "قبل از دسترسی به این بارگیری ، دسترسی به پشتیبانی و به روز رسانی باید تمدید شود";
$_LANG['supportAndUpdatesClickHereToRenew'] = "جهت تمدید کلیک کنید";

$_LANG['pwresetemailneeded'] = "رمز عبور خود را فراموش کرده اید؟ برای شروع روند بازیابی آن، لطفا آدرس ایمیل خود را در زیر وارد کنید";

$_LANG['quotestageexpired'] = "منقضی شده";

$_LANG['ticketinfo'] = "اطلاعات تیکت";
$_LANG['customfield'] = "فیلد های دلخواه";

$_LANG['domainsActive'] = "فعال";
$_LANG['domainsExpired'] = "منقضی شده";
$_LANG['domainsCancelled'] = "لغو شده";
$_LANG['domainsFraud'] = "کلاهبردار";
$_LANG['domainsPending'] = "معلق";
$_LANG['domainsPendingRegistration'] = "در انتظار ثبت نام";
$_LANG['domainsPendingTransfer'] = "انتقال معلق";
$_LANG['domainsTransferredAway'] = "منتقل دور";

$_LANG['kbtagcloud'] = "ابر تگ ها";

$_LANG['cancellationrequestedexplanation'] = "یک درخواست لغو برای این محصول/صرویس قبلا ارسال شده است";
$_LANG['cancellationrequested'] = "درخواست لغو ارسال شد";

$_LANG['yourrecenttickets'] = "تیکت های اخیر شما";

$_LANG['domains']['deTermsDescription1'] = "برای ثبت دامنه جدید ، انتقال یا تغییر اطلاعات ثبت نام کننده ، ثبت کننده باید صراحتاً شرایط و ضوابط  را بپذیرد";
$_LANG['domains']['deTermsDescription2'] = "(متن کامل شرایط و ضوابط  را ببینید: http://www.denic.de/fa/bedingungen.html.)";
$_LANG['directDebitPageTitle'] = "پرداخت بدهی مستقیم";
$_LANG['directDebitHeader'] = "پرداخت بدهی مستقیم";
$_LANG['directDebitErrorNoBankName'] = "شما باید نام بانک خود را وارد کنید";
$_LANG['directDebitErrorAccountType'] = "شما باید نوع حساب بانکی خود را انتخاب کنید";
$_LANG['directDebitErrorNoABA'] = "شما باید کد ای بی ای بانک خود را وارد کنید";
$_LANG['directDebitErrorAccNumber'] = "شما باید شماره حساب بانکی خود را وارد کنید";
$_LANG['directDebitErrorConfirmAccNumber'] = "باید شماره حساب بانکی خود را تأیید کنید";
$_LANG['directDebitErrorAccNumberMismatch'] = "شماره حساب بانکی و تأیید شما مطابقت ندارد";
$_LANG['directDebitThanks'] = "متشکرم که مشخصات خود را ارسال کردید. ما سعی می کنیم پرداخت شما را با استفاده از جزئیات ارائه شده طی چند روز آینده پردازش کنیم و در صورت بروز هرگونه مشکل با شما تماس بگیریم";
$_LANG['directDebitPleaseSubmit'] = "لطفاً جزئیات حساب بانکی خود را در زیر برای پرداخت با واریز مستقیم ارسال کنید";
$_LANG['directDebitBankName'] = "نام بانک";
$_LANG['directDebitAccountType'] = "نوع اکانت بانکی";
$_LANG['directDebitABA'] = "کد بانک ABA";
$_LANG['directDebitAccNumber'] = "شماره حساب بانک";
$_LANG['directDebitConfirmAccNumber'] = "تایید شماره حساب";
$_LANG['directDebitSubmit'] = "ارسال";
$_LANG['directDebitChecking'] = "در حال بررسی";
$_LANG['directDebitSavings'] = "در حال ذخیره";

$_LANG['outOfStockProductRemoved'] = "محصولی که موجود نیست به صورت خودکار از کارت خرید شما حذف شد";

$_LANG['subaccountpermsquotes'] = "مشاهده و قبول نقل قول";

$_LANG['chooselanguage'] = "انتخاب زبان";

$_LANG['success'] = "موفقیت";
$_LANG['error'] = "اخطار";
$_LANG['print'] = "پرینت";
$_LANG['invoicelineitems'] = "اقلام صورت حساب";

$_LANG['quotelineitems'] = "موارد نقل قول";

$_LANG['quoteproposal'] = "پروپوزال";
$_LANG['quoteacceptagreetos'] = "برای پذیرش نقل قول ، لطفاً پذیرفتن شرایط خدمات ما را تأیید کنید";
$_LANG['quoteacceptcontractwarning'] = "لطفاً توجه داشته باشید که پذیرفتن نقل قول به منزله انعقاد قرارداد تلقی می شود و پس از پذیرش نمی توانید آن را لغو کنید";

// Client alerts
$_LANG['clientAlerts']['creditCardExpiring'] = "Your credit card :creditCardType-:creditCardLastFourDigits expires within :days days. Please update it at your earliest convenience.";
$_LANG['clientAlerts']['domainsExpiringSoon'] = ":numberOfDomains دامنه شما طی :days روز آینده منقضی خواهد شد";
$_LANG['clientAlerts']['invoicesUnpaid'] = "شما :numberOfInvoices صورت حساب پرداخت نشده دارید. جهت اطمینان خاطر امروز پرداخت خود را انجام دهید.";
$_LANG['clientAlerts']['invoicesOverdue'] = "شما :numberOfInvoices صورت حساب پرداخت نشده با مبلغ بدهی :balanceDue دارید. جهت جلوگیری از بروز مشکل برای سرویس هایتان، هم اکنون جهت پرداخت اقدام کنید.";
$_LANG['clientAlerts']['creditBalance'] = "شما موجودی :creditBalance. در حسابتان دارید";
$_LANG['clientAlerts']['servicesRenewingSoon'] = "You have :numberOfServices service(s) that are available for renewal soon.";

// Client homepage panels
$_LANG['clientHomePanels']['unpaidInvoices'] = "صورت حساب های پرداخت نشده";
$_LANG['clientHomePanels']['unpaidInvoicesMsg'] = "شما :numberOfInvoices صورت حساب پرداخت نشده با مبلغ بدهی :balanceDue دارید. جهت اطمینان خاطر، همینک جهت پرداخت اقدام کنید.";
$_LANG['clientHomePanels']['overdueInvoices'] = "فاکتورها سر رسیده";
$_LANG['clientHomePanels']['overdueInvoicesMsg'] = "شما :numberOfInvoices صورت حساب پرداخت نشده با مبلغ بدهی :balanceDue دارید. جهت جلوگیری از بروز مشکل برای سرویس هایتان، همینک جهت پرداخت اقدام کنید.";
$_LANG['clientHomePanels']['domainsExpiringSoon'] = "دامنه هایی که بزودی منقضی میشوند";
$_LANG['clientHomePanels']['domainsExpiringSoonMsg'] = ":numberOfDomains دامنه شما طی :days روز آینده منقضی خواهند شد. جهت اطمینان خاطر، امروز جهت تمدید اقدام کنید.";
$_LANG['clientHomePanels']['activeProductsServices'] = "محصولات/سرویس های فعال شما";
$_LANG['clientHomePanels']['activeProductsServicesNone'] = "انگار هیچ سرویس و محصولی نزد ما ندارید. برای شروع هم اکنون یک سفارش ارسال کنید";
$_LANG['clientHomePanels']['recentNews'] = "اخبار اخیر";
$_LANG['clientHomePanels']['affiliateProgram'] = "برنامه همکاری";
$_LANG['clientHomePanels']['recentSupportTickets'] = "تیکت های اخیر";
$_LANG['clientHomePanels']['recentSupportTicketsNone'] = "هیچ تیکتی یافت نشد. اگر سوالی دارید، تیکت جدید برای ما ارسال کنید.";
$_LANG['clientHomePanels']['affiliateSummary'] = "موجودی کمیسیون فعلی شما است :commissionBalance. شما فقط به دیگری نیاز دارید :amountUntilWithdrawalLevel قبل از اینکه بتوانید درآمد خود را برداشت کنید";
$_LANG['clientHomePanels']['affiliateSummaryWithdrawalReady'] = "موجودی کمیسیون فعلی شما است :commissionBalanceاکنون می توانید درآمد خود را برداشت کنید";
$_LANG['clientHomePanels']['productsAndServices'] = "مرور محصولات / خدمات ما";
$_LANG['clientHomePanels']['serviceRenewingSoon'] = "Services Renewing Soon";
$_LANG['clientHomePanels']['serviceRenewingSoonMsg'] = "You have :numberOfServices service(s) that are available for renewal soon. Renew them today for peace of mind.";

$_LANG['upgradeNotPossible'] = "ارتقای این سرویس امکانپذیر نمیباشد.میتوانید با بخش پشتیبانی در ارتباط باشید یا به عقب بازگردید و انتخاب خود را بررسی کنید";
$_LANG['upgradeSameProductMustExtendCycle'] = "برای ارتقاء چرخه صورتحساب ، لطفاً چرخه ای را انتخاب کنید که بیشتر از چرخه صورتحساب فعلی شما باشد";

$_LANG['hostingInfo'] = "اطلاعات میزبانی";
$_LANG['additionalInfo'] = "اطلاعات دیگر";
$_LANG['resourceUsage'] = "منابع مصرفی";
$_LANG['primaryIP'] = "آی پی اصلی";
$_LANG['assignedIPs'] = "آی پی های اختصاصی یافته";
$_LANG['diskSpace'] = "فضای دیسک";
$_LANG['bandwidth'] = "ترافیک";
$_LANG['registered'] = "ثبت شده";
$_LANG['upgrade'] = "بروز رسانی";

$_LANG['downdoadsdesc'] = "راهنما ها، برنامه ها و دیگر فایل ها";

$_LANG['doToday'] = "امروز مایل هستید چه کاری انجام دهید؟";
$_LANG['changeDomainNS'] = "نیم سرور های دامنه را تغییر دهید";
$_LANG['updateWhoisContact'] = "اطلاعات هویز دامنه را بروز رسانی کنید";
$_LANG['changeRegLock'] = "وضعیت قفل دامنه را تغییر دهید";
$_LANG['renewYourDomain'] = "دامنه خود را تمدید کنید";

$_LANG['oops'] = "اووپس";
$_LANG['goback'] = "بازگشت به عقب";
$_LANG['returnhome'] = "بازگشت به صفحه اصلی";
$_LANG['blankCustomField'] = "(بدون مقدار)";

$_LANG['viewAll'] = "مشاهده همه";
$_LANG['moreDetails'] = "جزئیات بیشتر";

$_LANG['clientHomeSearchKb'] = "سوال خود را جهت جستجو در بخش آموزش ها وارد کنید...";

$_LANG['whoisContactWarning'] = "بسیار مهم است که اطلاعات هویز دامنه خود را به روز نگهدارید تا دسترسی به دامنه را از دست ندهید";

$_LANG['paymentstodate'] = "پرداخت به تاریخ";
$_LANG['balancedue'] = "بدهی معوقه";
$_LANG['submitpayment'] = "ثبت پرداخت";

$_LANG['domaincheckeravailable'] = "در دسترس";
$_LANG['domaincheckertransferable'] = "جهت انتقال در دسترس است";
$_LANG['domaincheckertaken'] = "تکراری";
$_LANG['domaincheckeradding'] = "افزودن";
$_LANG['domaincheckeradded'] = "افزوده شده";
$_LANG['domaincheckernomoresuggestions'] = "کل اطلاعاتی که داریم همین است.اگر همچنان به دنبال موردی هستید، لطفا با کلمه کلیدی دیگری امتحان کنید";
$_LANG['domaincheckerunabletooffertld'] = "متاسفانه هم اکنون قادر به ثبت این پسوند نمیباشیم.";
$_LANG['domaincheckerbulkplaceholder'] = "Enter up to 20 domain names.\nEach name must be on a separate line.\n\nExamples:\nexample.com\nexample.net";

$_LANG['domainchecker']['suggestiontakentitle'] = "دامنه در دسترس نیست";
$_LANG['domainchecker']['suggestiontakenmsg'] = "متاسفانه دامنه ای که وارد کردید در دسترس نیست.امکان دارد این دامنه اخیرا ثبت شده باشد. لطفا با بازگشت به عقب، نام دیگری انتخاب کنید";
$_LANG['domainchecker']['suggestiontakenchooseanother'] = "دامنه دیگری انتخاب کنید";

$_LANG['domainchecker']['alreadyincarttitle'] = "در کارت خرید موجود است";
$_LANG['domainchecker']['alreadyincartmsg'] = "این دامنه در کارت خرید شما موجود است. جهت تکمیل خرید لطفا هزینه را پردات کنید";
$_LANG['domainchecker']['alreadyincartcheckoutnow'] = "هم اکنون پرداخت کنید";

$_LANG['genericerror']['title'] = "اوپس . یک چیزی اشتباه است";
$_LANG['genericerror']['msg'] = "لطفا مجدد تلاش کنید و اگر مشکل همچنان پابرجا بود با تیم پشتیبانی در ارتباط باشید";

# Licensing Addon

$_LANG['licensingaddon']['mylicenses'] = "لایسنس های من";
$_LANG['licensingaddon']['latestdownload'] = "آخرین دانلود ها";
$_LANG['licensingaddon']['downloadnow'] = "هم اکنون دانلود کنید";
$_LANG['licensingaddon']['licensekey'] = "کلید لایسنس";
$_LANG['licensingaddon']['validdomains'] = "دامنه های مجاز";
$_LANG['licensingaddon']['validips'] = "آی پی های مجاز";
$_LANG['licensingaddon']['validdirectory'] = "آدرس مجاز";
$_LANG['licensingaddon']['status'] = "وضعیت لایسنس";
$_LANG['licensingaddon']['reissue'] = "Reissue";
$_LANG['licensingaddon']['reissuestatusmsg'] = "دفعه بعد که به مجوز دسترسی پیدا کنید ، دامنه ، آیپی  و فهرست معتبر شناسایی و ذخیره می شوند";
$_LANG['licensingaddon']['manageLicense'] = "مدیریت لایسنس";

$_LANG['affiliateWithdrawalSummary'] = "به محض اینکه موجودی شما به حداقل مقدار مورد نیاز برسد ، می توانید درخواست برداشت ثبت نمایید :amountForWithdrawal.";

$_LANG['projectManagement']['activeProjects'] = "پروژه های فعال شما";

# cPanel Module

$_LANG['packageDomain'] = "بسته/دامنه";
$_LANG['addonsExtras'] = "افزونه ها و موارد اضافی";
$_LANG['purchaseActivate'] = "خرید و فعال سازی";

$_LANG['usageStats'] = "آمار مصرف";
$_LANG['diskUsage'] = "آمار دیسک";
$_LANG['bandwidthUsage'] = "آمار ترافیک";
$_LANG['usageStatsBwLimitNear'] = "ترافیک مصرفی شما رو به پایان است";
$_LANG['usageStatsDiskLimitNear'] = "فضای مصرفی شما رو به پایان است";
$_LANG['usageUpgradeNow'] = "هم اکنون ارتقا دهید";
$_LANG['usageLastUpdated'] = "آخرین بروز رسانی";

$_LANG['quickShortcuts'] = "میانبرهای سریع";
$_LANG['cPanel']['emailAccounts'] = "حسابهای ایمیل";
$_LANG['cPanel']['forwarders'] = "فورواردرها";
$_LANG['cPanel']['autoresponders'] = "پاسخ دهندگان خودکار";
$_LANG['fileManager'] = "مدیریت فایل";
$_LANG['cPanel']['backup'] = "پشتیبان";
$_LANG['cPanel']['subdomains'] = "زیردامنه";
$_LANG['cPanel']['addonDomains'] = "دامنه های افزونه";
$_LANG['cPanel']['cronJobs'] = "کرون جاب";
$_LANG['mysqlDatabases'] = "MySQL Databases";
$_LANG['cPanel']['phpMyAdmin'] = "phpMyAdmin";
$_LANG['cPanel']['awstats'] = "Awstats";

$_LANG['cPanel']['createEmailAccount'] = "ایجاد سریع ایمیل حساب";
$_LANG['cPanel']['usernamePlaceholder'] = "نام شما";
$_LANG['cPanel']['passwordPlaceholder'] = "رمز مورد نظر";
$_LANG['cPanel']['create'] = "Create";
$_LANG['cPanel']['emailAccountCreateSuccess'] = "حساب ایمیل با موفقیت ایجاد شد";
$_LANG['cPanel']['emailAccountCreateFailed'] = ":ایجاد حساب ایمیل ناموفق بود ";

$_LANG['cPanel']['packageNotActive'] = "بسته ی میزبانی وب هم اکنون";
$_LANG['cPanel']['statusPendingNotice'] = "تا زمانیکه این سرویس میزبانی فعال نشود، نمیتوانید از آن استفاده کنید";
$_LANG['cPanel']['statusSuspendedNotice'] = "شما تا زمان فعال سازی مجدد، نمیتوانید از این سرویس استفاده کنید یا آن را مدیریت کنید";

$_LANG['wpsquared']['login'] = "Log in to WP Squared";

$_LANG['wordpress']['invalidPath'] = "The supplied path is invalid.";

$_LANG['billingOverview'] = "خلاصه وضعیت مالی";

$_LANG['liveHelp']['chatNow'] = "گفتگو کنید";

$_LANG['quotes'] = "نقل قول";

$_LANG['productMustBeActiveForModuleCmds'] = "محصول انتخابی باید فعال باشد";
$_LANG['domainCannotBeManagedUnlessActive'] = "این دامنه فعال نیست. دامنه ی فعال قابل مدیریت میباشد";

$_LANG['actionRequiresAtLeastOneDomainSelected'] = "لطفا جهت اعمال تغییرات، حداقل یکی از دامنه ها را انتخاب کنید";

$_LANG['clientAreaProductDownloadsAvailable'] = "برای محصول/سرویس شما، فایل های زیر جهت دانلود در دسترس هستند";
$_LANG['clientAreaProductAddonsAvailable'] = "افزونه ها برای محصول/خدمات شما در دسترس هستند <a href=\"cart.php?gid=addons\">برای رقابت اینجا را کلیک کنید &amp; سقارش &raquo;</a>";
$_LANG['clientAreaSecurityTwoFactorAuthRecommendation'] = "ما به شدت شما را تشویق می کنیم که برای امنیت بیشتر ، احراز هویت دو عاملی را فعال کنید";
$_LANG['clientAreaSecurityTwoFactorAuthRequired'] = "To ensure your account's security, you must configure two-factor authentication.";
$_LANG['clientAreaSecurityNoSecurityQuestions'] = "تنظیم پرسش و پاسخ امنیتی به محافظت از حساب شما در برابر بازنشانی گذرواژه های غیر مجاز کمک می کند و به ما اجازه می دهد هنگام درخواست تغییرات حساب ، هویت شما را تأیید کنیم";
$_LANG['clientAreaSecuritySecurityQuestionOtherError'] = "سوالات  امنیتی به محافظت از حساب شما در برابر بازنشانی گذرواژه های غیر مجاز کمک می کند و به ما اجازه می دهد هنگام درخواست تغییر حساب ، هویت شما را تأیید کنیم";

$_LANG['billingAddress'] = "آدرس مالی";

$_LANG['noPasswordResetWhenLoggedIn'] = "تا زمانیکه وارد سیستم هستید نمیتوانید درخواست بازیابی رمز عبور داشته باشید. لطفا در ابتدا از سیستم خارج شوید.";

$_LANG['unableToLoadShoppingCart'] = "دسترسی به کارت خرید امکان پذیر نیست. لطفا با بخش پشتیبانی در ارتباط باشید.";

$_LANG['showMenu'] = "نمایش منو";
$_LANG['hideMenu'] = "مخفی سازی منو";

$_LANG['from'] = "از";
$_LANG['featuredProduct'] = "محبوب ترین";
$_LANG['shoppingCartProductPerMonth'] = "<span>:price</span>/:countmo";
$_LANG['shoppingCartProductPerYear'] = "<span>:price</span>/:countyr";

$_LANG['orderForm']['findNewDomain'] = "نام جدید برای دامنه خود پیدا کنید. نام دامنه یا کلید واژه ای را وارد کنید تا امکان ثبت آن را بررسی کنیم.";
$_LANG['orderForm']['transferExistingDomain'] = "دامنه ی فعلی خود را به سیستم ما منتقل کنید";
$_LANG['orderForm']['www'] = "www.";
$_LANG['orderForm']['returnToClientArea'] = "بازگشت به محیط کاربری";
$_LANG['orderForm']['checkout'] = "پرداخت نهایی";
$_LANG['orderForm']['alreadyRegistered'] = "قبلا ثبت نام کرده اید؟";
$_LANG['orderForm']['createAccount'] = "ساخت اکانت جدید";
$_LANG['orderForm']['enterPersonalDetails'] = "لطفا اطلاعات شخصی و مالی خود را جهت اتمام مراحل خرید، وارد نمایید";
$_LANG['orderForm']['correctErrors'] = "قبل از ادامه، لطفا ارور های زیر را برطرف سازید.";
$_LANG['orderForm']['existingCustomerLogin'] = "ورود کاربران ثبت نام شده";
$_LANG['orderForm']['emailAddress'] = "آدرس ایمیل";
$_LANG['orderForm']['personalInformation'] = "اطلاعات شخصی";
$_LANG['orderForm']['firstName'] = "نام";
$_LANG['orderForm']['lastName'] = "نام خانوادگی";
$_LANG['orderForm']['phoneNumber'] = "شماره تلفن";
$_LANG['orderForm']['billingAddress'] = "آدرس مالی";
$_LANG['orderForm']['companyName'] = "نام شرکت";
$_LANG['orderForm']['optional'] = "اختیاری";
$_LANG['orderForm']['streetAddress'] = "آدرس";
$_LANG['orderForm']['streetAddress2'] = "آدرس 2";
$_LANG['orderForm']['city'] = "شهر";
$_LANG['orderForm']['state'] = "استان";
$_LANG['orderForm']['country'] = "کشور";
$_LANG['orderForm']['postcode'] = "کد پستی";
$_LANG['orderForm']['domainAlternativeContact'] = "هنگام ثبت سفارش به نمایندگی از شخص یا نهاد دیگر ، می توانید اطلاعات تماس دیگری را برای ثبت دامنه در ثبت سفارش خود مشخص کنید. اگر نیازی به این کار ندارید ، می توانید این بخش را رد کنید";
$_LANG['orderForm']['accountSecurity'] = "امنیت اکانت";
$_LANG['orderForm']['mediumStrength'] = "قدرت متوسط";
$_LANG['orderForm']['paymentDetails'] = "جزئیات پرداخت";
$_LANG['orderForm']['preferredPaymentMethod'] = "لطفا روش پرداخت خود را انتخاب نمایید";
$_LANG['orderForm']['cardNumber'] = "شماره کارت";
$_LANG['orderForm']['cvv'] = "CVV Security Number";
$_LANG['orderForm']['additionalNotes'] = "توضیح اضافه";
$_LANG['orderForm']['continueToClientArea'] = "ادامه به ناحیه کاربری";
$_LANG['orderForm']['reviewDomainAndAddons'] = "لطفا یکبار، نام دامنه ی انتخابی و اضافات آن را بررسی کنید";
$_LANG['orderForm']['addToCart'] = "افزودن به کارت خرید";
$_LANG['orderForm']['addedToCartRemove'] = "اضافه به سبد خرید (حذف)";
$_LANG['orderForm']['configureDesiredOptions'] = "گزینه های مورد نظر خود را پیکربندی کرده و به پرداخت ادامه دهید";
$_LANG['orderForm']['haveQuestionsContact'] = "سوالی دارید؟ حتما با واحد فروش در ارتباط باشید.";
$_LANG['orderForm']['haveQuestionsClickHere'] = "اینجا کلیک کنید";
$_LANG['orderForm']['use'] = "استفاده";
$_LANG['orderForm']['check'] = "بررسی";
$_LANG['orderForm']['transfer'] = "انتقال";
$_LANG['orderForm']['domainAddedToCart'] = "این دامنه به کارت خرید شما اضافه شد";
$_LANG['orderForm']['registerLongerAndSave'] = "دوره ی طولانی تری ثبت کنید و هزینه ها را کاهش دهید";
$_LANG['orderForm']['tryRegisteringInstead'] = "این دامنه را به جای دامنه ی قبل ثبت کن";
$_LANG['orderForm']['domainAvailabilityCached'] = "نتایج در دسترس بودن دامنه ذخیره می شود که ممکن است منجر به نمایش دامنه های اخیر شود";
$_LANG['orderForm']['submitTicket'] = "ارسال تیکت";
$_LANG['orderForm']['promotionAccepted'] = "کوپن تخفیف پذیرفته شد. قیمت مجموع بروز رسانی شد";
$_LANG['orderForm']['promoCycles'] = "Expires after :cycles billing period/s";
$_LANG['orderForm']['productOptions'] = "محصولات/تنظیمات";
$_LANG['orderForm']['qty'] = "Qty";
$_LANG['orderForm']['priceCycle'] = "هزینه/دوره";
$_LANG['orderForm']['edit'] = "ویرایش";
$_LANG['orderForm']['update'] = "بروز رسانی";
$_LANG['orderForm']['remove'] = "حذف";
$_LANG['orderForm']['applyPromoCode'] = "اعمال کوپن تخفیف";
$_LANG['orderForm']['estimateTaxes'] = "برآورد مالیات";
$_LANG['orderForm']['removePromotionCode'] = "حذف کوپن تخفیف";
$_LANG['orderForm']['updateTotals'] = "بروز رسانی محموع";
$_LANG['orderForm']['continueShopping'] = "ادامه به خرید دادن";
$_LANG['orderForm']['removeItem'] = "حذف موارد";
$_LANG['orderForm']['yes'] = "بله";
$_LANG['orderForm']['cancel'] = "لغو";
$_LANG['orderForm']['close'] = "بستن";
$_LANG['orderForm']['totals'] = "مجموع";
$_LANG['orderForm']['includedWithPlans'] = "همراه با هر پلن میباشد";
$_LANG['orderForm']['whatIsIncluded'] = "چه امکاناتی افزوده شده است؟";
$_LANG['orderForm']['errorNoProductGroup'] = "امکان اجرای هیچ گروه محصولی نمیباشد";
$_LANG['orderForm']['errorNoProducts'] = "در این گروه هیچ محصولی قابل روئیت نیست";
$_LANG['orderForm']['errorNoGateways'] = "درگاه پرداخت در دسترس نیست بنابراین سفارش نمی تواند ادامه یابد";
$_LANG['orderForm']['errorUnavailableGateway'] = "دروازه انتخاب شده در دسترس نیست. لطفاً از قسمت جزئیات پرداخت گزینه ای را انتخاب کنید";
$_LANG['orderForm']['requiredField'] = "(فیلدهای مورد نیاز با *مشخص شده اند)";

$_LANG['cloudSlider']['feature01Title'] = "حداکثر آپتایم سرور";
$_LANG['cloudSlider']['feature01Description'] = "به روزرسانی سرور برای همه مشاغل بسیار مهم است - آن را ضربان قلب میزبانی کسب و کار خود بدانید. سرورهای فایل و پایگاه های داده ، سرورهای ایمیل و وب بخش مهمی از اکثر فرایندهای تجاری هستند و زمان خرابی آثار منفی مستقیم بر بهره وری ، فروش ، رضایت کارکنان و مشتریان دارد. به همین دلیل است که اطمینان از حداکثر زمان کارکرد سرور برای ما بسیار مهم است - ما می خواهیم اطمینان حاصل کنیم که فرایندهای تجاری شما سالم است تا مشتریان شما خوشحال شوند";
$_LANG['cloudSlider']['feature01DescriptionTwo'] = "با اعتماد به ما در مورد نیازهای تجاری خود ، ما به شما قول می دهیم که 99.9  از خدمات خود را ارائه دهیم ، خارج از هر گونه تعمیر و نگهداری استاندارد که ممکن است ارائه دهیم";
$_LANG['cloudSlider']['feature02Title'] = "تحویل داده در سرتاسر جهان";
$_LANG['cloudSlider']['feature02Description'] = "خدمات ما از صدها سرور و مرکز داده در سراسر جهان پشتیبانی می کند ، بنابراین می توانید خیالتان راحت باشد که مشتریان می توانند از هر کجا به وب سایت شما دسترسی داشته باشند. علاوه بر این ، ما ابزارهای نظارتی را برای ارائه تجزیه و تحلیل تخصصی به شما ارائه می دهیم - ترافیک وب سایت یک گام مهم در بهبود کارآیی و محبوبیت سایت شما و همچنین پیگیری مکان بازدیدکنندگان شما ، در چه ساعتی از روز است که از شما دیدن می کنند. ، و مدت زمان اقامت آنها تعهد ما به یک بازار جهانی به ثبت دامنه نیز می انجامد ، زیرا ما محبوب ترین تی ال دی ها را برای ثبت نام ارائه می دهیم";
$_LANG['cloudSlider']['feature02DescriptionTwo'] = "تعهد ما به پشتیبانی مشتری به سراسر جهان نیز می رسد. ما اینجا هستیم تا به هر طریق ممکن در زمینه میزبانی به شما کمک کنیم و می توانید از طریق تلفن ، ایمیل یا چت زنده با ما تماس بگیرید";
$_LANG['cloudSlider']['feature03Title'] = "رده بالای امنیت";
$_LANG['cloudSlider']['feature03Description'] = "خیالتان راحت باشد که ما نظارت امنیتی 24 ساعته و حفاظت دیداس را ارائه می دهیم. شما محافظت از داده های مشتری خود را جدی می گیرید و ما نیز. تیم امنیتی و پادمان های ما همه روزه در حال کار هستند تا سطح امنیت مورد نیاز در عصر دیجیتال امروز را تأمین کنند";
$_LANG['cloudSlider']['feature03DescriptionTwo'] = "طیف گسترده ای از ابزارهای امنیتی در اختیار شماست ، از جمله گواهینامه های اس اس ال ، پیکربندی فایروال ، خدمات نظارت امنیتی ، دسترسی به وی پی ان و موارد دیگر";
$_LANG['cloudSlider']['selectProductLevel'] = "سطح ایده آل را برای خود انتخاب کنید";

$_LANG['domainChecker.additionalPricingOptions'] = "گزینه های اضافی قیمت گذاری برای :domain";

$_LANG['orderpaymenttermfree'] = "رایگان";

$_LANG['usageStatsBwOverLimit'] = "شما بیش از حد مجاز ترافیک مصرف کرده اید";
$_LANG['usageStatsDiskOverLimit'] = "شما بیش از حد مجاز از فضای دیسک استفاده کرده اید";
$_LANG['insufficientstockmessage'] = "در حال حاضر موجودی برخی از اقلام کم است. مقادیر سبد خرید بر این اساس تنظیم شده است";

$_LANG['only'] = "فقط";
$_LANG['startingat'] = "شروع از";

$_LANG['yourdomainplaceholder'] = "example";
$_LANG['yourtldplaceholder'] = "com";

$_LANG['subaccountpermsproductsso'] = "Perform Single Sign-On";

$_LANG['sso']['title'] = "Single Sign-On";
$_LANG['sso']['summary'] = "برنامه های شخص ثالث از قابلیت Single Sign-On استفاده می کنند تا دسترسی مستقیم به حساب صورتحساب شما را بدون نیاز به احراز هویت مجدد فراهم کنند.";
$_LANG['sso']['disablenotice'] = "در صورت دسترسی به هر یک از برنامه های شخص ثالث خود برای کاربرانی که مایل به دسترسی به حساب صورت حساب خود نیستند ، ممکن است بخواهید این قابلیت را غیرفعال کنید";
$_LANG['sso']['enabled'] = "ورود به سیستم تنها در حال حاضر برای حساب شما مجاز است";
$_LANG['sso']['disabled'] = "Single Sign-On در حال حاضر برای حساب شما غیرفعال شده است";
$_LANG['sso']['redirectafterlogin'] = "پس از ورود به سیستم هدایت می شوید";

$_LANG['oauth']['badTwoFactorAuthModule'] = "Bad Two-Factor Auth Module. Please contact support.";
$_LANG['oauth']['permAccessNameAndEmail'] = "به نام و آدرس ایمیل خود دسترسی پیدا کنید";

$_LANG['errorButTryAgain'] = "یک خطا رخ داده است ، لطفا دوباره تلاش کنید.";
$_LANG['emailSent'] = "ایمیل ارسال شد";
$_LANG['resendEmail'] = "ارسال مجدد ایمیل تاییدیه";

// Markdown Editor Help
$_LANG['markdown']['title'] = "راهنمای Markdown";
$_LANG['markdown']['emphasis'] = "تاکید";
$_LANG['markdown']['bold'] = "کلفت";
$_LANG['markdown']['italics'] = "کج";
$_LANG['markdown']['strikeThrough'] = "خط خورده";
$_LANG['markdown']['headers'] = "سربرگ";
$_LANG['markdown']['bigHeader'] = "سربرگ بزرگ";
$_LANG['markdown']['mediumHeader'] = "سربرگ متوسط";
$_LANG['markdown']['smallHeader'] = "سربرگ کوچک";
$_LANG['markdown']['tinyHeader'] = "سربرگ ریز";
$_LANG['markdown']['lists'] = "لیست ها";
$_LANG['markdown']['genericListItem'] = "ایجاد لیست آیتم ها";
$_LANG['markdown']['numberedListItem'] = "مورد لیست شماره گذاری شده";
$_LANG['markdown']['links'] = "لینک ها";
$_LANG['markdown']['textToDisplay'] = "متن برای نمایش";
$_LANG['markdown']['exampleLink'] = "http://www.example.com";
$_LANG['markdown']['quotes'] = "نقل قول ها";
$_LANG['markdown']['thisIsAQuote'] = "این یک نقل قول است";
$_LANG['markdown']['quoteMultipleLines'] = "می تواند چندین خط را پوشش دهد";
$_LANG['markdown']['tables'] = "جدول ها";
$_LANG['markdown']['columnOne'] = "ستون 1";
$_LANG['markdown']['columnTwo'] = "ستون 2";
$_LANG['markdown']['columnThree'] = "ستون 3";
$_LANG['markdown']['withoutAligning'] = "...یا بدون تراز کردن ستون ها";
$_LANG['markdown']['john'] = "John";
$_LANG['markdown']['doe'] = "Doe";
$_LANG['markdown']['male'] = "Male";
$_LANG['markdown']['mary'] = "Mary";
$_LANG['markdown']['smith'] = "Smith";
$_LANG['markdown']['female'] = "Female";
$_LANG['markdown']['displayingCode'] = "نوع نمایش";
$_LANG['markdown']['spanningMultipleLines'] = "...یا چندین خط را در بر می گیرد";
$_LANG['markdown']['saved'] = "ذخیره شد";
$_LANG['markdown']['saving'] = "ذخیره اتوماتیک";

$_LANG['oauth']['authoriseAppToAccess'] = "اجازه میدهید :appName<br />به اکانت شما دسترسی داشته باشد؟";
$_LANG['oauth']['willBeAbleTo'] = "این اپلیکیشن قادر است که";
$_LANG['oauth']['authorise'] = "Authorise";
$_LANG['oauth']['currentlyLoggedInAs'] = "شما وارد شدید با اطلاعات :firstName :lastName";
$_LANG['oauth']['notYou'] = "شما نیستید؟";
$_LANG['oauth']['returnToApp'] = "بازگشت به :appName";
$_LANG['oauth']['copyrightFooter'] = "Copyright &copy; :dateYear :companyName. All Rights Reserved.";
$_LANG['oauth']['loginToGrantApp'] = "Login to grant :appName<br />دسترسی به حساب شما";
$_LANG['oauth']['redirectDescriptionOne'] = "در حال انتقال شما به اپلیکیشن هستیم. لطفا صبر کنید";
$_LANG['oauth']['redirectDescriptionTwo'] = "اگر مرورگر شما را اتوماتیک منتقل نکرد، لطفا ";
$_LANG['oauth']['redirectDescriptionThree'] = "برای ادامه کلیک کنید";
$_LANG['downloadLoginRequiredTagline'] = "لطفاً برای دسترسی به بارگیری فایل درخواستی وارد شوید";

$_LANG['orderForm']['year'] = "سال";
$_LANG['orderForm']['years'] = "سال";
$_LANG['orderForm']['domainOrKeyword'] = "یک نام دامنه یا کلمه کلیدی را وارد کنید";
$_LANG['orderForm']['searching'] = "در حال جستجو";
$_LANG['orderForm']['domainIsUnavailable'] = "<strong>:domain</strong> is unavailable";
$_LANG['orderForm']['domainHasUnavailableTld'] = "<strong>:tld</strong> domains are currently unavailable.";
$_LANG['orderForm']['add'] = "افزودن";
$_LANG['orderForm']['suggestedDomains'] = "نام های پیشنهادی";
$_LANG['orderForm']['generatingSuggestions'] = "در حال ایجاد لیست پیشنهادی برای شما";
$_LANG['orderForm']['addHosting'] = "افزودن هاست اشتراکی";
$_LANG['orderForm']['chooseFromRange'] = "از بین پکیج ها متنوع هاست اشتراکی، انتخاب کنید";
$_LANG['orderForm']['packagesForBudget'] = "هر بودجه ای دارید، بر اساس آن ما پکیج پیشنهادی داریم";
$_LANG['orderForm']['exploreNow'] = "پکیج ها را بررسی کن";
$_LANG['orderForm']['transferToUs'] = "دامنه خود را به سیستم ما انتقال دهید";
$_LANG['orderForm']['transferExtend'] = "همینک دامنه خود را انتقال دهید تا یک سال نیز تمدید گردد!";
$_LANG['orderForm']['transferDomain'] = "انتقال یک دامنه";
$_LANG['orderForm']['extendExclusions'] = "شامل برخی از تی ال دی ها و دامنه های اخیراً تمدید شده نمی شود";
$_LANG['orderForm']['singleTransfer'] = "انتقال یک عدد دامنه";
$_LANG['orderForm']['enterDomain'] = "لطفا نام دامنه خود را وارد کنید";
$_LANG['orderForm']['authCode'] = "کد انتقال";
$_LANG['orderForm']['authCodePlaceholder'] = "Epp Code / Auth Code";
$_LANG['orderForm']['authCodeTooltip'] = "برای شروع انتقال ، باید کد مجوز را از ثبت کننده فعلی خود دریافت کنید. اغلب می توان از آنها به عنوان کد ایی پی پی یا کد نویسنده نام برد. آنها به عنوان رمز عبور عمل می کنند و منحصر به نام دامنه هستند";
$_LANG['orderForm']['help'] = "کمک";
$_LANG['orderForm']['required'] = "ضروری";

$_LANG['orderForm']['checkingAvailability'] = "بررسی در دسترس بودن";
$_LANG['orderForm']['verifyingTransferEligibility'] = "تایید روند انتقال دامنه";
$_LANG['orderForm']['verifyingDomain'] = "تایید نام های انتخابی";
$_LANG['orderForm']['transferEligible'] = "دامنه شما واجد شرایط انتقال است";
$_LANG['orderForm']['transferUnlockBeforeContinuing'] = "لطفا قبل از ادامه روند انتقال، از باز بودن قفل انتقال دامنه در رجیستار قبلی، اطمینان حاصل نمایید";
$_LANG['orderForm']['transferNotEligible'] = "روند انتقال قابل انجام نیست";
$_LANG['orderForm']['transferNotRegistered'] = "دامنه وارد شده، اصلا ثبت نشده است !";
$_LANG['orderForm']['trasnferRecentlyRegistered'] = "اگر دامنه اخیرا ثبت شده است، لطفا چند روز دیگر مجدد برای انتقال تلاش کنید.";
$_LANG['orderForm']['transferAlternativelyRegister'] = "روش دیگر ، می توانید جستجویی را برای ثبت این دامنه انجام دهید";
$_LANG['orderForm']['domainInvalid'] = "نام دامنه وارد شده، نامعتبر است";
$_LANG['orderForm']['domainInvalidCheckEntry'] = "لطفا مقادیر وارد شده را مجدد بررسی کنید";
$_LANG['orderForm']['domainPriceRegisterLabel'] = "ادامه جهت ثبت دامنه برای";
$_LANG['orderForm']['domainPriceTransferLabel'] = "انتقال به ما و تمدید 1 سال* برای";

$_LANG['change'] = "تغییر";

$_LANG['filemanagement']['nofileuploaded'] = "فایلی بارگذاری نشد";
$_LANG['filemanagement']['invalidname'] = "نام فایلهای معتبر فقط شامل کاراکترهای عددی آلفا ، نقطه ، خط فاصله و زیر خط هستند";
$_LANG['filemanagement']['couldNotSaveFile'] = "فایل بارگذاری شده ذخیره نشد";
$_LANG['filemanagement']['checkPermissions'] = "لطفاً مجوزها را بررسی کنید";
$_LANG['filemanagement']['checkAvailableDiskSpace'] = "لطفاً فضای دیسک موجود را بررسی کنید";
$_LANG['filemanagement']['fileAlreadyExists'] = "فایل مورد نظر از قبل وجود دارد";
$_LANG['filemanagement']['noUniqueName'] = "نام فایل منحصر به فرد پیدا نشد";

$_LANG['cartSimpleCaptcha'] = "لطفا کد نمایش داده شده را وارد نمایید";

$_LANG['clientHomePanels']['showingRecent100'] = "نمایش 100 رکورد اخیر";
$_LANG['orderForm']['domainLetterOrNumber'] = "دامنه ها باید با حرف یا عدد شروع شوند";
$_LANG['orderForm']['domainLengthRequirements'] = " و بین <span class=\"min-length\"></span> و <span class=\"max-length\"></span>طول شخصیت ها";

$_LANG['clientareatransferredaway'] = "به دور منتقل شد";
$_LANG['clientareacompleted'] = "تکمیل شد";
$_LANG['domainContactUs'] = "تماس با ما";

$_LANG['orderForm']['shortPerYear'] = "/:yearsyr";
$_LANG['orderForm']['shortPerYears'] = "/:yearsyrs";

$_LANG['domainCheckerSalesGroup']['sale'] = "فروش";
$_LANG['domainCheckerSalesGroup']['hot'] = "داغ";
$_LANG['domainCheckerSalesGroup']['new'] = "جدید";

$_LANG['pricing']['browseExtByCategory'] = "مرور افزونه ها بر اساس دسته";
$_LANG['pricing']['register'] = "قیمت جدید";
$_LANG['pricing']['transfer'] = "انتقال";
$_LANG['pricing']['renewal'] = "بازسازی";
$_LANG['pricing']['selectExtCategory'] = "لطفاً یک دسته را از بالا انتخاب کنید";
$_LANG['pricing']['noExtensionsDefined'] = "هیچ افزونه ای در دسترس نیست";

$_LANG['navStore'] = "فروشگاه";
$_LANG['navBrowseProductsServices'] = "مشاهده همه";

$_LANG['navWebsiteSecurity'] = "وب سایت و امنیت";
$_LANG['navMarketConnectService']['symantec'] = "SSL Certificates";
$_LANG['navMarketConnectService']['weebly'] = "وب سایت ساز";
$_LANG['navMarketConnectService']['spamexperts'] = "خدمات پست الکترونیکی";

$_LANG['store']['emailServices']['title'] = "خدمات پست الکترونیکی";
$_LANG['store']['ssl']['title'] = "SSL Certificates";
$_LANG['store']['ssl']['dv']['title'] = "SSL معتبر دامنه";
$_LANG['store']['ssl']['ov']['title'] = "SSL اعتبارسنجی سازمان";
$_LANG['store']['ssl']['ev']['title'] = "SSL اعتبار سنجی گسترده";
$_LANG['store']['ssl']['wildcard']['title'] = "Wildcard SSL";
$_LANG['store']['websiteBuilder']['title'] = "وب سایت ساز";
$_LANG['store']['configure']['configureProduct'] = "پیکربندی محصول";

$_LANG['store']['ssl']['dv']['tagline'] = "فقط در چند دقیقه وب سایت خود را ایمن کنید";
$_LANG['store']['ssl']['dv']['descriptionTitle'] = "What is Standard DV SSL?";
$_LANG['store']['ssl']['dv']['descriptionContent'] = "<p>گواهی های اعتبار دامنه راهی مقرون به صرفه و سریع برای پیاده سازی اس اس ال در وب سایت شما ارائه می دهد. گواهینامه های تأیید شده دامنه تأیید می کنند که شما مالک دامنه هستید ، اما هیچگونه تأیید اعتبار اضافی در سطح سازمان انجام نمی دهید</p><p>گواهینامه های تأیید شده دامنه برای وب سایت های شخصی ، وبلاگ ها و رسانه های اجتماعی یا هر سایتی که اطلاعات خصوصی و محرمانه را منتقل نمی کند ایده آل است. گواهی تأیید شده دامنه قفل مرورگر را فعال می کند و استفاده از اج تی تی پی اس را برای اطمینان از بازدیدکنندگان وب سایت و مشتریان شما امکان پذیر می کند که حریم خصوصی آنها را جدی می گیرید.</p>";

$_LANG['store']['ssl']['ov']['tagline'] = "SSL با اطمینان بالا به بازدیدکنندگان وب سایت هویت معتبر شما را نشان می دهد";
$_LANG['store']['ssl']['ov']['descriptionTitle'] = "What is Organization Validation SSL?";
$_LANG['store']['ssl']['ov']['descriptionContent'] = "<p>Organization Validated SSL Certificates provide instant identity confirmation and strong SSL protection for your website and business.</p><p>OV SSL is an organization validated certificate that gives your website a step up in credibility over domain validated SSL Certificates. It activates the browser padlock and https, shows your corporate identity, and assures your customers that you take security very seriously. Site visitors can verify that the website is operated by a legitimate company and is not an imposter site.</p>";

$_LANG['store']['ssl']['ev']['tagline'] = "نوار آدرس سبز را برای بالاترین اعتماد و تبدیل فعال کنید";
$_LANG['store']['ssl']['ev']['descriptionTitle'] = "What is Extended Validation SSL?";
$_LANG['store']['ssl']['ev']['descriptionContent'] = "<p>EV SSL is an Extended Validation Certificate, the highest class of SSL available today and gives more credibility and trust to your website compared to using an organization or domain validated SSL Certificate.</p><p>Extended Validation SSL will in most cases display your company or site name in green. This prominent visual verification provides visitors added confidence that steps were taken to confirm the identity of the website and business they're visiting, increasing user trust in your website and its credibility – this is why most large companies and organizations choose EV certificates.</p>";

$_LANG['store']['ssl']['wildcard']['tagline'] = "زیر دامنه های نامحدود را در یک گواهینامه امن کنید";
$_LANG['store']['ssl']['wildcard']['descriptionTitle'] = "What is a Wildcard SSL Certificate?";
$_LANG['store']['ssl']['wildcard']['descriptionContent'] = "<p>Wildcard SSL allows you to secure an unlimited number of subdomains on a single certificate. It’s a great solution for anyone who hosts or manages multiple sites or pages that exist on the same domain. The one-time cost of the certificate covers you for additional subdomains you may add in the future.</p><p>Unlike a standard SSL Certificate that is issued to a single Fully Qualified Domain Name only, e.g. www.example.com, which means it can only be used to secure the exact domain to which it has been issued, a Wildcard SSL Certificate is issued to *.example.com, where the asterisk represents all possible subdomains.</p><p>Wildcard SSL is an option available for DV and OV SSL Certificates.</p>";

$_LANG['store']['websiteBuilder']['headline'] = "ساختن یک وب سایت هرگز آسان تر نبوده است";
$_LANG['store']['websiteBuilder']['tagline'] = "با ابزارهای کشیدن و رها کردن قدرتمند ، یک سایت عالی ایجاد کنید";
$_LANG['store']['websiteBuilder']['introduction'] = "Weebly’s drag and drop website builder makes it easy to create a powerful, professional website without any technical skills. Over 40 million entrepreneurs and small businesses have already used Weebly to build their online presence with a website, blog or store.";

$_LANG['store']['emailServices']['headline'] = "امنیت ایمیل ، ساخته شده برای شما";
$_LANG['store']['emailServices']['tagline'] = "کنترل صندوق دریافت خود را دوباره در دست گیرید";
$_LANG['store']['emailServices']['blockSpamHeadline'] = "تقریباً 100٪ ویروس ها ، بدافزارها و هرزنامه ها را قبل از رسیدن به صندوق ورودی شما مسدود کنید";

$_LANG['store']['sitelock']['features']['malwareScanning'] = "اسکن روزانه بدافزار";
$_LANG['store']['sitelock']['features']['numberOfPages'] = "تعدادی از صفحات";
$_LANG['store']['sitelock']['features']['dailyBlacklistMonitoring'] = "نظارت روزانه بر لیست سیاه";
$_LANG['store']['sitelock']['features']['sitelockRiskScore'] = "نمره خطر SiteLock";
$_LANG['store']['sitelock']['features']['websiteAppScan'] = "اسکن برنامه وب سایت";
$_LANG['store']['sitelock']['features']['sqlInjectionScan'] = "SQL Injection Scan";
$_LANG['store']['sitelock']['features']['xssScan'] = "اسکن Cross Site (XSS)";
$_LANG['store']['sitelock']['features']['trustSeal'] = "Sitelock ™ مهر اعتماد";
$_LANG['store']['sitelock']['features']['dailySmartScans'] = "اسکن روزانه SMART";
$_LANG['store']['sitelock']['features']['autoMalwareRemoval'] = "حذف خودکار بدافزارها";
$_LANG['store']['sitelock']['features']['trueshieldProtection'] = "TrueShield Protection";
$_LANG['store']['sitelock']['features']['wordPressScan'] = "WordPress Scan";
$_LANG['store']['sitelock']['features']['spamBlacklistMonitoring'] = "Spam Blacklist Monitoring";
$_LANG['store']['sitelock']['features']['waf'] = "فایروال برنامه وب";
$_LANG['store']['sitelock']['features']['globalCdn'] = "Global CDN";
$_LANG['store']['sitelock']['features']['contentAcceleration'] = "سرعت بخشیدن به محتوا";

$_LANG['pricingCycleShort']['monthly'] = "mo";
$_LANG['pricingCycleShort']['quarterly'] = "3mo";
$_LANG['pricingCycleShort']['semiannually'] = "6mo";
$_LANG['pricingCycleShort']['annually'] = "yr";
$_LANG['pricingCycleShort']['biennially'] = "2yrs";
$_LANG['pricingCycleShort']['triennially'] = "3yrs";
$_LANG['pricingCycleLong']['monthly'] = "ماه";
$_LANG['pricingCycleLong']['quarterly'] = "سه ماه";
$_LANG['pricingCycleLong']['semiannually'] = "شش ماه";
$_LANG['pricingCycleLong']['annually'] = "یکساله";
$_LANG['pricingCycleLong']['biennially'] = "دو ساله";
$_LANG['pricingCycleLong']['triennially'] = "سه ساله";

$_LANG['navManageSsl'] = "مدیریت گواهینامه های SSL";
$_LANG['almostDone'] = "تقریبا انجام شد";

$_LANG['invoicesPaymentPending'] = "پرداخت در انتظار";

$_LANG['ssl']['changeApproverEmail'] = "تغییر ایمیل تأیید کننده";
$_LANG['ssl']['reissueCertificate'] = "صدور مجدد گواهینامه";
$_LANG['ssl']['retrieveCertificate'] = "بازیابی گواهینامه";
$_LANG['ssl']['selectValidation'] = "یک روش اعتبار سنجی را انتخاب کنید";
$_LANG['ssl']['dnsMethod'] = "DNS";
$_LANG['ssl']['emailMethod'] = "ایمیل";
$_LANG['ssl']['fileMethod'] = "HTTP File";
$_LANG['ssl']['emailMethodDescription'] = "اعتبار سنجی توسط مرجع صدور گواهینامه انجام می شود و یک ایمیل با دستورالعمل های بیشتر به آدرس انتخاب شده در زیر ارسال می کند";
$_LANG['ssl']['dnsMethodDescription'] = "مرجع صدور گواهینامه ، پرونده های دی ان اس دامنه را بررسی می کند و به دنبال یک رکورد خاص با ارزش منحصر به فرد است. اطمینان حاصل کنید که برای تکمیل این تنظیمات به مدیریت تنظیمات دی ان اس دامنه دسترسی دارید. اطلاعات پیکربندی دی ان اس با پیکربندی موفق ارائه می شود";
$_LANG['ssl']['fileMethodDescription'] = "The Certificate Authority will make an HTTP request to a path hosted within the domain, expecting the response to contain a unique value. The path and value will be provided upon successful configuration.";
$_LANG['ssl']['selectEmail'] = "آدرس ایمیل را انتخاب کنید";
$_LANG['ssl']['nextSteps'] = "بعدی چیست";
$_LANG['ssl']['emailSteps'] = "مرجع صدور گواهینامه یک ایمیل به آدرس ایمیل انتخاب شده ارسال می کند. این شامل دستورالعمل های بیشتری است که برای تأیید مالکیت دامنه مورد نیاز است. پس از اتمام مراحل ، گواهینامه صادر می شود";
$_LANG['ssl']['fileSteps'] = "اکنون مرجع صدور گواهینامه درخواست خود را برای نشانی اینترنتی زیر شروع می کند تا اعتبار مقدار ارائه شده را تأیید کند. هنگامی که پاسخی با مقدار مشخص شده تشخیص داده شود ، گواهی صادر می شود";
$_LANG['ssl']['dnsSteps'] = "اکنون مرجع صدور گواهی ، سوابق دی ان اس دامنه را برای رکوردی مطابق با اطلاعات زیر آغاز می کند. به تنظیمات دی ان اس دامنه خود دسترسی داشته باشید و رکورد را ایجاد کنید. پس از کشف رکورد ، گواهی صادر می شود";
$_LANG['ssl']['url'] = "آدرس";
$_LANG['ssl']['value'] = "مقدار";
$_LANG['ssl']['type'] = "نوع";
$_LANG['ssl']['host'] = "Host";
$_LANG['ssl']['dnsRecordInformation'] = "DNS Record Information";
$_LANG['ssl']['fileInformation'] = "اطلاعات فایل";
$_LANG['ssl']['emailInformation'] = "اطلاعات ایمیل";
$_LANG['ssl']['dcv'] = "اعتبار سنجی دامنه";
$_LANG['ssl']['defaultcontacts'] = "Default Domain Contacts";
$_LANG['ssl']['reissueInfo1'] = "If you have lost your certificate, need to move servers, or had a problem with the installation, you can reissue your certificate to generate a new one.";
$_LANG['ssl']['reissueInfo2'] = "When reissuing a certificate, you cannot change the domain name and it must remain exactly the same.";
$_LANG['ssl']['reissueSuccess'] = "Reissue request submitted successfully!";
$_LANG['ssl']['reissueSuccessInfo'] = "<p>Your request to reissue your certificate has been submitted to the certificate authority.</p><p>You will receive an email shortly to <em>:approverEmail</em> to approve the certificate.</p><p>If you do not receive the email, please check any spam filters and virus protection folders in case the email has been quarantined. If you are still unable to find it, please <a href=\"submitticket.php\">contact support</a>.</p>";
$_LANG['ssl']['approverEmailUpdateSuccess'] = "Approver email updated successfully!";
$_LANG['ssl']['approverEmailUpdateInfo'] = "<p>You will receive an email shortly to <em>:newApproverEmail</em> to approve the certificate.</p><p>If you do not receive the email, please check any spam filters and virus protection folders in case the email has been quarantined. If you are still unable to find it, please <a href=\"submitticket.php\">contact support</a>.</p>";
$_LANG['ssl']['disableWhoisPrivacy'] = "Please disable any WHOIS privacy services before proceeding.";
$_LANG['ssl']['selectDcvEmail'] = "Select an active email address from the list below. You will receive an email to approve the SSL certificate.";
$_LANG['ssl']['approverEmailProcess'] = "<h4>About the Approver Email Process</h4><p>In order to issue an SSL certificate, the Certificate Authority has to validate the certificate order's authenticity to ensure that the request is legitimate and comes from an authorized owner of the domain.</p><p>Email-based domain validation is the most common certificate validation mechanism for certificate orders. The certificate authority compiles a list of approved email addresses using common administrative email addresses (for example, admin or webmaster) in combination with the public WHOIS data for the domain. You can only use one of these email addresses to confirm ownership.</p>";



$_LANG['upgradeCredit'] = "اعتبار را ارتقا دهید";
$_LANG['upgradeCreditDescription'] = "Calculation based on :daysRemaining unused days of :totalDays totals days in the current billing cycle.";

$_LANG['orderForm']['domainExtensionTransferNotSupported'] = "در حال حاضر دامنه شما برای انتقال به ما پشتیبانی نمی شود. لطفاً دامنه دیگری را امتحان کنید";
$_LANG['orderForm']['domainExtensionTransferPricingNotConfigured'] = "دامنه شما واجد شرایط انتقال به ما نیست. لطفاً دامنه دیگری را امتحان کنید";

$_LANG['remoteAuthn']['success'] = "!موفقیت";
$_LANG['remoteAuthn']['errorExclamation'] = "!خطا";
$_LANG['remoteAuthn']['error'] = "خطا";
$_LANG['remoteAuthn']['linkInitiated'] = "!پیوند آغاز شد";
$_LANG['remoteAuthn']['areYouSure'] = "مطمئنی؟";
$_LANG['remoteAuthn']['yesUnlinkIt'] = "بله ، پیوند آن را لغو کنید";
$_LANG['remoteAuthn']['unlinked'] = "!پیوند قطع شد";
$_LANG['remoteAuthn']['unavailable'] = "در حال حاضر در دسترس نیست لطفاً بعداً دوباره امتحان کنید";
$_LANG['remoteAuthn']['connectError'] = "ما نتوانستیم حساب شما را وصل کنیم. لطفا با سرپرست سیستم خود تماس بگیرید";
$_LANG['remoteAuthn']['completeSignIn'] = "لطفاً با ارائه دهنده خدمات انتخابی خود وارد سیستم شوید";
$_LANG['remoteAuthn']['redirecting'] = "ورود خودکار با موفقیت انجام شد! تغییر مسیر ";
$_LANG['remoteAuthn']['accountNowLinked'] = "اکنون حساب شما با حساب شما پیوند خورده است :displayName حساب.";
$_LANG['remoteAuthn']['oneTimeAuthRequired'] = "لطفاً برای ارتباط این سرویس با حساب موجود خود ، ورود به سیستم را کامل کنید. شما فقط باید یک بار این کار را انجام دهید";
$_LANG['remoteAuthn']['completeRegistrationForm'] = "لطفا فرم ثبت نام زیر را تکمیل کنید";
$_LANG['remoteAuthn']['completeNewAccountForm'] = "لطفاً اطلاعات حساب جدید خود را تکمیل کنید";
$_LANG['remoteAuthn']['linkedToAnotherClient'] = "این حساب قبلاً با ما به یک حساب موجود متصل شده است. لطفاً حساب دیگری را در ارائه دهنده احراز هویت شخص ثالث انتخاب کنید";
$_LANG['remoteAuthn']['alreadyLinkedToYou'] = "این حساب قبلاً با ما به حساب شما متصل شده است. لطفاً حساب دیگری را در ارائه دهنده احراز هویت شخص ثالث انتخاب کنید";
$_LANG['remoteAuthn']['saveTimeByLinking'] = "با ثبت نام با استفاده از حساب موجود با هر یک از خدمات زیر ، در وقت خود صرفه جویی کنید";
$_LANG['remoteAuthn']['unlinkDesc'] = "با این کار پیوند پیوسته حساب مجاز قطع می شود";
$_LANG['remoteAuthn']['mayHaveMultipleLinks'] = "برای ساده کردن تجربه ورود به سیستم ، حساب خود را با هر یک از خدمات زیر متصل کنید. ما فقط از این اطلاعات برای تأیید حساب شما استفاده می کنیم و هرگز از طرف شما پست نمی دهیم";
$_LANG['remoteAuthn']['titleSignUpVerb'] = "ثبت نام";
$_LANG['remoteAuthn']['titleOr'] = "یا";
$_LANG['remoteAuthn']['titleLinkedAccounts'] = "حساب های مرتبط";
$_LANG['remoteAuthn']['provider'] = "تامین کننده";
$_LANG['remoteAuthn']['name'] = "نام";
$_LANG['remoteAuthn']['emailAddress'] = "آدرس ایمیل";
$_LANG['remoteAuthn']['actions'] = "عملیات";
$_LANG['remoteAuthn']['noLinkedAccounts'] = "هیچ حساب پیوندی یافت نشد";
$_LANG['remoteAuthn']['signInWith'] = "ورود به سیستم با:provider";
$_LANG['remoteAuthn']['connectWith'] = "ارتباط با :provider";
$_LANG['remoteAuthn']['signUpWith'] = "ثبت نام با :provider";

$_LANG['unlink'] = "لغو پیوند";

$_LANG['invoicePaymentSuccessAwaitingNotify'] = "با تشکر از شما برای تکمیل مراحل پرداخت. ما منتظر اطلاع رسانی برای تأیید پرداختی هستیم که تازه انجام داده اید. به محض دریافت این ایمیل ، تأییدیه ای را برای شما ارسال می کنیم";

$_LANG['errorPage']['404']['title'] = "!اوه";
$_LANG['errorPage']['404']['subtitle'] = "ما نتوانستیم آن صفحه را پیدا کنیم";
$_LANG['errorPage']['404']['description'] = "برای رفتن به صفحات دیگر از گزینه های زیر استفاده کنید";
$_LANG['errorPage']['404']['home'] = "صفحه اصلی";
$_LANG['errorPage']['404']['submitTicket'] = "با پشتیبانی تماس بگیرید";

$_LANG['creditCard']['removeDescription'] = "آیا مطمئن هستید که می خواهید مشخصات کارت اعتباری خود را حذف کنید؟";

$_LANG['marketConnect']['websiteBuilder']['ftpHost'] = "FTP Host";
$_LANG['marketConnect']['websiteBuilder']['ftpUsername'] = "FTP نام کاربری";
$_LANG['marketConnect']['websiteBuilder']['ftpPassword'] = "FTP رمزعبور";
$_LANG['marketConnect']['websiteBuilder']['ftpPath'] = "FTP Path";
$_LANG['marketConnect']['websiteBuilder']['updateFtp'] = " را بروز کنیدFTPاطلاعات";
$_LANG['marketConnect']['websiteBuilder']['manage'] = "Login to Weebly";

$_LANG['domainChecker']['contactSupport'] = "برای خرید با پشتیبانی تماس بگیرید";

$_LANG['cart']['availableCreditBalance'] = "موجودی اعتبار موجود شما می باشد :amount.";
$_LANG['cart']['applyCreditAmount'] = "درخواست دادن <span>:amount</span>از موجودی اعتباری من تا این سفارش و مبلغ باقی مانده را از طریق روش پرداختی که در زیر انتخاب شده پرداخت می کنم";
$_LANG['cart']['applyCreditAmountNoFurtherPayment'] = "درخواست دادن <span>:amount</span> از موجودی اعتباری من تا این سفارش. هیچ گونه پرداخت دیگری پرداخت نمی شود";
$_LANG['cart']['applyCreditSkip'] = "هیچ اعتباری از موجودی اعتبار من به این سفارش اعمال نکنید. هزینه آن را با استفاده از روش پرداختی که در زیر انتخاب شده است ، پرداخت می کنم";

$_LANG['dateTime']['monday'] = "دوشنبه";
$_LANG['dateTime']['tuesday'] = "سه شنبه";
$_LANG['dateTime']['wednesday'] = "چهارشنبه";
$_LANG['dateTime']['thursday'] = "پنج شنبه";
$_LANG['dateTime']['friday'] = "حمعه";
$_LANG['dateTime']['saturday'] = "شنبه";
$_LANG['dateTime']['sunday'] = "یک شنبه";
$_LANG['dateTime']['mon'] = "Mon";
$_LANG['dateTime']['tue'] = "Tue";
$_LANG['dateTime']['wed'] = "Wed";
$_LANG['dateTime']['thu'] = "Thu";
$_LANG['dateTime']['fri'] = "Fri";
$_LANG['dateTime']['sat'] = "Sat";
$_LANG['dateTime']['sun'] = "Sun";
$_LANG['dateTime']['th'] = "th";
$_LANG['dateTime']['nd'] = "nd";
$_LANG['dateTime']['rd'] = "rd";
$_LANG['dateTime']['st'] = "st";
$_LANG['dateTime']['january'] = "January";
$_LANG['dateTime']['february'] = "February";
$_LANG['dateTime']['march'] = "March";
$_LANG['dateTime']['april'] = "April";
$_LANG['dateTime']['may'] = "May";
$_LANG['dateTime']['june'] = "June";
$_LANG['dateTime']['july'] = "July";
$_LANG['dateTime']['august'] = "August";
$_LANG['dateTime']['september'] = "September";
$_LANG['dateTime']['october'] = "October";
$_LANG['dateTime']['november'] = "November";
$_LANG['dateTime']['december'] = "December";
$_LANG['dateTime']['jan'] = "Jan";
$_LANG['dateTime']['feb'] = "Feb";
$_LANG['dateTime']['mar'] = "Mar";
$_LANG['dateTime']['apr'] = "Apr";
$_LANG['dateTime']['jun'] = "Jun";
$_LANG['dateTime']['jul'] = "Jul";
$_LANG['dateTime']['aug'] = "Aug";
$_LANG['dateTime']['sep'] = "Sept";
$_LANG['dateTime']['oct'] = "Oct";
$_LANG['dateTime']['nov'] = "Nov";
$_LANG['dateTime']['dec'] = "Dec";
$_LANG['dateTime']['AM'] = "AM";
$_LANG['dateTime']['PM'] = "PM";
$_LANG['dateTime']['am'] = "am";
$_LANG['dateTime']['pm'] = "pm";
$_LANG['dateTime']['day'] = "Day";
$_LANG['dateTime']['days'] = "Days";
$_LANG['dateTime']['hour'] = "Hour";
$_LANG['dateTime']['hours'] = "Hours";
$_LANG['dateTime']['minute'] = "Minute";
$_LANG['dateTime']['minutes'] = "Minutes";
$_LANG['dateTime']['abbr']['minute'] = "min";
$_LANG['dateTime']['abbr']['second'] = "sec";
$_LANG['dateTime']['title']['days'] = "Days";
$_LANG['dateTime']['title']['hours'] = "Hours";
$_LANG['dateTime']['symbol']['second'] = "s";

$_LANG['emailMarketing']['joinOurMailingList'] = "به خبرنامه  ما بپیوندید";

$_LANG['edit'] = "ویرایش";
$_LANG['thankYou'] = "متشکرم";
$_LANG['na'] = "N/A";

$_LANG['domainGracePeriodFeeInvoiceItem'] = "هزینه تمدید دامنه در دوره گریس برای :domainName";
$_LANG['domainRedemptionPeriodFeeInvoiceItem'] = "Domain Renewal Fee in Redemption Grace Period for :domainName";
$_LANG['gracePeriod'] = "مهلت";
$_LANG['redemptionPeriod'] = "Redemption Period";
$_LANG['domainsExpiringSoon'] = "به زودی منقضی می شود";
$_LANG['expiresToday'] = "امروز منقضی می شود";
$_LANG['clientareagrace'] = "مهلت (منقضی شده)";
$_LANG['clientarearedemption'] = "دوره بازخرید (منقضی شده)";
$_LANG['domainRenewal']['availablePeriods'] = "دوره های تمدید موجود";
$_LANG['domainRenewal']['unavailable'] = "تمدید دامنه در دسترس نیست";
$_LANG['domainRenewal']['renewingDomains'] = "دامنه های خود را تمدید کنید";
$_LANG['domainRenewal']['graceFee'] = "هزینه مهلت";
$_LANG['domainRenewal']['redemptionFee'] = "کارمزد دوره بازخرید";
$_LANG['domainRenewal']['graceRenewalPeriodDescription'] = "دامنه ها پس از انقضا وارد دوره  هزینه بازخرید می شوند. هنگامی که در این وضعیت قرار گرفتید ، دامنه فقط برای حداکثر مدت دوره ثبت نام قابل تمدید است.";
$_LANG['domainRenewal']['hasExpired'] = "این دامنه منقضی شده است";
$_LANG['domainRenewal']['expiringIn'] = "انقضا در :days days";
$_LANG['domainRenewal']['expiredDaysAgo'] = "منقضی شده :days days ago";
$_LANG['domainRenewal']['noDomains'] = "شما در حال حاضر هیچ دامنه ای ندارید که واجد شرایط تمدید باشد";
$_LANG['domainRenewal']['showingDomains'] = "نمایش :showing از :totalCount دامنه";
$_LANG['domainRenewal']['showAll'] = "نمایش همه";
$_LANG['domainRenewal']['maximumAdvanceRenewal'] = "حداکثر تمدید پیش فرض است :days روز";

$_LANG['navMarketConnectService']['sitelock'] = "امنیت وب سایت";
$_LANG['store']['sitelock']['title'] = "SiteLock امنیت وب سایت";
$_LANG['store']['sitelock']['tagline'] = "وب سایت خود را بطور خودکار برای بدافزار اسکن کرده و از اعتبار آنلاین محافظت کنید";
$_LANG['store']['sitelock']['manageService'] = " خود را مدیریت کنیدSiteLock سرویس ";
$_LANG['store']['sitelock']['cartShortDescription'] = " طیف وسیعی از ویژگی ها را برای محافظت از وب سایت شما و اعتبار کسب و کار شما ارائه می دهدSiteLock";
$_LANG['store']['sitelock']['plansAndPricing'] = "پلن ها و قیمت گذاری";
$_LANG['store']['sitelock']['featuresLink'] = "امکانات";
$_LANG['store']['sitelock']['websiteHacked'] = "وب سایت هک شده؟";
$_LANG['store']['sitelock']['faq'] = "سوالات متداول";
$_LANG['store']['sitelock']['contentHeadline'] = "امنیت وب سایت و حفاظت از بدافزار برای وب سایت شما";
$_LANG['store']['sitelock']['contentBodyParagraph1'] = "رهبر جهانی در امنیت وب سایت ، از وب سایت شما محافظت می کند تا به شما آرامش بدهد SiteLock leader ";
$_LANG['store']['sitelock']['contentBodyParagraph2'] = "آسیب پذیری ها و کد مخرب شناخته شده را شناسایی می کند و به طور خودکار آن را از وب سایت شما حذف می کند تا از وب سایت و بازدیدکنندگان شما در برابر تهدیدها محافظت کندSiteLockاسکن روزانه بدافزار";
$_LANG['store']['sitelock']['contentBodyParagraph3'] = "Plus you get the SiteLock Trust Seal which builds customer confidence and is proven to increase sales and conversion rates.";
$_LANG['store']['sitelock']['comparePlans'] = "Compare SiteLock Plans";
$_LANG['store']['sitelock']['comparePlansSubtitle'] = "ویژگی های امنیتی حرفه ای برای وب سایت شما";
$_LANG['store']['sitelock']['featuresTitle'] = "ویژگی های SiteLock";
$_LANG['store']['sitelock']['featuresHeadline'] = "طیف وسیعی از ویژگی های طراحی شده برای محافظت از وب سایت و اعتبار کسب و کار شما را ارائه می دهد";
$_LANG['store']['sitelock']['featuresMalwareTitle'] = "اسکن بدافزار";
$_LANG['store']['sitelock']['featuresMalwareContent'] = "هرگونه بدافزاری که در وب سایت شما شناسایی شده است را بطور فعال رصد کرده و به شما هشدار می دهد";
$_LANG['store']['sitelock']['featuresMalwareRemovalTitle'] = "حذف خودکار بدافزارها";
$_LANG['store']['sitelock']['featuresMalwareRemovalContent'] = "If a scan finds anything, SiteLock will safely remove any known malware automatically.";
$_LANG['store']['sitelock']['featuresVulnerabilityTitle'] = "اسکن آسیب پذیری";
$_LANG['store']['sitelock']['featuresVulnerabilityContent'] = "به طور خودکار برنامه های خود را بررسی می کند تا از به روز بودن و ایمن بودن آنها در برابر آسیب پذیری های شناخته شده اطمینان حاصل کند";
$_LANG['store']['sitelock']['featuresOWASPTitle'] = "OWASP Protection";
$_LANG['store']['sitelock']['featuresOWASPContent'] = "Get protection against the top 10 web app security flaws as recognised by OWASP, the Open Web Application Security Project.";
$_LANG['store']['sitelock']['featuresTrustSealTitle'] = "SiteLock&trade; Trust Seal";
$_LANG['store']['sitelock']['featuresTrustSealContent'] = " با نشان دادن محافظت از وب سایت خود ، به بازدیدکنندگان خود اطمینان بیشتری دهیدSiteLock.";
$_LANG['store']['sitelock']['featuresFirewallTitle'] = "فایروال";
$_LANG['store']['sitelock']['featuresFirewallContent'] = "The TrueShield&trade; Web Application Firewall protects your website against hackers and attacks.";
$_LANG['store']['sitelock']['featuresReputationTitle'] = "از شهرت خود محافظت کنید";
$_LANG['store']['sitelock']['featuresReputationContent'] = "اسکن روزانه به تشخیص بدافزار کمک می کند قبل از اینکه موتورهای جستجو فرصتی برای یافتن آن پیدا کرده و سایت شما را در لیست سیاه قرار دهند";
$_LANG['store']['sitelock']['featuresSetupTitle'] = "راه اندازی خودکار سریع";
$_LANG['store']['sitelock']['featuresSetupContent'] = "راه اندازی فوری و کاملاً خودکار بدون نیاز به نصب ، بلافاصله از شما محافظت می کند";
$_LANG['store']['sitelock']['featuresCDNTitle'] = "شبکه تحویل محتوا (CDN)";
$_LANG['store']['sitelock']['featuresCDNContent'] = "وب سایت خود را با توزیع در سطح جهانی و ارائه آن به بازدیدکنندگان از نزدیکترین مکان برای سرعت بیشتر بارگذاری صفحه در هر کجا که هستید ، افزایش دهید";
$_LANG['store']['sitelock']['emergencyPlanTitle'] = "وب سایت هک شده؟";
$_LANG['store']['sitelock']['emergencyPlanHeadline'] = "Fix it now with SiteLock Emergency Response";
$_LANG['store']['sitelock']['emergencyPlanBody'] = "If your website has been attacked and compromised get immediate emergency assistance to quickly recover your site. Here's how SiteLock Emergency Response helps:";
$_LANG['store']['sitelock']['emergencyPlanResponseTitle'] = "ریسپانسیو فوری";
$_LANG['store']['sitelock']['emergencyPlanResponseContent'] = "سریعترین زمان پاسخگویی ما را با تجزیه و تحلیل دریافت کنید و برای بازیابی سایت خود در مدت 30 دقیقه کار کنید";
$_LANG['store']['sitelock']['emergencyPlanMalwareTitle'] = "حذف کامل بدافزار";
$_LANG['store']['sitelock']['emergencyPlanMalwareContent'] = "اگر فناوری خودکار ما نتواند محتوای مخرب را حذف کند ، ما تمیز کردن دستی را انجام می دهیم";
$_LANG['store']['sitelock']['emergencyPlanPriorityTitle'] = "Priority treatment";
$_LANG['store']['sitelock']['emergencyPlanPriorityContent'] = "با بسته اضطراری سریعاً به بالای صف ردیابی می شوید";
$_LANG['store']['sitelock']['emergencyPlanAftercareTitle'] = "7 روز مراقبت بعد";
$_LANG['store']['sitelock']['emergencyPlanAftercareContent'] = "در طول فرآیند پاکسازی و بازیابی سایت خود ، پیشرفت را با به روزرسانی های زمان واقعی ما پیگیری کنید";
$_LANG['store']['sitelock']['emergencyPlanUpdatesTitle'] = "به روز رسانی در زمان واقعی";
$_LANG['store']['sitelock']['emergencyPlanUpdatesContent'] = "در طول فرآیند پاکسازی و بازیابی سایت خود ، پیشرفت را با به روزرسانی های زمان واقعی ما پیگیری کنید";
$_LANG['store']['sitelock']['emergencyPlanPaymentTitle'] = "پرداخت یکجا";
$_LANG['store']['sitelock']['emergencyPlanPaymentContent'] = "خدمات اورژانس با هزینه یکبار در دسترس است ، هیچ هزینه یا اشتراک مشترکی وجود ندارد";
$_LANG['store']['sitelock']['emergencyPlanOnlyCost'] = "فقط :price  برای 7 روز محافظت";
$_LANG['store']['sitelock']['buyNow'] = "هم اکنون خریداری کنید";
$_LANG['store']['sitelock']['faqTitle'] = "سوالات متداول";
$_LANG['store']['sitelock']['faqOneTitle'] = "SiteLock چیست؟";
$_LANG['store']['sitelock']['faqOneBody'] = "SiteLock provides simple, fast and affordable website security to websites of all sizes. Founded in 2008, the company protects over 12 million websites worldwide. The SiteLock cloud-based suite of products offers automated website vulnerability detection and malware removal, DDoS protection, website acceleration, website risk assessments, and PCI compliance.";
$_LANG['store']['sitelock']['faqOneBodyLearnMore'] = "To learn more about SiteLock, :learnMoreLink";
$_LANG['store']['sitelock']['faqOneBodyLearnLinkText'] = "watch the 'How SiteLock Works' video by clicking here";
$_LANG['store']['sitelock']['faqTwoTitle'] = "?SiteLock چه کاری انجام می دهد";
$_LANG['store']['sitelock']['faqTwoBody'] = "SiteLock provides comprehensive website security. It performs website daily scans to identify vulnerabilities or malware. When vulnerabilities or malware are found, you will be alerted immediately. Based on your SiteLock scanner, it will automatically remove any malware on your website.  For content management system (CMS) websites, SiteLock can automatically patch found vulnerabilities.";
$_LANG['store']['sitelock']['faqThreeTitle'] = "SiteLock برای چه نوع مسائلی اسکن می کند؟";
$_LANG['store']['sitelock']['faqThreeBody'] = ":SiteLock دارای فناوری انجام اسکن جامع وب سایت است که شامل می شود";
$_LANG['store']['sitelock']['faqThreeBodyList1Title'] = "اسکن و حذف بدافزارهای مبتنی بر فایل";
$_LANG['store']['sitelock']['faqThreeBodyList1'] = "SiteLock performs daily scans of a website's files for malware. If malware is found, the website owner is alerted immediately. SiteLock also offers comprehensive scans to automatically remove the malware.";
$_LANG['store']['sitelock']['faqThreeBodyList2Title'] = "اسکن آسیب پذیری";
$_LANG['store']['sitelock']['faqThreeBodyList2'] = "SiteLock performs scans of website applications for common vulnerabilities that could lead to a compromise.";
$_LANG['store']['sitelock']['faqThreeBodyList3Title'] = "امنیت برنامه و وصله آسیب پذیری";
$_LANG['store']['sitelock']['faqThreeBodyList3'] = "SiteLock has the technology to automatically patch vulnerabilities in content management systems (CMS).";
$_LANG['store']['sitelock']['faqFourTitle'] = "آسیب پذیری ها و بدافزارها چیست؟";
$_LANG['store']['sitelock']['faqFourBodyParagraph1'] = "A :vulnerabilityStrong is a weakness or misconfiguration in a website or web application code that allows an attacker to gain some level of control of the site, and possibly the hosting server. Most vulnerabilities are exploited through automated means, such as vulnerability scanners and botnets.";
$_LANG['store']['sitelock']['websiteVulnerability'] = "آسیب پذیری وب سایت";
$_LANG['store']['sitelock']['faqFourBodyParagraph2'] = ":malwareStrong. short for malicious software, is used to gather sensitive data, gain unauthorized access to websites and even hijack computers.";
$_LANG['store']['sitelock']['malware'] = "بد افزار";
$_LANG['store']['sitelock']['faqFiveTitle'] = "Will SiteLock impact website performance?";
$_LANG['store']['sitelock']['faqFiveBody'] = "No. During a website scan, SiteLock downloads the relevant files to a secure server and performs scans there. There is no impact to the website content, code, bandwidth or server resources on the website.";
$_LANG['store']['sitelock']['faqSixTitle'] = "What is the SiteLock Trust Seal?";
$_LANG['store']['sitelock']['faqSixBody'] = "The SiteLock Trust Seal is a widely-recognized security badge you can display on your website. It is a clear indication that your website is secure and malware-free. To add the seal to your website, simply include the code snippet that SiteLock provides in the footer area of your website.";

$_LANG['learnmore'] = "اطلاعات بیشتر";
$_LANG['category'] = "دسته بندی";
$_LANG['changeCurrency'] = "تغییر ارز";

$_LANG['store']['ssl']['competitiveUpgrade'] = "ارتقاء رقابتی";
$_LANG['store']['ssl']['competitiveUpgradeBannerMsg'] = "دامنه شما <em>:domain</em> با موفقیت تأیید شده است لطفاً برای ادامه و تکمیل مراحل پرداخت ، نوع گواهی را انتخاب کنید";
$_LANG['store']['ssl']['competitiveUpgradeQualified'] = "واجد شرایط ارتقاء رقابتی";

$_LANG['dismiss'] = "رد";

$_LANG['store']['emailServices']['manageService'] = "Login to SpamExperts Control Panel";

$_LANG['noDomain'] = "بدون دامنه";

$_LANG['upgradeService']['serviceBeingUpgraded'] = "سرویس در حال ارتقا است";
$_LANG['upgradeService']['chooseNew'] = "انتخاب محصول /طرح جدید";
$_LANG['upgradeService']['currentProduct'] = "محصول فعلی شما";
$_LANG['upgradeService']['recommended'] = "توصیه شده";
$_LANG['upgradeService']['select'] = "انتخاب";

$_LANG['servicesRenew'] = "Renew";
$_LANG['renewService']['titlePlural'] = "Renew Services";
$_LANG['renewService']['titleSingular'] = "Renew Service";
$_LANG['renewService']['titleAltPlural'] = "Service Renewals";
$_LANG['renewService']['titleAltSingular'] = "Service Renewal";
$_LANG['renewService']['noServices'] = "You do not currently have any services that are eligible for renewal.";
$_LANG['renewService']['showingServices'] = "Showing :showing of :totalCount services.";
$_LANG['renewService']['renewingIn'] = "Renewing in :days days";
$_LANG['renewService']['renewalUnavailable'] = "Renewal Unavailable";
$_LANG['renewService']['serviceNextDueDateBasic'] = "Next Due Date: :nextDueDate";
$_LANG['renewService']['serviceNextDueDateExtended'] = "Next Due Date: :nextDueDate (:nextDueDateFormatted)";
$_LANG['renewService']['renewalPeriodLabel'] = "Renewal Period";
$_LANG['renewService']['renewalPeriod'] = "(:nextDueDate - :nextPayUntilDate) @ :renewalPrice";
$_LANG['renewService']['searchPlaceholder'] = "Search by Name, Domain, or ID";
$_LANG['renewService']['hideShowServices']['hide'] = "Hide Non-Renewable Items";
$_LANG['renewService']['hideShowServices']['show'] = "Show Non-Renewable Items";

$_LANG['renewService']['statusInfo']['notSupported'] = "This product does not support on-demand renewals.";
$_LANG['renewService']['statusInfo']['nonRecurring'] = "This is a one-time service that does not use recurring billing.";
$_LANG['renewService']['statusInfo']['outsideRenewal'] = "This service is not within its renewal period.";
$_LANG['renewService']['statusInfo']['serviceStatus'] = "This service is :serviceStatus. Renewals require an Active status.";
$_LANG['renewService']['statusInfo']['unpaidInvoices'] = "The service has :unpaidInvoiceCount unpaid invoice(s).";
$_LANG['renewService']['statusInfo']['metricUsage'] = "This is a usage-billed service that cannot support on-demand renewals.";

$_LANG['renewServiceAddon']['titleAltSingular'] = "Addon Renewal";
$_LANG['renewServiceAddon']['titleAltPlural'] = "Addon Renewals";

$_LANG['feeds']['itemsInBasket'] = "You have <b>:count</b> items in your basket";

$_LANG['validation']['accepted'] = "The :attribute must be accepted.";
$_LANG['validation']['active_url'] = "The :attribute is not a valid URL.";
$_LANG['validation']['after'] = "The :attribute must be a date after :date.";
$_LANG['validation']['alpha'] = "The :attribute may only contain letters.";
$_LANG['validation']['alpha_dash'] = "The :attribute may only contain letters, numbers, and dashes.";
$_LANG['validation']['alpha_num'] = "The :attribute may only contain letters and numbers.";
$_LANG['validation']['array'] = "The :attribute must be an array.";
$_LANG['validation']['before'] = "The :attribute must be a date before :date.";
$_LANG['validation']['between']['numeric'] = "The :attribute must be between :min and :max.";
$_LANG['validation']['between']['file'] = "The :attribute must be between :min and :max kilobytes.";
$_LANG['validation']['between']['string'] = "The :attribute must be between :min and :max characters.";
$_LANG['validation']['between']['array'] = "The :attribute must have between :min and :max items.";
$_LANG['validation']['boolean'] = "The :attribute field must be true or false.";
$_LANG['validation']['confirmed'] = "The :attribute confirmation does not match.";
$_LANG['validation']['date'] = "The :attribute is not a valid date.";
$_LANG['validation']['date_format'] = "The :attribute does not match the format :format.";
$_LANG['validation']['different'] = "The :attribute and :other must be different.";
$_LANG['validation']['digits'] = "The :attribute must be :digits digits.";
$_LANG['validation']['digits_between'] = "The :attribute must be between :min and :max digits.";
$_LANG['validation']['email'] = "The :attribute must be a valid email address.";
$_LANG['validation']['exists'] = "The selected :attribute is invalid.";
$_LANG['validation']['filled'] = "The :attribute field is required.";
$_LANG['validation']['image'] = "The :attribute must be an image.";
$_LANG['validation']['in'] = "The selected :attribute is invalid.";
$_LANG['validation']['integer'] = "The :attribute must be an integer.";
$_LANG['validation']['ip'] = "The :attribute must be a valid IP address.";
$_LANG['validation']['json'] = "The :attribute must be a valid JSON string.";
$_LANG['validation']['max']['numeric'] = "The :attribute may not be greater than :max.";
$_LANG['validation']['max']['file'] = "The :attribute may not be greater than :max kilobytes.";
$_LANG['validation']['max']['string'] = "The :attribute may not be greater than :max characters.";
$_LANG['validation']['max']['array'] = "The :attribute may not have more than :max items.";
$_LANG['validation']['mimes'] = "The :attribute must be a file of type: :values.";
$_LANG['validation']['min']['numeric'] = "The :attribute must be at least :min.";
$_LANG['validation']['min']['file'] = "The :attribute must be at least :min kilobytes.";
$_LANG['validation']['min']['string'] = "The :attribute must be at least :min characters.";
$_LANG['validation']['min']['array'] = "The :attribute must have at least :min items.";
$_LANG['validation']['not_in'] = "The selected :attribute is invalid.";
$_LANG['validation']['numeric'] = "The :attribute must be a number.";
$_LANG['validation']['present'] = "The :attribute field must be present.";
$_LANG['validation']['regex'] = "The :attribute format is invalid.";
$_LANG['validation']['required'] = "The :attribute field is required.";
$_LANG['validation']['required_if'] = "The :attribute field is required when :other is :value.";
$_LANG['validation']['required_unless'] = "The :attribute field is required unless :other is in :values.";
$_LANG['validation']['required_with'] = "The :attribute field is required when :values is present.";
$_LANG['validation']['required_with_all'] = "The :attribute field is required when :values is present.";
$_LANG['validation']['required_without'] = "The :attribute field is required when :values is not present.";
$_LANG['validation']['required_without_all'] = "The :attribute field is required when none of :values are present.";
$_LANG['validation']['same'] = "The :attribute and :other must match.";
$_LANG['validation']['size']['numeric'] = "The :attribute must be :size.";
$_LANG['validation']['size']['file'] = "The :attribute must be :size kilobytes.";
$_LANG['validation']['size']['string'] = "The :attribute must be :size characters.";
$_LANG['validation']['size']['array'] = "The :attribute must contain :size items.";
$_LANG['validation']['string'] = "The :attribute must be a string.";
$_LANG['validation']['timezone'] = "The :attribute must be a valid zone.";
$_LANG['validation']['unique'] = "The :attribute has already been taken.";
$_LANG['validation']['url'] = "The :attribute format is invalid.";

$_LANG['orderErrorServerHostnameInvalid'] = "نام هاست سرور شما معتبر نیست";
$_LANG['orderErrorServerNameserversInvalid'] = "The nameserver prefix is invalid.";

$_LANG['toggleNav'] = "تغییر وضعیت ناوبری";
$_LANG['checkAll'] = "بررسی  همه";
$_LANG['uncheckAll'] = "خارج کردن از حالت انتخاب همه";

$_LANG['maxmind']['manualReview'] = "سفارش شما برای بررسی دستی نگه داشته شده است<br /><br />اگر احساس می کنید این پیام را به اشتباه دریافت کرده اید ، لطفاً عذرخواهی ما را بپذیرید و <a href=\"submitticket.php\"> یک تیکت پشتیبانی ارسال کنید</a>  به تیم خدمات مشتری ما. متشکرم";

$_LANG['nodomain'] = "دامنه ای مشخص نشده است";

$_LANG['store']['symantec']['cartTitle'] = "از سایت خود با اس اس ال محافظت کنید";
$_LANG['store']['symantec']['cartShortDescription'] = "SSL را به میزبانی وب خود اضافه کنید تا به بازدیدکنندگان اطمینان دهید که وب سایت شما ایمن و ایمن است و به ایجاد اعتماد کمک می کند";

$_LANG['store']['weebly']['cartTitle'] = "وب سایت ساز قدرتمند";
$_LANG['store']['weebly']['cartShortDescription'] = "Add Weebly's drag and drop website builder to your hosting to allow you to create an awesome looking website, store or blog.";

$_LANG['store']['spamexperts']['cartTitle'] = "امنیت ایمیل SpamExperts";
$_LANG['store']['spamexperts']['cartShortDescription'] = "برای محافظت و ایمن سازی ایمیل خود در برابر حملات و بدافزارها ، امنیت و بایگانی ایمیل حرفه ای را به دامنه خود اضافه کنید";

$_LANG['store']['sitelock']['cartTitle'] = "SiteLock امنیت وب سایت";

$_LANG['store']['symantec']['promo']['sidebar']['title'] = "SSL را به وب سایت خود اضافه کنید";
$_LANG['store']['symantec']['promo']['sidebar']['body'] = "نماد قفل را فعال کرده و از حریم خصوصی کاربر محافظت کنید";

$_LANG['store']['weebly']['promo']['sidebar']['title'] = "Powerful Site Builder";
$_LANG['store']['weebly']['promo']['sidebar']['body'] = "Create a stunning website faster than ever with Weebly";

$_LANG['store']['spamexperts']['promo']['sidebar']['title'] = "دریافت محافظت از هرزنامه ها";
$_LANG['store']['spamexperts']['promo']['sidebar']['body'] = "با فیلترینگ حرفه ای هرزنامه ، هرزنامه ها را در مسیر خود متوقف کنید";

$_LANG['store']['sitelock']['promo']['sidebar']['title'] = "حفاظت از بدافزارها";
$_LANG['store']['sitelock']['promo']['sidebar']['body'] = "بدافزارها را بطور خودکار پیدا کنید و از اعتبار آنلاین خود محافظت کنید";

$_LANG['store']['recommendedForYou'] = "توصیه شده برای شما";
$_LANG['store']['lastChance'] = "آخرین شانس";

$_LANG['domains']['importantReminder'] = "یادآوری مهم";
$_LANG['domains']['irtpNotice'] = "The changes you have made will enable the IRTP Transfer Lock for this domain.";
$_LANG['domains']['optOut'] = "انصراف از قفل انتقال (در صورت وجود)";
$_LANG['domains']['optOutReason'] = "دلیل انصراف (اختیاری)";
$_LANG['domains']['contactChangePending'] = "تماس در انتظار تغییر";
$_LANG['domains']['verificationRequired'] = "تأیید مورد نیاز است";
$_LANG['domains']['contactsChanged'] = "درخواست تغییر اطلاعات  دامین فرآیند تأیید تماس را آغاز کرده است. ایمیلی به مالک دامنه ثبت شده ارسال شده است تا تغییرات را تأیید کند";
$_LANG['domains']['contactsChangedDate'] = "A request to change WHOIS information has triggered the contact verification process. An email has been sent to the registered domain owner to approve the changes. This action must be completed by :date.";
$_LANG['domains']['newRegistration'] = "یک ایمیل به مالک دامنه ثبت شده ارسال شده است. برای جلوگیری از تعلیق ، تأیید باید تکمیل شود";
$_LANG['domains']['newRegistrationDate'] = "An email has been sent to the registered domain owner. The verification must be completed by :date to avoid suspension.";
$_LANG['domains']['irtpLockEnabled'] = "IRTP Transfer Lock Enabled";
$_LANG['domains']['irtpLockDescription'] = "این دامنه در حال حاضر به دلیل تغییر مخاطب یا ثبت نام جدید برای انتقال قفل شده است";
$_LANG['domains']['irtpLockDescriptionDate'] = "This domain is currently locked for transfer due to a contact change or new registration. This will expire on :date.";
$_LANG['domains']['resendNotification'] = "ارسال مجدد ایمیل تایید";
$_LANG['domains']['resendNotificationQuestion'] = "?آیا مطمئن به ارسال مجدد ایمیل هستید";
$_LANG['domains']['resendNotificationSuccess'] = "ایمیل تأیید مجددا ارسال شد";
$_LANG['domains']['modifyPending'] = "تأیید مورد نیاز است";
$_LANG['domains']['changePending'] = "تغییر درخواستی شما فرآیند تأیید مخاطب را آغاز کرده است. یک ایمیل تأیید مالکیت به آدرس ایمیل ارسال شده است. برای اعمال تغییرات روی پیوند موجود در ایمیل کلیک کنید";
$_LANG['domains']['changePendingDate'] = "Your requested change has triggered the contact verification process. An ownership verification email has been sent to :email. Click on the link in the email within :days days to apply the changes.";
$_LANG['domains']['changePendingFormRequired'] = "Your change of Registrant contact information was submitted successfully. In order to complete the process, you are required to complete a <strong>Change of Registrant</strong> form. Please visit :form, complete the form following the instructions and return it to us to finalize the process.";

$_LANG['getStartedNow'] = " شروع در حال حاضر";
$_LANG['notificationsnew'] = "جدید";

$_LANG['store']['websiteBuilder']['tab']['overview'] = "بررسی اجمالی";
$_LANG['store']['websiteBuilder']['tab']['features'] = "ویژگی ها";
$_LANG['store']['websiteBuilder']['tab']['pricing'] = "قیمت گذاری";
$_LANG['store']['websiteBuilder']['tab']['faq'] = "سوالات متداول";
$_LANG['store']['websiteBuilder']['ddEditor'] = "Drag & Drop Builder";
$_LANG['store']['websiteBuilder']['ddEditorDescription'] = "سازنده آسان کشیدن و رها کردن به شما امکان می دهد یک وب سایت حرفه ای بدون نیاز به مهارت های فنی ایجاد کنید. عناصر مختلف را برای افزودن عکس ها ، نقشه ها یا فیلم ها فقط با کشیدن و رها کردن آنها در محل ، درست از مرورگر وب خود انتخاب کنید";
$_LANG['store']['websiteBuilder']['features']['builder'] = "سازنده";
$_LANG['store']['websiteBuilder']['features']['builderDescription'] = "یک وب سایت عالی با ابزارهای کشیدن و رها کردن قدرتمند ایجاد کنید";
$_LANG['store']['websiteBuilder']['features']['ecommerce'] = "E-Commerce";
$_LANG['store']['websiteBuilder']['features']['ecommerceDescription'] = "راه حل کامل تجارت الکترونیک برای توسعه آنلاین کسب و کار شما";
$_LANG['store']['websiteBuilder']['features']['forms'] = "فرمها";
$_LANG['store']['websiteBuilder']['features']['formsDescription'] = "ایجاد فرم های تماس سفارشی ، لیست پاسخ دهید و نظرسنجی ها";
$_LANG['store']['websiteBuilder']['features']['templates'] = "قالب ها";
$_LANG['store']['websiteBuilder']['features']['templatesDescription'] = "قالب وب سایت حرفه ای با سفارشی سازی کامل طراحی شده است";
$_LANG['store']['websiteBuilder']['features']['gallery'] = "عکس ها";
$_LANG['store']['websiteBuilder']['features']['galleryDescription'] = "گالری ، نمایش اسلاید و پس زمینه سفارشی ایجاد کنید";
$_LANG['store']['websiteBuilder']['features']['blogging'] = "وبلاگ نویسی";
$_LANG['store']['websiteBuilder']['features']['bloggingDescription'] = "در عرض چند دقیقه یک وبلاگ شگفت انگیز بسازید";
$_LANG['store']['websiteBuilder']['features']['video'] = "ویدیو";
$_LANG['store']['websiteBuilder']['features']['videoDescription'] = "ویدیو را از سرویس های محبوب جاسازی کنید یا سرویس خود را میزبانی کنید";
$_LANG['store']['websiteBuilder']['features']['seo'] = "SEO";
$_LANG['store']['websiteBuilder']['features']['seoDescription'] = "ابزارهای قدرتمند سئو برای کمک به موتورهای جستجو برای یافتن شما";
$_LANG['store']['websiteBuilder']['pricing']['free']['headline'] = "Weebly را امتحان کنید";
$_LANG['store']['websiteBuilder']['pricing']['free']['tagline'] = "هر آنچه برای ایجاد وب سایت نیاز دارید";
$_LANG['store']['websiteBuilder']['pricing']['idealFor'] = "مناسب برای :for";
$_LANG['store']['websiteBuilder']['pricing']['siteFeatures'] = "ویژگی های سایت";
$_LANG['store']['websiteBuilder']['pricing']['eCommerceFeatures'] = "ویژگی های تجارت الکترونیک";
$_LANG['store']['websiteBuilder']['pricing']['features']['ddBuilder'] = "Drag & Drop Builder";
$_LANG['store']['websiteBuilder']['pricing']['features']['pages'] = "صفحات نامحدود";
$_LANG['store']['websiteBuilder']['pricing']['features']['noAds'] = "No Weebly Ads";
$_LANG['store']['websiteBuilder']['pricing']['features']['search'] = "جستجوی سایت";
$_LANG['store']['websiteBuilder']['pricing']['features']['passwords'] = "Password Protection";
$_LANG['store']['websiteBuilder']['pricing']['features']['backgrounds'] = "Video Backgrounds";
$_LANG['store']['websiteBuilder']['pricing']['features']['hdVideo'] = "HD Video & Audio";
$_LANG['store']['websiteBuilder']['pricing']['features']['memberCount'] = "Up to 100 Members";
$_LANG['store']['websiteBuilder']['pricing']['features']['registration'] = "Membership Registration";
$_LANG['store']['websiteBuilder']['pricing']['features']['emailCampaigns'] = "Email Campaigns";
$_LANG['store']['websiteBuilder']['pricing']['features']['3pcFee'] = "3% Weebly Transaction Fees";
$_LANG['store']['websiteBuilder']['pricing']['features']['tenProducts'] = "Up to 10 Products";
$_LANG['store']['websiteBuilder']['pricing']['features']['checkoutOnWeebly'] = "Checkout on Weebly.com";
$_LANG['store']['websiteBuilder']['pricing']['features']['twentyFiveProducts'] = "Up to 25 Products";
$_LANG['store']['websiteBuilder']['pricing']['features']['0pcFee'] = "0% Weebly Transaction Fees";
$_LANG['store']['websiteBuilder']['pricing']['features']['unlimitedProducts'] = "Unlimited Products";
$_LANG['store']['websiteBuilder']['pricing']['features']['checkoutDomain'] = "Checkout on your domain";
$_LANG['store']['websiteBuilder']['pricing']['features']['inventory'] = "Inventory Management";
$_LANG['store']['websiteBuilder']['pricing']['features']['coupons'] = "Coupons";
$_LANG['store']['websiteBuilder']['pricing']['features']['tax'] = "Tax Calculator";
$_LANG['store']['websiteBuilder']['pricing']['features']['shipping'] = "Real Time Shipping Rates";
$_LANG['store']['websiteBuilder']['pricing']['features']['abandonedCart'] = "Abandoned Cart Emails";
$_LANG['store']['websiteBuilder']['pricing']['features']['giftCards'] = "Gift Cards";
$_LANG['store']['websiteBuilder']['adminPreview'] = "Weebly plans you activate will be displayed here";
$_LANG['store']['websiteBuilder']['faq']['title'] = "Frequently Asked Questions";
$_LANG['store']['websiteBuilder']['faq']['q1'] = "Can I create a blog?";
$_LANG['store']['websiteBuilder']['faq']['q2'] = "Will my site be mobile friendly?";
$_LANG['store']['websiteBuilder']['faq']['q3'] = "Can I add photos to my website?";
$_LANG['store']['websiteBuilder']['faq']['q4'] = "Can I sell products through my site?";
$_LANG['store']['websiteBuilder']['faq']['q5'] = "Can I add forms to my site?";
$_LANG['store']['websiteBuilder']['faq']['q6'] = "How do I get my site into search engines?";
$_LANG['store']['websiteBuilder']['faq']['q7'] = "Are there multiple styles to choose from?";
$_LANG['store']['websiteBuilder']['faq']['q8'] = "Can I upgrade?";
$_LANG['store']['websiteBuilder']['faq']['a1'] = "Yes the website builder allows you to include blog functionality.";
$_LANG['store']['websiteBuilder']['faq']['a2'] = "Yes all websites created with the Weebly site builder are optimised for mobile.";
$_LANG['store']['websiteBuilder']['faq']['a3'] = "Yes, you can add photos to your site, but HD Video and Audio are only available on Pro & Business plans.";
$_LANG['store']['websiteBuilder']['faq']['a4'] = "Yes eCommerce functionality is included with all plans but the number of products you can offer varies.";
$_LANG['store']['websiteBuilder']['faq']['a5'] = "Yes the Weebly site builder makes it easy to create contact forms, RSVP lists, surveys and more.";
$_LANG['store']['websiteBuilder']['faq']['a6'] = "All Weebly powered websites include powerful SEO tools to help maximise your search engine ranking.";
$_LANG['store']['websiteBuilder']['faq']['a7'] = "Yes there are multiple pre-made templates for you to choose from.";
$_LANG['store']['websiteBuilder']['faq']['a8'] = "Yes you can upgrade at any time. Simply login to your account and choose the upgrade option.";
$_LANG['store']['websiteBuilder']['trust'] = "Trusted by over 40,000,000 people worldwide";
$_LANG['store']['websiteBuilder']['upgrade']['title'] = "Weebly Upgrade";
$_LANG['store']['websiteBuilder']['upgrade']['required'] = "Upgrade Required";
$_LANG['store']['websiteBuilder']['upgrade']['requiredDescription'] = "To access the functionality you requested, you need to upgrade your Weebly Site Builder plan.";
$_LANG['store']['websiteBuilder']['upgrade']['recommended'] = "The recommended plan is displayed.";
$_LANG['store']['websiteBuilder']['upgrade']['login'] = "To view the available options, please login.";
$_LANG['store']['websiteBuilder']['upgrade']['no'] = "No upgrade available";
$_LANG['store']['websiteBuilder']['upgrade']['noUpgrade'] = "There is no upgrade available at this time.";
$_LANG['store']['websiteBuilder']['upgrade']['submitTicket'] = "Contact support";
$_LANG['store']['websiteBuilder']['upgrade']['to'] = "Upgrade to :product for :amount";
$_LANG['store']['websiteBuilder']['upgrade']['noPlans'] = "No active Weebly plans found";
$_LANG['store']['websiteBuilder']['upgrade']['loggedInAs'] = "You are currently logged in as :email";
$_LANG['store']['websiteBuilder']['upgrade']['switchUser'] = "Logout/switch user";

$_LANG['tax']['taxLabel'] = "شناسه مالیاتی";
$_LANG['tax']['vatLabel'] = "شماره مالیات بر ارزش افزوده";
$_LANG['tax']['errorInvalid'] = "ارائه شده  :taxLabel معتبر نیست";
$_LANG['tax']['errorService'] = "The :taxLabel verification service is not available. Try again later.";

$_LANG['fraud']['checkConfiguration'] = "هنگام بررسی تقلب خطایی روی داد. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['fraud']['title'] = "بررسی تقلب";
$_LANG['fraud']['error'] = "خظا";
$_LANG['fraud']['manualReview'] = "سفارش شما برای بررسی دستی نگه داشته شده است<br /><br />اگر احساس می کنید این پیام را به اشتباه دریافت کرده اید ، لطفاً عذرخواهی ما را بپذیرید و <a href=\"submitticket.php\">یک تیکت پشتیبانی ارسال کنید</a>به تیم خدمات مشتری ما متشکرم";
$_LANG['fraud']['highFraudRiskScore'] = "سفارش شما به عنوان خطر بالقوه پرچم گذاری شده است و بنابراین برای بررسی دستی نگه داشته شده است<br /><br />اگر احساس می کنید این پیام را به اشتباه دریافت کرده اید ، لطفاً عذرخواهی ما را بپذیرید و <a href=\"submitticket.php\">یک تیکت پشتیبانی ارسال کنید</a>به تیم خدمات مشتری ما متشکرم";
$_LANG['fraud']['countryMismatch'] = "کشور آدرس آیپی  شما با کشور آدرس صورتحسابی که وارد کرده اید مطابقت ندارد بنابراین نمی توانیم سفارش شما را بپذیریم";
$_LANG['fraud']['highRiskCountry'] = "متأسفانه ما نمی توانیم سفارش شما را بپذیریم زیرا اقدامات تقلب زیادی از سوی کشور شما انجام شده است. اگر می خواهید روش دیگری برای پرداخت ترتیب دهید ، لطفاً با ما تماس بگیرید";
$_LANG['fraud']['anonymousProxy'] = "ما اجازه نمی دهیم سفارشات با استفاده از پراکسی ناشناس ثبت شوند";

$_LANG['fraud']['userVerification'] = "تأیید صحت کاربر";
$_LANG['fraud']['furtherVal'] = "برای پردازش سفارش شما به تأیید بیشتر نیاز است. روی دکمه کلیک کنید و مراحل مربوط به ارسال ایمن را دنبال کنید. کار شما در کمتر از یک دقیقه به پایان می رسد";
$_LANG['fraud']['furtherValShort'] = "تأیید بیشتر مورد نیاز است. روی دکمه کلیک کرده و مراحل ارائه شده را دنبال کنید";
$_LANG['fraud']['submitDocs'] = "ارسال مدارک";
$_LANG['fraud']['submitSuccessMsg'] = "متشکرم! اسناد ارائه شده است ، و به صورت دستی توسط تیم ما بررسی می شود";
$_LANG['fraud']['status']['notRequested'] = "درخواست نشده";
$_LANG['fraud']['status']['notReviewed'] = "درخواست کرد";
$_LANG['fraud']['status']['reviewRequested'] = "ارسال شده";
$_LANG['fraud']['status']['failed'] = "ناموفق";
$_LANG['fraud']['status']['validated'] = "تأیید شد";

$_LANG['navMarketConnectService']['codeguard'] = "پشتیبان گیری از وب سایت";
$_LANG['store']['codeguard']['cartTitle'] = "پشتیبان گیری CodeGuard";
$_LANG['store']['codeguard']['cartShortDescription'] = "سریعترین و معتبرترین سرویس پشتیبان گیری وب سایت ، که همه تغییرات شما را روزانه پیگیری می کند";
$_LANG['store']['codeGuard']['title'] = "پشتیبان گیری CodeGuard";
$_LANG['store']['codeGuard']['headline'] = "Protect <span>your website</span> with daily automated backups";
$_LANG['store']['codeGuard']['tagline'] = "با پشتیبان گیری وب سایت کدگارد در برابر ویروس ها ، هکرها و حتی کد شخصی خود که به طور تصادفی سایت شما را خراب می کند ، محافظت کنید";
$_LANG['store']['codeGuard']['tab']['overview'] = "بررسی اجمالی";
$_LANG['store']['codeGuard']['tab']['pricing'] = "قیمت گذاری";
$_LANG['store']['codeGuard']['tab']['features'] = "امکانات";
$_LANG['store']['codeGuard']['tab']['faq'] = "سوالات متداول";
$_LANG['store']['codeGuard']['leadTitle'] = "<strong><em>Every 0.65 seconds</em></strong>, a new web page is infected with malware.";
$_LANG['store']['codeGuard']['leadText1'] = "Protect your site from <strong>data loss and corruption</strong>, as well as against threats from <strong>viruses, hackers and malware</strong> with Daily Automated Website Backups from CodeGuard.";
$_LANG['store']['codeGuard']['leadText2'] = "With CodeGuard Website Backup, your website is backed up daily and if disaster strikes, you can restore your site to a previous point in time at the click of a button.";
$_LANG['store']['codeGuard']['dailyBackup'] = "پشتیبان گیری روزانه خودکار";
$_LANG['store']['codeGuard']['malwareProtection'] = "تشخیص و بازیابی بدافزار";
$_LANG['store']['codeGuard']['timeMachine'] = "وب سایت ماشین زمان";
$_LANG['store']['codeGuard']['wpPlugin'] = "WordPress Plugin Updates";
$_LANG['store']['codeGuard']['changeAlerts'] = "نظارت بر تغییر هشدار فایل";
$_LANG['store']['codeGuard']['features']['dailyBackup'] = "پشتیبان گیری روزانه خودکار وب سایت";
$_LANG['store']['codeGuard']['features']['dailyBackupDescription'] = "وب سایت خود را با پشتیبان گیری روزانه خودکار ذخیره شده در خارج از سایت با افزونگی داخلی ایمن کنید";
$_LANG['store']['codeGuard']['features']['unlimitedFiles'] = "فایلها و پایگاههای داده نامحدود";
$_LANG['store']['codeGuard']['features']['unlimitedFilesDescription'] = "از تعداد نامحدودی از فایل ها و پایگاه های داده پشتیبان تهیه کنید - فقط توسط فضای ذخیره سازی مورد استفاده محدود می شوید";
$_LANG['store']['codeGuard']['features']['oneClickRestore'] = "بازیابی با یک کلیک";
$_LANG['store']['codeGuard']['features']['oneClickRestoreDescription'] = "یک فرآیند بازیابی ساده باعث می شود که یک فایل یا کل وب سایت خود را به نسخه قبلی برگردانید";
$_LANG['store']['codeGuard']['features']['malwareMonitoring'] = "نظارت بر بدافزارها";
$_LANG['store']['codeGuard']['features']['malwareMonitoringDescription'] = "Rest easy knowing CodeGuard is diligently checking your site for changes every day.";
$_LANG['store']['codeGuard']['features']['wp'] = "Automatic WordPress Updates";
$_LANG['store']['codeGuard']['features']['wpDescription'] = "Automatically update WordPress and its plugins to keep it secure with auto recovery in case of problems.";
$_LANG['store']['codeGuard']['features']['fileMonitoring'] = "File Change Monitoring";
$_LANG['store']['codeGuard']['features']['fileMonitoringDescription'] = "Get notified by email anytime something changes within the source code of your site.";
$_LANG['store']['codeGuard']['features']['servers'] = "Staging of Restores";
$_LANG['store']['codeGuard']['features']['serversDescription'] = "Quickly test any backed up site with simple and automated staging prior to restore.";
$_LANG['store']['codeGuard']['features']['email'] = "Email Backup";
$_LANG['store']['codeGuard']['features']['emailDescription'] = "Get protection for your emails too as they are backed up as part of your websites files.";
$_LANG['store']['codeGuard']['features']['api'] = "Full Automation";
$_LANG['store']['codeGuard']['features']['apiDescription'] = "Completely hands free setup and ongoing backups with automated notifications if things go wrong.";
$_LANG['store']['codeGuard']['chooseBackupPlan'] = "Choose Backup Storage";
$_LANG['store']['codeGuard']['faq']['title'] = "Frequently Asked Questions";
$_LANG['store']['codeGuard']['faq']['q1'] = "What is CodeGuard?";
$_LANG['store']['codeGuard']['faq']['a1'] = "CodeGuard is a fully automated website backup service that gives you complete protection against data loss and malware.";
$_LANG['store']['codeGuard']['faq']['q2'] = "Why do I need CodeGuard?";
$_LANG['store']['codeGuard']['faq']['a2'] = "CodeGuard provides an independent offsite backup solution for your website along with daily monitoring to ensure your website is online and malware free.";
$_LANG['store']['codeGuard']['faq']['q3'] = "How does it work?";
$_LANG['store']['codeGuard']['faq']['a3'] = "CodeGuard takes daily automated snapshots of your website. Using these snapshots, you can restore your entire site or a specific file to an earlier version at any time.";
$_LANG['store']['codeGuard']['faq']['q4'] = "What if I run out of storage?";
$_LANG['store']['codeGuard']['faq']['a4'] = "Switching plans is easy! You can upgrade and increase your disk storage allowance in just a few simple clicks via our client area.";
$_LANG['store']['codeGuard']['faq']['q5'] = "Where are backups stored?";
$_LANG['store']['codeGuard']['faq']['a5'] = "Backups are stored on Amazon Web Services Simple Storage System which provides market leading resiliance and redundancy for your backups.";
$_LANG['store']['codeGuard']['faq']['q6'] = "Are the backups encrypted?";
$_LANG['store']['codeGuard']['faq']['a6'] = "Yes, backups are stored encrypted using the AES-256 Encryption Standard.";
$_LANG['store']['codeGuard']['faq']['q7'] = "Do you backup databases?";
$_LANG['store']['codeGuard']['faq']['a7'] = "Yes, databases can be backed up also. Database backups are supported for MySQL and MSSQL databases.";
$_LANG['store']['codeGuard']['faq']['q8'] = "What is File Change Alert Monitoring?";
$_LANG['store']['codeGuard']['faq']['a8'] = "CodeGuard can monitor and notify you by email when your website changes to alert you to new threats and malware.";
$_LANG['store']['codeGuard']['faq']['q9'] = "What happens if my site gets infected?";
$_LANG['store']['codeGuard']['faq']['a9'] = "With CodeGuard's daily snapshots, if your website gets attacked, you can restore to a previous uninfected version at any time.";
$_LANG['store']['codeGuard']['adminPreview'] = "CodeGuard plans you activate will be displayed here";

$_LANG['store']['codeguard']['promo']['sidebar']['title'] = "Add Website Backup";
$_LANG['store']['codeguard']['promo']['sidebar']['body'] = "Protect your website with daily automated backups";

$_LANG['marketConnect']['codeGuard']['manage'] = "Log in to CodeGuard Control Panel";

$_LANG['sslState']['sslInactive'] = "اس اس ال شناسایی نشد برای مرور گزینه های اس اس ال اینجا را کلیک کنید";
$_LANG['sslState']['sslActive'] = "Valid SSL Detected. Expires :expiry";
$_LANG['sslState']['sslUnknown'] = "Unable to validate SSL status";
$_LANG['sslState']['validSsl'] = "Valid SSL Detected";
$_LANG['sslState']['noSsl'] = "No SSL Detected";
$_LANG['sslState']['sslInactiveService'] = "Service inactive";
$_LANG['sslState']['sslInactiveDomain'] = "Domain inactive";
$_LANG['sslState']['startDate'] = "SSL Start Date";
$_LANG['sslState']['expiryDate'] = "SSL Expiry Date";
$_LANG['sslState']['issuerName'] = "SSL Issuer Name";
$_LANG['sslState']['sslStatus'] = "SSL Status";

$_LANG['generatePassword']['btnLabel'] = "ایجاد گذرواژه";
$_LANG['generatePassword']['btnShort'] = "تولید";
$_LANG['generatePassword']['title'] = "ایجاد گذرواژه";
$_LANG['generatePassword']['lengthValidationError'] = "لطفاً برای طول گذرواژه عددی بین 8 تا 64 وارد کنید";
$_LANG['generatePassword']['pwLength'] = "طول رمز عبور";
$_LANG['generatePassword']['generatedPw'] = "رمز عبور ایجاد شده";
$_LANG['generatePassword']['generateNew'] = "ایجاد رمز عبور جدید";
$_LANG['generatePassword']['copyAndInsert'] = "در کلیپ بورد کپی و درج کنید";

$_LANG['setupMandate'] = "دستور راه اندازی برای پرداخت";

$_LANG['invoicePaymentPendingCleared'] = "پرداخت شما در حال پردازش است و هنگام ترخیص به صورت خودکار اعمال می شود";
$_LANG['invoicePaymentAutoWhenDue'] = "پرداخت شما به صورت خودکار در موعد مقرر درخواست می شود";

$_LANG['support']['attachmentsRemoved'] = "به دلیل عدم فعالیت تیکت حذف شد";
$_LANG['unpaidInvoiceAlert'] = "شما یک فاکتور پرداخت نشده دارید. برای جلوگیری از وقفه در سرویس ، اکنون آن را پرداخت کنید";
$_LANG['overdueInvoiceAlert'] = "فاکتور پرداخت نشده دارید";
$_LANG['payInvoice'] = "پرداخت فاکتور";

$_LANG['close'] = "بستن";
$_LANG['submit'] = "ارسال";
$_LANG['finish'] = "تمام";

$_LANG['twofanowenabled'] = "احراز هویت دو عاملی در حال حاضر فعال";
$_LANG['twofacurrently'] = " احراز هویت دو عامل در حال حاضر";
$_LANG['enabled'] = "فعال";
$_LANG['disabled'] = "غیرفعال";

$_LANG['copyrightFooterNotice'] = "تمامی حقوق برای  &copy; :year :company. محفوط می باشد.";

$_LANG['paymentMethods']['title'] = "روش های پرداخت";
$_LANG['paymentMethods']['intro'] = "مروری بر روش ها و تنظیمات پرداخت شما";
$_LANG['paymentMethods']['description'] = "شرح";
$_LANG['paymentMethods']['cardDescription'] = "توضیحات کارت";
$_LANG['paymentMethods']['descriptionInput'] = "نامی برای این کارت وارد کنید";
$_LANG['paymentMethods']['fieldRequired'] = "این فیلد الزامی است";
$_LANG['paymentMethods']['close'] = "بستن";
$_LANG['paymentMethods']['saveChanges'] = "ذخیره تغییرات";

$_LANG['paymentMethods']['addedSuccess'] = "روش پرداخت با موفقیت اضافه شد";
$_LANG['paymentMethods']['addFailed'] = "روش پرداخت با موفقیت ایجاد نشد. لطفا دوباره تلاش کنید";
$_LANG['paymentMethods']['updateSuccess'] = "روش پرداخت با موفقیت به روز شد";
$_LANG['paymentMethods']['saveFailed'] = "روش پرداخت تغییرات را ذخیره نکرد. لطفا دوباره تلاش کنید";
$_LANG['paymentMethods']['defaultUpdateSuccess'] = "روش پرداخت پیش فرض با موفقیت به روز شد";
$_LANG['paymentMethods']['defaultUpdateFailed'] = "روش پیش فرض پرداخت را نمی توان به روز کرد. لطفا دوباره تلاش کنید";
$_LANG['paymentMethods']['deleteSuccess'] = "روش پرداخت با موفقیت حذف شد";
$_LANG['paymentMethods']['deleteFailed'] = "روش پرداخت انتخابی حذف نشد. لطفا دوباره تلاش کنید";
$_LANG['paymentMethods']['addNewCC'] = "افزودن کارت اعتباری جدید";
$_LANG['paymentMethods']['addNewBank'] = "افزودن حساب بانکی جدید";
$_LANG['paymentMethods']['name'] = "نام";
$_LANG['paymentMethods']['status'] = "وضعیت";
$_LANG['paymentMethods']['actions'] = "عملیات";
$_LANG['paymentMethods']['default'] = "پیشفرض";
$_LANG['paymentMethods']['setAsDefault'] = "تنظیم به عنوان پیشفرض";
$_LANG['paymentMethods']['edit'] = "ویرایش";
$_LANG['paymentMethods']['delete'] = "حذف";
$_LANG['paymentMethods']['noPaymentMethodsCreated'] = "هنوز هیچ روش پرداختی ایجاد نشده است";
$_LANG['paymentMethods']['areYouSure'] = "مطمئنی؟";
$_LANG['paymentMethods']['deletePaymentMethodConfirm'] = "آیا مطمئن هستید که می خواهید این روش پرداخت را حذف کنید؟ این عملکرد قابل واگرد نیست";
$_LANG['paymentMethods']['type'] = "نوع";
$_LANG['paymentMethods']['requestCancelled'] = "درخواست روش پرداخت لغو شد ";
$_LANG['paymentMethods']['retry'] = "دوباره امتحان کنید";
$_LANG['paymentMethods']['creditCardChangesWontBeReflected'] = "تغییراتی که در اینجا ایجاد می کنید ذخیره می شود اما هنگام مشاهده روش پرداخت در محدوده مشتری ما ، همه تغییرات منعکس نمی شوند";

$_LANG['paymentMethodsManage']['editPaymentMethod'] = "ویرایش روش پرداخت";
$_LANG['paymentMethodsManage']['addPaymentMethod'] = "افزودن روش پرداخت جدید";
$_LANG['paymentMethodsManage']['invalidCardDetails'] = "به نظر می رسد شماره کارتی که وارد کرده اید نامعتبر است. لطفاً دوباره امتحان کنید";
$_LANG['paymentMethodsManage']['creditCard'] = "کارت اعتباری";
$_LANG['paymentMethodsManage']['bankAccount'] = "حساب بانکی";
$_LANG['paymentMethodsManage']['optional'] = "(اختیاری)";
$_LANG['paymentMethodsManage']['cardNumberNotValid'] = "به نظر می رسد شماره کارتی که وارد کرده اید معتبر نیست";
$_LANG['paymentMethodsManage']['expiryDateNotValid'] = "به نظر نمی رسد تاریخ انقضی که وارد کرده اید معتبر باشد";
$_LANG['paymentMethodsManage']['cvcNumberNotValid'] = "به نظر نمی رسد شماره  سی وی سی وارد شده معتبر باشد";
$_LANG['paymentMethodsManage']['accountType'] = "نوع حساب";
$_LANG['paymentMethodsManage']['checking'] = "چک کردن";
$_LANG['paymentMethodsManage']['savings'] = "پس انداز";
$_LANG['paymentMethodsManage']['accountHolderName'] = "نام صاحب حساب";
$_LANG['paymentMethodsManage']['bankName'] = "نام بانک";
$_LANG['paymentMethodsManage']['sortCodeRoutingNumber'] = "مرتب سازی کد/شماره مسیریابی";
$_LANG['paymentMethodsManage']['routingNumberNotValid'] = "به نظر نمی رسد شماره مسیریابی که وارد کرده اید معتبر باشد";
$_LANG['paymentMethodsManage']['accountNumber'] = "شماره حساب";
$_LANG['paymentMethodsManage']['accountNumberNotValid'] = "به نظر می رسد شماره حساب بانکی که وارد کرده اید معتبر نیست";
$_LANG['paymentMethodsManage']['addNewAddress'] = "یک آدرس جدید اضافه کنید";
$_LANG['paymentMethodsManage']['addNewBillingAddress'] = "آدرس صورتحساب جدید اضافه کنید";
$_LANG['paymentMethodsManage']['unsupportedCardType'] = "ما نمی توانیم نوع کارتی را که وارد کرده اید بپذیریم. لطفاً از کارت دیگری استفاده کنید";

$_LANG['store']['ssl']['shared']['pricing'] = "گواهی قیمت گذاری";
$_LANG['store']['ssl']['shared']['encryption256'] = "رمزگذاری 256 بیتی";
$_LANG['store']['ssl']['shared']['issuanceTime'] = "زمان صدور";
$_LANG['store']['ssl']['shared']['greatFor'] = "عالی برای";
$_LANG['store']['ssl']['shared']['warrantyValue'] = "ارزش گارانتی";
$_LANG['store']['ssl']['shared']['freeReissues'] = "تجدید چاپ مجدد";
$_LANG['store']['ssl']['shared']['browserSupport'] = "پشتیبانی از مرورگر";
$_LANG['store']['ssl']['shared']['price'] = "قیمت";
$_LANG['store']['ssl']['shared']['noProducts'] = "SSL Certificate products you activate will be displayed here";
$_LANG['store']['ssl']['shared']['helpMeChoose'] = "مطمئن نیستید کدام را انتخاب کنید؟ اجازه دهید ما در تصمیم گیری به شما کمک کنیم";
$_LANG['store']['ssl']['shared']['ev']['visualVerification'] = "هویت بصری برجسته";
$_LANG['store']['ssl']['shared']['ev']['visualVerificationDescription'] = "با تأیید هویت کامل و ویژگی های برجسته بصری ، اعتماد و اطمینان خود را در وب سایت خود افزایش دهید";
$_LANG['store']['ssl']['shared']['ev']['warranty'] = "$1.5m Warranty";
$_LANG['store']['ssl']['shared']['ev']['warrantyDescription'] = "EV Certificates come with a $1.5m warranty that covers data breaches caused due to a certificate flaw.";
$_LANG['store']['ssl']['shared']['ev']['issuance'] = "Issued in 2-3 Days";
$_LANG['store']['ssl']['shared']['ov']['ov'] = "Organization Validated";
$_LANG['store']['ssl']['shared']['ov']['ovDescription'] = "With an OV SSL Certificate, the identity of the company or organization that holds the certificate is validated, providing more trust for end users.";
$_LANG['store']['ssl']['shared']['ov']['warranty'] = "$1.25m Warranty";
$_LANG['store']['ssl']['shared']['ov']['warrantyDescription'] = "OV Certificates come with a $1.25m warranty that covers data breaches caused due to a certificate flaw.";
$_LANG['store']['ssl']['shared']['ov']['issuance'] = "Issued in 1-2 Days";
$_LANG['store']['ssl']['shared']['delivery'] = "Delivered in Minutes for Instant Protection";
$_LANG['store']['ssl']['shared']['deliveryDescription'] = "The fastest and most affordable way to activate SSL protection for your website, issuance is quick and often fully automated.";
$_LANG['store']['ssl']['shared']['siteSeal'] = "Trust Site Seal";
$_LANG['store']['ssl']['shared']['siteSealDescription'] = "Our SSL Certificates come with a trust seal that has been proven to increase visitor confidence and customer conversions.";
$_LANG['store']['ssl']['shared']['googleRanking'] = "Boost your Google Ranking";
$_LANG['store']['ssl']['shared']['googleRankingDescription'] = "Google uses SSL/HTTPS as a factor in determining search engine ranking. Add SSL today to help boost your Google ranking!";
$_LANG['store']['ssl']['shared']['features'] = "Certificate Features";
$_LANG['store']['ssl']['shared']['encryptData'] = "Encrypt sensitive data";
$_LANG['store']['ssl']['shared']['secureTransactions'] = "Secure online transactions";
$_LANG['store']['ssl']['shared']['legitimacy'] = "Prove legitimacy";
$_LANG['store']['ssl']['shared']['fastestSsl'] = "Strongest & Fastest SSL";
$_LANG['store']['ssl']['shared']['browserCompatability'] = "99.9% Browser Compatibility";
$_LANG['store']['ssl']['shared']['seoRank'] = "Increase SEO rank";
$_LANG['store']['ssl']['shared']['issuance'] = "Instant Issuance";
$_LANG['store']['ssl']['shared']['trusted'] = "Our SSL certificates are from some of the most trusted brands in Online Security.";
$_LANG['store']['ssl']['shared']['dvSsl'] = "Standard SSL (DV)";
$_LANG['store']['ssl']['shared']['ovSsl'] = "Organisation Validation (OV)";
$_LANG['store']['ssl']['shared']['evSsl'] = "Extended Validation (EV)";
$_LANG['store']['ssl']['shared']['wildcardSsl'] = "Wildcard";
$_LANG['store']['ssl']['shared']['switch'] = "Switch to Us";
$_LANG['store']['ssl']['competitiveUpgrades']['switch'] = "Switch to DigiCert SSL";
$_LANG['store']['ssl']['competitiveUpgrades']['replace'] = "Replace your current SSL Certificate without losing any time or money";
$_LANG['store']['ssl']['competitiveUpgrades']['buyWithTime'] = "Buy a new SSL Certificate from us and we'll add any remaining time you have on your current SSL Certificate up to a maximum of an additional 12 months";
$_LANG['store']['ssl']['competitiveUpgrades']['foc'] = "free of charge";
$_LANG['store']['ssl']['competitiveUpgrades']['exampleScenario'] = "Example Scenario";
$_LANG['store']['ssl']['competitiveUpgrades']['example']['line1'] = "Your current 2 year certificate has 11 months left to run.";
$_LANG['store']['ssl']['competitiveUpgrades']['example']['line2'] = "You make the switch and your new certificate will be valid for <strong>1 year AND 11 months</strong>.";
$_LANG['store']['ssl']['competitiveUpgrades']['example']['line3'] = "The fee for the new certificate will <strong>ONLY</strong> be for 1 year.";
$_LANG['store']['ssl']['competitiveUpgrades']['eligibilityCheck'] = "This special upgrade offer is available for SSL Certificates issued by one of the supported competitor SSL providers*. Enter your domain name below to validate your eligibility and see how much you could save.";
$_LANG['store']['ssl']['competitiveUpgrades']['checkFailed'] = "Unable to connect to the validation API. Please try again later or contact support.";
$_LANG['store']['ssl']['competitiveUpgrades']['eligible'] = "Congratulations! Your domain is eligible for the DigiCert Competitive Upgrade Offer.";
$_LANG['store']['ssl']['competitiveUpgrades']['expirationDate'] = "Current Expiration Date";
$_LANG['store']['ssl']['competitiveUpgrades']['monthsRemaining'] = "Months Remaining";
$_LANG['store']['ssl']['competitiveUpgrades']['months'] = ":months Months";
$_LANG['store']['ssl']['competitiveUpgrades']['maxMonths'] = "Maximum of 12 months offered";
$_LANG['store']['ssl']['competitiveUpgrades']['freeExtension'] = "Free Extension Eligibility";
$_LANG['store']['ssl']['competitiveUpgrades']['saving'] = "Potential Saving";
$_LANG['store']['ssl']['competitiveUpgrades']['savingInfomation'] = "Save up to <strong>:saveAmount</strong> on a new certificate!";
$_LANG['store']['ssl']['competitiveUpgrades']['continue'] = "Continue to Choose SSL Certificate";
$_LANG['store']['ssl']['competitiveUpgrades']['ineligible'] = "Unfortunately the domain you entered is not eligible for the DigiCert Competitive Upgrade Offer. Please verify the domain is entered correctly and has an active and current SSL Certificate from one of the supported vendors";
$_LANG['store']['ssl']['competitiveUpgrades']['validate'] = "Validate";
$_LANG['store']['ssl']['competitiveUpgrades']['competitors'] = "Offer valid for Comodo, GlobalSign, Entrust, and GoDaddy SSL Certificates.";
$_LANG['store']['ssl']['competitiveUpgrades']['enterDomain'] = "Enter your domain here";
$_LANG['store']['ssl']['useCases']['title'] = "Recommended Use Cases";
$_LANG['store']['ssl']['useCases']['blogs'] = "Blogs";
$_LANG['store']['ssl']['useCases']['infoPages'] = "Informational<br>Pages";
$_LANG['store']['ssl']['useCases']['serverComms'] = "Server-to-server<br>Communications";
$_LANG['store']['ssl']['useCases']['criticalDomains'] = "Business-critical<br>domains";
$_LANG['store']['ssl']['useCases']['ecommerce'] = "eCommerce";
$_LANG['store']['ssl']['useCases']['signupPages'] = "New account<br>signup pages";
$_LANG['store']['ssl']['useCases']['loginPages'] = "Login Pages";
$_LANG['store']['ssl']['useCases']['intranetSites'] = "Intranet Sites";
$_LANG['store']['ssl']['useCases']['webmail'] = "Webmail";
$_LANG['store']['ssl']['ov']['orgInfo'] = "Contains your Authenticated Organization Details";
$_LANG['store']['ssl']['ov']['orgInfoDescription'] = "Certificate details indicate your website is using an Organization Validated SSL Certificate and include the issuing CA, validity status and expiration date.";
$_LANG['store']['ssl']['ev']['orgInfo'] = "Contains Your EV Authenticated Organization Details";
$_LANG['store']['ssl']['ev']['orgInfoDescription'] = "Certificate details indicate your website is using an Extended Validation SSL Certificate and include the issuing CA, validity status, and expiration date.";
$_LANG['store']['ssl']['landingPage']['title'] = "SSL Certificates";
$_LANG['store']['ssl']['landingPage']['tagline1'] = "Secure your site and add trust & confidence for your visitors.";
$_LANG['store']['ssl']['landingPage']['tagline2'] = "With a range of brands, we have the right certificate for all your site security needs";
$_LANG['store']['ssl']['landingPage']['chooseLevel'] = "Choose your level of validation";
$_LANG['store']['ssl']['landingPage']['dv'] = "Domain Validation (DV)";
$_LANG['store']['ssl']['landingPage']['dvSubtitle'] = "Basic Security";
$_LANG['store']['ssl']['landingPage']['dvInformation'] = "Domain validation only. Issued in minutes. Ideal for blogs, social media & personal websites.";
$_LANG['store']['ssl']['landingPage']['ov'] = "Organization Validation (OV)";
$_LANG['store']['ssl']['landingPage']['ovSubtitle'] = "Strong business level SSL";
$_LANG['store']['ssl']['landingPage']['ovInformation'] = "Basic identity verification. Ideal for small business websites and pages accepting sensitive information.";
$_LANG['store']['ssl']['landingPage']['ev'] = "Extended Validation (EV)";
$_LANG['store']['ssl']['landingPage']['evSubtitle'] = "Maximum Protection & Trust";
$_LANG['store']['ssl']['landingPage']['evInformation'] = "Full identity verification. Ideal for Business & Ecommerce sites looking to provide maximum visitor confidence.";
$_LANG['store']['ssl']['landingPage']['buy'] = "Buy";
$_LANG['store']['ssl']['landingPage']['what'] = "What is SSL?";
$_LANG['store']['ssl']['landingPage']['whatInfo'] = "SSL Certificates are fundamental to internet security. They are used to establish an encrypted connection and allow data to be transmitted securely between a browser or user's computer and a server or website.";
$_LANG['store']['ssl']['landingPage']['secureConnection'] = "Establishes a secure connection between a browser and a server";
$_LANG['store']['ssl']['landingPage']['encrypts'] = "Encrypts communication to protect sensitive information your customers provide to you";
$_LANG['store']['ssl']['landingPage']['padlock'] = "Places a padlock next to your web address in the browser";
$_LANG['store']['ssl']['landingPage']['authenticates'] = "Authenticates an organization's identity";
$_LANG['store']['ssl']['landingPage']['certTypeInfo'] = "<a href=\":dvLink\">Standard SSL (Domain Validated)</a> Certificates are the easiest and most common type of SSL certificate. <a href=\":ovLink\">OV</a> and <a href=\":evLink\">EV Certificates</a> also authenticate the identity of the company or organization that holds the certificate providing more trust to end users. <br><br>With our SSL certificate services*, you won't need to take manual steps to configure and deploy new certificates every year. We generate a renewal order automatically when your certificate nears the end of its validity. After payment, we will automatically configure, validate, and provision your new certificate for you.<br><br><small>* Your domain must be hosted through the same hosting provider who sold the SSL certificate, and the server must use cPanel, Plesk, or DirectAdmin.</small>";
$_LANG['store']['ssl']['landingPage']['benefits']['title'] = "Improve Your Search Engine Ranking";
$_LANG['store']['ssl']['landingPage']['benefits']['subtitle'] = "Establish trust and online security for your website visitors and business.";
$_LANG['store']['ssl']['landingPage']['benefits']['higherResults'] = "Google wants to make the web safer and a big part of that involves making sure that the sites people access via Google are secure. That's why websites using SSL have been shown to benefit from higher ranking in search results.";
$_LANG['store']['ssl']['landingPage']['benefits']['reasons'] = "There's also a lot more reasons why you should consider adding SSL to your website";
$_LANG['store']['ssl']['landingPage']['benefits']['encrypt'] = "Encrypt sensitive data";
$_LANG['store']['ssl']['landingPage']['benefits']['privacy'] = "Protect user privacy";
$_LANG['store']['ssl']['landingPage']['benefits']['secure'] = "Secure online transactions";
$_LANG['store']['ssl']['landingPage']['benefits']['https'] = "Activate HTTPS and the lock icon";
$_LANG['store']['ssl']['landingPage']['benefits']['legitimacy'] = "Prove legitimacy";
$_LANG['store']['ssl']['landingPage']['benefits']['seo'] = "Increase SEO rank";
$_LANG['store']['ssl']['landingPage']['browser']['title'] = "Browsers have changed, don't get left behind";
$_LANG['store']['ssl']['landingPage']['browser']['insecureNotice'] = "Web pages not served via HTTPS are now being displayed as ‘not secure’ in <strong>Google Chrome</strong> and <strong>Mozilla Firefox</strong>. Don't let your website be one of them. Add SSL today.";
$_LANG['store']['ssl']['landingPage']['competitiveUpgrade'] = "Upgrade with us and get up to an additional 12 months free.";
$_LANG['store']['ssl']['landingPage']['browser']['competitiveUpgrade'] = "Upgrade with us and get up to an additional 12 months free.";
$_LANG['store']['ssl']['landingPage']['evs']['upgradeTitle'] = "Upgrade to Extended Validation SSL";
$_LANG['store']['ssl']['landingPage']['evs']['description'] = "While all SSL certificates use similar methods to protect and validate your data, the level of trust and assertion they provide varies.";
$_LANG['store']['ssl']['landingPage']['evs']['whatIs'] = "<strong>Extended Validation Certificates</strong> offer the highest level of validation and trust. They validate and display the name and location of companies and organisations to give customers added confidence when dealing with businesses online.";
$_LANG['store']['ssl']['landingPage']['evs']['learn'] = "Learn more about Extended Validation SSL Certificates";
$_LANG['store']['ssl']['landingPage']['help']['title'] = "Help Me Choose The Right Type of Certificate";
$_LANG['store']['ssl']['landingPage']['help']['guide'] = "While the need for online security is universal, not all SSL Certificates are created equal. The guide below is designed to help you decide which type of certificate is right for you.";
$_LANG['store']['ssl']['landingPage']['help']['dv']['title'] = "Domain Validation (DV)";
$_LANG['store']['ssl']['landingPage']['help']['dv']['verify'] = "Verifies ownership and control of the domain name only";
$_LANG['store']['ssl']['landingPage']['help']['dv']['issued'] = "Issued in minutes";
$_LANG['store']['ssl']['landingPage']['help']['dv']['compliance'] = "Maintains browser compliance";
$_LANG['store']['ssl']['landingPage']['help']['dv']['for'] = "Ideal for non-critical web pages";
$_LANG['store']['ssl']['landingPage']['help']['dv']['type'] = "Think of DV like getting a library card—no confirmation of who you really are, very minimal requirements to obtain and issued very quickly.";
$_LANG['store']['ssl']['landingPage']['help']['dv']['browse'] = "Browse Domain Validation Certificates";
$_LANG['store']['ssl']['landingPage']['help']['ov']['title'] = "Organization Validation (OV)";
$_LANG['store']['ssl']['landingPage']['help']['ov']['verify'] = "Enhanced validation including authenticating the identity of the applicant";
$_LANG['store']['ssl']['landingPage']['help']['ov']['issued'] = "Issued within one day";
$_LANG['store']['ssl']['landingPage']['help']['ov']['compliance'] = "Maintains browser compliance";
$_LANG['store']['ssl']['landingPage']['help']['ov']['for'] = "Ideal for more sensitive webpages such as login pages";
$_LANG['store']['ssl']['landingPage']['help']['ov']['type'] = "Think of OV like getting a driver’s license—more hoops to jump through than a library card but more trusted as a form of identification.";
$_LANG['store']['ssl']['landingPage']['help']['ov']['browse'] = "Browse Organization Validation Certificates";
$_LANG['store']['ssl']['landingPage']['help']['ev']['title'] = "Extended Validation (EV)";
$_LANG['store']['ssl']['landingPage']['help']['ev']['verify'] = "Standards-based approach to authentication, representing the highest level of authentication for SSL Certificates";
$_LANG['store']['ssl']['landingPage']['help']['ev']['issued'] = "Typically issued within 1-3 days";
$_LANG['store']['ssl']['landingPage']['help']['ev']['compliance'] = "Maintains browser and other industry compliance";
$_LANG['store']['ssl']['landingPage']['help']['ev']['for'] = "Ideal for sensitive webpages including ecommerce, online banking, account signups";
$_LANG['store']['ssl']['landingPage']['help']['ev']['type'] = "Think of EV like getting a passport—much more stringent processes, longer lead times and more verification of who you are than with a library card or driver’s license. Recognized internationally as the most trusted way to verify your identity.";
$_LANG['store']['ssl']['landingPage']['help']['ev']['browse'] = "Browse Extended Validation Certificates";
$_LANG['store']['ssl']['landingPage']['viewAll'] = "View All SSL Certificates";
$_LANG['store']['ssl']['landingPage']['buyNow'] = "Buy Now";
$_LANG['store']['ssl']['landingPage']['faq']['title'] = "FAQ";
$_LANG['store']['ssl']['landingPage']['faq']['q1'] = "What is an SSL Certificate?";
$_LANG['store']['ssl']['landingPage']['faq']['a1'] = "SSL Certificates enable data encryption on the internet and allow data to be transmitted securely from a web server to a browser. With SSL, your website can use the https protocol and will display a padlock in end users web browsers to indicate the connection is secure.";
$_LANG['store']['ssl']['landingPage']['faq']['q2'] = "Why do I need an SSL Certificate?";
$_LANG['store']['ssl']['landingPage']['faq']['a2'] = "SSL Certificates are an essential part of the internet. They not only encrypt communication between your computer and the server where a website is located, but they also provide verification that a site is what it claims to be.";
$_LANG['store']['ssl']['landingPage']['faq']['q3'] = "What are the different types of SSL?";
$_LANG['store']['ssl']['landingPage']['faq']['a3'] = "There are 3 different levels of vetting that SSL Certificates are based upon. Domain Validated (DV) , Organization Validated (OV), and Extended Validation (EV). The major difference between the types of certificate relates to the information the Certificate Authority, RapidSSL, GeoTrust and DigiCert, requires and validates in order to issue a certificate. The higher levels of certificate require more information, and often is displayed in the browser bar. EV SSL for example turns the browser bar green and displays the organization name to visitors to generate more trust.";
$_LANG['store']['ssl']['landingPage']['faq']['q4'] = "What is a Wildcard SSL Certificate";
$_LANG['store']['ssl']['landingPage']['faq']['a4'] = "A Wildcard SSL certificate provides the same encryption and authentication features as other SSL certificates but can also be applied to an unlimited number of subdomains of a website. A Wildcard SSL certificate supports the root domain (example.com) as well as its subdomains.";
$_LANG['store']['ssl']['landingPage']['faq']['q5'] = "What are the advantages of an EV SSL Certificate?";
$_LANG['store']['ssl']['landingPage']['faq']['a5'] = "EV or Extended Validation certificates are the highest class of SSL available and give the most credibility and trust to your website. EV assures consumers that their personal and financial information is protected at the highest levels of authentication. Additional verifications are performed, such as corporate agency record checks, applicant contact info, and whether the business has existed for a minimum of 3 years. EV certificates are best suited for business-critical webpages.";
$_LANG['store']['ssl']['landingPage']['faq']['q6'] = "What if I already have an SSL Certificate?";
$_LANG['store']['ssl']['landingPage']['faq']['a6'] = "You can switch to us at any time.  We offer highly competitive pricing and if you already have an existing certificate, we'll add any remaining validity that you have on your existing competitor SSL Certificate up to a maximum of an additional 12 months.";

$_LANG['creditCardStore'] = "کارت را برای تسویه سریعتر در آینده ذخیره کنید";

$_LANG['support']['ccRecipients'] = "گیرندگان CC";
$_LANG['support']['addCcRecipients'] = "آدرس ایمیل را وارد کن";
$_LANG['support']['removeRecipient'] = "حذف گیرنده";
$_LANG['support']['successDelete'] = "The cc recipient :email has been removed";
$_LANG['support']['deleteEmailNotExisting'] = "The email :email is not a cc recipient";
$_LANG['support']['addEmailExists'] = "The email :email is already a cc recipient";
$_LANG['support']['successAdd'] = "The cc recipient :email has been added";
$_LANG['support']['clientEmail'] = "آدرس ایمیل مشتری را نمی توان به عنوان گیرنده سی سی اضافه کرد";
$_LANG['support']['emailNotPossible'] = "It is not possible to add :email as a cc recipient";
$_LANG['support']['invalidEmail'] = "آدرس ایمیل نامعتبر وارد شده است";
$_LANG['support']['ipAddress'] = "آدرس آیپی";
$_LANG['support']['ticketError'] = "We cannot process your ticket request at this time. Please try again later.";

$_LANG['confirmAndPay'] = "تأیید و پرداخت";
$_LANG['paymentPreApproved'] = "پرداخت از پیش تأیید شده با :gateway";
$_LANG['expressCheckoutInfo'] = "پرداخت شما در انتظار تأیید است. معمولاً فقط چند دقیقه طول می کشد تا پرداخت ها تکمیل شود. اگر ظرف چند دقیقه رسید ایمیل دریافت نکردید ، لطفاً با پشتیبانی تماس بگیرید.";
$_LANG['expressCheckoutError'] = "هنگام پردازش پرداخت شما مشکلی پیش آمد. لطفاً با پشتیبانی تماس بگیرید";

$_LANG['subscription']['active'] = "شما یک اشتراک فعال دارید";
$_LANG['subscription']['manual'] = "ممکن است هنوز پرداخت دستی انجام دهید اما ممکن است منجر به اضافه پرداخت شود";
$_LANG['subscription']['moreDetails'] = "جزئیات بیشتر";
$_LANG['subscription']['makePayment'] = "ایجاد یک پرداخت";
$_LANG['subscription']['paypalDetails'] = "جزئیات اشتراک PayPal";
$_LANG['subscription']['subscriptionWarning'] = "هرگونه اشتراک فعال زیر به صورت خودکار بر روی این فاکتور اعمال می شود. اگر پرداخت اشتراک منجر به اضافه پرداخت شود ، اعتباری دریافت خواهید کرد که به صورت خودکار در صورتحساب بعدی شما اعمال می شود";
$_LANG['subscription']['subscriptionid'] = "شناسه اشتراک";
$_LANG['subscription']['status'] = "وضعیت اشتراک";
$_LANG['subscription']['lastpayment'] = "آخرین پرداخت";
$_LANG['subscription']['nextpaymentdate'] = "تاریخ پرداخت بعدی";
$_LANG['subscription']['subscriptionstartdate'] = "تاریخ شروع اشتراک";
$_LANG['subscription']['failedpaymentscount'] = "تعداد پرداخت های ناموفق";
$_LANG['subscription']['errorFetchingDetails'] = "هنگام تلاش برای به دست آوردن اطلاعات اشتراک خطایی روی داد. لطفاً با پشتیبانی تماس بگیرید";

$_LANG['navMarketConnectService']['sitelockvpn'] = "VPN";
$_LANG['store']['sitelockvpn']['tagline'] = "بدون محدودیت های مربوط به حریم خصوصی ، محدودیت های محتوا یا محدودیت داده ها ، به اینترنت دسترسی نامحدود داشته باشید";
$_LANG['store']['sitelockvpn']['manageService'] = "Manage your SiteLock VPN Service";
$_LANG['store']['sitelockvpn']['cartShortDescription'] = "SiteLock VPN allows anonymous, encrypted browsing sessions over any network connection.";
$_LANG['store']['sitelockvpn']['cartTitle'] = "SiteLock VPN";
$_LANG['store']['sitelockvpn']['promo']['sidebar']['title'] = "Virtual Private Network";
$_LANG['store']['sitelockvpn']['promo']['sidebar']['body'] = "Anonymize your browsing";
$_LANG['store']['sitelockvpn']['adminPreview'] = "SiteLock VPN plans you activate will be displayed here";

$_LANG['store']['sitelockvpn']['title'] = "SiteLock VPN";
$_LANG['store']['sitelockvpn']['getStarted'] = "Get Started";
$_LANG['store']['sitelockvpn']['subtitle1'] = "Secure & Protect";
$_LANG['store']['sitelockvpn']['subtitle2'] = "Your Web Browsing";
$_LANG['store']['sitelockvpn']['tagline1'] = "High speed, secure, and easy";
$_LANG['store']['sitelockvpn']['tagline2'] = "to use with instant setup.";
$_LANG['store']['sitelockvpn']['feature1']['title'] = "Get secure and private access to the internet.";
$_LANG['store']['sitelockvpn']['feature1']['subtitle'] = "<strong>Shield your personal data</strong> and get peace of mind each time you use public Wi-Fi, access personal and work accounts on the road, or just want to keep your browsing history to yourself.";
$_LANG['store']['sitelockvpn']['feature1']['highlights']['one'] = "Hide your IP address";
$_LANG['store']['sitelockvpn']['feature1']['highlights']['two'] = "Protect your online identity";
$_LANG['store']['sitelockvpn']['feature1']['highlights']['three'] = "No activity logs to track browsing";
$_LANG['store']['sitelockvpn']['feature1']['highlights']['four'] = "Secure your bank transactions";
$_LANG['store']['sitelockvpn']['feature1']['highlights']['five'] = "Use military-grade encryption";
$_LANG['store']['sitelockvpn']['feature1']['highlights']['six'] = "Be safe on public Wi-Fi networks";
$_LANG['store']['sitelockvpn']['feature2']['title'] = "Stream and browse without limitations.";
$_LANG['store']['sitelockvpn']['feature2']['subtitle'] = "From video streaming to social networks, <strong>our VPN works anywhere</strong> and allows you to access the sites and apps you love. Plus fast speeds for easy browsing and no more buffering or long waits.";
$_LANG['store']['sitelockvpn']['feature2']['highlights']['one'] = "Access blocked websites";
$_LANG['store']['sitelockvpn']['feature2']['highlights']['two'] = "Watch streaming services anywhere";
$_LANG['store']['sitelockvpn']['feature2']['highlights']['three'] = "Bypass local internet censorship";
$_LANG['store']['sitelockvpn']['feature2']['highlights']['four'] = "Play region-locked games";
$_LANG['store']['sitelockvpn']['feature2']['highlights']['five'] = "Get better deals online";
$_LANG['store']['sitelockvpn']['feature2']['highlights']['six'] = "Stay private and anonymous";
$_LANG['store']['sitelockvpn']['feature3']['title'] = "Protect all your devices.";
$_LANG['store']['sitelockvpn']['feature3']['subtitle'] = "<strong>1-click-setup VPN</strong> for Mac, Windows, iOS, and Android.";
$_LANG['store']['sitelockvpn']['feature3']['subtitle2'] = "Access the internet from anywhere, whether you're on a computer, smartphone, or tablet. Auto-configuration is supported for all major platforms<sup>*</sup> allowing you to surf unrestricted with no coding or complex setup required. <strong>Simply download and connect.</strong>";
$_LANG['store']['sitelockvpn']['feature3']['subtitle3'] = "* Other platforms can be configured manually.";
$_LANG['store']['sitelockvpn']['pricing']['oneSubscription'] = "Just one subscription covers and protects";
$_LANG['store']['sitelockvpn']['pricing']['fiveDevices'] = "up to 5 devices simultaneously.";
$_LANG['store']['sitelockvpn']['pricing']['features']['noRestrictions'] = "No Restrictions";
$_LANG['store']['sitelockvpn']['pricing']['features']['highSpeed'] = "High Speed Network";
$_LANG['store']['sitelockvpn']['pricing']['features']['unlimited'] = "Unlimited bandwidth";
$_LANG['store']['sitelockvpn']['pricing']['features']['encryption'] = "256-bit AES Encryption";
$_LANG['store']['sitelockvpn']['plans']['features']['allInclude'] = "All Subscription Plans include";
$_LANG['store']['sitelockvpn']['plans']['features']['noRestrictions'] = "No Restrictions";
$_LANG['store']['sitelockvpn']['plans']['features']['highSpeed'] = "High Speed Network";
$_LANG['store']['sitelockvpn']['plans']['features']['unlimited'] = "Unlimited bandwidth";
$_LANG['store']['sitelockvpn']['plans']['features']['encryption'] = "256-bit AES Encryption";
$_LANG['store']['sitelockvpn']['plans']['features']['protocol'] = "OpenVPN, L2TP-IPsec<br>and PPTP protocols";
$_LANG['store']['sitelockvpn']['plans']['features']['simultaneous'] = "Simultaneous connections on<br>up to 5 devices";
$_LANG['store']['sitelockvpn']['plans']['features']['apps'] = "Apps for Windows, Mac, iOS,<br>Android, and Linux";
$_LANG['store']['sitelockvpn']['plans']['features']['switching'] = "Unlimited Server Switching";
$_LANG['store']['sitelockvpn']['plans']['features']['countries'] = "40+ Countries";
$_LANG['store']['sitelockvpn']['plans']['features']['servers'] = "1000+ Servers";
$_LANG['store']['sitelockvpn']['plans']['features']['support'] = "24/7 US Based Support";
$_LANG['store']['sitelockvpn']['world']['features']['title'] = "Blazing fast speeds, unlimited bandwidth";
$_LANG['store']['sitelockvpn']['world']['features']['servers'] = "servers";
$_LANG['store']['sitelockvpn']['world']['features']['countries'] = "countries";
$_LANG['store']['sitelockvpn']['world']['features']['unlimited'] = "Unlimited";
$_LANG['store']['sitelockvpn']['world']['features']['bandwidth'] = "bandwidth";

$_LANG['navMarketConnectService']['nordvpn'] = "VPN";
$_LANG['store']['nordvpn']['tagline'] = "Get unlimited access to an Internet free of privacy concerns, content restrictions or data caps.";
$_LANG['store']['nordvpn']['manageService'] = "Manage your NordVPN Service";
$_LANG['store']['nordvpn']['cartShortDescription'] = "NordVPN allows anonymous, encrypted browsing sessions over any network connection.";
$_LANG['store']['nordvpn']['cartTitle'] = "NordVPN";
$_LANG['store']['nordvpn']['promo']['sidebar']['title'] = "NordVPN Security";
$_LANG['store']['nordvpn']['promo']['sidebar']['body'] = "Cybersecurity built for every day.";

$_LANG['store']['nordvpn']['title'] = "NordVPN";
$_LANG['store']['nordvpn']['shared']['get'] = "Get NordVPN";
$_LANG['store']['nordvpn']['hero']['title'] = "Cybersecurity.:tagBreak:tagOpenBuilt for everyday:tagClose";
$_LANG['store']['nordvpn']['hero']['tagline'] = "Secure your connection and hide your IP.:tagBreakBlock malware, trackers, and ads.";
$_LANG['store']['nordvpn']['hero']['available'] = "Available on";
$_LANG['store']['nordvpn']['hero']['guarantee'] = "15-day money-back guarantee";
$_LANG['store']['nordvpn']['features']['icon']['title1'] = "With a VPN, you can:";
$_LANG['store']['nordvpn']['features']['icon']['video'] = "Browse, stream, and download content with a secure and private connection";
$_LANG['store']['nordvpn']['features']['icon']['global'] = "Watch home shows and sports from abroad";
$_LANG['store']['nordvpn']['features']['icon']['hacker'] = "Shield against hackers on unsecured networks (like public Wi-Fi®)";
$_LANG['store']['nordvpn']['features']['icon']['property'] = "Reduce online tracking by hiding your IP address";
$_LANG['store']['nordvpn']['features']['icon']['title2'] = "Keep your data safe";
$_LANG['store']['nordvpn']['features']['icon']['check1'] = "Secure, high-speed VPN";
$_LANG['store']['nordvpn']['features']['icon']['check2'] = "Encrypt your internet connect, reclaim digital privacy, and access your favorite content with the fastest VPN on the market. Choose from VPN servers in 59 countries, and protect up to 6 devices at once.";
$_LANG['store']['nordvpn']['features']['icon']['bug1'] = "Malware protection";
$_LANG['store']['nordvpn']['features']['icon']['bug2'] = "Get warnings about unsafe sites and automatically scan all downloaded files and attachments for malware. If they're not safe to open, they're automatically deleted to prevent any damage to your device.";
$_LANG['store']['nordvpn']['features']['icon']['shield1'] = "Tracker and ad blocker";
$_LANG['store']['nordvpn']['features']['icon']['shield2'] = "Block annoying ads, pop-ups, and banners, and stop third-party websites from tracking your online activity. Enjoy a safer, smoother, and faster browsing experience on all sites, and on every device.";
$_LANG['store']['nordvpn']['features']['comparison']['title'] = "Why choose NordVPN?";
$_LANG['store']['nordvpn']['features']['comparison']['speed1'] = "Connection Speed*";
$_LANG['store']['nordvpn']['features']['comparison']['speed2'] = "6730+ Mbps";
$_LANG['store']['nordvpn']['features']['comparison']['speed3'] = "2200+ Mbps";
$_LANG['store']['nordvpn']['features']['comparison']['speed4'] = "3320+ Mbps";
$_LANG['store']['nordvpn']['features']['comparison']['speed5'] = "1600+ Mbps";
$_LANG['store']['nordvpn']['features']['comparison']['speed6'] = "2320+ Mbps";
$_LANG['store']['nordvpn']['features']['comparison']['wireguard'] = "WireGuard&reg; for top speeds";
$_LANG['store']['nordvpn']['features']['comparison']['vpn1'] = "VPN Servers";
$_LANG['store']['nordvpn']['features']['comparison']['vpn2'] = "5500+";
$_LANG['store']['nordvpn']['features']['comparison']['vpn3'] = "3000+";
$_LANG['store']['nordvpn']['features']['comparison']['vpn4'] = "200+";
$_LANG['store']['nordvpn']['features']['comparison']['vpn5'] = "1600+";
$_LANG['store']['nordvpn']['features']['comparison']['vpn6'] = "6500+";
$_LANG['store']['nordvpn']['features']['comparison']['log'] = "Verified no-logs policy";
$_LANG['store']['nordvpn']['features']['comparison']['chat'] = "Live chat customer support";
$_LANG['store']['nordvpn']['features']['comparison']['asterisk'] = "*Overall network performance according to research by AV-Test. You can :tagOpenread the full report:tagClose. Date of comparison: February 17, 2021.";
$_LANG['store']['nordvpn']['features']['threat']['title'] = "More than just a VPN";
$_LANG['store']['nordvpn']['features']['threat']['tagline'] = "NordVPN's :tagOpenThreat Protection:tagClose feature is a game changer that offers even more security benefits and better protection with a single extra click.";
$_LANG['store']['nordvpn']['features']['threat']['protection'] = ":tagOpenThreat Protection:tagClose blocks intrusive ads and web trackers, and automatically scans URLs and blocks malicious ones.";
$_LANG['store']['nordvpn']['features']['threat']['malware'] = "Whenever you download a file, :tagOpenThreat Protection:tagClose inspects it for malware.";
$_LANG['store']['nordvpn']['features']['threat']['safe'] = ":tagOpenThreat Protection:tagClose protects not only your devices but also you. The ability to block trackers helps you avoid online spies and stalkers.";
$_LANG['store']['nordvpn']['features']['device']['title1'] = "No bandwidth limits";
$_LANG['store']['nordvpn']['features']['device']['tagline1'] = "There are no speed limits at our end. Enjor your full-speed VPN connection without any throttling.";
$_LANG['store']['nordvpn']['features']['device']['title2'] = "Works on all devices";
$_LANG['store']['nordvpn']['features']['device']['tagline2'] = "NordVPN is compatible with all popular platforms, including Windows, macOS, Linux, Android, and iOS. Besides, you can secure up to 6 devices with a single account, including your router.";
$_LANG['store']['nordvpn']['features']['world']['title'] = "A truly global VPN server network";
$_LANG['store']['nordvpn']['features']['world']['tagline'] = "Choose among thousands of ultra-fast VPN servers worldwide.:tagBreakEnjoy a stable connection wherever you are.";
$_LANG['store']['nordvpn']['features']['world']['bullet1'] = "VPN servers";
$_LANG['store']['nordvpn']['features']['world']['count1'] = "5500+";
$_LANG['store']['nordvpn']['features']['world']['bullet2'] = "Countries";
$_LANG['store']['nordvpn']['features']['world']['count2'] = "59";
$_LANG['store']['nordvpn']['features']['world']['bullet3'] = "Blazing speeds";
$_LANG['store']['nordvpn']['features']['world']['bullet4'] = "Unlimited bandwidth";
$_LANG['store']['nordvpn']['features']['world']['getDeal'] = "Grab the Deal";
$_LANG['store']['nordvpn']['features']['security']['title1'] = "Increase your online security with a VPN";
$_LANG['store']['nordvpn']['features']['security']['tagline1'] = "If you want protection from hackers and online monitoring, you can make your connection more secure with a virtual private network (VPN) from NordVPN.";
$_LANG['store']['nordvpn']['features']['security']['tagline2'] = ":tagOpenUse NordVPN to encrypt your online activity:tagClose for an extra layer of protection whenever and wherever you're connected.";
$_LANG['store']['nordvpn']['features']['security']['title2'] = "Ultimate security";
$_LANG['store']['nordvpn']['features']['security']['tagline3'] = "NordVPN safeguards your connection with next-generation encryption, so you can log into your accounts, make bank transfers, and shop online without worries. Even on unprotected Wi-Fi.";
$_LANG['store']['nordvpn']['features']['security']['title3'] = "No-logs policy";
$_LANG['store']['nordvpn']['features']['security']['tagline4'] = "It's nobody's business what you do online. That's why we don't track, collect, or share your private data. We couldn't provide any details about you to third parties, even if they ask.";
$_LANG['store']['nordvpn']['features']['security']['title4'] = "Extra features for extra security";
$_LANG['store']['nordvpn']['features']['security']['tagline5'] = "NordVPN boasts a wide range of features to protect you from cyber threats. In addition to :tagOpenThreat Protection:tagClose, there is an automatic :tagOpenKill Switch:tagClose that blocks your internet connection if your VPN connection drops, ensuring that your data stays safe. :tagOpenDouble VPN:tagClose will help when a high level of online security is required due to government censorship and strict internet regulations. You'll be protected from :tagOpenDNS leaks:tagClose, too.";
$_LANG['store']['nordvpn']['features']['use']['title1'] = "Use Cases";
$_LANG['store']['nordvpn']['features']['use']['tagline1'] = "Even if you have nothing to hide, you probably don't like the idea of being watched and tracked. The main reason why internet users choose VPN services is online privacy and general security.:tagBreak:tagOpenHere are specific reasons WHY?:tagClose";
$_LANG['store']['nordvpn']['features']['use']['title2'] = "Wi-Fi in Public Places";
$_LANG['store']['nordvpn']['features']['use']['tagline2'] = "Public Wi-Fi networks in Hotels, Airports, & Coffee Shops are the perfect targets for hackers due to often low security measures.";
$_LANG['store']['nordvpn']['features']['use']['title3'] = "Shield browsing from third parties";
$_LANG['store']['nordvpn']['features']['use']['tagline3'] = "Prevent third parties such as Internet Service Providers from seeing and tracking your day-to-day online activity.";
$_LANG['store']['nordvpn']['features']['use']['title4'] = "Access social media platforms anywhere";
$_LANG['store']['nordvpn']['features']['use']['tagline4'] = "Avoid regional and political restrictions on platforms like Facebook, Twitter, WhatsApp and more.";
$_LANG['store']['nordvpn']['features']['use']['title5'] = "Enjoy online entertainment and live sports";
$_LANG['store']['nordvpn']['features']['use']['tagline5'] = "Even though online platforms can be accessed from anywhere in the world, certain broadcasts, shows or sporting events are often restricted.";
$_LANG['store']['nordvpn']['features']['use']['title6'] = "Protect your device from malicious ads";
$_LANG['store']['nordvpn']['features']['use']['tagline6'] = "Online ads usually make your browsing experience way worse. They clutter large parts of websites, slow downloading speeds, and might be sources of malware.";
$_LANG['store']['nordvpn']['features']['use']['title7'] = "Secure your smart home gadgets";
$_LANG['store']['nordvpn']['features']['use']['tagline7'] = "Smart home technologies and in particular unsecure IoT devices can create vulnerabilities for home networks.";
$_LANG['store']['nordvpn']['features']['pricing']['title'] = "Choose how you pay:";
$_LANG['store']['nordvpn']['features']['pricing']['get'] = "Get Started";
$_LANG['store']['nordvpn']['features']['pricing']['save'] = "Save :amount%!";
$_LANG['store']['nordvpn']['features']['faq']['title'] = "FAQ";
$_LANG['store']['nordvpn']['features']['faq']['question1'] = "What is a VPN?";
$_LANG['store']['nordvpn']['features']['faq']['answer1'] = "A :tagOpenvirtual private network:tagClose routes your internet traffic through a secure tunnel, changing your virtual location in the process. But NordVPN is more than just a VPN &mdash; we also offer powerful anti-malware tools.";
$_LANG['store']['nordvpn']['features']['faq']['question2'] = "What is Auto-Kill Switch?";
$_LANG['store']['nordvpn']['features']['faq']['answer2'] = "VPN Fail-Safe switch. If VPN connection drops, Kill Switch will block your device from sending unsecured data.";
$_LANG['store']['nordvpn']['features']['faq']['question3'] = "What is NordVPN's Threat Protection?";
$_LANG['store']['nordvpn']['features']['faq']['answer3'] = "NordVPN’s Threat Protection feature makes you much safer from online threats. Turn it on, and Threat Protection will block intrusive ads and trackers, scan URLs to protect you from dangerous websites, and inspect downloaded files for malware.  Experience the internet without intrusive tracking or censorship. Stay secure on Wi-Fi networks and stop your mobile apps from leaking unencrypted data. Get it all with just the click of a button.";
$_LANG['store']['nordvpn']['features']['faq']['question4'] = "What is DNS Leak Protection?";
$_LANG['store']['nordvpn']['features']['faq']['answer4'] = "Protects your online activity in case DNS servers send unencrypted queries outside a secure VPN tunnel.";
$_LANG['store']['nordvpn']['features']['faq']['question5'] = "What is Double VPN?";
$_LANG['store']['nordvpn']['features']['faq']['answer5'] = "Double Encryption. When a high level of security and privacy is needed.";

$_LANG['navMarketConnectService']['threesixtymonitoring'] = "Site & Server Monitoring";
$_LANG['marketConnect']['threesixtymonitoring']['manage'] = "Log in to Dashboard";
$_LANG['store']['threesixtymonitoring']['title'] = "360 Monitoring";
$_LANG['store']['threesixtymonitoring']['cartTitle'] = "360 Monitoring";
$_LANG['store']['threesixtymonitoring']['cartShortDescription'] = "A reliable and comprehensive solution for multi-server and multi-site monitoring.";
$_LANG['store']['threesixtymonitoring']['promo']['sidebar']['title'] = "360 Monitoring";
$_LANG['store']['threesixtymonitoring']['promo']['sidebar']['body'] = "A reliable and comprehensive, multi-server and multi-site monitoring.";

$_LANG['store']['threesixtymonitoring']['websiteHeading']['title'] = "Find your website's problems before your visitors do!";
$_LANG['store']['threesixtymonitoring']['websiteHeading']['tagline'] = "Enter your URL for a fast and free assessment of your website:";
$_LANG['store']['threesixtymonitoring']['serverHeading']['title'] = "Because uptime is money!";
$_LANG['store']['threesixtymonitoring']['serverHeading']['tagline'] = "Safeguard your server and website health today.";
$_LANG['store']['threesixtymonitoring']['modal']['title'] = "Test results for:";
$_LANG['store']['threesixtymonitoring']['modal']['subtitle'] = "Tester Results";
$_LANG['store']['threesixtymonitoring']['modal']['currentStatus'] = "Current Status";
$_LANG['store']['threesixtymonitoring']['modal']['resolvingTime'] = "DNS Resolving Time";
$_LANG['store']['threesixtymonitoring']['modal']['connectionTime'] = "Connection Time";
$_LANG['store']['threesixtymonitoring']['modal']['totalTime'] = "Total Time Needed";
$_LANG['store']['threesixtymonitoring']['modal']['positive'] = "Positive";
$_LANG['store']['threesixtymonitoring']['modal']['concern'] = "Concern";
$_LANG['store']['threesixtymonitoring']['modal']['negative'] = "Negative";
$_LANG['store']['threesixtymonitoring']['button']['getStarted'] = "Get Started";
$_LANG['store']['threesixtymonitoring']['button']['startMonitoringShort'] = "Start Monitoring";
$_LANG['store']['threesixtymonitoring']['button']['startMonitoringLong'] = "Start Monitoring Your Website";
$_LANG['store']['threesixtymonitoring']['navTab']['website'] = "Site Monitoring";
$_LANG['store']['threesixtymonitoring']['navTab']['server'] = "Server Monitoring";
$_LANG['store']['threesixtymonitoring']['navTab']['full'] = "Full Site Check";
$_LANG['store']['threesixtymonitoring']['websiteDiscover']['title'] = "What is 360 Site Monitoring?";
$_LANG['store']['threesixtymonitoring']['websiteDiscover']['tagline'] = "360 Site Monitoring makes unnoticed downtime a thing of the past!";
$_LANG['store']['threesixtymonitoring']['websiteDiscover']['i1'] = "Monitor load times and responsiveness with :tagOpenregular scans:tagClose and metrics you can use.";
$_LANG['store']['threesixtymonitoring']['websiteDiscover']['i2'] = "Maximize uptime by resolving website problems before they happen with :tagOpeninstant alerting.:tagClose";
$_LANG['store']['threesixtymonitoring']['websiteDiscover']['i3'] = "Prevent downtime and boost visibility and customer experiences with :tagOpen360 Monitoring!:tagClose";
$_LANG['store']['threesixtymonitoring']['serverDiscover']['title'] = "What is 360 Site Monitoring?";
$_LANG['store']['threesixtymonitoring']['serverDiscover']['tagline'] = "Our all-in-one, panel-agnostic solution for multi-server and multi-site management is the key to providing your customers with peace of mind and reliable resource monitoring.";
$_LANG['store']['threesixtymonitoring']['serverDiscover']['i1'] = "360 Monitoring is <strong>open-source and customizable</strong>, ensuring that all essential metrics and resources are properly monitored to suit your needs.";
$_LANG['store']['threesixtymonitoring']['serverDiscover']['i2'] = "With 360 Monitoring, you can ensure <strong>optimal performance</strong> for your visitors, avoid downtime, and proactively address any potential issues.";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['title'] = "How Does 360 Monitoring Help my Website?";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i1a'] = "Downtime Monitoring";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i1b'] = "Get instant alerts when your website is offline!";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i1c'] = "Identify and respond to issues before your customers are negatively impacted and before you lose revenue!";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i2a'] = "Performance Monitoring";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i2b'] = "Make sure your website performs faster and ranks higher in search engine results!";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i2c'] = "Check Time to First Byte (TTFB), DNS time, connection time, and total duration.";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i3a'] = "Geo Monitoring";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i3b'] = "Learn about location-specific problems in your websites.";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i3c'] = "Ensure accessibility and performance from up to 26 different locations.";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i4a'] = "Keyword Monitoring";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i4b'] = "Monitor website sources for specific words and phrases (for example, “error” or “stock out”) and set up alerts for their presence or absence.";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i5a'] = "Port Monitoring";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i5b'] = "Check responsiveness of HTTP/S for web traffic, TCP for network connectivity issues or firewall blockages, and ICMP (ping) for availability.";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i6a'] = "SSL Monitoring";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i6b'] = "Get alerted about SSL/TLS certificate expirations and make sure that your visitors can always access your website securely.";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i7a'] = "Identify Broken Links";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i7b'] = "Find and fix broken links before they affect your search engine rankings and cause a poor customer experience.";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i8a'] = "Detect Missing Assets";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i8b'] = "Get alerts about missing files, missing resources, and JavaScript errors that can slow down page load times, cause visual inconsistencies, and degrade the user experience.";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i9a'] = "Performance-Impacting Assets";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i9b'] = "Identify large files and libraries that impact your website's bounce rate, engagement, and conversions.";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i10a'] = "Scan Your Google® Fonts for Compliance";
$_LANG['store']['threesixtymonitoring']['websiteFeatures']['i10b'] = "Comply with privacy laws by scanning for Google Fonts and avoiding collection of personal data from website visitors, potentially violating data protection regulations.";
$_LANG['store']['threesixtymonitoring']['serverFeatures']['title'] = "Server Monitoring Features";
$_LANG['store']['threesixtymonitoring']['notifications']['title'] = "Get Alerts via Your Favorite App";
$_LANG['store']['threesixtymonitoring']['notifications']['tagline'] = "Be the first to know when your site is down or performing poorly!";
$_LANG['store']['threesixtymonitoring']['notifications']['email'] = "Email";
$_LANG['store']['threesixtymonitoring']['notifications']['sms'] = "SMS";
$_LANG['store']['threesixtymonitoring']['notifications']['pushbullet'] = "Pushbullet™";
$_LANG['store']['threesixtymonitoring']['notifications']['googlechat'] = "Google Chat™";
$_LANG['store']['threesixtymonitoring']['notifications']['pushover'] = "Pushover";
$_LANG['store']['threesixtymonitoring']['notifications']['discord'] = "Discord";
$_LANG['store']['threesixtymonitoring']['notifications']['slack'] = "Slack®";
$_LANG['store']['threesixtymonitoring']['notifications']['webhook'] = "Webhook";
$_LANG['store']['threesixtymonitoring']['notifications']['stride'] = "Stride";
$_LANG['store']['threesixtymonitoring']['notifications']['pagerduty'] = "PagerDuty";
$_LANG['store']['threesixtymonitoring']['notifications']['telegram'] = "Telegram";
$_LANG['store']['threesixtymonitoring']['notifications']['flock'] = "Flock";
$_LANG['store']['threesixtymonitoring']['notifications']['microsoft365'] = "Microsoft 365®";
$_LANG['store']['threesixtymonitoring']['notifications']['opsgenie'] = "OpsGenie";
$_LANG['store']['threesixtymonitoring']['websiteMonitor']['title'] = "Monitor and Communicate the Status of Your Website";
$_LANG['store']['threesixtymonitoring']['websiteMonitor']['tagline'] = "Reduce frustration and grow user trust by quickly alerting users to issues and providing updates on the status of ongoing incidents.";
$_LANG['store']['threesixtymonitoring']['serverMonitor']['title'] = "Why Choose 360 Monitoring?";
$_LANG['store']['threesixtymonitoring']['serverMonitor']['tagline'] = "Because no one can afford downtime!";
$_LANG['store']['threesixtymonitoring']['serverMonitor']['lostRevenue'] = "Lost revenue per year due to downtime:";
$_LANG['store']['threesixtymonitoring']['serverMonitor']['uptime'] = "Uptime";
$_LANG['store']['threesixtymonitoring']['serverMonitor']['perYear'] = "/year";
$_LANG['store']['threesixtymonitoring']['serverMonitor']['asterisk'] = "* Calculation is based on a website generating $500K in revenue per year, excluding peak campaign seasons.";
$_LANG['store']['threesixtymonitoring']['websitePricing']['title'] = "Pricing";
$_LANG['store']['threesixtymonitoring']['websitePricing']['cta'] = ":tagOpenLooking for Server Monitoring?:tagClose Metrics like CPU, network, memory, and disk usage.";
$_LANG['store']['threesixtymonitoring']['serverPricing']['cta'] = ":tagOpenLooking for Website Monitoring?:tagClose Metrics like uptime, performance, and health.";
$_LANG['store']['threesixtymonitoring']['comparison']['servers'] = "Servers";
$_LANG['store']['threesixtymonitoring']['comparison']['monitors'] = "Websites";
$_LANG['store']['threesixtymonitoring']['comparison']['timeIntervals'] = "Time Intervals";
$_LANG['store']['threesixtymonitoring']['comparison']['alerting'] = "Alerting";
$_LANG['store']['threesixtymonitoring']['comparison']['dataRetention'] = "Data Retention";
$_LANG['store']['threesixtymonitoring']['comparison']['fullSiteCheck'] = "Full Site Check";
$_LANG['store']['threesixtymonitoring']['comparison']['concurrentCrawls'] = "Concurrent Crawls";
$_LANG['store']['threesixtymonitoring']['comparison']['highPriorityCrawls'] = "High-Priority Crawls";
$_LANG['store']['threesixtymonitoring']['comparison']['recurringScheduledCrawls'] = "Recurring Scheduled Crawls";
$_LANG['store']['threesixtymonitoring']['comparison']['crawlDepth'] = "Crawl Depth (URLs)";
$_LANG['store']['threesixtymonitoring']['comparison']['startingFrom'] = "Starting From";
$_LANG['store']['threesixtymonitoring']['comparison']['tagLine'] = "";
$_LANG['store']['threesixtymonitoring']['comparison']['tagLite'] = "Free 1 Site";
$_LANG['store']['threesixtymonitoring']['comparison']['tagPersonal'] = "Ideal for 1 Site ";
$_LANG['store']['threesixtymonitoring']['comparison']['tagPlus'] = "Ideal for 3 Sites";
$_LANG['store']['threesixtymonitoring']['comparison']['tagAdvanced'] = "Ideal for 10 Sites";
$_LANG['store']['threesixtymonitoring']['comparison']['tagPro'] = "Growing Projects";
$_LANG['store']['threesixtymonitoring']['comparison']['tagBusiness'] = "Big Workloads";
$_LANG['store']['threesixtymonitoring']['comparison']['tagEnterprise'] = "Monitoring at Scale";
$_LANG['store']['threesixtymonitoring']['comparison']['emailOnly'] = "email only";
$_LANG['store']['threesixtymonitoring']['comparison']['multiChannel'] = ":tagOpenmulti-channel:tagClose";
$_LANG['store']['threesixtymonitoring']['comparison']['manual'] = "manual";
$_LANG['store']['threesixtymonitoring']['faq']['title'] = "FAQ";
$_LANG['store']['threesixtymonitoring']['faq']['q1'] = "What is Website Monitoring?";
$_LANG['store']['threesixtymonitoring']['faq']['a1'] = "Website Monitoring tests websites for uptime, performance, and overall function. It verifies that your site is up, running, and accessible for visitors. Website Monitoring results will let you resolve any issues with your site before they impact your business.";
$_LANG['store']['threesixtymonitoring']['faq']['q2'] = "How does Website Monitoring work?";
$_LANG['store']['threesixtymonitoring']['faq']['a2'] = "Website Monitoring performs tests on your website at regular intervals (every 1, 5, or 10 minutes, depending on your plan). These tests detect problems with your website. When an issue is detected, 360 Monitoring sends an alert and records the issue for later analysis.";
$_LANG['store']['threesixtymonitoring']['faq']['q3'] = "How does Performance Monitoring work?";
$_LANG['store']['threesixtymonitoring']['faq']['a3'] = "Performance Monitoring tools and processes check how well the system is running by monitoring system resources like CPU use, memory consumption, disk usage, input/output (I/O) performance, and network uptime. 360 Monitoring tracks all of these metrics to ensure that everything is running smoothly.";
$_LANG['store']['threesixtymonitoring']['faq']['q4'] = "Why is Performance Monitoring important?";
$_LANG['store']['threesixtymonitoring']['faq']['a4'] = "Performance Monitoring is crucial in identifying performance issues before they hurt your business. Its system resource findings also let you proactively plan for your future needs.";
$_LANG['store']['threesixtymonitoring']['faq']['q5'] = "How does SSL Monitoring work?";
$_LANG['store']['threesixtymonitoring']['faq']['a5'] = "With SSL Monitoring, you can track your SSL certificates and plan ahead for expirations, ensuring seamless certificate management.";
$_LANG['store']['threesixtymonitoring']['faq']['q6'] = "What locations are supported for monitoring?";
$_LANG['store']['threesixtymonitoring']['faq']['a6'] = "You can perform monitoring from anywhere in the world, with monitoring locations in Australia, Canada, Finland, France, Germany, Japan, Mexico, the Netherlands, Sweden, the United Kingdom, and the United States.";
$_LANG['store']['threesixtymonitoring']['faq']['q7'] = "What languages are supported?";
$_LANG['store']['threesixtymonitoring']['faq']['a7'] = "360 Monitoring supports English, German, Japanese, Spanish, Italian, Brazilian Portuguese, French, and Russian.";
$_LANG['store']['threesixtymonitoring']['faq']['q8'] = "Can I upgrade my plan?";
$_LANG['store']['threesixtymonitoring']['faq']['a8'] = "Yes, you can upgrade your plan at any time.";
$_LANG['store']['threesixtymonitoring']['faq']['q9'] = "Are there any extra fees for notifications?";
$_LANG['store']['threesixtymonitoring']['faq']['a9'] = "All paid plans allow unlimited multi-channel alerts. Some carriers may charge additional fees for data use or SMS messages.";
$_LANG['store']['threesixtymonitoring']['faq']['q10'] = "What is Server Monitoring?";
$_LANG['store']['threesixtymonitoring']['faq']['a10'] = "Server Monitoring runs regular scans and tracks the health of your server, including CPU, load times, network statistics, memory, disk usage, and more to help you find and resolve issues fast.";
$_LANG['store']['threesixtymonitoring']['faq']['q11'] = "What is Full Site Check?";
$_LANG['store']['threesixtymonitoring']['faq']['a11'] = "Full Site Check protects your online presence against errors. It crawls your entire website or online store and identifies dead links, broken images, JavaScript errors, and many more anomalies, helping avoid website issues.";

$_LANG['marketConnect']['threesixtymonitoring']['clientPanel']['title'] = "360 Monitoring";
$_LANG['marketConnect']['threesixtymonitoring']['clientPanel']['servers'] = "Servers";
$_LANG['marketConnect']['threesixtymonitoring']['clientPanel']['monitors'] = "Websites";
$_LANG['marketConnect']['threesixtymonitoring']['clientPanel']['alerts'] = "Alerts";

$_LANG['store']['noDomain'] = "بدون نیاز به دامنه";
$_LANG['store']['noDomainRequired'] = "هیچ دامنه ای برای این محصول مورد نیاز نیست";
$_LANG['back'] = "بازگشت";

$_LANG['errors']['badRequest'] = "درخواست بد";
$_LANG['errors']['badRequestTryAgain'] = "خطایی روی داد. لطفا دوباره تلاش کنید";
$_LANG['errors']['tryAgainOrSupport'] = "Please try again later or <a href=\"submitticket.php\">contact support</a>.";

$_LANG['paymentMethods']['iban'] = "IBAN";
$_LANG['paymentMethods']['mandateAcceptance'] = "By providing your payment information and confirming this payment, you authorise (A) :companyName and Stripe, our payment service provider, to send instructions to your bank to debit your account and (B) your bank to debit your account in accordance with those instructions. As part of your rights, you are entitled to a refund from your bank under the terms and conditions of your agreement with your bank. A refund must be claimed within 8 weeks starting from the date on which your account was debited. Your rights are explained in a statement that you can obtain from your bank. You agree to receive notifications for future debits up to 2 days before they occur.";
$_LANG['paymentMethods']['achMandateAcceptance'] = "By clicking 'Submit Payment', you authorise :companyName to debit the bank account specified above for any amount owed for charges arising from your use of :companyName's services and/or purchase of products from :companyName, pursuant to :companyName's website and terms, until this authorisation is revoked. You may amend or cancel this authorisation at any time by providing notice to :companyName with 30 (thirty) days notice. If you use :companyName services or purchase additional products periodically pursuant to :companyName's terms, you authorise :companyName to debit your bank account periodically. Payments that fall outside the regular debits authorised above will only be debited after your authorisation is obtained.";

$_LANG['metrics']['title'] = "متریک ها";
$_LANG['metrics']['explanation'] = "این محصول علاوه بر قیمت پایه دارای هزینه های صورتحساب مبتنی بر استفاده است. معیارهای استفاده و اطلاعات قیمت آنها در زیر نشان داده شده است";
$_LANG['metrics']['from'] = "فرم";
$_LANG['metrics']['to'] = "به";
$_LANG['metrics']['startingQuantity'] = "مقدار شروع";
$_LANG['metrics']['unit'] = "واحد";
$_LANG['metrics']['pricePerUnit'] = "قیمت هر واحد";
$_LANG['metrics']['pricePer'] = "قیمت هر";
$_LANG['metrics']['viewPricing'] = "مشاهده قیمت گذاری";
$_LANG['metrics']['pricing'] = "قیمت گذاری";
$_LANG['metrics']['startingFrom'] = "شروع از";
$_LANG['metrics']['pricingschema']['simple']['info'] = "این مورد دارای ساختار قیمت گذاری منحصر به فرد است";
$_LANG['metrics']['pricingschema']['simple']['detail'] = "قیمت هر واحد بدون در نظر گرفتن حجم ثابت است";
$_LANG['metrics']['pricingschema']['grad']['info'] = "این مورد دارای ساختار قیمت گذاری درجه بندی شده است";
$_LANG['metrics']['pricingschema']['grad']['detail'] = "قیمت هر واحد در محدوده مصرف است. کل هزینه مجموع محاسبات محدوده است";
$_LANG['metrics']['pricingschema']['flat']['info'] = "این مورد دارای ساختار قیمت گذاری حجم مسطح است";
$_LANG['metrics']['pricingschema']['flat']['detail'] = "واحد قیمت با کل حجم مصرف تعیین می شود";
$_LANG['metrics']['previousUsage'] = "استفاده قبلی";
$_LANG['metrics']['currentUsage'] = "مصرف کنونی";
$_LANG['metrics']['lastUpdated'] = "اخرین بروزرسانی";
$_LANG['metrics']['metric'] = "متریک";
$_LANG['metrics']['billing'] = "صورتحساب";
$_LANG['metrics']['includedNotCounted'] = "مشمول";
$_LANG['metrics']['includedInBase'] = "در قیمت پایه گنجانده شده است";

$_LANG['metrics']['invoiceitem']['perunit'] = ":consumed :metricname @ :price Per :perUnitName";
$_LANG['metrics']['invoiceitem']['included'] = ":included :metricname Included";

$_LANG['bankPaymentDeclined'] = "اطلاعات حساب بانکی که وارد کرده اید رد شد. لطفاً حساب دیگری را امتحان کنید یا با پشتیبانی تماس بگیرید";
$_LANG['invoicePaymentInitiated'] = "متشکرم! پرداخت شما با موفقیت شروع شد پس از اتمام پرداخت ، ایمیل تأیید دریافت خواهید کرد";
$_LANG['genericPaymentDeclined'] = "پرداخت شما رد شد. لطفاً دوباره امتحان کنید یا با پشتیبانی تماس بگیرید";

$_LANG['sitelockvpn']['loginPanelText'] = "Login to setup and manage your VPN user credentials and download the VPN clients.";
$_LANG['store']['save'] = "Save :saving%";
$_LANG['marketConnect']['codeGuard']['manageBackup'] = "پشتیبان گیری را مدیریت کنید";
$_LANG['store']['chooseExistingDomain'] = "دامنه موجود را انتخاب کنید";
$_LANG['store']['choosePaymentTerm'] = "شرایط پرداخت را انتخاب کنید";
$_LANG['store']['chooseDomain'] = "انتخاب دامنه";
$_LANG['store']['subOfExisting'] = "زیر دامنه یک دامنه موجود";
$_LANG['store']['domainAlreadyOwned'] = "دامنه ای که قبلاً مالک آن هستم";
$_LANG['store']['eligible'] = "Eligible";
$_LANG['store']['login'] = "ورود";
$_LANG['store']['addToExistingPackage'] = "این را به بسته میزبانی موجود اضافه کنید";

$_LANG['marketConnect']['sitelock']['manageSecurity'] = "امنیت خود را مدیریت کنید";
$_LANG['marketConnect']['sitelock']['ftpHost'] = "FTP Host";
$_LANG['marketConnect']['sitelock']['ftpUsername'] = "FTP نام کاربری";
$_LANG['marketConnect']['sitelock']['ftpPassword'] = "FTP رمز عبور";
$_LANG['marketConnect']['sitelock']['ftpPath'] = "FTP Path";
$_LANG['marketConnect']['sitelock']['updateFtp'] = "Update FTP Credentials";
$_LANG['marketConnect']['sitelock']['manage'] = "Log in to SiteLock";
$_LANG['marketConnect']['sitelockvpn']['manageVPN'] = "Manage Your VPN";
$_LANG['marketConnect']['emailServices']['manageEmail'] = "مدیریت ایمیل l";
$_LANG['marketConnect']['emailServices']['manage'] = "Log in to SpamExperts";
$_LANG['marketConnect']['sitelockvpn']['manage'] = "Log in to SiteLock VPN";
$_LANG['marketConnect']['websiteBuilder']['buildWebsite'] = "Build Your Website";

$_LANG['marketConnect']['nordvpn']['clientOutput']['1'] = "Thank you for purchasing NordVPN to secure your personal and business data. You will receive an email from NordVPN that contains your activation link soon. If you don’t see it in your inbox, check your spam folder.";
$_LANG['marketConnect']['nordvpn']['clientOutput']['2'] = "If you have questions about NordVPN or need technical support, contact :anchorOpenNordVPN support:anchorClose.";
$_LANG['marketConnect']['nordvpn']['clientOutput']['3'] = "If you have order or billing questions, contact our support team via :anchorOpenSubmit a Ticket:anchorClose.";
$_LANG['marketConnect']['nordvpn']['clientOutput']['4'] = "If you already have an account and want to manage your Nord account settings, :anchorOpenlog in here:anchorClose.";

$_LANG['creditCardHolderName'] = "نام دارنده کارت";

$_LANG['redirectingToCompleteCheckout'] = "شما را به تکمیل پرداخت نهایی هدایت می کند. لطفا صبر کنید";

$_LANG['paypalEmailAddress'] = "PayPal Email Address";
$_LANG['paypalCommerce']['payerApprovedPlaceholder'] = "Linked Account";
$_LANG['paypalCommerce']['paymentInstructions'] = "To complete payment with PayPal, choose an existing linked PayPal account or link a new account.";
$_LANG['paypalCommerce']['payerApprovedInstructions'] = "Click below to finish checking out with PayPal.";
$_LANG['paypalCommerce']['linkAccount'] = "Link a New PayPal Account";
$_LANG['paypalCommerce']['error']['noAccount'] = "You must select an existing linked PayPal account or link a new account before making payment.";

$_LANG['fromJust'] = "از فقط";
$_LANG['forJust'] = "فقط برای";
$_LANG['remoteTransError'] = "شکست معامله از راه دور. لطفا با پشتیبانی تماس بگیرید.";

$_LANG['imageUnavailable'] = "تصویر در دسترس نیست";

$_LANG['emailPreferences']['affiliate'] = "ایمیل های  همکاری در فروش - اعلان های همکاری در فروش را دریافت کنید";
$_LANG['emailPreferences']['domain'] = "ایمیل های دامنه - اعلامیه ثبت و انتقال و تمدید";
$_LANG['emailPreferences']['general'] = "ایمیل های عمومی - همه ایمیل های مربوط به حساب";
$_LANG['emailPreferences']['invoice'] = "ایمیل های فاکتور - فاکتورهای جدید ، یادآوری ها و اطلاعیه های تعلیق";
$_LANG['emailPreferences']['product'] = "ایمیل سرویس ها - ایمیل های راه اندازی سرویس، انسداد و ...";
$_LANG['emailPreferences']['support'] = "ایمیل های پشتیبانی - یک نسخه  از همه ارتباطات پشتیبانی تیکت ها دریافت کنید";

$_LANG['navMarketConnectService']['marketgoo'] = "SEO ابزار";
$_LANG['store']['marketgoo']['title'] = "Marketgoo SEO Tools";
$_LANG['store']['marketgoo']['headline'] = "Improve your Site's traffic";
$_LANG['store']['marketgoo']['tagline'] = "and <em>Grow your Business</em> with marketgoo";
$_LANG['store']['marketgoo']['tab']['how'] = "How does it work?";
$_LANG['store']['marketgoo']['tab']['features'] = "Features & Pricing";
$_LANG['store']['marketgoo']['tab']['testimonials'] = "What other users say";
$_LANG['store']['marketgoo']['tab']['faqs'] = "FAQs and Support";
$_LANG['store']['marketgoo']['features']['1'] = "Sign Up and get instant SEO Report";
$_LANG['store']['marketgoo']['features']['2'] = "Get your easy SEO plan";
$_LANG['store']['marketgoo']['features']['3'] = "Follow the simple step-by-step instructions";
$_LANG['store']['marketgoo']['features']['4'] = "Start Improving";
$_LANG['store']['marketgoo']['featuresdetail']['4'] = "Put your SEO plan into action (with no experts needed) and get a monthly progress report";
$_LANG['store']['marketgoo']['features']['5'] = "Track & Monitor";
$_LANG['store']['marketgoo']['featuresdetail']['5'] = "See how your competitors rank for the keywords you're focusing on, and track their site's popularity";
$_LANG['store']['marketgoo']['featurematrix']['1'] = "Search engine submission";
$_LANG['store']['marketgoo']['featurematrix']['2'] = "Connect Google Analytics";
$_LANG['store']['marketgoo']['featurematrix']['3'] = "Download SEO report as PDF";
$_LANG['store']['marketgoo']['featurematrix']['4'] = "Pages scanned";
$_LANG['store']['marketgoo']['featurematrix']['5'] = "Competitor tracking";
$_LANG['store']['marketgoo']['featurematrix']['6'] = "Keyword tracking & optimization";
$_LANG['store']['marketgoo']['featurematrix']['7'] = "Updated report & plan";
$_LANG['store']['marketgoo']['featurematrix']['8'] = "Custom SEO Plan";
$_LANG['store']['marketgoo']['featurematrix']['9'] = "Monthly progress report";
$_LANG['store']['marketgoo']['completeStepByStep'] = "<span>Complete</span> with step-by-step guide";
$_LANG['store']['marketgoo']['signup'] = "Signup Now";
$_LANG['store']['marketgoo']['testimonials']['casestudy'] = "Read the case study";
$_LANG['store']['marketgoo']['faqs']['title'] = "FAQs and Support";
$_LANG['store']['marketgoo']['faqs']['q1'] = "Should I choose Lite or Pro?";
$_LANG['store']['marketgoo']['faqs']['a1'] = "See a Video comparison of the Plans";
$_LANG['store']['marketgoo']['faqs']['q2'] = "Does marketgoo make the recommended changes or do I?";
$_LANG['store']['marketgoo']['faqs']['a2'] = "marketgoo is a Do-it-Yourself tool, so while we help you with analysing your site and giving recommendations, along with tasks and instructions for your to optimize your site, we don't make these changes for you.";
$_LANG['store']['marketgoo']['faqs']['q3'] = "Why do I need SEO?";
$_LANG['store']['marketgoo']['faqs']['a3'] = "You work on your SEO in order to improve your site's rankings in search results. This leads to attracting more traffic - and ideally, to convert that traffic into customers and leads.";
$_LANG['store']['marketgoo']['adminPreview'] = "Marketgoo plans you activate will be displayed here";
$_LANG['store']['marketgoo']['labelBestValue'] = "Best value!";

$_LANG['upTo'] = "تا :num";
$_LANG['weekly'] = "هفتگی";
$_LANG['daily'] = "روزانه";
$_LANG['limited'] = "محدود";

$_LANG['marketConnect']['marketgoo']['manageSEO'] = "Marketgoo SEO";
$_LANG['marketConnect']['marketgoo']['manage'] = "Log in to Dashboard";

$_LANG['store']['marketgoo']['cartTitle'] = "Marketgoo SEO Tools";
$_LANG['store']['marketgoo']['cartShortDescription'] = "Improve your site's traffic and grow your business with do-it-yourself SEO Tools from marketgoo.";

$_LANG['store']['marketgoo']['promo']['sidebar']['title'] = "Marketgoo SEO Tools";
$_LANG['store']['marketgoo']['promo']['sidebar']['body'] = "Improve your site's traffic and grow your business";

$_LANG['emailPreferences']['oneRequired'] = "You must have at least one email address enabled to receive domain related notifications as required by ICANN.";
$_LANG['emailPreferences']['domainContactRequired'] = "برای غیرفعال کردن اعلان های دامنه ، لطفاً اعلان های دامنه را برای دارنده حساب اصلی یا مخاطب دیگری فعال کنید";
$_LANG['emailPreferences']['domainClientRequired'] = "برای غیرفعال کردن اعلان های دامنه ، لطفاً یک مخاطب جایگزین ایجاد کنید که برای دریافت آنها تنظیم شده است";

$_LANG['twoFactor']['duosecurity']['friendlyName'] = "Duo Security";
$_LANG['twoFactor']['duosecurity']['description'] = "Get codes via Duo Push, SMS or Phone Callback.";
$_LANG['twoFactor']['totp']['friendlyName'] = "نشانه های زمان محور";
$_LANG['twoFactor']['totp']['description'] = "Get codes from an app like Google Authenticator or Duo.";
$_LANG['twoFactor']['yubico']['friendlyName'] = "Yubico";
$_LANG['twoFactor']['yubico']['description'] = "تولید کدها با استفاده از دستگاه سخت افزاری YubiKey";

$_LANG['orderForm']['selectCategory'] = "لطفاً یک دسته را از منوی نوار کناری انتخاب کنید";

$_LANG['marketConnect']['ox']['manage'] = "Log in to OX App Suite";

$_LANG['store']['sampleProduct'] = "This is a sample product";
$_LANG['store']['emailServices']['tab']['overview'] = "Overview";
$_LANG['store']['emailServices']['tab']['howitworks'] = "How It Works";
$_LANG['store']['emailServices']['tab']['pricing'] = "Pricing";
$_LANG['store']['emailServices']['tab']['faq'] = "FAQ";
$_LANG['store']['emailServices']['incoming']['title'] = "Incoming Email Filtering";
$_LANG['store']['emailServices']['outgoing']['title'] = "Outgoing Email Filtering";
$_LANG['store']['emailServices']['archiving']['title'] = "Email Archiving";
$_LANG['store']['emailServices']['overview']['learn'] = "Learn More";
$_LANG['store']['emailServices']['overview']['buy'] = "Buy";
$_LANG['store']['emailServices']['overview']['incoming']['tagline'] = "Protect your network";
$_LANG['store']['emailServices']['overview']['incoming']['headline'] = "Eliminate Spam and Viruses from email before they ever reach your network";
$_LANG['store']['emailServices']['overview']['outgoing']['tagline'] = "Safeguard your reputation";
$_LANG['store']['emailServices']['overview']['outgoing']['headline'] = "Prevent Spam and Viruses from ever unknowingly leaving your network";
$_LANG['store']['emailServices']['overview']['archiving']['tagline'] = "Backup and Compliance";
$_LANG['store']['emailServices']['overview']['archiving']['headline'] = "Never lose an email again and ensure email data integrity for legal compliance";
$_LANG['store']['emailServices']['benefits']['incoming']['title'] = "Incoming email filtering gives you all these benefits...";
$_LANG['store']['emailServices']['benefits']['incoming']['1'] = "Full Inbox protection at competitive prices";
$_LANG['store']['emailServices']['benefits']['incoming']['2'] = "Extremely accurate filtering";
$_LANG['store']['emailServices']['benefits']['incoming']['3'] = "Easy configuration";
$_LANG['store']['emailServices']['benefits']['incoming']['4'] = "Increase inbound email continuity and redundancy";
$_LANG['store']['emailServices']['benefits']['incoming']['5'] = "Various reporting options";
$_LANG['store']['emailServices']['benefits']['incoming']['6'] = "Friendly interface to keep you in full control over your email";
$_LANG['store']['emailServices']['benefits']['incoming']['7'] = "Increase employee productivity";
$_LANG['store']['emailServices']['benefits']['incoming']['8'] = "Compatible with any mail server";
$_LANG['store']['emailServices']['benefits']['incoming']['q1'] = "Why Choose SpamExperts Incoming Filter?";
$_LANG['store']['emailServices']['benefits']['incoming']['a1'] = "Incoming Email Filtering filters all inbound email and eliminates spam and viruses before these threats reach your network at a nearly 100% accuracy rate. The extensive control-panel allows you to remain in full control. Moreover, in case your email server is down, your email will be queued. Queued email can be accessed, read, and replied to via the web-interface adding to your inbound email continuity!";
$_LANG['store']['emailServices']['benefits']['incoming']['q2'] = "Why do you need a professional Incoming Filter?";
$_LANG['store']['emailServices']['benefits']['incoming']['a2'] = "Stop running the risk of IT network threats. If your Inbox is crowded with unsolicited bulk mail every day, then that's a sign you need a professional Incoming Filter solution. Get full protection for your Inbox and say goodbye to spam, virus and malware threats!";
$_LANG['store']['emailServices']['benefits']['incoming']['q3'] = "How it works";
$_LANG['store']['emailServices']['benefits']['incoming']['a3'] = "Once your domain is (automatically) deployed to the Incoming Filter, and filtering is activated, email will pass through the SpamExperts filtering cloud. Incoming emails are securely analyzed and scanned in real time. No training or configurations are required and everything works out of the box. Any message detected as spam is moved to the quarantine, while non-spam is sent to your email server. The quarantine can be monitored in the user-friendly SpamPanel, through email-reports, or even directly in your email client! No more wasted time in dealing with spam, simply focus your energy on business tasks, while you remain in full control.";
$_LANG['store']['emailServices']['benefits']['outgoing']['title'] = "Outgoing email filtering gives you all these benefits...";
$_LANG['store']['emailServices']['benefits']['outgoing']['1'] = "No more blacklisting";
$_LANG['store']['emailServices']['benefits']['outgoing']['2'] = "Protect the reputation of your brand and IT-systems";
$_LANG['store']['emailServices']['benefits']['outgoing']['3'] = "Avoid de-listing related costs";
$_LANG['store']['emailServices']['benefits']['outgoing']['4'] = "Increase outbound email continuity and delivery";
$_LANG['store']['emailServices']['benefits']['outgoing']['5'] = "Enhance employee productivity";
$_LANG['store']['emailServices']['benefits']['outgoing']['6'] = "Improve abuse manageability";
$_LANG['store']['emailServices']['benefits']['outgoing']['q1'] = "What is outgoing filtering?";
$_LANG['store']['emailServices']['benefits']['outgoing']['a1'] = "Outgoing Email Filtering is vital to safeguard your IT infrastructure reputation and ensure all your outgoing email arrives safely where it should. This professional solution will block spam and viruses from leaving your network and prevent your IP(s) from being blacklisted ever again. Moreover, the SpamExperts Outgoing Filter gives you the reporting and tools to detect compromised accounts and lock-down spamming users.";
$_LANG['store']['emailServices']['benefits']['outgoing']['q2'] = "Why you need it?";
$_LANG['store']['emailServices']['benefits']['outgoing']['a2'] = "Has your network ever sent out spam email without your knowledge? Due to network weaknesses almost any device can be compromised to transmit outbound SMTP, allowing spam or malware to be sent out from your network without you even knowing it! Therefore, it's critical you invest in a professional Outgoing Filter solution. Maintain your company’s good reputation, stop spam from leaving your network and prevent being blacklisted so that your email always arrives where it is meant to go.";
$_LANG['store']['emailServices']['benefits']['archiving']['title'] = "Email archiving gives you all these benefits...";
$_LANG['store']['emailServices']['benefits']['archiving']['1'] = "Includes Incoming and Outcoming Email Filtering!";
$_LANG['store']['emailServices']['benefits']['archiving']['2'] = "Never lose an email again!";
$_LANG['store']['emailServices']['benefits']['archiving']['3'] = "Achieve legal compliance";
$_LANG['store']['emailServices']['benefits']['archiving']['4'] = "Improve IT system performance";
$_LANG['store']['emailServices']['benefits']['archiving']['5'] = "User friendly data-protection management";
$_LANG['store']['emailServices']['benefits']['archiving']['6'] = "Added email continuity, journaling support, and easy re-delivery";
$_LANG['store']['emailServices']['benefits']['archiving']['7'] = "Compressed, encrypted and secure archive";
$_LANG['store']['emailServices']['benefits']['archiving']['q1'] = "Email Archiving";
$_LANG['store']['emailServices']['benefits']['archiving']['a1'] = "Email Archiving preserves and protects all inbound and outbound email messages for later access. It is a great way to recover lost or accidentally deleted emails, accelerate audit response, secure intellectual property emails and attachments, as well as for “eDiscovery” purposes in case of litigation.";
$_LANG['store']['emailServices']['benefits']['archiving']['q2'] = "Why you need it";
$_LANG['store']['emailServices']['benefits']['archiving']['a2a'] = "Are you desperately looking for an important email from last year, but can’t seem to find it and you’re risking a fine or losing an important business deal as the result of this? Prevent this with a professional Email Archiving solution. Email Archiving is a critical tool to preserve a secure backup of all email and be legally compliant.";
$_LANG['store']['emailServices']['benefits']['archiving']['a2b'] = "At the same time, as email exchanges have judicial power and are legally binding, email compliance has become an extremely important concern for organizations. Therefore it is mandatory in certain industries to preserve a secure backup of all email messages and be legally compliant.";
$_LANG['store']['emailServices']['signup']['title'] = "Sign Up and Get Started";
$_LANG['store']['emailServices']['signup']['choose'] = "Choose Product";
$_LANG['store']['emailServices']['signup']['additional'] = "Additional Options";
$_LANG['store']['emailServices']['signup']['order'] = "Order Now";
$_LANG['store']['emailServices']['signup']['none'] = "None available";
$_LANG['store']['emailServices']['options']['incomingFilter'] = "Incoming Filtering";
$_LANG['store']['emailServices']['options']['outgoingFilter'] = "Outgoing Filtering";
$_LANG['store']['emailServices']['options']['incomingArchive'] = "Incoming Archiving";
$_LANG['store']['emailServices']['options']['outgoingArchive'] = "Outgoing Archiving";
$_LANG['store']['emailServices']['options']['incomingFilterArchive'] = "Incoming Filtering and Archiving";
$_LANG['store']['emailServices']['options']['outgoingFilterArchive'] = "Outgoing Filtering and Archiving";
$_LANG['store']['emailServices']['options']['addFor'] = "Add :description for <span>just :pricing more</span>";
$_LANG['store']['emailServices']['faqs']['title'] = "Frequently Asked Questions";
$_LANG['store']['emailServices']['faqs']['q1'] = "How does it work?";
$_LANG['store']['emailServices']['faqs']['a1'] = "Email is routed through SpamExperts intelligent self-learning servers that will detect and block spam before it ever reaches you.";
$_LANG['store']['emailServices']['faqs']['q2'] = "How accurate is the filtering?";
$_LANG['store']['emailServices']['faqs']['a2'] = "Thanks to processing millions of emails every day, our email filters have an industry leading rate with close to 100% accuracy.";
$_LANG['store']['emailServices']['faqs']['q3'] = "Can I recover messages that get blocked?";
$_LANG['store']['emailServices']['faqs']['a3'] = "Yes, a comprehensive control panel with log-search, quarantine, and many other tools allows you to check the status of any email which passed through the system.";
$_LANG['store']['emailServices']['faqs']['q4'] = "How long does it take to setup?";
$_LANG['store']['emailServices']['faqs']['a4'] = "Setup is fast, automated and it will be up and running protecting your email in minutes.";
$_LANG['store']['emailServices']['faqs']['q5'] = "What is Email Archiving?";
$_LANG['store']['emailServices']['faqs']['a5'] = "Email is so important nowadays, with archiving email is securely stored, giving you extra confidence and peace of mind.";
$_LANG['store']['emailServices']['faqs']['q6'] = "How much email can I store?";
$_LANG['store']['emailServices']['faqs']['a6'] = "Email Archiving includes 10GB of compressed email storage by default. If you need more storage, additional 10GB licenses can be added.";
$_LANG['store']['emailServices']['preview'] = "Email service products you activate will display here";
$_LANG['store']['emailServices']['domain'] = "domain";
$_LANG['domainDns']['a'] = "A (Address)";
$_LANG['domainDns']['aaaa'] = "AAAA (Address)";
$_LANG['domainDns']['mxe'] = "MXE (Mail Easy)";
$_LANG['domainDns']['mx'] = "MX (Mail)";
$_LANG['domainDns']['cname'] = "CNAME (Alias)";
$_LANG['domainDns']['txt'] = "SPF (txt)";
$_LANG['domainDns']['url'] = "تغییر مسیر لینک";
$_LANG['domainDns']['frame'] = " قاب نشانی وب";

$_LANG['navContacts'] = "تماسها/حسابهای فرعی";
$_LANG['navUserManagement'] = "مدیریت کاربر";
$_LANG['navSwitchAccount'] = "تعویض حساب";
$_LANG['navAccountSecurity'] = "امنیت حساب";

$_LANG['never'] = "هرگز";

$_LANG['yourProfile'] = "مشخصات شما";
$_LANG['verifyEmailAddress'] = "لطفا ایمیل خود را چک کنید و مراحل تایید ایمیل را انجام دهید.";

$_LANG['emailVerification']['title'] = "تأیید ایمیل";
$_LANG['emailVerification']['success'] = "آدرس ایمیل شما تأیید شده است";
$_LANG['emailVerification']['expired'] = "پیوند تأیید ایمیل شما منقضی شده است";
$_LANG['emailVerification']['notFound'] = "متأسفانه ، ما نتوانستیم تأییدیه معلق مطابق با درخواست شما پیدا کنیم";
$_LANG['emailVerification']['loginToRequest'] = "لطفاً برای درخواست پیوند تأیید ایمیل جدید وارد شوید";

$_LANG['switchAccount']['title'] = "انتخاب حساب";
$_LANG['switchAccount']['choose'] = "انتخاب برای ورود و مدیریت حساب";
$_LANG['switchAccount']['noneFound'] = "هیچ حسابی یافت نشد";
$_LANG['switchAccount']['createInstructions'] = "برای ایجاد یک حساب جدید ، باید یک سفارش جدید ثبت کنید";
$_LANG['switchAccount']['noLongerActive'] = "این حساب دیگر فعال نیست";
$_LANG['switchAccount']['invalidChooseAnother'] = "حساب نامعتبر درخواست شد. لطفاً دیگری را انتخاب کنید";
$_LANG['switchAccount']['cancelAndReturn'] = "لغو و بازگشت به صفحه اصلی";
$_LANG['switchAccount']['forcedSwitchRequest'] = "نشانی اینترنتی که سعی کرده اید به آن دسترسی داشته باشید نیاز دارد که به عنوان یک سرویس گیرنده دیگر وارد سیستم شوید";

$_LANG['shopNow'] = "همین حالا بخرید";
$_LANG['clientOwner'] = "مالک";

$_LANG['userManagement']['title'] = "مدیریت کاربر";
$_LANG['userManagement']['managePermissions'] = "مدیریت مجوزها";
$_LANG['userManagement']['permissions'] = "مجوزها";
$_LANG['userManagement']['usersFound'] = ":count کاربر یافت شد";
$_LANG['userManagement']['userDescriptor'] = "آدرس ایمیل / آخرین ورود";
$_LANG['userManagement']['lastLogin'] = "آخرین ورود";
$_LANG['userManagement']['actions'] = "عملیات";
$_LANG['userManagement']['emailAddress'] = "آدرس ایمیل";
$_LANG['userManagement']['removeAccess'] = "حذف دسترسی";
$_LANG['userManagement']['pendingInvites'] = "در انتظار دعوت";
$_LANG['userManagement']['inviteSent'] = "ارسال دعوت";
$_LANG['userManagement']['resendInvite'] = "ارسال مجدد دعوت";
$_LANG['userManagement']['cancelInvite'] = "لغو دعوت";
$_LANG['userManagement']['accountOwnerPermissionsInfo'] = "صاحبان حسابها همیشه مجوزهای کاملی برای حساب مشتری دارند";
$_LANG['userManagement']['inviteNewUser'] = "دعوت کاربر جدید";
$_LANG['userManagement']['inviteEmail'] = "دعوت از ایمیل";
$_LANG['userManagement']['inviteNewUserDescription'] = "دعوت از یک کاربر جدید به شما امکان می دهد تا یک کاربر جدید را به حساب خود دعوت کنید. اگر دعوت کننده قبلاً حساب کاربری فعلی دارد ، می تواند با استفاده از اطلاعات ورود به سیستم موجود به حساب شما دسترسی پیدا کند. اگر کاربر هنوز حساب کاربری نداشته باشد ، می تواند یک حساب کاربری ایجاد کند";
$_LANG['userManagement']['allPermissions'] = "همه مجوزها";
$_LANG['userManagement']['choosePermissions'] = "انتخاب مجوز ";
$_LANG['userManagement']['noPermissionsSelected'] = "Choose at least 1 permission.";
$_LANG['userManagement']['sendInvite'] = "ارسال دعوتنامه";
$_LANG['userManagement']['removeAccessSure'] = "آیا مطمئن هستید که می خواهید این دسترسی کاربران را حذف کنید؟";
$_LANG['userManagement']['removeAccessInfo'] = "آنها دیگر نمی توانند به این حساب دسترسی داشته باشند یا مدیریت کنند";
$_LANG['userManagement']['cancelInviteSure'] = "آیا مطمئن هستید که می خواهید این دعوت را لغو کنید؟";
$_LANG['userManagement']['cancelInviteInfo'] = "این لغو به کاربر اطلاع داده نخواهد شد";
$_LANG['userManagement']['permissionsUpdateSuccess'] = "مجوزها با موفقیت به روز شد";
$_LANG['userManagement']['userRemoveSuccess'] = "کاربر با موفقیت حذف شد";
$_LANG['userManagement']['inviteSentSuccess'] = "دعوت با موفقیت ارسال شد";
$_LANG['userManagement']['alreadyLinked'] = "آدرس ایمیل وارد شده از قبل کاربر این حساب است";
$_LANG['userManagement']['alreadyInvited'] = "آدرس ایمیلی که وارد کرده اید قبلاً دعوت نامه فعال دارد";
$_LANG['userManagement']['inviteResendSuccess'] = "دعوت مجدد با موفقیت ارسال شد";
$_LANG['userManagement']['inviteCancelled'] = "دعوت با موفقیت لغو شد";
$_LANG['userManagement']['settings'] = "تنظیمات امنیتی زیر برای حساب کاربری شما اعمال می شود";

$_LANG['userProfile']['profile'] = "مشخصات";
$_LANG['userProfile']['changeEmail'] = "تغییر آدرس ایمیل";
$_LANG['userProfile']['notVerified'] = "ایمیل تأیید نشده است";
$_LANG['userProfile']['verified'] = "ایمیل تأییده شده است";

$_LANG['accountInvite']['title'] = "دعوت را بپذیرید";
$_LANG['accountInvite']['youHaveBeenInvited'] = "شما به دعوت شده اید :clientName";
$_LANG['accountInvite']['givenAccess'] = ":ot:senderName:ct has given you access to the :ot:clientName:ct account.";
$_LANG['accountInvite']['inviteAcceptLoggedIn'] = "برای پذیرش دعوت ، کافی است روی دکمه زیر کلیک کنید";
$_LANG['accountInvite']['inviteAcceptLoggedOut'] = "برای پذیرش دعوت ، لطفاً وارد شوید یا ثبت نام کنید";
$_LANG['accountInvite']['accept'] = "پذیرش دعوت";
$_LANG['accountInvite']['userAlreadyAssociated'] = "حساب کاربری شما قبلاً با حساب دعوت هدف مرتبط است";
$_LANG['accountInvite']['acceptSuccess'] = "دعوت حساب پذیرفته شد";
$_LANG['accountInvite']['emailAlreadyExists'] = "کاربر قبلاً با آن آدرس ایمیل وجود دارد. لطفاً وارد شوید یا از ایمیل دیگری استفاده کنید";
$_LANG['accountInvite']['notFound'] = "متأسفیم ، ما نتوانستیم یک دعوت معلق متناسب با درخواست شما پیدا کنیم";
$_LANG['accountInvite']['contactAdministrator'] = "لطفاً برای درخواست دعوت جدید با سرپرست حساب تماس بگیرید";

$_LANG['clientareanavcontacts'] = "تماسها/حسابهای فرعی";

$_LANG['permissions']['descriptions']['profile'] = "دسترسی و اصلاح اطلاعات نمایه مشتری";
$_LANG['permissions']['descriptions']['contacts'] = "دسترسی و مدیریت مخاطبین";
$_LANG['permissions']['descriptions']['products'] = "مشاهده دسترسی به محصولات ، خدمات و افزونه ها";
$_LANG['permissions']['descriptions']['manageproducts'] = "اجازه بازنشانی گذرواژه و سایر اقدامات ";
$_LANG['permissions']['descriptions']['productsso'] = "اجازه ورود به سیستم برای ورود به سرویس ها";
$_LANG['permissions']['descriptions']['domains'] = "مشاهده دسترسی به ثبت دامنه";
$_LANG['permissions']['descriptions']['managedomains'] = "اجازه مدیریت دامنه";
$_LANG['permissions']['descriptions']['invoices'] = "مشاهده و پرداخت دسترسی به صورتحساب ها";
$_LANG['permissions']['descriptions']['quotes'] = "مشاهده و پذیرش مجوزها برای نقل قول ها";
$_LANG['permissions']['descriptions']['tickets'] = "دسترسی به باز کردن ، پاسخگویی و مدیریت تیکت های پشتیبانی";
$_LANG['permissions']['descriptions']['affiliates'] = "دسترسی به مشاهده و درخواست برداشت";
$_LANG['permissions']['descriptions']['emails'] = "دسترسی به مشاهده سابقه ایمیل حساب";
$_LANG['permissions']['descriptions']['orders'] = "اجازه ثبت سفارشات جدید را بدهید";

$_LANG['closed'] = "بسته شد";
$_LANG['noPermission'] = "بدون مجوز";

$_LANG['domainDetails']['error']['getNs'] = "هنگام بازیابی نیم سرور  دامنه ، مشکلی پیش آمد. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['domainDetails']['error']['saveNs'] = "هنگام بروزرسانی  نیم سرورها دامنه مشکلی پیش آمد. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['domainDetails']['error']['getContact'] = "هنگام بازیابی اطلاعات تماس دامنه ، مشکلی پیش آمد. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['domainDetails']['error']['saveContact'] = "هنگام به روز رسانی اطلاعات تماس دامنه ، مشکلی پیش آمد. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['domainDetails']['error']['getDns'] = "هنگام بازیابی پرونده های دی ان اس مشکلی پیش آمد. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['domainDetails']['error']['saveDns'] = "هنگام بروزرسانی سوابق دی ان اس مشکلی پیش آمد. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['domainDetails']['error']['getEmailFwd'] = "هنگام بازیابی فورواردرها با مشکلی روبرو شد. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['domainDetails']['error']['saveEmailFwd'] = "هنگام بروزرسانی فورواردرهای ایمیل مشکلی پیش آمد. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['domainDetails']['error']['deleteNs'] = "هنگام حذف نیم سرور خصوصی ، مشکلی پیش آمد. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['domainDetails']['error']['modifyNs'] = "هنگام تغییر نیم سرور خصوصی با مشکلی روبرو شد. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['domainDetails']['error']['registerNs'] = "هنگام ثبت نیم سرور خصوصی مشکلی پیش آمد. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['domainDetails']['error']['saveRegLock'] = "هنگام بروزرسانی وضعیت قفل دامنه ، مشکلی پیش آمد. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['domainDetails']['error']['releaseDomain'] = "هنگام انتشار دامنه مشکلی پیش آمد. لطفاً با پشتیبانی تماس بگیرید";
$_LANG['domainDetails']['error']['resendNotification'] = "هنگام ارسال مجدد ایمیل اعلان ، مشکلی پیش آمد. لطفاً با پشتیبانی تماس بگیرید";

$_LANG['idnLanguage']['afr'] = "آفریقایی";
$_LANG['idnLanguage']['alb'] = "آلبانیایی";
$_LANG['idnLanguage']['ara'] = "Arabic";
$_LANG['idnLanguage']['arg'] = "Aragonese";
$_LANG['idnLanguage']['arm'] = "Armenian";
$_LANG['idnLanguage']['asm'] = "Assamese";
$_LANG['idnLanguage']['ast'] = "Asturian";
$_LANG['idnLanguage']['ave'] = "Avestan";
$_LANG['idnLanguage']['awa'] = "Awadhi";
$_LANG['idnLanguage']['aze'] = "Azerbaijani";
$_LANG['idnLanguage']['ban'] = "Balinese";
$_LANG['idnLanguage']['bal'] = "Baluchi";
$_LANG['idnLanguage']['bas'] = "Basa";
$_LANG['idnLanguage']['bak'] = "Bashkir";
$_LANG['idnLanguage']['baq'] = "Basque";
$_LANG['idnLanguage']['bel'] = "Belarusian";
$_LANG['idnLanguage']['ben'] = "Bengali";
$_LANG['idnLanguage']['bho'] = "Bhojpuri";
$_LANG['idnLanguage']['bos'] = "Bosnian";
$_LANG['idnLanguage']['bul'] = "Bulgarian";
$_LANG['idnLanguage']['bur'] = "Burmese";
$_LANG['idnLanguage']['car'] = "Carib";
$_LANG['idnLanguage']['cat'] = "Catalan";
$_LANG['idnLanguage']['che'] = "Chechen";
$_LANG['idnLanguage']['chi'] = "Chinese";
$_LANG['idnLanguage']['chv'] = "Chuvash";
$_LANG['idnLanguage']['cop'] = "Coptic";
$_LANG['idnLanguage']['cos'] = "Corsican";
$_LANG['idnLanguage']['scr'] = "Croatian";
$_LANG['idnLanguage']['cze'] = "Czech";
$_LANG['idnLanguage']['dan'] = "Danish";
$_LANG['idnLanguage']['div'] = "Divehi";
$_LANG['idnLanguage']['doi'] = "Dogri";
$_LANG['idnLanguage']['dut'] = "Dutch";
$_LANG['idnLanguage']['eng'] = "English";
$_LANG['idnLanguage']['est'] = "Estonian";
$_LANG['idnLanguage']['fao'] = "Faroese";
$_LANG['idnLanguage']['fij'] = "Fijian";
$_LANG['idnLanguage']['fin'] = "Finnish";
$_LANG['idnLanguage']['fre'] = "French";
$_LANG['idnLanguage']['fry'] = "Frisian";
$_LANG['idnLanguage']['gla'] = "Gaelic; Scottish Gaelic";
$_LANG['idnLanguage']['geo'] = "Georgian";
$_LANG['idnLanguage']['ger'] = "German";
$_LANG['idnLanguage']['gon'] = "Gondi";
$_LANG['idnLanguage']['gre'] = "Greek";
$_LANG['idnLanguage']['guj'] = "Gujarati";
$_LANG['idnLanguage']['heb'] = "Hebrew";
$_LANG['idnLanguage']['hin'] = "Hindi";
$_LANG['idnLanguage']['hun'] = "Hungarian";
$_LANG['idnLanguage']['ice'] = "Icelandic";
$_LANG['idnLanguage']['inc'] = "Indic";
$_LANG['idnLanguage']['ind'] = "Indonesian";
$_LANG['idnLanguage']['inh'] = "Ingush";
$_LANG['idnLanguage']['gle'] = "Irish";
$_LANG['idnLanguage']['ita'] = "Italian";
$_LANG['idnLanguage']['jpn'] = "Japanese";
$_LANG['idnLanguage']['jav'] = "Javanese";
$_LANG['idnLanguage']['kas'] = "Kashmiri";
$_LANG['idnLanguage']['kaz'] = "Kazakh";
$_LANG['idnLanguage']['khm'] = "Khmer";
$_LANG['idnLanguage']['kir'] = "Kirghiz";
$_LANG['idnLanguage']['kor'] = "Korean";
$_LANG['idnLanguage']['kur'] = "Kurdish";
$_LANG['idnLanguage']['lao'] = "Lao";
$_LANG['idnLanguage']['lat'] = "Latin";
$_LANG['idnLanguage']['lav'] = "Latvian";
$_LANG['idnLanguage']['lit'] = "Lithuanian";
$_LANG['idnLanguage']['ltz'] = "Luxembourgish";
$_LANG['idnLanguage']['mac'] = "Macedonian";
$_LANG['idnLanguage']['may'] = "Malay";
$_LANG['idnLanguage']['mal'] = "Malayalam";
$_LANG['idnLanguage']['mlt'] = "Maltese";
$_LANG['idnLanguage']['mao'] = "Maori";
$_LANG['idnLanguage']['mol'] = "Moldavian";
$_LANG['idnLanguage']['mon'] = "Mongolian";
$_LANG['idnLanguage']['nep'] = "Nepali";
$_LANG['idnLanguage']['nor'] = "Norwegian";
$_LANG['idnLanguage']['ori'] = "Oriya";
$_LANG['idnLanguage']['oss'] = "Ossetian";
$_LANG['idnLanguage']['per'] = "Persian";
$_LANG['idnLanguage']['pol'] = "Polish";
$_LANG['idnLanguage']['por'] = "Portuguese";
$_LANG['idnLanguage']['pan'] = "Punjabi";
$_LANG['idnLanguage']['pus'] = "Pushto";
$_LANG['idnLanguage']['raj'] = "Rajasthani";
$_LANG['idnLanguage']['rum'] = "Romanian";
$_LANG['idnLanguage']['rus'] = "Russian";
$_LANG['idnLanguage']['smo'] = "Samoan";
$_LANG['idnLanguage']['san'] = "Sanskrit";
$_LANG['idnLanguage']['srd'] = "Sardinian";
$_LANG['idnLanguage']['scc'] = "Serbian";
$_LANG['idnLanguage']['snd'] = "Sindhi";
$_LANG['idnLanguage']['sin'] = "Sinhalese";
$_LANG['idnLanguage']['slo'] = "Slovak";
$_LANG['idnLanguage']['slv'] = "Slovenian";
$_LANG['idnLanguage']['som'] = "Somali";
$_LANG['idnLanguage']['spa'] = "Spanish";
$_LANG['idnLanguage']['swa'] = "Swahili";
$_LANG['idnLanguage']['swe'] = "Swedish";
$_LANG['idnLanguage']['syr'] = "Syriac";
$_LANG['idnLanguage']['tgk'] = "Tajik";
$_LANG['idnLanguage']['tam'] = "Tamil";
$_LANG['idnLanguage']['tel'] = "Telugu";
$_LANG['idnLanguage']['tha'] = "Thai";
$_LANG['idnLanguage']['tib'] = "Tibetan";
$_LANG['idnLanguage']['tur'] = "Turkish";
$_LANG['idnLanguage']['ukr'] = "Ukrainian";
$_LANG['idnLanguage']['urd'] = "Urdu";
$_LANG['idnLanguage']['uzb'] = "Uzbek";
$_LANG['idnLanguage']['vie'] = "Vietnamese";
$_LANG['idnLanguage']['wel'] = "Welsh";
$_LANG['idnLanguage']['yid'] = "Yiddish";
$_LANG['idnLanguage']['invalidSelectionForTld'] = "Invalid IDN language selected for :tld TLD";
$_LANG['cart']['idnLanguageDescription'] = "ما متوجه شدیم دامنه ای که وارد کرده اید یک نام دامنه بین المللی است. برای ادامه ، لطفاً زبان دامنه مورد نظر خود را انتخاب کنید";
$_LANG['cart']['idnLanguage'] = "Choose IDN Language";
$_LANG['cart']['selectIdnLanguageForRegister'] = "لطفاً زبان دامنه ای را که مایل به ثبت نام هستید انتخاب کنید";

$_LANG['support']['requestor']['operator'] = "اپراتور";
$_LANG['support']['requestor']['owner'] = "مالک";
$_LANG['support']['requestor']['authorizeduser'] = "کاربر مجاز";
$_LANG['support']['requestor']['registereduser'] = "کاربر ثبت نام شده";
$_LANG['support']['requestor']['subaccount'] = "حساب فرعی";
$_LANG['support']['requestor']['guest'] = "مهمان";

$_LANG['twoFactor']['enabled'] = "احراز هویت دو عاملی فعال است";
$_LANG['twoFactor']['disabled'] = "احراز هویت دو عاملی غیرفعال شده است";

$_LANG['store']['poweredBy'] = "طراحی شده توسط: :service";

$_LANG['navMarketConnectService']['ox'] = "ایمیل حرفه ای";

$_LANG['store']['ox']['title'] = "ایمیل حرفه ای";
$_LANG['store']['ox']['manage'] = "Manage Accounts";
$_LANG['store']['ox']['appSuite'] = "OX App Suite";
$_LANG['store']['ox']['promoHeading'] = "OX App Suite is powerful Email and Productivity Apps built for any-size business (and budget).";
$_LANG['store']['ox']['viewPricing'] = "Views Plans & Pricing";
$_LANG['store']['ox']['standout']['feature1']['title'] = "Expect More from Email";
$_LANG['store']['ox']['standout']['feature2']['title'] = "Say Goodbye to Spam";
$_LANG['store']['ox']['standout']['feature3']['title'] = "Work Anywhere";
$_LANG['store']['ox']['standout']['feature1']['bullet1'] = "Professional email@your-domain.com";
$_LANG['store']['ox']['standout']['feature1']['bullet2'] = "Secure and reliable; with 99.9% Uptime";
$_LANG['store']['ox']['standout']['feature1']['bullet3'] = "Use Webmail, Mobile or Desktop Apps";
$_LANG['store']['ox']['standout']['feature1']['bullet4'] = "Huge 10GB & 50GB mailboxes";
$_LANG['store']['ox']['standout']['feature2']['detail'] = "Using AI and predictive email defense software, OX App Suite fights to keep your inbox safe from spam, viruses, malware and phishing attacks.";
$_LANG['store']['ox']['standout']['feature3']['detail'] = "OX App Suite syncs across all your devices. And Mobile and Desktop access are no problem as OX App Suite works seamlessly across all native clients.";
$_LANG['store']['ox']['featuresHeadline'] = "Features";
$_LANG['store']['ox']['feature1']['title'] = "Cloud File Storage";
$_LANG['store']['ox']['feature1']['detail'] = "Store and share your important documents safely in the cloud. And with (up to) 50 GBs, you'll have plenty of room for years to come.";
$_LANG['store']['ox']['feature2']['title'] = "Calendaring & Contacts";
$_LANG['store']['ox']['feature2']['detail'] = "Communicate like an enterprise with shared calendaring, scheduling wizard, iCal support and Global Address List!";
$_LANG['store']['ox']['feature3']['title'] = "Lots of Email Features";
$_LANG['store']['ox']['feature3']['detail'] = "Your favorite email features are all here including Forwarders, Aliases, Auto-Responders, Filters, Signatures, Notifications and more!";
$_LANG['store']['ox']['feature4']['title'] = "Add Productivity Apps!";
$_LANG['store']['ox']['feature4']['detail'] = "Create, edit and share Microsoft Office docs like Word, Excel and PowerPoint with App Suite's powerful online Apps.";
$_LANG['store']['ox']['feature5']['title'] = "Bring your Apps";
$_LANG['store']['ox']['feature5']['detail'] = "Easily add your favorite email services and/or apps into App Suite; like Gmail, Dropbox, Zoom (coming soon) and more!";
$_LANG['store']['ox']['feature6']['title'] = "Privacy Matters";
$_LANG['store']['ox']['feature6']['detail'] = "App Suite, nor ourselves, will ever read, scan or share any of your personal or email information with any 3rd parties. Ever.";
$_LANG['store']['ox']['pricingHeadline'] = "Pricing & Plans";
$_LANG['store']['ox']['faq1']['question'] = "What apps are included in OX App Suite?";
$_LANG['store']['ox']['faq1']['answer'] = "All OX App Suite plans include access to Webmail, Calendar, Tasks and Address Book. The Productivity package adds OX Drive and OX Documents (Text, Spreadsheets and Presentations).";
$_LANG['store']['ox']['faq2']['question'] = "Can I add outside email accounts to OX App Suite?";
$_LANG['store']['ox']['faq2']['answer'] = "Yes, OX App Suite supports connecting all external IMAP email accounts including popular providers such as Gmail, Yahoo and Outlook.com. Simply add your email address and password into App Suite and any email sent to those accounts will appear in your App Suite Interface.";
$_LANG['store']['ox']['faq3']['question'] = "Can I sync calendar and contacts between OX App Suite and my mobile device?";
$_LANG['store']['ox']['faq3']['answer'] = "Yes, OX App Suite fully supports CalDAV and CardDAV. And for Android users, syncing is easy via our dedicated Android Sync App.";
$_LANG['store']['ox']['faq4']['question'] = "Will OX App Suite work on my device?";
$_LANG['store']['ox']['faq4']['answer'] = "App Suite works seamlessly with most native desktop and mobile email clients.";
$_LANG['store']['ox']['faq4']['devices'] = "Mobile Devices: iPhone on iOS 11/iOS 12, Smartphone on Android 4.1 or later<br>Supported Browsers: Safari, Chrome (latest & previous version), Mozilla Firefox (latest & previous version), Microsoft Internet Explorer 11/Edge";
$_LANG['store']['ox']['faq5']['question'] = "Does OX App Suite protect against Spam and Viruses?";
$_LANG['store']['ox']['faq5']['answer'] = "Yes! OX App Suite uses proprietary technology as well as partnerships with well-established vendors in the Anti-Spam industry to keep your inbox as clean and safe as possible.";
$_LANG['store']['ox']['faq6']['question'] = "What is OX Drive (Productivity)?";
$_LANG['store']['ox']['faq6']['answer'] = "OX Drive is an online storage solution to store your documents, photos and media in the cloud. This means, you only need access to OX App Suite and OX Drive and you will have access to all your files, too. OX Drive lets you synchronize your files with all your devices using the browser or native apps.";
$_LANG['store']['ox']['faq7']['question'] = "What is OX Documents (Productivity)?";
$_LANG['store']['ox']['faq7']['answer'] = "OX Text, OX Spreadsheet and OX Presentation are the 3 applications within the broader term OX Documents. These applications can be used to create and edit text documents, spreadsheets and presentations online. Create and edit your documents from anywhere using the familiar features and functions from your Office software solution and on all your devices.";
$_LANG['store']['ox']['faq8']['question'] = "What Languages does OX App Suite support?";
$_LANG['store']['ox']['faq8']['answer'] = "OX App Suite supports the following languages: English, German, Spanish, French, Italian, Dutch, Polish, 中文 简体, 中文 繁體, 日本語 日本";
$_LANG['store']['ox']['faq9']['question'] = "Can I migrate my existing email account from another provider?";
$_LANG['store']['ox']['faq9']['answer'] = "Yes, we offer a self-service migration tool that is intuitive and easy to use. Migrate from all popular email services including Apple iCloud, Gmail, Outlook.com/Windows Live/Hotmail, Yahoo Mail, GMX, or T-Online, or manually enter your provider's information using IMAP/POP3 or other available preferred protocols.";
$_LANG['store']['ox']['pricing']['features']['sla'] = "99.9% Uptime SLA";
$_LANG['store']['ox']['pricing']['features']['antivirus'] = "Premium Anti-Virus & Anti-Spam";
$_LANG['store']['ox']['pricing']['features']['email'] = "email@your-domain.com";
$_LANG['store']['ox']['pricing']['features']['size'] = "Mailboxes Size";
$_LANG['store']['ox']['pricing']['features']['webmail'] = "Full-Featured Webmail";
$_LANG['store']['ox']['pricing']['features']['imap'] = "Mobile & Desktop Access (IMAP)";
$_LANG['store']['ox']['pricing']['features']['calendars'] = "Shared Calendars, Contacts, Tasks";
$_LANG['store']['ox']['pricing']['features']['caldav'] = "CardDAV & CalDAV";
$_LANG['store']['ox']['pricing']['features']['portal'] = "Integrated Portal Page";
$_LANG['store']['ox']['pricing']['features']['migration'] = "Self-Service Migration Tool";
$_LANG['store']['ox']['pricing']['features']['filestorage'] = "Cloud File Storage";
$_LANG['store']['ox']['pricing']['features']['collab'] = "File Sharing & Collaboration";
$_LANG['store']['ox']['pricing']['features']['officeapps'] = "Online Office Suite";
$_LANG['store']['ox']['pricing']['features']['appsword'] = "Create / Edit Word Docs";
$_LANG['store']['ox']['pricing']['features']['appsspreadsheets'] = "Create / Edit Spreadsheets";
$_LANG['store']['ox']['pricing']['features']['appsslides'] = "Create / Edit PowerPoint";
$_LANG['store']['ox']['cartTitle'] = "Professional Email";
$_LANG['store']['ox']['cartShortDescription'] = "Get professional business-grade email with fully featured communication and collaboration tools for secure and reliable working.";
$_LANG['store']['ox']['promo']['sidebar']['title'] = "Professional Email";
$_LANG['store']['ox']['promo']['sidebar']['body'] = "Reliable, affordable email for your small business";

$_LANG['store']['addon']['wptk']['title'] = "WP Toolkit";
$_LANG['store']['addon']['wptk']['pleskTitle'] = "Smart Updates for WordPress";
$_LANG['store']['addon']['wptk']['pleskTagline'] = "Super charge your WordPress experience";
$_LANG['store']['addon']['wptk']['getItNow'] = "Get It Now";
$_LANG['store']['addon']['wptk']['redefined1'] = "WordPress Management Redefined with";
$_LANG['store']['addon']['wptk']['redefined2'] = "WP Toolkit Deluxe for";
$_LANG['store']['addon']['wptk']['switchCpanel'] = "Looking for WP Toolkit for cPanel?";
$_LANG['store']['addon']['wptk']['switchPlesk'] = "Looking for WP Toolkit for Plesk?";
$_LANG['store']['addon']['wptk']['introTitle'] = "WP Toolkit Deluxe delivers powerful WordPress plugin &amp; theme management, security hardening, automation, cloning, and backup/restores all from a single user-friendly dashboard.";
$_LANG['store']['addon']['wptk']['introBody'] = "Take the guesswork, and the legwork, out of managing WordPress. In addition to everything you’d expect, from easy backup and restores to search engine index management and one-click WordPress login, you also get automatic Smart Updates, staging and cloning to easily duplicate or test existing websites, one-click security hardening, and so much more!";
$_LANG['store']['addon']['wptk']['pleskIntroTitle'] = "Smart Updates for WP Toolkit identifies and analyzes any potential updates for your WordPress installations, then either performs the update at no risk to your live website or notifies you that a potentially dangerous update is now available.";
$_LANG['store']['addon']['wptk']['pleskIntroBody'] = "Using cutting-edge intelligence and automation, Smart Updates keeps your WordPress websites up-to-date, online, and safe from any potentially damaging updates to your core files, plugins, and theme.";
$_LANG['store']['addon']['wptk']['midTitle1'] = "The Only Toolkit You'll :breaktag Ever Need...";
$_LANG['store']['addon']['wptk']['featureTitle1'] = "Create Quickly &amp; Easily";
$_LANG['store']['addon']['wptk']['featureBody1'] = "Install and configure plugins and themes to customize the look and feel of any (or all) of your WordPress websites simultaneously with just a few clicks.";
$_LANG['store']['addon']['wptk']['featureTitle2'] = "Experiment Safely";
$_LANG['store']['addon']['wptk']['featureBody2'] = "Clone any existing WordPress site to test designs, plugins, or any aspect of your site. Then sync back to your live site anytime you choose.";
$_LANG['store']['addon']['wptk']['featureTitle3'] = "Enjoy Security";
$_LANG['store']['addon']['wptk']['featureBody3'] = "A single click of a button will scan and harden your WordPress websites against your selected security risks. You can also password protect specific sites or pages.";
$_LANG['store']['addon']['wptk']['featureTitle4'] = "Automate Updates";
$_LANG['store']['addon']['wptk']['featureBody4'] = "Smart Updates automatically identifies and analyzes updates for compatibility and safety, then either installs or notifies you of any issue, ensuring your site’s safety.";
$_LANG['store']['addon']['wptk']['featureTitle5'] = "Cloning &amp; Mass Hardening";
$_LANG['store']['addon']['wptk']['featureBody5'] = "Create a duplicate of your live site to experiment with, all while protecting all of your WordPress sites with a single click.";
$_LANG['store']['addon']['wptk']['featureTitle6'] = "Maintenance Mode";
$_LANG['store']['addon']['wptk']['featureBody6'] = "Take your site down while displaying a custom message.";
$_LANG['store']['addon']['wptk']['smartUpdates']['featureTitle1'] = "How Does It Work?";
$_LANG['store']['addon']['wptk']['smartUpdates']['featureBody1'] = "Smart Updates clones and updates a copy of the live website, then compares the two versions to determine success.";
$_LANG['store']['addon']['wptk']['smartUpdates']['featureTitle2'] = "What If An Update Is Safe?";
$_LANG['store']['addon']['wptk']['smartUpdates']['featureBody2'] = "Safe updates can be automatically installed to the live website, at no risk of breaking or otherwise damaging the website.";
$_LANG['store']['addon']['wptk']['smartUpdates']['featureTitle3'] = "What If An Update Is Unsafe?";
$_LANG['store']['addon']['wptk']['smartUpdates']['featureBody3'] = "The site owner will be presented with an interface to review each issue discovered to decide if they wish to proceed.";
$_LANG['store']['addon']['wptk']['plesk']['featureTitle1'] = "WordPress Simplified";
$_LANG['store']['addon']['wptk']['plesk']['featureBody1'] = "One-click installer to initialize and configure WordPress from start to finish. One dashboard to mass-manage multiple WordPress instances.";
$_LANG['store']['addon']['wptk']['plesk']['featureTitle2'] = "Stage and Test";
$_LANG['store']['addon']['wptk']['plesk']['featureBody2'] = "Test new features and ideas in a sandbox before pushing them to production – No plugins required, no separate server needed.";
$_LANG['store']['addon']['wptk']['plesk']['featureTitle3'] = "Secure Against Attacks";
$_LANG['store']['addon']['wptk']['plesk']['featureBody3'] = "Hardens your site by default, further enhanced with WP Toolkit’s security scanner. No security expertise necessary.";
$_LANG['store']['addon']['wptk']['plesk']['featureTitle4'] = "Run and Automate";
$_LANG['store']['addon']['wptk']['plesk']['featureBody4'] = "Singularly or mass-execute updates to WordPress or its themes or plugins. Monitor and run all your WordPress sites from one dashboard.";
$_LANG['store']['addon']['wptk']['plesk']['featureTitle5'] = "Cut Out Complexity";
$_LANG['store']['addon']['wptk']['plesk']['featureBody5'] = "Stage, Clone, Sync, Update, Migrate and other complex tasks executed with one click. No more stressed-out dev teams, no more high-risk activities.";
$_LANG['store']['addon']['wptk']['plesk']['featureTitle6'] = "Simple, but not Amateur";
$_LANG['store']['addon']['wptk']['plesk']['featureBody6'] = "Get full control with WP-CLI, maintenance mode, debug management, search engine index management and more.";
$_LANG['store']['addon']['wptk']['midTitle2'] = "The Most Complete, Secure, and Versatile Toolkit for WordPress";
$_LANG['store']['addon']['wptk']['screenshotDesc'] = "WP Toolkit Deluxe provides everything you need to install, configure, update, and secure WordPress websites. Upgrade to WP Toolkit Deluxe today for as low as :price.";
$_LANG['store']['addon']['wptk']['screenshotDescFree'] = "WP Toolkit Deluxe provides everything you need to install, configure, update, and secure WordPress websites. Upgrade to WP Toolkit Deluxe today.";
$_LANG['store']['addon']['wptk']['smartUpdates']['screenshotDesc'] = "Smart Updates for WP Toolkit provides everything you need to keep your WordPress websites up-to-date and running smoothly. Upgrade to Smart Updates today for as low as :price.";
$_LANG['store']['addon']['wptk']['smartUpdates']['screenshotDescFree'] = "Smart Updates for WP Toolkit provides everything you need to keep your WordPress websites up-to-date and running smoothly. Upgrade to Smart Updates today.";
$_LANG['store']['addon']['wptk']['getStartedToday'] = "Get started with WP Toolkit Deluxe today!";
$_LANG['store']['addon']['wptk']['smartUpdates']['getStartedToday'] = "Get started with Smart Updates for WP Toolkit today!";
$_LANG['store']['addon']['wptk']['chooseDomains'] = "Choose domains to add:";
$_LANG['store']['addon']['wptk']['addAddonFor'] = "Add :addon for";
$_LANG['store']['addon']['wptk']['unavailable'] = "Not available";
$_LANG['store']['addon']['wptk']['for'] = "for";
$_LANG['store']['addon']['wptk']['totalInCart'] = "Total in cart:";
$_LANG['store']['addon']['wptk']['proceedToCheckout'] = "Proceed to Checkout";
$_LANG['store']['addon']['wptk']['loginToSeePricing'] = "Log in to see pricing to add to your existing hosting";
$_LANG['store']['addon']['wptk']['loginNow'] = "Log In Now";
$_LANG['store']['addon']['wptk']['browsePackages'] = "Browse Hosting Packages";
$_LANG['store']['addon']['wptk']['faqQ1'] = "What is WP Toolkit?";
$_LANG['store']['addon']['wptk']['faqA1'] = "WP Toolkit is a management interface for WordPress from cPanel and Plesk that allows you to install, configure, and manage WordPress websites.";
$_LANG['store']['addon']['wptk']['faqQ2'] = "How is WP Toolkit Deluxe different?";
$_LANG['store']['addon']['wptk']['faqA2'] = "WP Toolkit Deluxe is a paid upgrade with advanced features including plugin and theme management, staging, cloning, Smart Updates and more.";
$_LANG['store']['addon']['wptk']['faqQ3'] = "What is Smart Updates?";
$_LANG['store']['addon']['wptk']['faqA3'] = "Smart Updates automatically tests updates for themes, plugins, languages, and WordPress itself in a completely safe environment at no risk to your live website.";
$_LANG['store']['addon']['wptk']['faqQ4'] = "How much does WP Toolkit cost?";
$_LANG['store']['addon']['wptk']['faqA4'] = "WP Toolkit Deluxe is available as an add-on for applicable hosting packages. To see pricing, please <a href=\":webRoot/login.php\">login</a> to view pricing for your existing domains, or <a href=\":webRoot/register.php\">sign up</a> as a new customer.";
$_LANG['store']['addon']['wptk']['faqQ5'] = "How do I access WP Toolkit?";
$_LANG['store']['addon']['wptk']['faqA5'] = "If you have access, you will find a WP Toolkit icon and link in your cPanel dashboard. For those with WP Toolkit Deluxe, you will also find a login link from the hosting service view within our <a href=\":webRoot/clientarea.php\">client area</a>.";
$_LANG['store']['addon']['wptk']['faqQ6'] = "How much does Smart Updates cost?";
$_LANG['store']['addon']['wptk']['faqA6'] = "Smart Updates is available as an add-on for applicable hosting packages. To see pricing, please <a href=\":webRoot/login.php\">login</a> to view pricing for your existing domains, or <a href=\":webRoot/register.php\">sign up</a> as a new customer.";
$_LANG['store']['addon']['wptk']['faqQ7'] = "How do I access WP Toolkit?";
$_LANG['store']['addon']['wptk']['faqA7'] = "If you have access, you will find a WP Toolkit icon and link in your Plesk dashboard. Smart Updates will be accessible only after purchase.";

$_LANG['store']['addon']['notFound']['productUnavailable'] = "Product unavailable";
$_LANG['store']['addon']['notFound']['productUnavailableText'] = "This product is not currently available.<br>Please contact us if you believe this to be an error.";
$_LANG['store']['addon']['notFound']['contactSupport'] = "Contact Support";
$_LANG['store']['addon']['notFound']['ref'] = "Ref";

$_LANG['ox']['intro'] = "This is where you can create and manage mailboxes and users for your OX App Suite subscription.";
$_LANG['ox']['accountCount'] = "You have created <span class=\"number\">:number</span> of <span class=\"limit\">:limit</span> available accounts.";
$_LANG['ox']['refresh'] = "تازه کردن";
$_LANG['ox']['emailActions'] = "مدیریت ایمیل";
$_LANG['ox']['createUser'] = "ایجاد کاربر";
$_LANG['ox']['emailAccounts'] = "ایمیل حساب";
$_LANG['ox']['emailAddress'] = "آدرس ایمیل";
$_LANG['ox']['mailboxSize'] = "اندازه صندوق پستی";
$_LANG['ox']['setPassword'] = "گذاشتن رمز عبور";
$_LANG['ox']['delete'] = "جذف";
$_LANG['ox']['noAccounts'] = "بدون حساب موجود";
$_LANG['ox']['accountRequired'] = "فیلد حساب الزامی است";
$_LANG['ox']['passwordRequired'] = "فیلد گذرواژه الزامی است";
$_LANG['ox']['deleteAccount'] = "جذف جساب <span class=\"email\"></span>?";
$_LANG['ox']['manageAccount'] = "مدیریت <span class=\"email\"></span>";
$_LANG['ox']['setPasswordFor'] = "تنظیم رمز عبور برای <span class=\"email\"></span>";
$_LANG['ox']['deleteAccountQuestion'] = "آیا مطمئن هستید که می خواهید این حساب را حذف کنید؟";
$_LANG['ox']['deleteAccountWithAliasesQuestion'] = "Are you sure you want to delete this account and any aliases?";
$_LANG['ox']['settings']['retrieval'] = "Retrieval Settings";
$_LANG['ox']['settings']['retrievalIntro'] = "To configure your email account within an email application, use the information below.";
$_LANG['ox']['settings']['usageInstructions'] = "Usage Instructions";
$_LANG['ox']['settings']['username'] = "Username";
$_LANG['ox']['settings']['email'] = "Use account email address";
$_LANG['ox']['settings']['password'] = "Use the email account's password";
$_LANG['ox']['settings']['incoming'] = "Incoming Server (IMAP)";
$_LANG['ox']['settings']['pop'] = "Incoming Server (POP3)";
$_LANG['ox']['settings']['outgoing'] = "Outgoing Server";
$_LANG['ox']['settings']['port'] = "Port: :port";
$_LANG['ox']['settings']['davSettings'] = "Calendars and Contacts";
$_LANG['ox']['settings']['davSettingsIntro'] = "To access your calendars and contacts on your personal devices, you need to configure your client to connect to CalDAV for calendars and CardDAV for contacts. Use the information below to configure your client.";
$_LANG['ox']['settings']['caldavPassword'] = "Enter the same password that you use for your email login.";
$_LANG['ox']['settings']['serverUrl'] = "Server URL";
$_LANG['ox']['settings']['migrationTitle'] = "Migration Tool";
$_LANG['ox']['settings']['migrationIntro'] = "Migrate from all popular email services including Apple iCloud, Gmail, Outlook.com/Windows Live/Hotmail, Yahoo Mail, GMX, or T-Online, or manually enter your provider's information using IMAP/POP3 or other available preferred protocols.";
$_LANG['ox']['settings']['migrationLaunch'] = "Launch Migration Tool";
$_LANG['ox']['displayName'] = "Display Name";
$_LANG['ox']['required']['displayName'] = "Display Name is a required field.";
$_LANG['ox']['required']['firstName'] = "First Name is a required field.";
$_LANG['ox']['required']['lastName'] = "Last Name is a required field.";
$_LANG['ox']['required']['email'] = "Email Address is a required field.";
$_LANG['ox']['required']['password'] = "Password is a required field.";
$_LANG['ox']['required']['passwordMatchMissing'] = "Confirmation Password is a required field.";
$_LANG['ox']['required']['passwordMatch'] = "Confirmation Password must match Password.";
$_LANG['ox']['accessSuite'] = "Online Portal";
$_LANG['ox']['accountDeleted'] = "Account deleted successfully.";
$_LANG['ox']['accountCreated'] = "Account created successfully.";
$_LANG['ox']['accountModified'] = "Account modified successfully.";
$_LANG['ox']['passwordChanged'] = "Account password changed successfully.";
$_LANG['ox']['alias']['intro'] = "Email aliases act as additional email addresses from which you can send and receive mail.";
$_LANG['ox']['alias']['emailAliases'] = "Email Aliases";
$_LANG['ox']['alias']['deleteTitle'] = "Delete alias <span class=\"alias\"></span>@:domain?";
$_LANG['ox']['alias']['deleteQuestion'] = "Are you sure you want to delete this alias?";
$_LANG['ox']['alias']['deleteSuccess'] = "Alias deleted successfully.";
$_LANG['ox']['alias']['createButton'] = "Create";
$_LANG['ox']['alias']['createSuccess'] = "Alias created successfully.";

$_LANG['orderForm']['upgradeQuantityCannotBeLowerThanMinimum'] = "مقدار خدمات را نمی توان کمتر از حداقل تغییر داد (:minimum).";
$_LANG['orderForm']['upgradeQuantityMustChange'] = "شما باید برنامه ارتقاء را انتخاب کنید یا مقدار را تغییر دهید";
$_LANG['orderForm']['downgradeNotPossible'] = "امکان کاهش رتبه این محصول وجود ندارد. لطفاً در عوض سفارش جدیدی برای این سرویس ثبت کنید";
$_LANG['unavailable'] = "غیر قابل دسترسی";
$_LANG['orderForm']['idnNotEnabled'] = "ما در حال حاضر از نام دامنه های بین المللی پشتیبانی نمی کنیم. لطفاً نام دامنه دیگری را امتحان کنید";

$_LANG['store']['ssl']['landingPage']['secureInMinutes'] = "Secure your site in minutes with our fully automated provisioning and deployment";
$_LANG['store']['fromJust'] = "from just";
$_LANG['store']['forJust'] = "for just";

$_LANG['goCardless']['paymentPending'] = "A payment has been submitted that will clear your bank on :date. <br>A payment confirmation email will be sent when the payment clears.";
$_LANG['goCardless']['automaticPayment'] = "برای این حساب راه اندازی پرداخت خودکار وجود دارد. نیازی به پرداخت دستی نیست";

$_LANG['contactDetails'] = "اطلاعات تماس";
$_LANG['createNewSupportRequest'] = "ایجاد درخواست پشتیبانی جدید";

$_LANG['nonotifications'] = "بدون اعلان";
$_LANG['apply'] = "Apply";
$_LANG['admin']['returnToAdmin'] = "بازگشت به پنل مدیریت";
$_LANG['searchOurKnowledgebase'] = "جستجو پایگاه دانش";
$_LANG['browseProducts'] = "مرور محصولات";
$_LANG['secureYourDomain'] = "با ثبت نام امروز دامنه خود را ایمن کنید";
$_LANG['secureYourDomainShort'] = "نام دامنه خود را ایمن کنید";
$_LANG['transferYourDomain'] = "دامنه خود را انتقال دهید";
$_LANG['transferExtend'] = "اکنون انتقال دهید تا دامنه خود را 1 سال تمدید کنید";
$_LANG['howCanWeHelp'] = "چگونه می توانیم امروز کمک کنیم";
$_LANG['homepage']['submitTicket'] = "ارسال تیکت";
$_LANG['homepage']['manageServices'] = "مدیریت سرویس";
$_LANG['homepage']['manageDomains'] = "مدیریت دامنه ها";
$_LANG['homepage']['supportRequests'] = "درخواست های پشتیبانی";
$_LANG['homepage']['makeAPayment'] = "ایجاد یک پرداخت";
$_LANG['homepage']['yourAccount'] = "حساب شما";

$_LANG['downloads']['numDownload'] = ":num File";
$_LANG['downloads']['numDownloads'] = ":num Files";
$_LANG['knowledgebase']['numArticle'] = ":num Article";
$_LANG['knowledgebase']['numArticles'] = ":num Articles";

$_LANG['userLogin']['createAccount'] = "ایجاد حساب";
$_LANG['userLogin']['signInToContinue'] = "برای ادامه به حساب خود وارد شوید";
$_LANG['userLogin']['notRegistered'] = "ثبت نشده است؟";

$_LANG['networkIssues']['scheduled'] = "موارد زیر وجود دارد :count مسائل مربوط به تأثیرگذاری شبکه برنامه ریزی شده";
$_LANG['networkIssues']['http'] = "HTTP";
$_LANG['networkIssues']['ftp'] = "FTP";
$_LANG['networkIssues']['pop3'] = "POP3";
$_LANG['networkIssues']['affectingYou'] = "این مشکل بر سروری تأثیر می گذارد که ممکن است خدمات شما را تحت تأثیر قرار دهد";

$_LANG['chooseFile'] = "انتخاب فایل";
$_LANG['support']['postedBy'] = "طراحی شده توسط :name on :date :requestorType";

$_LANG['requestor'] = "درخواست کننده";

$_LANG['facebook']['notAuthorized'] = "You did not authorize the use of Facebook for authentication. We can't use it to log you in.";

$_LANG['navMarketConnectService']['siteBuilder'] = "Site Builder";
$_LANG['marketConnect']['siteBuilder']['ftpHost'] = "FTP Host";
$_LANG['marketConnect']['siteBuilder']['ftpUsername'] = "FTP نام کاربری";
$_LANG['marketConnect']['siteBuilder']['ftpPassword'] = "FTP رمز عبور";
$_LANG['marketConnect']['siteBuilder']['ftpPath'] = "FTP Path";
$_LANG['marketConnect']['siteBuilder']['updateFtp'] = "Update FTP Credentials";
$_LANG['marketConnect']['siteBuilder']['manage'] = "Log in to Site Builder";
$_LANG['store']['siteBuilder']['upgrade']['title'] = "Site Builder Upgrade";
$_LANG['store']['siteBuilder']['upgrade']['required'] = "Upgrade Required";
$_LANG['store']['siteBuilder']['upgrade']['requiredDescription'] = "To access the functionality you requested, you need to upgrade your Site Builder plan.";
$_LANG['store']['siteBuilder']['upgrade']['recommended'] = "The recommended plan is displayed.";
$_LANG['store']['siteBuilder']['upgrade']['login'] = "To view the available options, please log in.";
$_LANG['store']['siteBuilder']['upgrade']['no'] = "No upgrade available";
$_LANG['store']['siteBuilder']['upgrade']['noUpgrade'] = "There is no upgrade available at this time.";
$_LANG['store']['siteBuilder']['upgrade']['submitTicket'] = "Contact Support";
$_LANG['store']['siteBuilder']['upgrade']['to'] = "Upgrade to :product for :amount";
$_LANG['store']['siteBuilder']['upgrade']['noPlans'] = "No active Site Builder plans found.";
$_LANG['store']['siteBuilder']['upgrade']['loggedInAs'] = "You are currently logged in as :email";
$_LANG['store']['siteBuilder']['upgrade']['switchUser'] = "Log Out/Switch User";

$_LANG['domainRenewal']['freeWithService'] = "Free Renewal with Service";
$_LANG['domainRenewal']['freeWithServiceDesc'] = "Renewal is provided automatically at no additional cost while the associated service is active.";

$_LANG['store']['siteBuilder']['title'] = "Site Builder";
$_LANG['store']['siteBuilder']['introHeadline'] = "Your online journey <br class=\"hidden-xs\">starts here.";
$_LANG['store']['siteBuilder']['intro1'] = "Creating a web presence requires the right platform. Get noticed using our drag and drop DIY Site Builder.";
$_LANG['store']['siteBuilder']['intro2'] = "Whether you want to promote yourself or your business, our site builder is a template and wizard-based with guided content that is simple enough for beginners and feature rich for professionals. Feels like PowerPoint but with more muscle, elegance, and simplicity. A solution that you will enjoy using.";
$_LANG['store']['siteBuilder']['featuresTitle'] = "Site Builder Features";
$_LANG['store']['siteBuilder']['featuresEssentials'] = "The Essentials";
$_LANG['store']['siteBuilder']['featuresSocial'] = "Social Media and Blog";
$_LANG['store']['siteBuilder']['featuresStore'] = "Online Store";
$_LANG['store']['siteBuilder']['features']['essentials']['tagline'] = "Our Site Builder includes the full set of features.";
$_LANG['store']['siteBuilder']['features']['blog']['tagline'] = "Sharing your story makes all the difference. Connect with your visitors through social media and your blog.";
$_LANG['store']['siteBuilder']['features']['store']['tagline'] = "Online sales can fuel your business. Build your website as a shop, boutique, or a store.";
$_LANG['store']['siteBuilder']['features']['essentials']['1'] = "Drag & Drop Editor";
$_LANG['store']['siteBuilder']['features']['essentials']['2'] = "Building Features";
$_LANG['store']['siteBuilder']['features']['essentials']['3'] = "Pre-designed Building Blocks";
$_LANG['store']['siteBuilder']['features']['essentials']['4'] = "Built-in Mobile-Friendly";
$_LANG['store']['siteBuilder']['features']['essentials']['5'] = "Stock Photos Integration";
$_LANG['store']['siteBuilder']['features']['essentials']['6'] = "Auto Save & Backup";
$_LANG['store']['siteBuilder']['featuresdescriptions']['essentials']['1'] = "ویرایشگر کشیدن و رها کردن به مشتریان امکان می دهد ویژگی های وب سایت را مستقیماً در صفحه با برجسته سازی پیش بینی کننده مناطق برای قرار دادن اضافه و ترتیب دهند";
$_LANG['store']['siteBuilder']['featuresdescriptions']['essentials']['2'] = "می توانید از عناصر چیدمان آماده مانند متن ، دکمه ها ، عکس ها یا نمادها برای ایجاد هر گونه طرح وب سایت سفارشی با ظاهر حرفه ای استفاده کنید";
$_LANG['store']['siteBuilder']['featuresdescriptions']['essentials']['3'] = "You don’t have to waste time manipulating content layouts. A collection of 350+ content blocks helps them build professional websites without any technical skills.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['essentials']['4'] = "Websites will look great on any device. Templates are 100% responsive to all devices, including smartphones, tablets and desktops.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['essentials']['5'] = "Empower your website with a selection of over 200,000 professional premium photos in high-resolution. Our Site Builder also includes Embedded Videos and Image Optimization.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['essentials']['6'] = "You can be sure not to lose any work with real-time saving. The editor automatically saves everything while you work.";
$_LANG['store']['siteBuilder']['features']['blog']['1'] = "Blog Page";
$_LANG['store']['siteBuilder']['features']['blog']['2'] = "Draft Post";
$_LANG['store']['siteBuilder']['features']['blog']['3'] = "Post Editor";
$_LANG['store']['siteBuilder']['features']['blog']['4'] = "Social Sharing";
$_LANG['store']['siteBuilder']['features']['blog']['5'] = "Facebook Comments and Likes";
$_LANG['store']['siteBuilder']['features']['blog']['6'] = "Instagram and Twitter Connect";
$_LANG['store']['siteBuilder']['featuresdescriptions']['blog']['1'] = "Share your story and connect with your visitors by adding a customizable blog to your website. Configure post appearance on your published website.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['blog']['2'] = "Create your blog post now to save and publish later to coincide with specific news or a special promotion.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['blog']['3'] = "Make changes to a blog post after it has already been published using the built-in post content authoring tool and editor.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['blog']['4'] = "Encourage your visitors to like and share your content by adding icons for social media platforms such as Facebook, Twitter, LinkedIn and Pinterest to your site.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['blog']['5'] = "Give visitors the option to comment and like your linked Facebook page without leaving your website.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['blog']['6'] = "Automatically showcase your Instagram photos on your website every time you post and keep your site visitors updated by displaying a live feed of your Twitter account.";
$_LANG['store']['siteBuilder']['features']['store']['1'] = "Flexible Plans";
$_LANG['store']['siteBuilder']['features']['store']['2'] = "Secure and Worldwide Payments";
$_LANG['store']['siteBuilder']['features']['store']['3'] = "Easy and Quick Checkout";
$_LANG['store']['siteBuilder']['features']['store']['5'] = "Product Listing and Management";
$_LANG['store']['siteBuilder']['features']['store']['6'] = "Promotions, Discounts and Coupons";
$_LANG['store']['siteBuilder']['features']['store']['7'] = "Stock Management";
$_LANG['store']['siteBuilder']['features']['store']['8'] = "Worldwide Shipping";
$_LANG['store']['siteBuilder']['features']['store']['9'] = "Tax and VAT";
$_LANG['store']['siteBuilder']['features']['store']['10'] = "Order Management and Tracking";
$_LANG['store']['siteBuilder']['featuresdescriptions']['store']['1'] = "Whether you’re a boutique, shop, or full store, plans available for 10, 50, and 500 products.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['store']['2'] = "Connect with Paypal, Square, Stripe and over 50 trusted credit card payment providers to instantly accept credit cards.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['store']['3'] = "Give customers a faster and easier checkout with optional registration during check out. Provide a secure one-page checkout that includes customer order comments.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['store']['5'] = "Choose from multiple product page layouts and customize the descriptions and designs as you wish. Make it easier for customers to find products by organizing them into categories.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['store']['6'] = "Create discount coupons or promotional codes to increase sales. Increase your conversions by showing regular prices alongside discounted prices.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['store']['7'] = "Inventory tracking helps to know if it’s time to replenish a product stock and what product variations are the most popular.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['store']['8'] = "You can give your customers real-time carrier rates at checkout by connecting your online store with a carrier company such as USPS, FedEx, UPS, Australia Post, Canada Post, etc.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['store']['9'] = "Apply tax calculations for any country or define specific zones. Fully control the calculation of taxes; set up taxes per location, add tax per group of products, or setup tax-free products.";
$_LANG['store']['siteBuilder']['featuresdescriptions']['store']['10'] = "Instantly receive order notifications via email. Manage and view an overview of all orders, search for orders, filter them by categories and update orders, customer information and add tacking number for shipping.";
$_LANG['store']['siteBuilder']['viewPricing'] = "View pricing and packages";
$_LANG['store']['siteBuilder']['templatesTitle'] = "Business Accelerating Templates";
$_LANG['store']['siteBuilder']['templatesOutro'] = "Get Site Builder to view all 150+ templates that give you a quick and easy way to get started.";
$_LANG['store']['siteBuilder']['tryFree'] = "Try Site Builder for FREE";
$_LANG['store']['siteBuilder']['tryFreeIntro'] = "With the Open Trial, you can try Site Builder and fully build your new website for FREE with no upfront costs.";
$_LANG['store']['siteBuilder']['tryFreeIntro2'] = "Pay nothing until you're ready to publish!";
$_LANG['store']['siteBuilder']['tryFreeCta'] = "Try Site Builder today for FREE";
$_LANG['store']['siteBuilder']['pricingTitle'] = "Pricing";
$_LANG['store']['siteBuilder']['featuresLabelTitle'] = "Features";
$_LANG['store']['siteBuilder']['featuresLabels']['0'] = "Professional Quality Website Templates";
$_LANG['store']['siteBuilder']['featuresLabels']['1'] = "User-First Design for All Skill Levels";
$_LANG['store']['siteBuilder']['featuresLabels']['2'] = "Easy Drag & Drop Editing";
$_LANG['store']['siteBuilder']['featuresLabels']['3'] = "Responsive to Mobile Devices";
$_LANG['store']['siteBuilder']['featuresLabels']['4'] = "Free Image Gallery";
$_LANG['store']['siteBuilder']['featuresLabels']['5'] = "Component Based Building Blocks";
$_LANG['store']['siteBuilder']['featuresLabels']['6'] = "Blog";
$_LANG['store']['siteBuilder']['featuresLabels']['7'] = "Auto Layouts for Proportional Spacing";
$_LANG['store']['siteBuilder']['featuresLabels']['8'] = "Contact Form Builder";
$_LANG['store']['siteBuilder']['featuresLabels']['9'] = "Restore Websites";
$_LANG['store']['siteBuilder']['featuresLabels']['10'] = "Theme Inheritance";
$_LANG['store']['siteBuilder']['featuresLabels']['11'] = "Social Media Integration";
$_LANG['store']['siteBuilder']['featuresLabels']['12'] = "SEO Friendly";
$_LANG['store']['siteBuilder']['featuresLabels']['13'] = "Built-In Analytics";
$_LANG['store']['siteBuilder']['featuresLabels']['14'] = "Pages";
$_LANG['store']['siteBuilder']['featuresLabels']['15'] = "E-Commerce Products";
$_LANG['store']['siteBuilder']['compareTitle'] = "How does our Site Builder compare<br class=\"hidden-xs\">with competitors?";
$_LANG['store']['siteBuilder']['compare1'] = "User-First Design for all Skill Levels";
$_LANG['store']['siteBuilder']['compare1desc'] = "Designed for simplicity and ease-of-use mean higher CSS (Customer Satisfaction Scores) and a better user experience.";
$_LANG['store']['siteBuilder']['compare2'] = "Responsive to Mobile Devices";
$_LANG['store']['siteBuilder']['compare2desc'] = "Saves a lot of time and effort when creating a website for different mobile devices.";
$_LANG['store']['siteBuilder']['compare3'] = "Component-Based Building Blocks";
$_LANG['store']['siteBuilder']['compare3desc'] = "The Pre-designed Building Blocks will help you build professional websites without wasting time manipulating content layouts.";
$_LANG['store']['siteBuilder']['compare4'] = "No Coding required";
$_LANG['store']['siteBuilder']['compare4desc'] = "SiteBuilder is not targeting professional coders. Our aim is to provide SMEs with a platform that anybody can use to create elegant websites that work on any device, in minutes.";
$_LANG['store']['siteBuilder']['compare5'] = "Pay less for more";
$_LANG['store']['siteBuilder']['compare5desc'] = "Half the price of other website builder tools but receive all the benefits and better features.";

$_LANG['store']['siteBuilder']['templates']['singlePage'] = "Single Page Templates";
$_LANG['store']['siteBuilder']['templates']['multiPage'] = "Multi-Page Templates";
$_LANG['store']['siteBuilder']['templates']['eCommerce'] = "e-Commerce Templates";
$_LANG['store']['siteBuilder']['templates']['typeLabels']['single'] = "Single Page";
$_LANG['store']['siteBuilder']['templates']['typeLabels']['multi'] = "Multi-Page";
$_LANG['store']['siteBuilder']['templates']['typeLabels']['ecom'] = "e-Commerce";
$_LANG['store']['siteBuilder']['templates']['barber-shop'] = "Barber Shop";
$_LANG['store']['siteBuilder']['templates']['bike-event'] = "Bike Event";
$_LANG['store']['siteBuilder']['templates']['childcare'] = "Childcare";
$_LANG['store']['siteBuilder']['templates']['conference'] = "Conference";
$_LANG['store']['siteBuilder']['templates']['creative-portfolio'] = "Creative Portfolio";
$_LANG['store']['siteBuilder']['templates']['dj'] = "DJ";
$_LANG['store']['siteBuilder']['templates']['gardener'] = "Gardener";
$_LANG['store']['siteBuilder']['templates']['makeup-artist'] = "Makeup Artist";
$_LANG['store']['siteBuilder']['templates']['painters'] = "Painters";
$_LANG['store']['siteBuilder']['templates']['landscape-photographer'] = "Landscape Photographer";
$_LANG['store']['siteBuilder']['templates']['rock-band'] = "Rock Band";
$_LANG['store']['siteBuilder']['templates']['seafood-restaurant'] = "Seafood Restaurant";
$_LANG['store']['siteBuilder']['templates']['sushi-restaurant'] = "Sushi Restaurant";
$_LANG['store']['siteBuilder']['templates']['tailor-shop'] = "Tailor Shop";
$_LANG['store']['siteBuilder']['templates']['training-courses'] = "Training Courses";
$_LANG['store']['siteBuilder']['templates']['travel-tours'] = "Travel Tours";
$_LANG['store']['siteBuilder']['templates']['wedding-planner'] = "Wedding Planner";
$_LANG['store']['siteBuilder']['templates']['writer'] = "Writer";
$_LANG['store']['siteBuilder']['templates']['architect'] = "Architect";
$_LANG['store']['siteBuilder']['templates']['beauty-salon'] = "Beauty Salon";
$_LANG['store']['siteBuilder']['templates']['biography'] = "Biography";
$_LANG['store']['siteBuilder']['templates']['blog-page'] = "Blog Page";
$_LANG['store']['siteBuilder']['templates']['burger-cafe'] = "Burger Cafe";
$_LANG['store']['siteBuilder']['templates']['car-dealer'] = "Car Dealer";
$_LANG['store']['siteBuilder']['templates']['catering-services'] = "Catering Services";
$_LANG['store']['siteBuilder']['templates']['city-hotel'] = "City Hotel";
$_LANG['store']['siteBuilder']['templates']['cleaning-services'] = "Cleaning Services";
$_LANG['store']['siteBuilder']['templates']['coffee-house'] = "Coffee House";
$_LANG['store']['siteBuilder']['templates']['crossfit'] = "Crossfit";
$_LANG['store']['siteBuilder']['templates']['dentist-v2'] = "Dentist";
$_LANG['store']['siteBuilder']['templates']['event-venue'] = "Event Venue";
$_LANG['store']['siteBuilder']['templates']['handyman'] = "Handyman";
$_LANG['store']['siteBuilder']['templates']['life-coach'] = "Life Coach";
$_LANG['store']['siteBuilder']['templates']['local-cafe'] = "Local Cafe";
$_LANG['store']['siteBuilder']['templates']['locksmith'] = "Locksmith";
$_LANG['store']['siteBuilder']['templates']['mobile-app'] = "Mobile App";
$_LANG['store']['siteBuilder']['templates']['mortgage-brokers'] = "Mortgage Brokers";
$_LANG['store']['siteBuilder']['templates']['photographer'] = "Photographer";
$_LANG['store']['siteBuilder']['templates']['real-estate'] = "Real Estate";
$_LANG['store']['siteBuilder']['templates']['spa'] = "Spa";
$_LANG['store']['siteBuilder']['templates']['villa-rental'] = "Villa Rental";
$_LANG['store']['siteBuilder']['templates']['wedding-event'] = "Wedding Event";
$_LANG['store']['siteBuilder']['templates']['animal-groomers'] = "Animal Groomers";
$_LANG['store']['siteBuilder']['templates']['bakery'] = "Bakery";
$_LANG['store']['siteBuilder']['templates']['beauty-store'] = "Beauty Store";
$_LANG['store']['siteBuilder']['templates']['blinds'] = "Blinds";
$_LANG['store']['siteBuilder']['templates']['bookstore'] = "Bookstore";
$_LANG['store']['siteBuilder']['templates']['furniture-collection'] = "Furniture Collection";
$_LANG['store']['siteBuilder']['templates']['grape-farm'] = "Grape Farm";
$_LANG['store']['siteBuilder']['templates']['grocery-store'] = "Grocery Store";
$_LANG['store']['siteBuilder']['templates']['home-decor'] = "Home Decor";
$_LANG['store']['siteBuilder']['templates']['toy-store'] = "Toy Store";
$_LANG['store']['siteBuilder']['templates']['tyre-repairs'] = "Tyre Repairs";

$_LANG['marketConnect']['siteBuilder']['buildWebsite'] = "وب سایت خود را بسازید";
$_LANG['store']['siteBuilder']['cartTitle'] = "Responsive site builder";
$_LANG['store']['siteBuilder']['cartShortDescription'] = "Add our site builder to your order to create an awesome looking website, store or blog.";

$_LANG['clickHere'] = "اینجا کلیک کنید";
$_LANG['buy'] = "خرید";
$_LANG['viewMore'] = "مشاهده بیشتر.";

$_LANG['store']['siteBuilder']['promo']['sidebar']['title'] = "Add Site Builder";
$_LANG['store']['siteBuilder']['promo']['sidebar']['body'] = "Create your website fast with Site Builder";

$_LANG['cPanel']['wptk'] = "WP Toolkit";

$_LANG['wptk']['goToWebsite'] = "به وب سایت بروید";
$_LANG['wptk']['goToAdmin'] = "ادمین";
$_LANG['wptk']['createNew'] = "ایجاد جدید";
$_LANG['wptk']['installationSuccess'] = "<strong>Success!</strong> <a href=\"\" target=\"_blank\" id=\"newWordPressLink\">Visit</a> your new WordPress® install, or go to the <a href=\"\" target=\"_blank\" id=\"newWordPressAdminLink\">Admin Area</a>.";
$_LANG['wptk']['installWordPress'] = "Install WordPress®";
$_LANG['wptk']['installWordPressShort'] = "Install";

$_LANG['api']['client']['countryError'] = "Valid country required";

$_LANG['plesk']['mail'] = "Mail";
$_LANG['plesk']['applications'] = "Applications";
$_LANG['plesk']['statistics'] = "Statistics";
$_LANG['plesk']['users'] = "Users";
$_LANG['plesk']['manageDomains'] = "Manage Domains";

$_LANG['contactCreated'] = "!مخاطب با موفقیت ایجاد شد";
$_LANG['contactUpdated'] = "!مخاطب با موفقیت به روز شد";
$_LANG['contactDeleted'] = "!مخاطب با موفقیت حذف شد";
$_LANG['recommended'] = "Recommended";

$_LANG['ssl']['siteSeal'] = "Site Seal";
$_LANG['ssl']['getSiteSeal'] = "Get Site Seal Code";
$_LANG['ssl']['copyTheSiteSeal'] = "Copy your site seal code from the text below:";
$_LANG['ssl']['howToUseSiteSeal'] = "How to Use the Site Seal Code";
$_LANG['ssl']['siteSealError1'] = "You can only retrieve the seal HTML code after the certificate authority issues the certificate.";
$_LANG['ssl']['sealSuccess'] = "Your site seal code has been successfully retrieved.";
$_LANG['ssl']['rapidSslInstructions'] = "Copy the HTML image tag to your HTML document in the location in which you want the RapidSSL seal to display.";
$_LANG['ssl']['siteSealInstructions1'] = "Copy the DigiCert Seal HTML section and paste it into your HTML document in the location in which you want your site seal to display.";
$_LANG['ssl']['siteSealInstructions2'] = "Copy the DigiCert Seal Code section and paste it into the HEAD section of your HTML document.";
$_LANG['ssl']['certError1'] = "You can only retrieve the certificate after the certificate authority issues it.";
$_LANG['ssl']['certError2'] = "If you submitted the configuration information recently, allow time for the certificate authority to complete security checks and issue the certificate. For DV orders, this is typically under 24 hours. OV and EV certificates may require up to 3–5 days.";
$_LANG['ssl']['certError3'] = "If you continue to see this message, <a href=\"submitticket.php\">contact support</a>.";
$_LANG['ssl']['retrieved'] = "The system successfully retrieved your certificate.";
$_LANG['ssl']['copyCert'] = "Copy your certificate from the text below:";
$_LANG['ssl']['installing'] = "Installing Your Certificate";
$_LANG['ssl']['howToInstall'] = "To install your certificate, upload the certificate above to your server or control panel. The method to do this depends on your hosting environment.";
$_LANG['ssl']['installFurtherInfo'] = "For more information, see the :anchorRapidSSL Installation Support:endAnchor page.";

$_LANG['recommendations']['title']['generic'] = "Recommendations";
$_LANG['recommendations']['title']['addedTo'] = "Added to Cart";
$_LANG['recommendations']['title']['yourOrder'] = "Based on Your Order";
$_LANG['recommendations']['title']['yourProducts'] = "Based on Your Products";
$_LANG['recommendations']['explain']['generic'] = "Based on your order, we recommend:";
$_LANG['recommendations']['explain']['product'] = "Based on this product, we recommend:";
$_LANG['recommendations']['explain']['ordered'] = "Because you ordered <strong>:productName</strong>, we recommend:";
$_LANG['recommendations']['learnMore'] = "Click to learn more.";
$_LANG['recommendations']['productAdded'] = "Product Added";
$_LANG['recommendations']['taglinePlaceholder'] = "A description (tagline) is not available for this product.";

$_LANG['copyToClipboard'] = "Copy to Clipboard";

$_LANG['usagebilling']['metric']['diskSpace'] = "Disk Space";
$_LANG['usagebilling']['metric']['bandwidth'] = "Bandwidth";
$_LANG['usagebilling']['metric']['emailAccounts'] = "Email Accounts";
$_LANG['usagebilling']['metric']['addonDomains'] = "Addon Domains";
$_LANG['usagebilling']['metric']['parkedDomains'] = "Parked Domains";
$_LANG['usagebilling']['metric']['subDomains'] = "Sub Domains";
$_LANG['usagebilling']['metric']['mysqlDatabases'] = "MySQL Databases";
$_LANG['usagebilling']['metric']['mysqlDiskUsage'] = "MySQL Disk Usage";
$_LANG['usagebilling']['metric']['subAccounts'] = "Sub-Accounts";
$_LANG['usagebilling']['metric']['wpInstances'] = "WordPress Instances";

$_LANG['idna']['emptyLabel'] = "The domain name input is empty.";
$_LANG['idna']['labelTooLong'] = "The domain label has exceeded the maximum length.";
$_LANG['idna']['domainTooLong'] = "The domain has exceeded the maximum length.";
$_LANG['idna']['invalidDomain'] = "The domain is invalid.";
$_LANG['idna']['unknownError'] = "An unknown error occurred.";

$_LANG['domains']['europeanDomainTerms'] = "Important Information Regarding Your Contact Data: We are contractually obligated to share your personal information with the registry for this TLD. We will transfer your personal information to the registry, which may publish it to WHOIS publicly. For details on why we share your personal information, review our privacy policy and the domain registration agreement.";


$_LANG['store']['ssl']['shared']['oneYearPrice'] = "1 Year";
$_LANG['store']['ssl']['shared']['twoYearPrice'] = "2 Years";
$_LANG['store']['ssl']['shared']['threeYearPrice'] = "3 Years";

$_LANG['store']['ssl']['landingPage']['multiYear']['title'] = "Multi-Year SSL Certificates";
$_LANG['store']['ssl']['landingPage']['multiYear']['p1'] = "Multi-year certificates allow you to pay a single discounted price for two or three years of SSL certificate coverage. When you purchase a multi-year SSL certificate, you lock in a single price for up to 3 years of coverage.";
$_LANG['store']['ssl']['landingPage']['multiYear']['p2'] = "Initially, you will receive a certificate that is valid for the Certificate Authority Browser Forum's maximum allowed term (1 year and 1 month) with the right to unlimited certificate reissues during the order period.";
$_LANG['store']['ssl']['landingPage']['multiYear']['p3'] = "Automated reissuance will occur automatically throughout the term to ensure continued protection for your website.";
$_LANG['store']['ssl']['landingPage']['multiYear']['p4'] = "For example, a 2-year SSL certificate order works as follows:";
$_LANG['store']['ssl']['landingPage']['multiYear']['p5'] = "SSL certificates must be revalidated periodically. The maximum certificate lifetime is 13 months, requiring revalidation annually.";
$_LANG['store']['ssl']['landingPage']['multiYear']['benefits']['title'] = "Benefits";
$_LANG['store']['ssl']['landingPage']['multiYear']['benefits']['b1'] = "Enjoy increasing discounts for each year of coverage that you purchase.";
$_LANG['store']['ssl']['landingPage']['multiYear']['benefits']['b2'] = "Remove the hassle of annual billing.";
$_LANG['store']['ssl']['landingPage']['multiYear']['benefits']['b3'] = "Annual validation. Yearly validation of identity in shorter validity certificates prevents potential fraud and spoofing.";
$_LANG['navMarketConnectService']['xovinow'] = "XOVI NOW";
$_LANG['marketConnect']['xoviNow']['manage'] = "Log in to XOVI NOW";
$_LANG['store']['xoviNow']['title'] = "XOVI NOW";
$_LANG['store']['xoviNow']['tagline'] = "Be Found Online With :lineBreak XOVI NOW";
$_LANG['store']['xoviNow']['getStarted'] = "Get Started";
$_LANG['store']['xoviNow']['productTourTitle'] = "Product Tour";
$_LANG['store']['xoviNow']['measureResultsTitle'] = "Measurable Results at Your Fingertips";
$_LANG['store']['xoviNow']['measureResults1'] = "Let's say you want to grow your business in the next year. You could start by investing some money in an SEO agency, but that seems like an overwhelming task for someone who doesn't have technical skills!";
$_LANG['store']['xoviNow']['measureResults2'] = ":startBold Luckily, there is an easier way :endBold: let us ensure that people are finding out what makes YOUR company great from their searches online using XOVI NOW.";
$_LANG['store']['xoviNow']['features']['keywords']['title'] = "Keywords";
$_LANG['store']['xoviNow']['features']['advisor']['title'] = "Advisor";
$_LANG['store']['xoviNow']['features']['rankTracker']['title'] = "Rank Tracker";
$_LANG['store']['xoviNow']['features']['siteAudit']['title'] = "Site Audit";
$_LANG['store']['xoviNow']['features']['textOptimizer']['title'] = "Text Optimizer";
$_LANG['store']['xoviNow']['features']['benchmarking']['title'] = "Benchmarking";
$_LANG['store']['xoviNow']['features']['keywords']['line1'] = "A 100M+ keyword database for research and inspiration";
$_LANG['store']['xoviNow']['features']['keywords']['bullet1'] = "Get comprehensive keyword data";
$_LANG['store']['xoviNow']['features']['keywords']['bullet2'] = "Find out which keywords your website's ranking for";
$_LANG['store']['xoviNow']['features']['keywords']['bullet3'] = "Identify promising keywords for better traffic";
$_LANG['store']['xoviNow']['features']['keywords']['bullet4'] = "Analyze your competition's keywords and rankings";
$_LANG['store']['xoviNow']['features']['keywords']['bullet5'] = "Compare international markets";
$_LANG['store']['xoviNow']['features']['keywords']['bullet6'] = "Profit from a 100M+ keyword database";
$_LANG['store']['xoviNow']['features']['advisor']['line1'] = "Receive, manage, and solve tasks to improve your website";
$_LANG['store']['xoviNow']['features']['advisor']['bullet1'] = "Kanban-style Task Manager";
$_LANG['store']['xoviNow']['features']['advisor']['bullet2'] = "Customized and prioritized tasks";
$_LANG['store']['xoviNow']['features']['advisor']['bullet3'] = "Detailed instructions and additional information";
$_LANG['store']['xoviNow']['features']['advisor']['bullet4'] = "No expert knowledge needed";
$_LANG['store']['xoviNow']['features']['advisor']['bullet5'] = "Updated weekly";
$_LANG['store']['xoviNow']['features']['rankTracker']['line1'] = "Monitor your rankings and those of your competitors";
$_LANG['store']['xoviNow']['features']['rankTracker']['bullet1'] = "Track essential rankings weekly or daily";
$_LANG['store']['xoviNow']['features']['rankTracker']['bullet2'] = "Local rankings for brick-and-mortar businesses";
$_LANG['store']['xoviNow']['features']['rankTracker']['bullet3'] = "International rankings for global companies";
$_LANG['store']['xoviNow']['features']['rankTracker']['bullet4'] = "Keep an eye on your competition";
$_LANG['store']['xoviNow']['features']['rankTracker']['bullet5'] = "Track keyword rankings or dedicated pages";
$_LANG['store']['xoviNow']['features']['siteAudit']['line1'] = "Check the technical foundation of your website";
$_LANG['store']['xoviNow']['features']['siteAudit']['bullet1'] = "Automated weekly site audits";
$_LANG['store']['xoviNow']['features']['siteAudit']['bullet2'] = "Technical website check";
$_LANG['store']['xoviNow']['features']['siteAudit']['bullet3'] = "Prioritized results";
$_LANG['store']['xoviNow']['features']['siteAudit']['bullet4'] = "Shows improvements";
$_LANG['store']['xoviNow']['features']['siteAudit']['bullet5'] = "Translated results to advisor tasks";
$_LANG['store']['xoviNow']['features']['textOptimizer']['line1'] = "Improve your rankings with data-driven content optimization";
$_LANG['store']['xoviNow']['features']['textOptimizer']['bullet1'] = "Compare your text to Amazon™'s and Google™'s top 10 results";
$_LANG['store']['xoviNow']['features']['textOptimizer']['bullet2'] = "Increase the content quality in a guided manner";
$_LANG['store']['xoviNow']['features']['textOptimizer']['bullet3'] = "Add, increase, or reduce keywords as instructed";
$_LANG['store']['xoviNow']['features']['benchmarking']['line1'] = "Analyse competitors, compare performance and improve your SEO";
$_LANG['store']['xoviNow']['features']['benchmarking']['bullet1'] = "Discover domains that share rankings for the same keywords";
$_LANG['store']['xoviNow']['features']['benchmarking']['bullet2'] = "Identify your niche's leader";
$_LANG['store']['xoviNow']['features']['benchmarking']['bullet3'] = "Compare keyword rankings of two or more domains";
$_LANG['store']['xoviNow']['features']['benchmarking']['bullet4'] = "Track and compare your competition's rankings for important keywords";
$_LANG['store']['xoviNow']['features']['benchmarking']['bullet5'] = "Track and compare visibility scores";
$_LANG['store']['xoviNow']['audience']['freelancersTitle'] = "Freelancers";
$_LANG['store']['xoviNow']['audience']['freelancersDesc'] = "XOVI NOW was designed to provide immediate value for your personal website or your clients’ sites, from an initial site audit through recommendations to improve your search engine results.";
$_LANG['store']['xoviNow']['audience']['smbizTitle'] = "Small and Medium-sized Businesses";
$_LANG['store']['xoviNow']['audience']['smbizDesc'] = "You don't have to be an SEO expert to improve your business's Google rankings. XOVI NOW will identify the best keywords for your business while also keeping an eye on the performance of your competitors.";
$_LANG['store']['xoviNow']['moneyBackGuarantee'] = "Flexible Pricing Options With :guaranteeStart 30 Day Money Back Guarantee :guaranteeEnd";
$_LANG['store']['xoviNow']['featurematrix']['1'] = "Projects";
$_LANG['store']['xoviNow']['featurematrix']['2'] = "Full-Access Accounts";
$_LANG['store']['xoviNow']['featurematrix']['3'] = "Read-Only Accounts";
$_LANG['store']['xoviNow']['featurematrix']['4'] = "Competitor Benchmarking";
$_LANG['store']['xoviNow']['featurematrix']['5'] = "Competitors per project";
$_LANG['store']['xoviNow']['featurematrix']['6'] = "Keyword Research";
$_LANG['store']['xoviNow']['featurematrix']['7'] = "Rank Tracker";
$_LANG['store']['xoviNow']['featurematrix']['8'] = "Keyword crawls";
$_LANG['store']['xoviNow']['featurematrix']['9'] = "Keyword check";
$_LANG['store']['xoviNow']['featurematrix']['10'] = "Site Audit";
$_LANG['store']['xoviNow']['featurematrix']['11'] = "Pages to crawl";
$_LANG['store']['xoviNow']['featurematrix']['12'] = "SEO Advisor";
$_LANG['store']['xoviNow']['featurematrix']['13'] = "SEO Text Optimizer";
$_LANG['store']['xoviNow']['faqTitle'] = "Frequently Asked Questions";
$_LANG['store']['xoviNow']['faq1'] = "What is SEO?";
$_LANG['store']['xoviNow']['faq1ans'] = "<p>SEO is an acronym for Search Engine Optimization. It is an essential online marketing strategy dedicated to driving prospective customers to your website. Its goal is to optimize a website to gain top positions for selected keywords on search engines. This goal is achieved by strategically employing measures to improve the website's technical setup and contents and obtaining backlinks from other domains.</p><p>SEO is divided into three general categories:</p><ol><li>Keywords and rankings</li><li>On-page SEO</li><li>Off-page SEO</li></ol><p>SEO specialists apply measures to meet the search engine's ranking factors for each category. Search engines use ranking factors to determine the position in which it lists a website in search results.</p>";
$_LANG['store']['xoviNow']['faq2'] = "Why Do I Need SEO?";
$_LANG['store']['xoviNow']['faq2ans'] = "<p>Every day, millions of people use search engines to find information or services from all aspects of life: Recipes, guides, products, flights, navigation, tickets, entertainment, and more. Most people navigate the web using search engines to find answers to their questions and solutions to their challenges.</p><p>A study shows that 68% of the web's traffic comes from search engines. 53% of this traffic has its origins in organic search—search results that are not ads (paid search) and can be improved through SEO.</p><img src=\":image1\"><p>In other words, organic search (SEO) and paid search (SEA, ads in search results) make up the lion's share of traffic on the web.</p><p>Even where we go offline is significantly influenced by search engines: We use Google and Apple Maps and local search results to find places and nearby services like hairdressers, supermarkets, restaurants, and doctors. We choose our destination based on online reviews. And we instruct search engine-based services to guide us there, be it by car, public transportation, or on foot.</p><p>Now, imagine if your business, products, and services are not listed in search results. Imagine people can't find you online to buy your products or find their way to your brick-and-mortar business. Instead, they will most likely choose your competition.</p>";
$_LANG['store']['xoviNow']['faq3'] = "What Can SEO Do For Me?";
$_LANG['store']['xoviNow']['faq3ans'] = "<p>With the help of SEO, users can find your business, products, and services online—and buy them. As mentioned, that means that people can find you online and much easier offline, too.</p><p>SEO maximizes your chances to be listed in top positions for keywords crucial to your business. The better your position, the more people will find their way to your website—preferably on the first page (or top ten) of search results.</p><p><strong>Why Page One?</strong></p><p>Good question. Studies have shown that 31.7% of users click on the first organic search result (position one); a whopping 75.1% of all clicks go to the top three search results. After that, the number of clicks shrinks rapidly with every following position.</p><img src=\":image2\"><p>This behavior shows that users rarely look at page two or lower results, let alone click on any of them.</p><img src=\":image3\"><p>That's why businesses need to be present on the first page of search results, at least for relevant keywords.</p><p>In short: It's crucial for freelancers and business owners to</p><ol><li>Own a website or any kind of online presence, even if they offer their products or services offline</li><li>Perform SEO to make sure they rank on page one for relevant keywords</li></ol>";
$_LANG['store']['xoviNow']['faq4'] = "Why Are Keywords Important?";
$_LANG['store']['xoviNow']['faq4ans'] = "<p><em>Keyword</em> is a technical term for search queries (words, phrases, sentences, and questions). With their help, users find content that answers their questions and provides solutions. Put simply, a keyword is the link between users and your website. Search engines compare keywords with websites, looking for content with the highest relevance.</p><p>A big part of SEO lies in identifying keywords that have the potential to drive relevant traffic to your website—in other words, bringing in prospective customers. To do that, you need to identify search terms (or keywords) people use when searching for offers like yours. This process is called keyword research. Ideally, keyword research provides you with a list of keywords covering search queries across the entire customer journey.</p>";
$_LANG['store']['xoviNow']['faq5'] = "What Is Keyword Optimization?";
$_LANG['store']['xoviNow']['faq5ans'] = "<p>So we know that relevance is a crucial factor for a top position in search results. To create relevant content, you want to deal with the topics and questions around a keyword on an individual subpage or URL. Then, make sure your keyword appears in crucial spots on your page.</p><p>Let's say you are in the ice cream business. One of your keywords is <em>s'mores ice cream sandwich</em>. Now you focus on everything that has to do with a <em>s'mores ice cream sandwich</em>.</p><p>What you want to do is create a recipe page for a <em>s'mores ice cream sandwich</em> where users find an easy-to-follow recipe, pictures or videos, and answers to questions they might have. <em>S'mores ice cream sandwich</em> is your focus keyword that should appear in your page's URL, title, headlines, and more.</p><p>Providing a dedicated and keyword-optimized page makes it easy for search engines—and users, too—to determine what your page is all about. That way, they can list it in good positions in related search results.</p>";
$_LANG['store']['xoviNow']['faq6'] = "How to use the Advisor";
$_LANG['store']['xoviNow']['faq6ans'] = "<p>First, check out the advisor's board by clicking Advisor in the top navigation bar. It is a Kanban board helping you organize your tasks by status. Your tasks are color coded by importance:</p><ul><li><strong>Red:</strong> High. Solve ASAP.</li><li><strong>Yellow:</strong> Medium. Tackle those soon.</li><li><strong>Blue:</strong> Low. Keep them in mind and solve them when you can.</li></ul><img src=\":image1\"><p>You can drag and drop as you complete tasks, assign tasks to other users (depending on your plan), and filter by the assignee.</p><p>As mentioned above, tasks are a mix of standard basic SEO measures and issues found in weekly automated audits of your website.</p>";
$_LANG['store']['xoviNow']['faq7'] = "I want an advisor for other websites. How do I get it?";
$_LANG['store']['xoviNow']['faq7ans'] = "<p>Keep in mind that you do need a <em>Project</em> for the Advisor feature to work. Also, most of the Advisor's tasks are tailored to a Project's website (usually yours or your client's). If you manage more than one website, you'll need to create an extra Project for each of them.</p><p>To add or switch to another project, click the <em>Projects</em> menu in the top navigation bar. Depending on your plan, you might need to upgrade it to add another Project.</p>";
$_LANG['store']['xoviNow']['faq8'] = "How do I assign tasks to other users?";
$_LANG['store']['xoviNow']['faq8ans'] = "<p>To assign a task to other users, you'll need a plan that allows additional users. If your plan includes additional users, you'll find the Assignee menu in your Advisor and tasks. Simply choose a user to assign a task or filter the Advisor by. To add a new user, click on your profile avatar and then click <em>Users</em>. If your plan does not include additional users, you won't see the <em>Assignee</em> menu in your Advisor or tasks. Upgrade your plan to add users.</p>";
$_LANG['store']['xoviNow']['faq9'] = "There are tasks I've already covered. Why do they pop up?";
$_LANG['store']['xoviNow']['faq9ans'] = "<p>There are two reasons why you might see tasks you've already solved or covered. As mentioned above, tasks are a mix of basic SEO measures and issues found in weekly automated audits of your website.</p><p>First, the tasks covering basic SEO measures are the same for everyone and are not tailored to your website or business. For example, we don't know whether you created a Google account for your business and set up Search Console or if you installed SEO plugins. If you already did—great work! Simply flag those tasks as Done.</p><p>The second reason is that the Advisor is automatically updated based on the results of automated weekly Site Audits. In other words, if a Site Audit identifies any issues concerning a task you completed in the past, it will automatically be updated and pop up in the Open section.</p>";
$_LANG['store']['xoviNow']['faq10'] = "What is Project Visibility?";
$_LANG['store']['xoviNow']['faq10ans'] = "<p>Maybe you already stopped to think, “Wait, but I don't care about my visibility for keywords that have nothing to do with my business.” And you are right. While Visibility is a great score to get an idea of your overall performance and compare websites in general, it's not tailored to your specific keyword set.</p><p>That's why we provide <em>Project Visibility</em>. This metric is calculated the same way as Visibility, but instead of using 500,000 cross-industry keywords, Project Visibility is exclusively based on keywords in your Rank Tracker.</p><p>In other words, Project Visibility is a custom visibility score for the unique set of keywords relevant to your business.</p><p>You'll find Project Visibility here: <em>Projects → Rank Tracker → Visibility</em>.</p><p>As you might already know, you can also track your competitors' rankings in your Rank Tracker. That way, you'll get Project Visibility for them, too, allowing for a much more realistic comparison. So, even if they have a slightly different product or service portfolio, Project Visibility accounts exclusively for keywords you actually share.</p>";
$_LANG['store']['xoviNow']['faq11'] = "Why is Visibility score useful?";
$_LANG['store']['xoviNow']['faq11ans'] = "<p>Use your Visibility score as an indicator of your overall SEO performance, problems, and potential for optimization.</p><p><strong>1. Get An Idea of Your Overall SEO Performance</strong></p><p>You can track rankings for single keywords and know which position you rank on. It's an important thing to do. However, rank tracking does not give you a bird's eye view perspective of the overall improvement of your rankings—but Visibility does. When your SEO measures are effective and rankings improve, so does your Visibility score.</p><p><strong>2. Diagnose SEO Problems</strong></p><p>A sudden drop in your Visibility indicates problems in your SEO performance. Use Visibility like an alert. If it drops significantly, start digging for what happened. Here's a list of common reasons:</p><ul><li>You were hit with a <strong>Google Penalty</strong>. Check Search Console for notifications. Make sure to follow <a href=\":googleWebmasterGuidelinesUrl\" target=\"_blank\">Google's Webmaster Guidelines</a>.</li><li>There are ramifications from a recent change in Google's algorithm. Inquire about recent <strong>Google Updates</strong> and what they entail.</li><li>Your competitors optimized their websites and content, and now they out-compete you. Compare their (historical) <strong>Visibility</strong> with yours. Use the <a href=\":waybackMachineUrl\" target=\"_blank\">Wayback Machine</a> to compare how their content changed.</li><li>You relaunched your site without SEO in mind. For example, check <em>robots.txt</em> and <em>.htaccess</em> for accidentally blocked pages, increased 404 status codes, faulty 301-redirects, and internal links.<br><br>You changed your content in a way that didn't help your rankings. Consider reversing the changes.<br><br>Your website has technical issues. Run a <em>Site Audit</em> or check your <strong><em>Advisor</em></strong> for open technical tasks. Check your backend for outdated, recently updated, or incompatible <strong>plugins</strong> that may cause havoc.<br><br>Hosting issues are the cause. Inquire whether your host made recent changes, has been hacked, moved their servers, or experienced technical difficulties. See if your server has issues.</li></ul><p>Keep in mind that this list is not exhaustive. One or more of those reasons can apply simultaneously, or there could be other reasons altogether.</p><p><strong>3. Competitor Comparison</strong></p><p>Visibility is a great metric for a quick comparison of two or more websites. Check your Visibility against theirs. Who is out-competing who? Has a competitor outperformed you in the past or vice versa? Who's leading the field, and how big is the gap between you and your fiercest competitor? Answering those questions will help you develop an SEO strategy to come out (and stay) at the top of your niche.</p><p><strong>4. Track Visibility Development Over Time With Historical Data</strong></p><p>Want to know how a website fared over time? We provide historical data going all the way back to 2009, free of seasonal fluctuations. That way, you can track and compare historic Visibility and see their development over long periods of time.</p>";
$_LANG['store']['xoviNow']['faq12'] = "How Can I Improve My Visibility Score?";
$_LANG['store']['xoviNow']['faq12ans'] = "<p>Short answer: Don't make improving Visibility a goal in your SEO strategy.</p><p>Long answer: Visibility <em>reflects</em> the quality of your rankings in a single metric; it won't lead to better rankings. Make it your goal to improve your rankings for relevant keywords that prospective customers actually use to find products and services like yours. Improving your rankings will improve your Visibility, too. But it's your rankings that really matter.</p><p>As a rule of thumb, your Visibility score will be higher if</p><ul><li>Your domain's URLs rank in good positions</li><li>You have a high number of indexed URLs with good rankings</li><li>You rank well for keywords with a high search volume</li></ul>";
$_LANG['store']['xoviNow']['promo']['sidebar']['title'] = "SEO Tools";
$_LANG['store']['xoviNow']['promo']['sidebar']['body'] = "Improve your site performance with accurate, reliable, and easy-to-use site rankings, keywords, and an advisor.";
$_LANG['store']['xoviNow']['cartTitle'] = "SEO Tools";
$_LANG['store']['xoviNow']['cartShortDescription'] = "Improve your site performance with accurate, reliable, and easy-to-use site rankings, keywords, and an advisor.";

$_LANG['ssl']['status']['awaitingConfiguration'] = "Awaiting Configuration";
$_LANG['ssl']['status']['awaitingIssuance'] = "Awaiting Issuance";
$_LANG['ssl']['status']['cancelled'] = "Cancelled";
$_LANG['ssl']['status']['completed'] = "Completed";
$_LANG['ssl']['status']['configurationSubmitted'] = "Configuration Submitted";
$_LANG['ssl']['status']['expired'] = "Expired";
$_LANG['ssl']['status']['reissueFailed'] = "Reissue Failed";
$_LANG['ssl']['status']['reissuePending'] = "Reissue Pending";
$_LANG['ssl']['status']['reissued'] = "Reissued";
$_LANG['ssl']['x500DN']['organization'] = "Organization";
$_LANG['ssl']['x500DN']['organizationUnit'] = "Organization Unit";
$_LANG['ssl']['x500DN']['locality'] = "Locality";
$_LANG['ssl']['x500DN']['country'] = "Country";
$_LANG['ssl']['x500DN']['state'] = "State";
$_LANG['ssl']['x500DN']['commonName'] = "Common Name";
$_LANG['ssl']['x500DN']['domainName'] = "Domain Name";

$_LANG['sitejetBuilder']['dashboardPanelTitle'] = "Sitejet Builder";
$_LANG['sitejetBuilder']['editWebsite'] = "Edit Website";
$_LANG['sitejetBuilder']['chooseWebsite'] = "Choose a website to manage:";
$_LANG['sitejetBuilder']['servicePage']['menuEdit'] = "Edit with Sitejet Builder";
$_LANG['sitejetBuilder']['servicePage']['visitSite'] = "Visit";
$_LANG['sitejetBuilder']['servicePage']['editSite'] = "Edit with Sitejet Builder";
$_LANG['sitejetBuilder']['servicePage']['panelTitle'] = "Sitejet Builder";
$_LANG['sitejetBuilder']['servicePage']['publishProgress'] = "Publishing in progress...";
$_LANG['sitejetBuilder']['servicePage']['publishSuccess'] = "Success! Your website is published.";
$_LANG['sitejetBuilder']['get']['title'] = "Get Sitejet Builder";
$_LANG['sitejetBuilder']['upgradeTo']['title'] = "Upgrade to Sitejet Builder";
$_LANG['sitejetBuilder']['upsellDescription'] = "A powerful drag-and-drop website builder that helps you build and publish your website.";
$_LANG['activateNowFor'] = "Activate Now for :price";
$_LANG['upgradeToFor'] = "Upgrade to :package for :price";

////////// End of farsi language file.  Do not place any translation strings below this line!
